@@ -35,9 +35,8 @@ my $oRenderTag =
         'b' => ['**', '**'],
         'i' => ['_', '_'],
         # 'bi' => ['_**', '**_'],
-        'ul' => ["\n", ""],
-        'ol' => ["\n", "\n"],
-        'li' => ['- ', "\n"],
+        'list-item' => ["\n", ""],
+        'list-item' => ['- ', "\n"],
         'id' => ['`', '`'],
         'file' => ['`', '`'],
         'path' => ['`', '`'],
@@ -57,12 +56,12 @@ my $oRenderTag =
     'text' =>
     {
         'quote' => ['"', '"'],
+        'p' => ['', "\n\n"],
         'b' => ['', ''],
         'i' => ['', ''],
         # 'bi' => ['', ''],
-        'ul' => ["\n", "\n"],
-        'ol' => ["\n", "\n"],
-        'li' => ['* ', "\n"],
+        'list' => ["", "\n"],
+        'list-item' => ['* ', "\n"],
         'id' => ['', ''],
         'host' => ['', ''],
         'file' => ['', ''],
@@ -78,18 +77,18 @@ my $oRenderTag =
         'backrest' => [undef, ''],
         'proper' => ['', ''],
         'postgres' => ['PostgreSQL', ''],
-        'admonition' => ["\n", "\n\n"],
+        'admonition' => ['', "\n\n"],
     },
 
     'latex' =>
     {
         'quote' => ['``', '"'],
+        'p' => ["\n\\begin{sloppypar}", "\\end{sloppypar}\n"],
         'b' => ['\textbf{', '}'],
         'i' => ['\textit{', '}'],
         # 'bi' => ['', ''],
-        'ul' => ["\\begin{itemize}\n", "\\end{itemize}\n"],
-        # 'ol' => ["\n", "\n"],
-        'li' => ['\item ', "\n"],
+        'list' => ["\\begin{itemize}\n", "\\end{itemize}\n"],
+        'list-item' => ['\item ', "\n"],
         'id' => ['\textnormal{\texttt{', '}}'],
         'host' => ['\textnormal{\textbf{', '}}'],
         'file' => ['\textnormal{\texttt{', '}}'],
@@ -119,10 +118,10 @@ my $oRenderTag =
         'quote' => ['<q>', '</q>'],
         'b' => ['<b>', '</b>'],
         'i' => ['<i>', '</i>'],
+        'p' => ['', ''],
         # 'bi' => ['<i><b>', '</b></i>'],
-        'ul' => ['<ul>', '</ul>'],
-        'ol' => ['<ol>', '</ol>'],
-        'li' => ['<li>', '</li>'],
+        'list' => ['<ul class="list-unordered">', '</ul>'],
+        'list-item' => ['<li class="list-unordered">', '</li>'],
         'id' => ['<span class="id">', '</span>'],
         'host' => ['<span class="host">', '</span>'],
         'file' => ['<span class="file">', '</span>'],
@@ -194,14 +193,14 @@ sub new
         my $oRenderOut =
             $self->{oManifest}->renderOutGet($self->{strType} eq 'latex' ? 'pdf' : $self->{strType}, $self->{strRenderOutKey});
 
-        # If these are the backrest docs then load the reference
+        # If these are the backrest docs then load the help
         if ($self->{oManifest}->isBackRest())
         {
             $self->{oReference} =
-                new pgBackRestDoc::Common::DocConfig(${$self->{oManifest}->sourceGet('reference')}{doc}, $self);
+                new pgBackRestDoc::Common::DocConfig(${$self->{oManifest}->sourceGet('help')}{doc}, $self);
         }
 
-        if (defined($$oRenderOut{source}) && $$oRenderOut{source} eq 'reference' && $self->{oManifest}->isBackRest())
+        if (defined($$oRenderOut{source}) && $$oRenderOut{source} eq 'help' && $self->{oManifest}->isBackRest())
         {
             if ($self->{strRenderOutKey} eq 'configuration')
             {
@@ -844,14 +843,14 @@ sub processTag
 
         $strBuffer .= $strStart;
 
-        # Admonitions in the reference materials are tags of the text element rather than field elements of the document so special
+        # Admonitions in the help materials are tags of the text element rather than field elements of the document so special
         # handling is required
         if ($strTag eq 'admonition')
         {
             $strBuffer .= $self->processAdmonitionStart($oTag);
         }
 
-        if ($strTag eq 'p' || $strTag eq 'title' || $strTag eq 'li' || $strTag eq 'code-block' || $strTag eq 'summary'
+        if ($strTag eq 'p' || $strTag eq 'title' || $strTag eq 'list-item' || $strTag eq 'code-block' || $strTag eq 'summary'
             || $strTag eq 'admonition')
         {
             $strBuffer .= $self->processText($oTag);
@@ -987,6 +986,7 @@ sub processText
 
     my $strType = $self->{strType};
     my $strBuffer = '';
+    my $strLastTag = 'body';
 
     foreach my $oNode ($oText->nodeList(undef, false))
     {
@@ -997,11 +997,30 @@ sub processText
                 confess &log(ERROR, "unable to process quotes in string (use <quote> instead):\n${oNode}");
             }
 
-            $strBuffer .= $oNode;
+            # Skip text nodes with linefeeds since they happen between tags
+            if (index($oNode, "\n") == -1)
+            {
+                $strBuffer .= $oNode;
+            }
         }
         else
         {
+            # Add br tags to separate paragraphs and linefeeds to make the output more diffable. This is needed because of the hacky
+            # way config text is being rendered in the final document, i.e. by passing rendered HTML into divs rather than XML to be
+            # rendered at that time.
+            if ($strLastTag eq 'p' && $strType eq 'html')
+            {
+                $strBuffer .= "<br/>\n";
+
+                if ($oNode->nameGet() eq 'p')
+                {
+                    $strBuffer .= "<br/>\n";
+                }
+            }
+
             $strBuffer .= $self->processTag($oNode);
+
+            $strLastTag = $oNode->nameGet();
         }
     }
     #
@@ -1056,6 +1075,11 @@ sub processText
         }
     }
 
+    if ($strType eq 'html')
+    {
+        $strBuffer =~ s/ma[s]ter/ma&#115;ter/g;
+    }
+
     if ($strType eq 'text')
     {
         $strBuffer =~ s/\&mdash\;/--/g;
