@@ -35,7 +35,7 @@ use constant CFGCMD_VERSION                                         => 'version'
 
 ####################################################################################################################################
 # Command role constants - roles allowed for each command. Commands may have multiple processes that work together to implement
-# their functionality. These roles allow each process to know what it is supposed to do.
+# their functionality.  These roles allow each process to know what it is supposed to do.
 ####################################################################################################################################
 # Called directly by the user. This is the main process of the command that may or may not spawn other command roles.
 use constant CFGCMD_ROLE_MAIN                                       => 'main';
@@ -147,8 +147,6 @@ use constant CFGDEF_DEFAULT_LITERAL                                 => 'default-
 use constant CFGDEF_GROUP                                           => 'group';
     push @EXPORT, qw(CFGDEF_GROUP);
 
-use constant CFGDEF_BETA                                            => 'beta';
-    push @EXPORT, qw(CFGDEF_BETA);
 use constant CFGDEF_INDEX                                           => 'index';
     push @EXPORT, qw(CFGDEF_INDEX);
 use constant CFGDEF_INHERIT                                         => 'inherit';
@@ -400,7 +398,7 @@ foreach my $strKey (sort(keys(%{$rhConfigDefine})))
         $rhConfigDefine->{$strKey}{&CFGDEF_INTERNAL} = false;
     }
 
-    # All boolean config options can be negated. Boolean command-line options must be marked for negation individually.
+    # All boolean config options can be negated.  Boolean command-line options must be marked for negation individually.
     if ($rhConfigDefine->{$strKey}{&CFGDEF_TYPE} eq CFGDEF_TYPE_BOOLEAN && defined($rhConfigDefine->{$strKey}{&CFGDEF_SECTION}))
     {
         $rhConfigDefine->{$strKey}{&CFGDEF_NEGATE} = true;
@@ -428,8 +426,9 @@ foreach my $strKey (sort(keys(%{$rhConfigDefine})))
         $rhConfigDefine->{$strKey}{&CFGDEF_SECURE} = false;
     }
 
-    # All size and time options must have an allow range
-    if (($rhConfigDefine->{$strKey}{&CFGDEF_TYPE} eq CFGDEF_TYPE_TIME ||
+    # All int, size and time options must have an allow range
+    if (($rhConfigDefine->{$strKey}{&CFGDEF_TYPE} eq CFGDEF_TYPE_INTEGER ||
+         $rhConfigDefine->{$strKey}{&CFGDEF_TYPE} eq CFGDEF_TYPE_TIME ||
          $rhConfigDefine->{$strKey}{&CFGDEF_TYPE} eq CFGDEF_TYPE_SIZE) &&
          !(defined($rhConfigDefine->{$strKey}{&CFGDEF_ALLOW_RANGE}) || defined($rhConfigDefine->{$strKey}{&CFGDEF_ALLOW_LIST})))
     {
