@@ -23,19 +23,14 @@ push @EXPORT, qw(PROJECT_CONF);
 
 # Project Version Number
 #
-# Defines the current version of the BackRest executable. The version number is used to track features but does not affect what
+# Defines the current version of the BackRest executable.  The version number is used to track features but does not affect what
 # repositories or manifests can be read - that's the job of the format number.
 #-----------------------------------------------------------------------------------------------------------------------------------
-push @EXPORT, qw(PROJECT_VERSION_MAJOR);
-push @EXPORT, qw(PROJECT_VERSION_MINOR);
-push @EXPORT, qw(PROJECT_VERSION_PATCH);
-push @EXPORT, qw(PROJECT_VERSION_SUFFIX);
-
 push @EXPORT, qw(PROJECT_VERSION);
 
 # Repository Format Number
 #
-# Defines format for info and manifest files as well as on-disk structure. If this number changes then the repository will be
+# Defines format for info and manifest files as well as on-disk structure.  If this number changes then the repository will be
 # invalid unless migration functions are written.
 #-----------------------------------------------------------------------------------------------------------------------------------
 push @EXPORT, qw(REPOSITORY_FORMAT);
@@ -51,6 +46,7 @@ my $strProjectInfo = ${new pgBackRestTest::Common::Storage(
 
 foreach my $strLine (split("\n", $strProjectInfo))
 {
+
     if ($strLine =~ /^#define PROJECT_NAME/)
     {
         eval("use constant PROJECT_NAME => " . (split(" ", $strLine))[-1]);
@@ -60,21 +56,9 @@ foreach my $strLine (split("\n", $strProjectInfo))
         eval("use constant PROJECT_EXE => " . (split(" ", $strLine))[-1]);
         eval("use constant PROJECT_CONF => " . (split(" ", $strLine))[-1] . " . \'.conf\'");
     }
-    elsif ($strLine =~ /^#define PROJECT_VERSION_MAJOR/)
+    elsif ($strLine =~ /^#define PROJECT_VERSION/)
     {
-        eval("use constant PROJECT_VERSION_MAJOR => \"" . (split(" ", $strLine))[-1] . "\"");
-    }
-    elsif ($strLine =~ /^#define PROJECT_VERSION_MINOR/)
-    {
-        eval("use constant PROJECT_VERSION_MINOR => " . (split(" ", $strLine))[-1]);
-    }
-    elsif ($strLine =~ /^#define PROJECT_VERSION_PATCH/)
-    {
-        eval("use constant PROJECT_VERSION_PATCH => " . (split(" ", $strLine))[-1]);
-    }
-    elsif ($strLine =~ /^#define PROJECT_VERSION_SUFFIX/)
-    {
-        eval("use constant PROJECT_VERSION_SUFFIX => " . (split(" ", $strLine))[-1]);
+        eval("use constant PROJECT_VERSION => " . (split(" ", $strLine))[-1]);
     }
     elsif ($strLine =~ /^#define REPOSITORY_FORMAT/)
     {
@@ -82,8 +66,4 @@ foreach my $strLine (split("\n", $strProjectInfo))
     }
 }
 
-eval(
-    'use constant PROJECT_VERSION => "' . PROJECT_VERSION_MAJOR() . '.' . PROJECT_VERSION_MINOR() . '.' . PROJECT_VERSION_PATCH() .
-    PROJECT_VERSION_SUFFIX() . '"');
-
 1;
