@@ -17,6 +17,7 @@ Archive Common
 #include "common/regExp.h"
 #include "common/wait.h"
 #include "config/config.h"
+#include "postgres/interface.h"
 #include "postgres/version.h"
 #include "storage/helper.h"
 #include "storage/helper.h"
@@ -46,7 +47,7 @@ static const String *
 archiveAsyncSpoolQueue(ArchiveMode archiveMode)
 {
     FUNCTION_TEST_BEGIN();
-        FUNCTION_TEST_PARAM(ENUM, archiveMode);
+        FUNCTION_TEST_PARAM(STRING_ID, archiveMode);
     FUNCTION_TEST_END();
 
     FUNCTION_TEST_RETURN((archiveMode == archiveModeGet ? STORAGE_SPOOL_ARCHIVE_IN_STR : STORAGE_SPOOL_ARCHIVE_OUT_STR));
@@ -57,7 +58,7 @@ void
 archiveAsyncErrorClear(ArchiveMode archiveMode, const String *archiveFile)
 {
     FUNCTION_LOG_BEGIN(logLevelDebug);
-        FUNCTION_LOG_PARAM(ENUM, archiveMode);
+        FUNCTION_LOG_PARAM(STRING_ID, archiveMode);
         FUNCTION_LOG_PARAM(STRING, archiveFile);
     FUNCTION_LOG_END();
 
@@ -71,12 +72,13 @@ archiveAsyncErrorClear(ArchiveMode archiveMode, const String *archiveFile)
 
 /**********************************************************************************************************************************/
 bool
-archiveAsyncStatus(ArchiveMode archiveMode, const String *walSegment, bool throwOnError)
+archiveAsyncStatus(ArchiveMode archiveMode, const String *walSegment, bool throwOnError, bool warnOnOk)
 {
     FUNCTION_LOG_BEGIN(logLevelDebug);
-        FUNCTION_LOG_PARAM(ENUM, archiveMode);
+        FUNCTION_LOG_PARAM(STRING_ID, archiveMode);
         FUNCTION_LOG_PARAM(STRING, walSegment);
         FUNCTION_LOG_PARAM(BOOL, throwOnError);
+        FUNCTION_LOG_PARAM(BOOL, warnOnOk);
     FUNCTION_LOG_END();
 
     ASSERT(walSegment != NULL);
@@ -135,15 +137,15 @@ archiveAsyncStatus(ArchiveMode archiveMode, const String *walSegment, bool throw
                     THROW_FMT(FormatError, "%s message must be > 0", strZ(statusFile));
 
                 // Get contents
-                code = varIntForce(VARSTR(strNewN(strZ(content), (size_t)(linefeedPtr - strZ(content)))));
-                message = strTrim(strNew(linefeedPtr + 1));
+                code = varIntForce(VARSTR(strNewZN(strZ(content), (size_t)(linefeedPtr - strZ(content)))));
+                message = strTrim(strNewZ(linefeedPtr + 1));
             }
 
             // Process OK files
             if (okFileExists)
             {
                 // If there is content in the status file it is a warning
-                if (strSize(content) != 0)
+                if (strSize(content) != 0 && warnOnOk)
                 {
                     // If error code is not success, then this was a renamed error file
                     if (code != 0)
@@ -179,7 +181,7 @@ void
 archiveAsyncStatusErrorWrite(ArchiveMode archiveMode, const String *walSegment, int code, const String *message)
 {
     FUNCTION_LOG_BEGIN(logLevelDebug);
-        FUNCTION_LOG_PARAM(ENUM, archiveMode);
+        FUNCTION_LOG_PARAM(STRING_ID, archiveMode);
         FUNCTION_LOG_PARAM(STRING, walSegment);
         FUNCTION_LOG_PARAM(INT, code);
         FUNCTION_LOG_PARAM(STRING, message);
@@ -208,7 +210,7 @@ void
 archiveAsyncStatusOkWrite(ArchiveMode archiveMode, const String *walSegment, const String *warning)
 {
     FUNCTION_LOG_BEGIN(logLevelDebug);
-        FUNCTION_LOG_PARAM(ENUM, archiveMode);
+        FUNCTION_LOG_PARAM(STRING_ID, archiveMode);
         FUNCTION_LOG_PARAM(STRING, walSegment);
         FUNCTION_LOG_PARAM(STRING, warning);
     FUNCTION_LOG_END();
@@ -233,7 +235,7 @@ void
 archiveAsyncExec(ArchiveMode archiveMode, const StringList *commandExec)
 {
     FUNCTION_LOG_BEGIN(logLevelDebug);
-        FUNCTION_LOG_PARAM(ENUM, archiveMode);
+        FUNCTION_LOG_PARAM(STRING_ID, archiveMode);
         FUNCTION_LOG_PARAM(STRING_LIST, commandExec);
     FUNCTION_LOG_END();
 
@@ -273,7 +275,7 @@ archiveAsyncExec(ArchiveMode archiveMode, const StringList *commandExec)
     THROW_ON_SYS_ERROR(waitpid(pid, &processStatus, 0) == -1, ExecuteError, "unable to wait for forked process");
 
     // The first fork should exit with success.  If not, something went wrong during the second fork.
-    CHECK(WIFEXITED(processStatus) && WEXITSTATUS(processStatus) == 0);
+    CHECK(ExecuteError, WIFEXITED(processStatus) && WEXITSTATUS(processStatus) == 0, "error on first fork");
 
 #ifdef DEBUG_EXEC_TIME
     // If the process does not exit immediately then something probably went wrong with the double fork.  It's possible that this
@@ -491,7 +493,7 @@ walSegmentNext(const String *walSegment, size_t walSegmentSize, unsigned int pgV
 
     MEM_CONTEXT_TEMP_BEGIN()
     {
-        timeline = (uint32_t)strtol(strZ(strSubN(walSegment, 0, 8)), NULL, 16);
+        timeline = pgTimelineFromWalSegment(walSegment);
         major = (uint32_t)strtol(strZ(strSubN(walSegment, 8, 8)), NULL, 16);
         minor = (uint32_t)strtol(strZ(strSubN(walSegment, 16, 8)), NULL, 16);
 
