@@ -123,7 +123,7 @@ archiveGetFind(
         const String *path = isSegment ? strSubN(archiveFileRequest, 0, 16) : NULL;
 
         // List to hold matches for the requested file
-        List *matchList = lstNewP(sizeof(ArchiveGetFile));
+        List *matchList = lstNewP(sizeof(ArchiveGetFile), .comparator = lstComparatorStr);
 
         // List of file level warnings
         StringList *fileWarnList = strLstDup(warnList);
@@ -260,7 +260,7 @@ archiveGetFind(
             {
                 getCheckResult->errorType = &RepoInvalidError;
                 getCheckResult->errorFile = strDup(archiveFileRequest);
-                getCheckResult->errorMessage = strNew(UNABLE_TO_FIND_VALID_REPO_MSG);
+                getCheckResult->errorMessage = strNewZ(UNABLE_TO_FIND_VALID_REPO_MSG);
                 getCheckResult->warnList = strLstMove(fileWarnList, memContextCurrent());
             }
             MEM_CONTEXT_END();
@@ -285,9 +285,12 @@ archiveGetFind(
                 {
                     // Build list of duplicates
                     unsigned int repoKeyLast = 0;
-                    String *message = strNew("");
+                    String *message = strNew();
                     bool first = true;
 
+                    // Sort the matches so they are logged in a consistent order
+                    lstSort(matchList, sortOrderAsc);
+
                     for (unsigned int matchIdx = 0; matchIdx < lstSize(matchList); matchIdx++)
                     {
                         ArchiveGetFile *file = lstGet(matchList, matchIdx);
@@ -390,7 +393,7 @@ archiveGetCheck(const StringList *archiveRequestList)
                 ArchiveGetFindCacheRepo cacheRepo =
                 {
                     .repoIdx = repoIdx,
-                    .cipherType = cipherType(cfgOptionIdxStr(cfgOptRepoCipherType, repoIdx)),
+                    .cipherType = cfgOptionIdxStrId(cfgOptRepoCipherType, repoIdx),
                     .archiveList = lstNewP(sizeof(ArchiveGetFindCacheArchive)),
                     .warnList = strLstNew(),
                 };
@@ -481,7 +484,7 @@ archiveGetCheck(const StringList *archiveRequestList)
             MEM_CONTEXT_BEGIN(lstMemContext(result.archiveFileMapList))
             {
                 result.errorType = &RepoInvalidError;
-                result.errorMessage = strNew(UNABLE_TO_FIND_VALID_REPO_MSG);
+                result.errorMessage = strNewZ(UNABLE_TO_FIND_VALID_REPO_MSG);
                 result.warnList = strLstMove(warnList, memContextCurrent());
             }
             MEM_CONTEXT_END();
@@ -626,15 +629,16 @@ cmdArchiveGet(void)
 
         // Destination is wherever we were told to move the WAL segment
         const String *walDestination =
-            walPath(strLstGet(commandParam, 1), cfgOptionStr(cfgOptPgPath), STR(cfgCommandName(cfgCommand())));
+            walPath(strLstGet(commandParam, 1), cfgOptionStr(cfgOptPgPath), STR(cfgCommandName()));
 
         // Async get can only be performed on WAL segments, history or other files must use synchronous mode
         if (cfgOptionBool(cfgOptArchiveAsync) && walIsSegment(walSegment))
         {
+            bool first = true;                                          // Is this the first time the loop has run?
             bool found = false;                                         // Has the WAL segment been found yet?
+            bool foundOk = false;                                       // Was an OK file found which confirms the file was missing?
             bool queueFull = false;                                     // Is the queue half or more full?
             bool forked = false;                                        // Has the async process been forked yet?
-            bool throwOnError = false;                                  // Should we throw errors?
 
             // Loop and wait for the WAL segment to be pushed
             Wait *wait = waitNew(cfgOptionUInt64(cfgOptArchiveTimeout));
@@ -645,15 +649,25 @@ cmdArchiveGet(void)
                 found = storageExistsP(storageSpool(), strNewFmt(STORAGE_SPOOL_ARCHIVE_IN "/%s", strZ(walSegment)));
 
                 // Check for errors or missing files. For archive-get ok indicates that the process succeeded but there is no WAL
-                // file to download, or that there was a warning.
-                if (archiveAsyncStatus(archiveModeGet, walSegment, throwOnError))
+                // file to download, or that there was a warning. Do not error on the first run so the async process can be spawned
+                // to correct any errors from a previous run. Do not warn on the first run if the segment was not found so the async
+                // process can be spawned to check for the file again.
+                if (archiveAsyncStatus(archiveModeGet, walSegment, !first, found || !first))
                 {
                     storageRemoveP(
                         storageSpoolWrite(), strNewFmt(STORAGE_SPOOL_ARCHIVE_IN "/%s" STATUS_EXT_OK, strZ(walSegment)),
                         .errorOnMissing = true);
 
-                    if (!found)
+                    // Break if an ok file was found but no segment exists, which means the segment was missing. However, don't
+                    // break if this is the first time through the loop since this means the ok file was written by an async process
+                    // spawned by a prior archive-get execution, which means we should spawn the async process again to see if the
+                    // file exists now. This also prevents spool files from a previous recovery interfering with the current
+                    // recovery.
+                    if (!found && !first)
+                    {
+                        foundOk = true;
                         break;
+                    }
                 }
 
                 // If found then move the WAL segment to the destination directory
@@ -712,8 +726,8 @@ cmdArchiveGet(void)
                     // The async process should not output on the console at all
                     KeyValue *optionReplace = kvNew();
 
-                    kvPut(optionReplace, VARSTR(CFGOPT_LOG_LEVEL_CONSOLE_STR), VARSTRDEF("off"));
-                    kvPut(optionReplace, VARSTR(CFGOPT_LOG_LEVEL_STDERR_STR), VARSTRDEF("off"));
+                    kvPut(optionReplace, VARSTRDEF(CFGOPT_LOG_LEVEL_CONSOLE), VARSTRDEF("off"));
+                    kvPut(optionReplace, VARSTRDEF(CFGOPT_LOG_LEVEL_STDERR), VARSTRDEF("off"));
 
                     // Generate command options
                     StringList *commandExec = cfgExecParam(cfgCmdArchiveGet, cfgCmdRoleAsync, optionReplace, true, false);
@@ -746,14 +760,26 @@ cmdArchiveGet(void)
                 if (found)
                     break;
 
-                // Now that the async process has been launched, throw any errors that are found
-                throwOnError = true;
+                // No longer the first run, so errors will be thrown and missing files will be reported
+                first = false;
             }
             while (waitMore(wait));
 
-            // Log that the file was not found
-            if (result == 1)
-                LOG_INFO_FMT(UNABLE_TO_FIND_IN_ARCHIVE_MSG " asynchronously", strZ(walSegment));
+            // If the WAL segment was not found
+            if (!found)
+            {
+                // If no ok file was found then something may be wrong with the async process. It's better to throw an error here
+                // than report not found for debugging purposes. Either way PostgreSQL will halt if it has not reached consistency.
+                if (!foundOk)
+                {
+                    THROW_FMT(
+                        ArchiveTimeoutError, "unable to get WAL file '%s' from the archive asynchronously after %s second(s)",
+                        strZ(walSegment), strZ(strNewDbl((double)cfgOptionInt64(cfgOptArchiveTimeout) / MSEC_PER_SEC)));
+                }
+                // Else report that the WAL segment could not be found
+                else
+                    LOG_INFO_FMT(UNABLE_TO_FIND_IN_ARCHIVE_MSG " asynchronously", strZ(walSegment));
+            }
         }
         // Else perform synchronous get
         else
@@ -817,36 +843,48 @@ static ProtocolParallelJob *archiveGetAsyncCallback(void *data, unsigned int cli
         FUNCTION_TEST_PARAM(UINT, clientIdx);
     FUNCTION_TEST_END();
 
-    // No special logic based on the client, we'll just get the next job
-    (void)clientIdx;
+    ProtocolParallelJob *result = NULL;
 
-    // Get a new job if there are any left
-    ArchiveGetAsyncData *jobData = data;
-
-    if (jobData->archiveFileIdx < lstSize(jobData->archiveFileMapList))
+    MEM_CONTEXT_TEMP_BEGIN()
     {
-        const ArchiveFileMap *archiveFileMap = lstGet(jobData->archiveFileMapList, jobData->archiveFileIdx);
-        jobData->archiveFileIdx++;
+        // No special logic based on the client, we'll just get the next job
+        (void)clientIdx;
 
-        ProtocolCommand *command = protocolCommandNew(PROTOCOL_COMMAND_ARCHIVE_GET_FILE_STR);
-        protocolCommandParamAdd(command, VARSTR(archiveFileMap->request));
+        // Get a new job if there are any left
+        ArchiveGetAsyncData *jobData = data;
 
-        // Add actual files to get
-        for (unsigned int actualIdx = 0; actualIdx < lstSize(archiveFileMap->actualList); actualIdx++)
+        if (jobData->archiveFileIdx < lstSize(jobData->archiveFileMapList))
         {
-            const ArchiveGetFile *actual = lstGet(archiveFileMap->actualList, actualIdx);
+            const ArchiveFileMap *archiveFileMap = lstGet(jobData->archiveFileMapList, jobData->archiveFileIdx);
+            jobData->archiveFileIdx++;
 
-            protocolCommandParamAdd(command, VARSTR(actual->file));
-            protocolCommandParamAdd(command, VARUINT(actual->repoIdx));
-            protocolCommandParamAdd(command, VARSTR(actual->archiveId));
-            protocolCommandParamAdd(command, VARUINT(actual->cipherType));
-            protocolCommandParamAdd(command, VARSTR(actual->cipherPassArchive));
+            ProtocolCommand *const command = protocolCommandNew(PROTOCOL_COMMAND_ARCHIVE_GET_FILE);
+            PackWrite *const param = protocolCommandParam(command);
+
+            pckWriteStrP(param, archiveFileMap->request);
+
+            // Add actual files to get
+            for (unsigned int actualIdx = 0; actualIdx < lstSize(archiveFileMap->actualList); actualIdx++)
+            {
+                const ArchiveGetFile *const actual = lstGet(archiveFileMap->actualList, actualIdx);
+
+                pckWriteStrP(param, actual->file);
+                pckWriteU32P(param, actual->repoIdx);
+                pckWriteStrP(param, actual->archiveId);
+                pckWriteU64P(param, actual->cipherType);
+                pckWriteStrP(param, actual->cipherPassArchive);
+            }
+
+            MEM_CONTEXT_PRIOR_BEGIN()
+            {
+                result = protocolParallelJobNew(VARSTR(archiveFileMap->request), command);
+            }
+            MEM_CONTEXT_PRIOR_END();
         }
-
-        FUNCTION_TEST_RETURN(protocolParallelJobNew(VARSTR(archiveFileMap->request), command));
     }
+    MEM_CONTEXT_TEMP_END();
 
-    FUNCTION_TEST_RETURN(NULL);
+    FUNCTION_TEST_RETURN(result);
 }
 
 void
@@ -893,79 +931,90 @@ cmdArchiveGetAsync(void)
                     protocolParallelClientAdd(parallelExec, protocolLocalGet(protocolStorageTypeRepo, 0, processIdx));
 
                 // Process jobs
-                do
+                MEM_CONTEXT_TEMP_RESET_BEGIN()
                 {
-                    unsigned int completed = protocolParallelProcess(parallelExec);
-
-                    for (unsigned int jobIdx = 0; jobIdx < completed; jobIdx++)
+                    do
                     {
-                        // Get the job
-                        ProtocolParallelJob *job = protocolParallelResult(parallelExec);
-                        unsigned int processId = protocolParallelJobProcessId(job);
+                        unsigned int completed = protocolParallelProcess(parallelExec);
 
-                        // Get wal segment name and archive file map
-                        const String *walSegment = varStr(protocolParallelJobKey(job));
-                        const ArchiveFileMap *fileMap = lstFind(checkResult.archiveFileMapList, &walSegment);
-                        ASSERT(fileMap != NULL);
-
-                        // Build warnings for status file
-                        String *warning = strNew("");
-
-                        if (!strLstEmpty(fileMap->warnList))
-                            strCatFmt(warning, "%s", strZ(strLstJoin(fileMap->warnList, "\n")));
-
-                        // The job was successful
-                        if (protocolParallelJobErrorCode(job) == 0)
+                        for (unsigned int jobIdx = 0; jobIdx < completed; jobIdx++)
                         {
-                            // Get the actual file retrieved
-                            const VariantList *fileResult = varVarLst(protocolParallelJobResult(job));
-                            ArchiveGetFile *file = lstGet(fileMap->actualList, varUIntForce(varLstGet(fileResult, 0)));
-                            ASSERT(file != NULL);
+                            // Get the job
+                            ProtocolParallelJob *job = protocolParallelResult(parallelExec);
+                            unsigned int processId = protocolParallelJobProcessId(job);
 
-                            // Output file warnings
-                            StringList *fileWarnList = strLstNewVarLst(varVarLst(varLstGet(fileResult, 1)));
+                            // Get wal segment name and archive file map
+                            const String *walSegment = varStr(protocolParallelJobKey(job));
+                            const ArchiveFileMap *fileMap = lstFind(checkResult.archiveFileMapList, &walSegment);
+                            ASSERT(fileMap != NULL);
 
-                            for (unsigned int warnIdx = 0; warnIdx < strLstSize(fileWarnList); warnIdx++)
-                                LOG_WARN_PID(processId, strZ(strLstGet(fileWarnList, warnIdx)));
+                            // Build warnings for status file
+                            String *warning = strNew();
 
-                            // Build file warnings for status file
-                            if (!strLstEmpty(fileWarnList))
-                                strCatFmt(warning, "%s%s", strSize(warning) == 0 ? "" : "\n", strZ(strLstJoin(fileWarnList, "\n")));
+                            if (!strLstEmpty(fileMap->warnList))
+                                strCatFmt(warning, "%s", strZ(strLstJoin(fileMap->warnList, "\n")));
 
-                            if (strSize(warning) != 0)
-                                archiveAsyncStatusOkWrite(archiveModeGet, walSegment, warning);
+                            // The job was successful
+                            if (protocolParallelJobErrorCode(job) == 0)
+                            {
+                                // Get the actual file retrieved
+                                PackRead *const fileResult = protocolParallelJobResult(job);
+                                ArchiveGetFile *file = lstGet(fileMap->actualList, pckReadU32P(fileResult));
+                                ASSERT(file != NULL);
 
-                            LOG_DETAIL_PID_FMT(
-                                processId, FOUND_IN_REPO_ARCHIVE_MSG, strZ(walSegment),
-                                cfgOptionGroupIdxToKey(cfgOptGrpRepo, file->repoIdx), strZ(file->archiveId));
+                                // Output file warnings
+                                StringList *fileWarnList = pckReadStrLstP(fileResult);
 
-                            // Rename temp WAL segment to actual name. This is done after the ok file is written so the ok file is
-                            // guaranteed to exist before the foreground process finds the WAL segment.
-                            storageMoveP(
-                                storageSpoolWrite(),
-                                storageNewReadP(
-                                    storageSpool(),
-                                    strNewFmt(STORAGE_SPOOL_ARCHIVE_IN "/%s." STORAGE_FILE_TEMP_EXT, strZ(walSegment))),
-                                storageNewWriteP(storageSpoolWrite(), strNewFmt(STORAGE_SPOOL_ARCHIVE_IN "/%s", strZ(walSegment))));
-                        }
-                        // Else the job errored
-                        else
-                        {
-                            LOG_WARN_PID_FMT(
-                                processId, "[%s] %s", errorTypeName(errorTypeFromCode(protocolParallelJobErrorCode(job))),
-                                strZ(protocolParallelJobErrorMessage(job)));
+                                for (unsigned int warnIdx = 0; warnIdx < strLstSize(fileWarnList); warnIdx++)
+                                    LOG_WARN_PID(processId, strZ(strLstGet(fileWarnList, warnIdx)));
 
-                            archiveAsyncStatusErrorWrite(
-                                archiveModeGet, walSegment, protocolParallelJobErrorCode(job),
-                                strNewFmt(
-                                    "%s%s", strZ(protocolParallelJobErrorMessage(job)),
-                                    strSize(warning) == 0 ? "" : strZ(strNewFmt("\n%s", strZ(warning)))));
+                                // Build file warnings for status file
+                                if (!strLstEmpty(fileWarnList))
+                                {
+                                    strCatFmt(
+                                        warning, "%s%s", strSize(warning) == 0 ? "" : "\n", strZ(strLstJoin(fileWarnList, "\n")));
+                                }
+
+                                if (strSize(warning) != 0)
+                                    archiveAsyncStatusOkWrite(archiveModeGet, walSegment, warning);
+
+                                LOG_DETAIL_PID_FMT(
+                                    processId, FOUND_IN_REPO_ARCHIVE_MSG, strZ(walSegment),
+                                    cfgOptionGroupIdxToKey(cfgOptGrpRepo, file->repoIdx), strZ(file->archiveId));
+
+                                // Rename temp WAL segment to actual name. This is done after the ok file is written so the ok file
+                                // is guaranteed to exist before the foreground process finds the WAL segment.
+                                storageMoveP(
+                                    storageSpoolWrite(),
+                                    storageNewReadP(
+                                        storageSpool(),
+                                        strNewFmt(STORAGE_SPOOL_ARCHIVE_IN "/%s." STORAGE_FILE_TEMP_EXT, strZ(walSegment))),
+                                    storageNewWriteP(
+                                        storageSpoolWrite(), strNewFmt(STORAGE_SPOOL_ARCHIVE_IN "/%s", strZ(walSegment))));
+                            }
+                            // Else the job errored
+                            else
+                            {
+                                LOG_WARN_PID_FMT(
+                                    processId, "[%s] %s", errorTypeName(errorTypeFromCode(protocolParallelJobErrorCode(job))),
+                                    strZ(protocolParallelJobErrorMessage(job)));
+
+                                archiveAsyncStatusErrorWrite(
+                                    archiveModeGet, walSegment, protocolParallelJobErrorCode(job),
+                                    strNewFmt(
+                                        "%s%s", strZ(protocolParallelJobErrorMessage(job)),
+                                        strSize(warning) == 0 ? "" : strZ(strNewFmt("\n%s", strZ(warning)))));
+                            }
+
+                            protocolParallelJobFree(job);
                         }
 
-                        protocolParallelJobFree(job);
+                        // Reset the memory context occasionally so we don't use too much memory or slow down processing
+                        MEM_CONTEXT_TEMP_RESET(1000);
                     }
+                    while (!protocolParallelDone(parallelExec));
                 }
-                while (!protocolParallelDone(parallelExec));
+                MEM_CONTEXT_TEMP_END();
             }
 
             // Log an error from archiveGetCheck() after any existing files have been fetched. This ordering is important because we
@@ -974,7 +1023,7 @@ cmdArchiveGetAsync(void)
             {
                 LOG_WARN_FMT("[%s] %s", errorTypeName(checkResult.errorType), strZ(checkResult.errorMessage));
 
-                String *message = strDup(checkResult.errorMessage);
+                String *message = strCat(strNew(), checkResult.errorMessage);
 
                 if (!strLstEmpty(checkResult.warnList))
                     strCatFmt(message, "\n%s", strZ(strLstJoin(checkResult.warnList, "\n")));
@@ -982,7 +1031,9 @@ cmdArchiveGetAsync(void)
                 archiveAsyncStatusErrorWrite(
                     archiveModeGet, checkResult.errorFile, errorTypeCode(checkResult.errorType), message);
             }
-            // Else log a warning if any files were missing
+            // If any files were missing write an ok file for the first missing file and add any warnings. It is important that this
+            // happen right before the async process exits so the main process can immediately respawn the async process to retry
+            // missing files.
             else if (archiveFileMissing != NULL)
             {
                 LOG_DETAIL_FMT(UNABLE_TO_FIND_IN_ARCHIVE_MSG, strZ(archiveFileMissing));
