@@ -229,7 +229,7 @@ archivePushCheck(bool pgPathSet)
                 storageRepoIdx(repoIdx);
 
                 // Get cipher type
-                CipherType repoCipherType = cipherType(cfgOptionIdxStr(cfgOptRepoCipherType, repoIdx));
+                CipherType repoCipherType = cfgOptionIdxStrId(cfgOptRepoCipherType, repoIdx);
 
                 // Attempt to load the archive info file
                 InfoArchive *info = infoArchiveLoadFile(
@@ -321,7 +321,7 @@ cmdArchivePush(void)
         lockStopTest();
 
         // Get the segment name
-        String *walFile = walPath(strLstGet(commandParam, 0), cfgOptionStrNull(cfgOptPgPath), STR(cfgCommandName(cfgCommand())));
+        String *walFile = walPath(strLstGet(commandParam, 0), cfgOptionStrNull(cfgOptPgPath), STR(cfgCommandName()));
         String *archiveFile = strBase(walFile);
 
         if (cfgOptionBool(cfgOptArchiveAsync))
@@ -345,7 +345,7 @@ cmdArchivePush(void)
             {
                 // Check if the WAL segment has been pushed.  Errors will not be thrown on the first try to allow the async process
                 // a chance to fix them.
-                pushed = archiveAsyncStatus(archiveModePush, archiveFile, throwOnError);
+                pushed = archiveAsyncStatus(archiveModePush, archiveFile, throwOnError, true);
 
                 // If the WAL segment has not already been pushed then start the async process to push it.  There's no point in
                 // forking the async process off more than once so track that as well.  Use an archive lock to prevent more than
@@ -358,8 +358,8 @@ cmdArchivePush(void)
                     // The async process should not output on the console at all
                     KeyValue *optionReplace = kvNew();
 
-                    kvPut(optionReplace, VARSTR(CFGOPT_LOG_LEVEL_CONSOLE_STR), VARSTRDEF("off"));
-                    kvPut(optionReplace, VARSTR(CFGOPT_LOG_LEVEL_STDERR_STR), VARSTRDEF("off"));
+                    kvPut(optionReplace, VARSTRDEF(CFGOPT_LOG_LEVEL_CONSOLE), VARSTRDEF("off"));
+                    kvPut(optionReplace, VARSTRDEF(CFGOPT_LOG_LEVEL_STDERR), VARSTRDEF("off"));
 
                     // Generate command options
                     StringList *commandExec = cfgExecParam(cfgCmdArchivePush, cfgCmdRoleAsync, optionReplace, true, false);
@@ -390,7 +390,7 @@ cmdArchivePush(void)
             {
                 THROW_FMT(
                     ArchiveTimeoutError, "unable to push WAL file '%s' to the archive asynchronously after %s second(s)",
-                    strZ(archiveFile), strZ(strNewDbl((double)cfgOptionInt64(cfgOptArchiveTimeout) / MSEC_PER_SEC)));
+                    strZ(archiveFile), strZ(cfgOptionDisplay(cfgOptArchiveTimeout)));
             }
 
             // Log success
@@ -413,7 +413,7 @@ cmdArchivePush(void)
                 // Push the file to the archive
                 ArchivePushFileResult fileResult = archivePushFile(
                     walFile, cfgOptionBool(cfgOptArchiveHeaderCheck), archiveInfo.pgVersion, archiveInfo.pgSystemId, archiveFile,
-                    compressTypeEnum(cfgOptionStr(cfgOptCompressType)), cfgOptionInt(cfgOptCompressLevel), archiveInfo.repoList,
+                    compressTypeEnum(cfgOptionStrId(cfgOptCompressType)), cfgOptionInt(cfgOptCompressLevel), archiveInfo.repoList,
                     archiveInfo.errorList);
 
                 // If a warning was returned then log it
@@ -449,43 +449,60 @@ archivePushAsyncCallback(void *data, unsigned int clientIdx)
         FUNCTION_TEST_PARAM(UINT, clientIdx);
     FUNCTION_TEST_END();
 
-    // No special logic based on the client, we'll just get the next job
-    (void)clientIdx;
+    ProtocolParallelJob *result = NULL;
 
-    // Get a new job if there are any left
-    ArchivePushAsyncData *jobData = data;
-
-    if (jobData->walFileIdx < strLstSize(jobData->walFileList))
+    MEM_CONTEXT_TEMP_BEGIN()
     {
-        const String *walFile = strLstGet(jobData->walFileList, jobData->walFileIdx);
-        jobData->walFileIdx++;
+        // No special logic based on the client, we'll just get the next job
+        (void)clientIdx;
 
-        ProtocolCommand *command = protocolCommandNew(PROTOCOL_COMMAND_ARCHIVE_PUSH_FILE_STR);
-        protocolCommandParamAdd(command, VARSTR(strNewFmt("%s/%s", strZ(jobData->walPath), strZ(walFile))));
-        protocolCommandParamAdd(command, VARBOOL(cfgOptionBool(cfgOptArchiveHeaderCheck)));
-        protocolCommandParamAdd(command, VARUINT(jobData->archiveInfo.pgVersion));
-        protocolCommandParamAdd(command, VARUINT64(jobData->archiveInfo.pgSystemId));
-        protocolCommandParamAdd(command, VARSTR(walFile));
-        protocolCommandParamAdd(command, VARUINT(jobData->compressType));
-        protocolCommandParamAdd(command, VARINT(jobData->compressLevel));
-        protocolCommandParamAdd(command, varNewVarLst(varLstNewStrLst(jobData->archiveInfo.errorList)));
-        protocolCommandParamAdd(command, VARUINT(lstSize(jobData->archiveInfo.repoList)));
+        // Get a new job if there are any left
+        ArchivePushAsyncData *jobData = data;
 
-        // Add data for each repo to push to
-        for (unsigned int repoListIdx = 0; repoListIdx < lstSize(jobData->archiveInfo.repoList); repoListIdx++)
+        if (jobData->walFileIdx < strLstSize(jobData->walFileList))
         {
-            ArchivePushFileRepoData *data = lstGet(jobData->archiveInfo.repoList, repoListIdx);
+            const String *walFile = strLstGet(jobData->walFileList, jobData->walFileIdx);
+            jobData->walFileIdx++;
 
-            protocolCommandParamAdd(command, VARUINT(data->repoIdx));
-            protocolCommandParamAdd(command, VARSTR(data->archiveId));
-            protocolCommandParamAdd(command, VARUINT(data->cipherType));
-            protocolCommandParamAdd(command, VARSTR(data->cipherPass));
+            ProtocolCommand *const command = protocolCommandNew(PROTOCOL_COMMAND_ARCHIVE_PUSH_FILE);
+            PackWrite *const param = protocolCommandParam(command);
+
+            pckWriteStrP(param, strNewFmt("%s/%s", strZ(jobData->walPath), strZ(walFile)));
+            pckWriteBoolP(param, cfgOptionBool(cfgOptArchiveHeaderCheck));
+            pckWriteU32P(param, jobData->archiveInfo.pgVersion);
+            pckWriteU64P(param, jobData->archiveInfo.pgSystemId);
+            pckWriteStrP(param, walFile);
+            pckWriteU32P(param, jobData->compressType);
+            pckWriteI32P(param, jobData->compressLevel);
+            pckWriteStrLstP(param, jobData->archiveInfo.errorList);
+
+            // Add data for each repo to push to
+            pckWriteArrayBeginP(param);
+
+            for (unsigned int repoListIdx = 0; repoListIdx < lstSize(jobData->archiveInfo.repoList); repoListIdx++)
+            {
+                ArchivePushFileRepoData *data = lstGet(jobData->archiveInfo.repoList, repoListIdx);
+
+                pckWriteObjBeginP(param);
+                pckWriteU32P(param, data->repoIdx);
+                pckWriteStrP(param, data->archiveId);
+                pckWriteU64P(param, data->cipherType);
+                pckWriteStrP(param, data->cipherPass);
+                pckWriteObjEndP(param);
+            }
+
+            pckWriteArrayEndP(param);
+
+            MEM_CONTEXT_PRIOR_BEGIN()
+            {
+                result = protocolParallelJobNew(VARSTR(walFile), command);
+            }
+            MEM_CONTEXT_PRIOR_END();
         }
-
-        FUNCTION_TEST_RETURN(protocolParallelJobNew(VARSTR(walFile), command));
     }
+    MEM_CONTEXT_TEMP_END();
 
-    FUNCTION_TEST_RETURN(NULL);
+    FUNCTION_TEST_RETURN(result);
 }
 
 void
@@ -509,7 +526,7 @@ cmdArchivePushAsync(void)
         ArchivePushAsyncData jobData =
         {
             .walPath = strLstGet(commandParam, 0),
-            .compressType = compressTypeEnum(cfgOptionStr(cfgOptCompressType)),
+            .compressType = compressTypeEnum(cfgOptionStrId(cfgOptCompressType)),
             .compressLevel = cfgOptionInt(cfgOptCompressLevel),
         };
 
@@ -556,54 +573,59 @@ cmdArchivePushAsync(void)
                     protocolParallelClientAdd(parallelExec, protocolLocalGet(protocolStorageTypeRepo, 0, processIdx));
 
                 // Process jobs
-                do
+                MEM_CONTEXT_TEMP_RESET_BEGIN()
                 {
-                    unsigned int completed = protocolParallelProcess(parallelExec);
-
-                    for (unsigned int jobIdx = 0; jobIdx < completed; jobIdx++)
+                    do
                     {
-                        protocolKeepAlive();
+                        unsigned int completed = protocolParallelProcess(parallelExec);
 
-                        // Get the job and job key
-                        ProtocolParallelJob *job = protocolParallelResult(parallelExec);
-                        unsigned int processId = protocolParallelJobProcessId(job);
-                        const String *walFile = varStr(protocolParallelJobKey(job));
-
-                        // The job was successful
-                        if (protocolParallelJobErrorCode(job) == 0)
+                        for (unsigned int jobIdx = 0; jobIdx < completed; jobIdx++)
                         {
-                            // Get job result
-                            const VariantList *fileResult = varVarLst(protocolParallelJobResult(job));
+                            protocolKeepAlive();
 
-                            // Output file warnings
-                            StringList *fileWarnList = strLstNewVarLst(varVarLst(varLstGet(fileResult, 0)));
+                            // Get the job and job key
+                            ProtocolParallelJob *job = protocolParallelResult(parallelExec);
+                            unsigned int processId = protocolParallelJobProcessId(job);
+                            const String *walFile = varStr(protocolParallelJobKey(job));
 
-                            for (unsigned int warnIdx = 0; warnIdx < strLstSize(fileWarnList); warnIdx++)
-                                LOG_WARN_PID(processId, strZ(strLstGet(fileWarnList, warnIdx)));
+                            // The job was successful
+                            if (protocolParallelJobErrorCode(job) == 0)
+                            {
+                                // Output file warnings
+                                StringList *fileWarnList = pckReadStrLstP(protocolParallelJobResult(job));
 
-                            // Log success
-                            LOG_DETAIL_PID_FMT(processId, "pushed WAL file '%s' to the archive", strZ(walFile));
+                                for (unsigned int warnIdx = 0; warnIdx < strLstSize(fileWarnList); warnIdx++)
+                                    LOG_WARN_PID(processId, strZ(strLstGet(fileWarnList, warnIdx)));
 
-                            // Write the status file
-                            archiveAsyncStatusOkWrite(
-                                archiveModePush, walFile, strLstEmpty(fileWarnList) ? NULL : strLstJoin(fileWarnList, "\n"));
-                        }
-                        // Else the job errored
-                        else
-                        {
-                            LOG_WARN_PID_FMT(
-                                processId,
-                                "could not push WAL file '%s' to the archive (will be retried): [%d] %s", strZ(walFile),
-                                protocolParallelJobErrorCode(job), strZ(protocolParallelJobErrorMessage(job)));
+                                // Log success
+                                LOG_DETAIL_PID_FMT(processId, "pushed WAL file '%s' to the archive", strZ(walFile));
 
-                            archiveAsyncStatusErrorWrite(
-                                archiveModePush, walFile, protocolParallelJobErrorCode(job), protocolParallelJobErrorMessage(job));
+                                // Write the status file
+                                archiveAsyncStatusOkWrite(
+                                    archiveModePush, walFile, strLstEmpty(fileWarnList) ? NULL : strLstJoin(fileWarnList, "\n"));
+                            }
+                            // Else the job errored
+                            else
+                            {
+                                LOG_WARN_PID_FMT(
+                                    processId,
+                                    "could not push WAL file '%s' to the archive (will be retried): [%d] %s", strZ(walFile),
+                                    protocolParallelJobErrorCode(job), strZ(protocolParallelJobErrorMessage(job)));
+
+                                archiveAsyncStatusErrorWrite(
+                                    archiveModePush, walFile, protocolParallelJobErrorCode(job),
+                                    protocolParallelJobErrorMessage(job));
+                            }
+
+                            protocolParallelJobFree(job);
                         }
 
-                        protocolParallelJobFree(job);
+                        // Reset the memory context occasionally so we don't use too much memory or slow down processing
+                        MEM_CONTEXT_TEMP_RESET(1000);
                     }
+                    while (!protocolParallelDone(parallelExec));
                 }
-                while (!protocolParallelDone(parallelExec));
+                MEM_CONTEXT_TEMP_END();
             }
         }
         // On any global error write a single error file to cover all unprocessed files
