@@ -56,7 +56,7 @@ checkStandby(const DbGetResult dbGroup, unsigned int pgPathDefinedTotal)
         // If primary was not found (only have 1 pg configured locally, and we want to still run because this is a standby)
         if (dbGroup.primary == NULL)
         {
-            // If any repo is local or more than one pg-path is found then a master should have been found so error
+            // If any repo is local or more than one pg-path is found then a primary should have been found so error
             bool error = pgPathDefinedTotal > 1;
             unsigned int repoIdx = 0;
 
@@ -72,11 +72,8 @@ checkStandby(const DbGetResult dbGroup, unsigned int pgPathDefinedTotal)
                 THROW(ConfigError, "primary database not found\nHINT: check indexed pg-path/pg-host configurations");
         }
 
-        // Validate the standby database config
-        PgControl pgControl = pgControlFromFile(storagePgIdx(dbGroup.standbyIdx));
-
         // Check the user configured path and version against the database
-        checkDbConfig(pgControl.version, dbGroup.standbyIdx, dbGroup.standby, true);
+        checkDbConfig(dbPgControl(dbGroup.standby).version, dbGroup.standbyIdx, dbGroup.standby, true);
 
         // Check each repository configured
         for (unsigned int repoIdx = 0; repoIdx < cfgOptionGroupIdxTotal(cfgOptGrpRepo); repoIdx++)
@@ -88,8 +85,8 @@ checkStandby(const DbGetResult dbGroup, unsigned int pgPathDefinedTotal)
 
             // Check that the backup and archive info files exist and are valid for the current database of the stanza
             checkStanzaInfoPg(
-                storageRepo, pgControl.version, pgControl.systemId, cipherType(cfgOptionIdxStr(cfgOptRepoCipherType, repoIdx)),
-                cfgOptionIdxStrNull(cfgOptRepoCipherPass, repoIdx));
+                storageRepo, dbPgControl(dbGroup.standby).version, dbPgControl(dbGroup.standby).systemId,
+                cfgOptionIdxStrId(cfgOptRepoCipherType, repoIdx), cfgOptionIdxStrNull(cfgOptRepoCipherPass, repoIdx));
         }
 
         LOG_INFO("switch wal not performed because this is a standby");
@@ -100,7 +97,7 @@ checkStandby(const DbGetResult dbGroup, unsigned int pgPathDefinedTotal)
     // If backup from standby is true then warn when a standby not found
     else if (cfgOptionBool(cfgOptBackupStandby))
     {
-        LOG_WARN_FMT("option '%s' is enabled but standby is not properly configured", cfgOptionName(cfgOptBackupStandby));
+        LOG_WARN("option '" CFGOPT_BACKUP_STANDBY "' is enabled but standby is not properly configured");
     }
 
     FUNCTION_LOG_RETURN_VOID();
@@ -116,11 +113,8 @@ checkPrimary(const DbGetResult dbGroup)
     // If a primary is defined, check the configuration and perform a WAL switch and make sure the WAL is archived
     if (dbGroup.primary != NULL)
     {
-        // Validate the primary database config
-        PgControl pgControl = pgControlFromFile(storagePgIdx(dbGroup.primaryIdx));
-
         // Check the user configured path and version against the database
-        checkDbConfig(pgControl.version, dbGroup.primaryIdx, dbGroup.primary, false);
+        checkDbConfig(dbPgControl(dbGroup.primary).version, dbGroup.primaryIdx, dbGroup.primary, false);
 
         // Check configuration of each repo
         const String **repoArchiveId = memNew(sizeof(String *) * cfgOptionGroupIdxTotal(cfgOptGrpRepo));
@@ -134,12 +128,12 @@ checkPrimary(const DbGetResult dbGroup)
 
             // Check that the backup and archive info files exist and are valid for the current database of the stanza
             checkStanzaInfoPg(
-                storageRepo, pgControl.version, pgControl.systemId, cipherType(cfgOptionIdxStr(cfgOptRepoCipherType, repoIdx)),
-                cfgOptionIdxStrNull(cfgOptRepoCipherPass, repoIdx));
+                storageRepo, dbPgControl(dbGroup.primary).version, dbPgControl(dbGroup.primary).systemId,
+                cfgOptionIdxStrId(cfgOptRepoCipherType, repoIdx), cfgOptionIdxStrNull(cfgOptRepoCipherPass, repoIdx));
 
             // Attempt to load the archive info file and retrieve the archiveId
             InfoArchive *archiveInfo = infoArchiveLoadFile(
-                storageRepo, INFO_ARCHIVE_PATH_FILE_STR, cipherType(cfgOptionIdxStr(cfgOptRepoCipherType, repoIdx)),
+                storageRepo, INFO_ARCHIVE_PATH_FILE_STR, cfgOptionIdxStrId(cfgOptRepoCipherType, repoIdx),
                 cfgOptionIdxStrNull(cfgOptRepoCipherPass, repoIdx));
 
             repoArchiveId[repoIdx] = infoArchiveId(archiveInfo);
