@@ -43,7 +43,7 @@ cmdOption(void)
     {
         MEM_CONTEXT_BEGIN(memContextTop())
         {
-            cmdOptionStr = strNew("");
+            cmdOptionStr = strNew();
 
             MEM_CONTEXT_TEMP_BEGIN()
             {
@@ -126,17 +126,11 @@ cmdOption(void)
                                 {
                                     valueList = strLstNewVarLst(cfgOptionIdxLst(optionId, optionIdx));
                                 }
-                                // Generate time value
-                                else if (cfgParseOptionType(optionId) == cfgOptTypeTime)
-                                {
-                                    valueList = strLstNew();
-                                    strLstAdd(valueList, strNewDbl((double)cfgOptionIdxInt64(optionId, optionIdx) / MSEC_PER_SEC));
-                                }
                                 // Else only one value
                                 else
                                 {
                                     valueList = strLstNew();
-                                    strLstAdd(valueList, varStrForce(cfgOptionIdx(optionId, optionIdx)));
+                                    strLstAdd(valueList, cfgOptionIdxDisplay(optionId, optionIdx));
                                 }
 
                                 // Output options and values
@@ -178,7 +172,7 @@ cmdBegin(void)
         MEM_CONTEXT_TEMP_BEGIN()
         {
             // Basic info on command start
-            String *info = strNewFmt("%s command begin", strZ(cfgCommandRoleName()));
+            String *info = strCatFmt(strNew(), "%s command begin", strZ(cfgCommandRoleName()));
 
             // Free the old option string if it exists. This is needed when more than one command is run in a row so an option
             // string gets created for the new command.
@@ -219,7 +213,7 @@ cmdEnd(int code, const String *errorMessage)
                 LOG_DETAIL_FMT("statistics: %s", strZ(jsonFromKv(statKv)));
 
             // Basic info on command end
-            String *info = strNewFmt("%s command end: ", strZ(cfgCommandRoleName()));
+            String *info = strCatFmt(strNew(), "%s command end: ", strZ(cfgCommandRoleName()));
 
             if (errorMessage == NULL)
             {
