@@ -6,10 +6,18 @@ Common Handler for Control Commands
 
 #include "common/type/string.h"
 
+/***********************************************************************************************************************************
+Constants
+***********************************************************************************************************************************/
+#define STOP_FILE_EXT                                               ".stop"
+
 /***********************************************************************************************************************************
 Functions
 ***********************************************************************************************************************************/
+// Create the stop filename
 String *lockStopFileName(const String *stanza);
+
+// Test for the existence of a stop file
 void lockStopTest(void);
 
 #endif
