@@ -133,10 +133,10 @@ expireAdhocBackup(InfoBackup *infoBackup, const String *backupLabel, unsigned in
         StringList *backupExpired = expireBackup(infoBackup, backupLabel, repoIdx);
 
         // If the latest backup was removed, then update the latest link if not a dry-run
-        if (infoBackupDataByLabel(infoBackup, latestBackup) == NULL)
+        if (!infoBackupLabelExists(infoBackup, latestBackup))
         {
             // If retention settings have been configured, then there may be holes in the archives. For example, if the archive
-            // for db-id=1 has 01,02,03,04,05 and F1 backup has archive start-stop 02-03 and rentention-full=1
+            // for db-id=1 has 01,02,03,04,05 and F1 backup has archive start-stop 02-03 and retention-full=1
             // (hence retention-archive=1 and retention-archive-type=full), then when F2 backup is created and assuming its
             // archive start-stop=05-06 then archives 01 and 04 will be removed resulting in F1 not being able to play through
             // PITR, which is expected. Now adhoc expire is attempted on F2 - it will be allowed but now there will be no
@@ -332,12 +332,12 @@ expireTimeBasedBackup(InfoBackup *infoBackup, const time_t minTimestamp, unsigne
                     (strLstSize(backupExpired) > 1 ? "set " : ""), strZ(strLstJoin(backupExpired, ", ")));
             }
 
-            if (strEqZ(cfgOptionIdxStr(cfgOptRepoRetentionArchiveType, repoIdx), CFGOPTVAL_TMP_REPO_RETENTION_ARCHIVE_TYPE_FULL) &&
+            if (cfgOptionIdxStrId(cfgOptRepoRetentionArchiveType, repoIdx) == backupTypeFull &&
                 !cfgOptionIdxTest(cfgOptRepoRetentionArchive, repoIdx) && numFullExpired > 0)
             {
                 cfgOptionIdxSet(
                     cfgOptRepoRetentionArchive, repoIdx, cfgSourceDefault,
-                    varNewUInt(strLstSize(currentBackupList) - numFullExpired));
+                    VARINT64(strLstSize(currentBackupList) - numFullExpired));
             }
         }
     }
@@ -355,7 +355,7 @@ logExpire(ArchiveExpired *archiveExpire, String *archiveId, unsigned int repoIdx
     if (archiveExpire->start != NULL)
     {
         // Force out any remaining message
-        LOG_DETAIL_FMT(
+        LOG_INFO_FMT(
             "repo%u: %s remove archive, start = %s, stop = %s", cfgOptionGroupIdxToKey(cfgOptGrpRepo, repoIdx), strZ(archiveId),
             strZ(archiveExpire->start), strZ(archiveExpire->stop));
 
@@ -380,7 +380,7 @@ removeExpiredArchive(InfoBackup *infoBackup, bool timeBasedFullRetention, unsign
     MEM_CONTEXT_TEMP_BEGIN()
     {
         // Get the retention options. repo-archive-retention-type always has a value as it defaults to "full"
-        const String *archiveRetentionType = cfgOptionIdxStr(cfgOptRepoRetentionArchiveType, repoIdx);
+        const BackupType archiveRetentionType = (BackupType)cfgOptionIdxStrId(cfgOptRepoRetentionArchiveType, repoIdx);
         unsigned int archiveRetention = cfgOptionIdxTest(
             cfgOptRepoRetentionArchive, repoIdx) ? cfgOptionIdxUInt(cfgOptRepoRetentionArchive, repoIdx) : 0;
 
@@ -388,7 +388,7 @@ removeExpiredArchive(InfoBackup *infoBackup, bool timeBasedFullRetention, unsign
         // cfgLoadUpdateOption based on certain rules.
         if (archiveRetention == 0)
         {
-            String *msg = strNew("- archive logs will not be expired");
+            String *msg = strNewZ("- archive logs will not be expired");
 
             // Only notify user if not time-based retention
             if (!timeBasedFullRetention)
@@ -406,30 +406,33 @@ removeExpiredArchive(InfoBackup *infoBackup, bool timeBasedFullRetention, unsign
             // remaining non-expired backups, from newest to oldest, based on the type.
             StringList *globalBackupRetentionList = NULL;
 
-            if (strCmp(archiveRetentionType, STRDEF(CFGOPTVAL_TMP_REPO_RETENTION_ARCHIVE_TYPE_FULL)) == 0)
+            switch (archiveRetentionType)
             {
-                globalBackupRetentionList = strLstSort(
-                    infoBackupDataLabelList(infoBackup, backupRegExpP(.full = true)), sortOrderDesc);
-            }
-            else if (strCmp(archiveRetentionType, STRDEF(CFGOPTVAL_TMP_REPO_RETENTION_ARCHIVE_TYPE_DIFF)) == 0)
-            {
-                globalBackupRetentionList = strLstSort(
-                    infoBackupDataLabelList(infoBackup, backupRegExpP(.full = true, .differential = true)), sortOrderDesc);
-            }
-            else
-            {   // Incrementals can depend on Full or Diff so get a list of all incrementals
-                globalBackupRetentionList = strLstSort(
-                    infoBackupDataLabelList(infoBackup, backupRegExpP(.full = true, .differential = true, .incremental = true)),
-                    sortOrderDesc);
+                case backupTypeFull:
+                    globalBackupRetentionList = strLstSort(
+                        infoBackupDataLabelList(infoBackup, backupRegExpP(.full = true)), sortOrderDesc);
+                    break;
+
+                case backupTypeDiff:
+                    globalBackupRetentionList = strLstSort(
+                        infoBackupDataLabelList(infoBackup, backupRegExpP(.full = true, .differential = true)), sortOrderDesc);
+                    break;
+
+                case backupTypeIncr:
+                    // Incrementals can depend on Full or Diff so get a list of all incrementals
+                    globalBackupRetentionList = strLstSort(
+                        infoBackupDataLabelList(infoBackup, backupRegExpP(.full = true, .differential = true, .incremental = true)),
+                        sortOrderDesc);
+                    break;
             }
 
-            // Expire archives. If no backups were found or the number of backups found is not enough to satify archive retention
+            // Expire archives. If no backups were found or the number of backups found is not enough to satisfy archive retention
             // then preserve current archive logs - too soon to expire them.
             if (!strLstEmpty(globalBackupRetentionList) && archiveRetention <= strLstSize(globalBackupRetentionList))
             {
                 // Attempt to load the archive info file
                 InfoArchive *infoArchive = infoArchiveLoadFile(
-                    storageRepoIdx(repoIdx), INFO_ARCHIVE_PATH_FILE_STR, cipherType(cfgOptionIdxStr(cfgOptRepoCipherType, repoIdx)),
+                    storageRepoIdx(repoIdx), INFO_ARCHIVE_PATH_FILE_STR, cfgOptionIdxStrId(cfgOptRepoCipherType, repoIdx),
                     cfgOptionIdxStrNull(cfgOptRepoCipherPass, repoIdx));
 
                 InfoPg *infoArchivePgData = infoArchivePg(infoArchive);
@@ -475,7 +478,7 @@ removeExpiredArchive(InfoBackup *infoBackup, bool timeBasedFullRetention, unsign
                 }
 
                 // Loop through the archive.info history from oldest to newest and if there is a corresponding directory on disk
-                // then remove WAL that are not part of retention as long as the db:history id verion/system-id matches backup.info
+                // then remove WAL that are not part of retention as long as the db:history id version/system-id matches backup.info
                 for (unsigned int pgIdx = infoPgDataTotal(infoArchivePgData) - 1; (int)pgIdx >= 0; pgIdx--)
                 {
                     String *archiveId = infoPgArchiveId(infoArchivePgData, pgIdx);
@@ -730,7 +733,7 @@ removeExpiredArchive(InfoBackup *infoBackup, bool timeBasedFullRetention, unsign
                             // Log if no archive was expired
                             if (archiveExpire.total == 0)
                             {
-                                LOG_DETAIL_FMT(
+                                LOG_INFO_FMT(
                                     "repo%u: %s no archive to remove", cfgOptionGroupIdxToKey(cfgOptGrpRepo, repoIdx),
                                     strZ(archiveId));
                             }
@@ -764,7 +767,7 @@ removeExpiredArchive(InfoBackup *infoBackup, bool timeBasedFullRetention, unsign
                                             strNewFmt(STORAGE_REPO_ARCHIVE "/%s/%s", strZ(archiveId), strZ(historyFile)));
                                     }
 
-                                    LOG_DETAIL_FMT(
+                                    LOG_INFO_FMT(
                                         "repo%u: %s remove history file %s", cfgOptionGroupIdxToKey(cfgOptGrpRepo, repoIdx),
                                         strZ(archiveId), strZ(historyFile));
                                 }
@@ -805,7 +808,7 @@ removeExpiredBackup(InfoBackup *infoBackup, const String *adhocBackupLabel, unsi
             .expression = backupRegExpP(.full = true, .differential = true, .incremental = true)),
         sortOrderDesc);
 
-    // Initialize the index to the lastest backup on disk
+    // Initialize the index to the latest backup on disk
     unsigned int backupIdx = 0;
 
     // Only remove the resumable backup if there is a possibility it is a dependent of the adhoc label being expired
@@ -828,11 +831,11 @@ removeExpiredBackup(InfoBackup *infoBackup, const String *adhocBackupLabel, unsi
             else
             {
                 Manifest *manifestResume = manifestLoadFile(
-                    storageRepoIdx(repoIdx), manifestFileName, cipherType(cfgOptionIdxStr(cfgOptRepoCipherType, repoIdx)),
+                    storageRepoIdx(repoIdx), manifestFileName, cfgOptionIdxStrId(cfgOptRepoCipherType, repoIdx),
                     infoPgCipherPass(infoBackupPg(infoBackup)));
 
                 // If the ancestor of the resumable backup still exists in backup.info then do not remove the resumable backup
-                if (infoBackupDataByLabel(infoBackup, manifestData(manifestResume)->backupLabelPrior) != NULL)
+                if (infoBackupLabelExists(infoBackup, manifestData(manifestResume)->backupLabelPrior))
                     backupIdx = 1;
             }
         }
@@ -860,6 +863,102 @@ removeExpiredBackup(InfoBackup *infoBackup, const String *adhocBackupLabel, unsi
     FUNCTION_LOG_RETURN_VOID();
 }
 
+/***********************************************************************************************************************************
+Remove expired backup history manifests from repo
+***********************************************************************************************************************************/
+static void
+removeExpiredHistory(InfoBackup *infoBackup, unsigned int repoIdx)
+{
+    FUNCTION_LOG_BEGIN(logLevelDebug);
+        FUNCTION_LOG_PARAM(INFO_BACKUP, infoBackup);
+        FUNCTION_LOG_PARAM(UINT, repoIdx);
+    FUNCTION_LOG_END();
+
+    ASSERT(infoBackup != NULL);
+
+    MEM_CONTEXT_TEMP_BEGIN()
+    {
+        if (cfgOptionIdxTest(cfgOptRepoRetentionHistory, repoIdx))
+        {
+            // Get current backups in backup.info - these will not be expired
+            StringList *currentBackupList = strLstSort(infoBackupDataLabelList(infoBackup, NULL), sortOrderDesc);
+
+            // If the full backup history manifests are expired, we should expire diff and incr too. So, format the oldest full
+            // backup label to retain.
+            const time_t minTimestamp = time(NULL) - (time_t)(cfgOptionIdxUInt(cfgOptRepoRetentionHistory, repoIdx) * SEC_PER_DAY);
+            String *minBackupLabel = backupLabelFormat(backupTypeFull, NULL, minTimestamp);
+
+            // Get all history years
+            const StringList *historyYearList = strLstSort(
+                storageListP(
+                    storageRepo(), STRDEF(STORAGE_REPO_BACKUP "/" BACKUP_PATH_HISTORY), .expression = STRDEF("^2[0-9]{3}$")),
+                sortOrderAsc);
+
+            for (unsigned int historyYearIdx = 0; historyYearIdx < strLstSize(historyYearList); historyYearIdx++)
+            {
+                // Get all the backup history manifests
+                const String *historyYear = strLstGet(historyYearList, historyYearIdx);
+
+                // If the entire year is less than the year of the minimum backup to retain, then remove completely the directory
+                if (strCmp(historyYear, strSubN(minBackupLabel, 0, 4)) < 0)
+                {
+                    LOG_INFO_FMT(
+                        "repo%u: remove expired backup history path %s",
+                        cfgOptionGroupIdxToKey(cfgOptGrpRepo, repoIdx), strZ(historyYear));
+
+                    // Execute the real expiration and deletion only if the dry-run mode is disabled
+                    if (!cfgOptionValid(cfgOptDryRun) || !cfgOptionBool(cfgOptDryRun))
+                    {
+                        storagePathRemoveP(
+                            storageRepoIdxWrite(repoIdx),
+                            strNewFmt(STORAGE_REPO_BACKUP "/" BACKUP_PATH_HISTORY "/%s", strZ(historyYear)), .recurse = true);
+                    }
+                }
+                // Else find and remove individual files
+                else if (strEq(historyYear, strSubN(minBackupLabel, 0, 4)))
+                {
+                    const StringList *historyList = strLstSort(
+                        storageListP(
+                            storageRepo(), strNewFmt(STORAGE_REPO_BACKUP "/" BACKUP_PATH_HISTORY "/%s", strZ(historyYear)),
+                            .expression = strNewFmt(
+                                "%s\\.manifest\\.%s$",
+                                strZ(backupRegExpP(.full = true, .differential = true, .incremental = true, .noAnchorEnd = true)),
+                                strZ(compressTypeStr(compressTypeGz)))),
+                        sortOrderDesc);
+                    for (unsigned int historyIdx = 0; historyIdx < strLstSize(historyList); historyIdx++)
+                    {
+                        const String *historyBackupFile = strLstGet(historyList, historyIdx);
+                        const String *historyBackupLabel = strLstGet(strLstNewSplitZ(historyBackupFile, "."), 0);
+
+                        // Keep backup history manifests for unexpired backups and backups newer than the oldest backup to retain
+                        if (!strLstExists(currentBackupList, historyBackupLabel) && strCmp(historyBackupLabel, minBackupLabel) < 0)
+                        {
+                            LOG_INFO_FMT(
+                                "repo%u: remove expired backup history manifest %s", cfgOptionGroupIdxToKey(cfgOptGrpRepo, repoIdx),
+                                strZ(historyBackupFile));
+
+                            // Execute the real expiration and deletion only if the dry-run mode is disabled
+                            if (!cfgOptionValid(cfgOptDryRun) || !cfgOptionBool(cfgOptDryRun))
+                            {
+                                storageRemoveP(
+                                    storageRepoIdxWrite(repoIdx),
+                                    strNewFmt(
+                                        STORAGE_REPO_BACKUP "/" BACKUP_PATH_HISTORY "/%s/%s",
+                                        strZ(historyYear), strZ(historyBackupFile)));
+                            }
+                        }
+                    }
+                }
+                else
+                    break;
+            }
+        }
+    }
+    MEM_CONTEXT_TEMP_END();
+
+    FUNCTION_LOG_RETURN_VOID();
+}
+
 /**********************************************************************************************************************************/
 void
 cmdExpire(void)
@@ -908,20 +1007,20 @@ cmdExpire(void)
             const Storage *storageRepo = storageRepoIdx(repoIdx);
             InfoBackup *infoBackup = NULL;
 
-            bool timeBasedFullRetention = strEqZ(
-                cfgOptionIdxStr(cfgOptRepoRetentionFullType, repoIdx), CFGOPTVAL_TMP_REPO_RETENTION_FULL_TYPE_TIME);
+            bool timeBasedFullRetention =
+                cfgOptionIdxStrId(cfgOptRepoRetentionFullType, repoIdx) == CFGOPTVAL_REPO_RETENTION_FULL_TYPE_TIME;
 
             TRY_BEGIN()
             {
                 // Load the backup.info
                 infoBackup = infoBackupLoadFileReconstruct(
-                    storageRepo, INFO_BACKUP_PATH_FILE_STR, cipherType(cfgOptionIdxStr(cfgOptRepoCipherType, repoIdx)),
+                    storageRepo, INFO_BACKUP_PATH_FILE_STR, cfgOptionIdxStrId(cfgOptRepoCipherType, repoIdx),
                     cfgOptionIdxStrNull(cfgOptRepoCipherPass, repoIdx));
 
                 // If a backupLabel was set, then attempt to expire the requested backup
                 if (adhocBackupLabel != NULL)
                 {
-                    if (infoBackupDataByLabel(infoBackup, adhocBackupLabel) != NULL)
+                    if (infoBackupLabelExists(infoBackup, adhocBackupLabel))
                     {
                         adhocBackupFound = true;
                         expireAdhocBackup(infoBackup, adhocBackupLabel, repoIdx);
@@ -960,13 +1059,13 @@ cmdExpire(void)
                 {
                     infoBackupSaveFile(
                         infoBackup, storageRepoIdxWrite(repoIdx), INFO_BACKUP_PATH_FILE_STR,
-                        cipherType(cfgOptionIdxStr(cfgOptRepoCipherType, repoIdx)),
-                        cfgOptionIdxStrNull(cfgOptRepoCipherPass, repoIdx));
+                        cfgOptionIdxStrId(cfgOptRepoCipherType, repoIdx), cfgOptionIdxStrNull(cfgOptRepoCipherPass, repoIdx));
                 }
 
                 // Remove all files on disk that are now expired
                 removeExpiredBackup(infoBackup, adhocBackupLabel, repoIdx);
                 removeExpiredArchive(infoBackup, timeBasedFullRetention, repoIdx);
+                removeExpiredHistory(infoBackup, repoIdx);
             }
             CATCH_ANY()
             {
