@@ -21,13 +21,14 @@ Restore File
 /**********************************************************************************************************************************/
 bool
 restoreFile(
-    const String *repoFile, const String *repoFileReference, CompressType repoFileCompressType, const String *pgFile,
-    const String *pgFileChecksum, bool pgFileZero, uint64_t pgFileSize, time_t pgFileModified, mode_t pgFileMode,
-    const String *pgFileUser, const String *pgFileGroup, time_t copyTimeBegin, bool delta, bool deltaForce,
+    const String *repoFile, unsigned int repoIdx, const String *repoFileReference, CompressType repoFileCompressType,
+    const String *pgFile, const String *pgFileChecksum, bool pgFileZero, uint64_t pgFileSize, time_t pgFileModified,
+    mode_t pgFileMode, const String *pgFileUser, const String *pgFileGroup, time_t copyTimeBegin, bool delta, bool deltaForce,
     const String *cipherPass)
 {
     FUNCTION_LOG_BEGIN(logLevelDebug);
         FUNCTION_LOG_PARAM(STRING, repoFile);
+        FUNCTION_LOG_PARAM(UINT, repoIdx);
         FUNCTION_LOG_PARAM(STRING, repoFileReference);
         FUNCTION_LOG_PARAM(ENUM, repoFileCompressType);
         FUNCTION_LOG_PARAM(STRING, pgFile);
@@ -90,7 +91,8 @@ restoreFile(
                         // If size and checksum are equal then no need to copy the file
                         if (pgFileSize == 0 ||
                             strEq(
-                                pgFileChecksum, varStr(ioFilterGroupResult(ioReadFilterGroup(read), CRYPTO_HASH_FILTER_TYPE_STR))))
+                                pgFileChecksum,
+                                pckReadStrP(ioFilterGroupResultP(ioReadFilterGroup(read), CRYPTO_HASH_FILTER_TYPE))))
                         {
                             // Even if hash/size are the same set the time back to backup time.  This helps with unit testing, but
                             // also presents a pristine version of the database after restore.
@@ -98,9 +100,9 @@ restoreFile(
                             {
                                 THROW_ON_SYS_ERROR_FMT(
                                     utime(
-                                        strPtr(storagePathP(storagePg(), pgFile)),
+                                        strZ(storagePathP(storagePg(), pgFile)),
                                         &((struct utimbuf){.actime = pgFileModified, .modtime = pgFileModified})) == -1,
-                                    FileInfoError, "unable to set time for '%s'", strPtr(storagePathP(storagePg(), pgFile)));
+                                    FileInfoError, "unable to set time for '%s'", strZ(storagePathP(storagePg(), pgFile)));
                             }
 
                             result = false;
@@ -127,8 +129,8 @@ restoreFile(
                 if (pgFileZero)
                 {
                     THROW_ON_SYS_ERROR_FMT(
-                        ftruncate(ioWriteHandle(storageWriteIo(pgFileWrite)), (off_t)pgFileSize) == -1, FileWriteError,
-                        "unable to truncate '%s'", strPtr(pgFile));
+                        ftruncate(ioWriteFd(storageWriteIo(pgFileWrite)), (off_t)pgFileSize) == -1, FileWriteError,
+                        "unable to truncate '%s'", strZ(pgFile));
 
                     // Report the file as not copied
                     result = false;
@@ -164,20 +166,20 @@ restoreFile(
                 // Copy file
                 storageCopyP(
                     storageNewReadP(
-                        storageRepo(),
+                        storageRepoIdx(repoIdx),
                         strNewFmt(
-                            STORAGE_REPO_BACKUP "/%s/%s%s", strPtr(repoFileReference), strPtr(repoFile),
-                            strPtr(compressExtStr(repoFileCompressType))),
+                            STORAGE_REPO_BACKUP "/%s/%s%s", strZ(repoFileReference), strZ(repoFile),
+                            strZ(compressExtStr(repoFileCompressType))),
                         .compressible = compressible),
                     pgFileWrite);
 
                 // Validate checksum
-                if (!strEq(pgFileChecksum, varStr(ioFilterGroupResult(filterGroup, CRYPTO_HASH_FILTER_TYPE_STR))))
+                if (!strEq(pgFileChecksum, pckReadStrP(ioFilterGroupResultP(filterGroup, CRYPTO_HASH_FILTER_TYPE))))
                 {
                     THROW_FMT(
                         ChecksumError,
-                        "error restoring '%s': actual checksum '%s' does not match expected checksum '%s'", strPtr(pgFile),
-                        strPtr(varStr(ioFilterGroupResult(filterGroup, CRYPTO_HASH_FILTER_TYPE_STR))), strPtr(pgFileChecksum));
+                        "error restoring '%s': actual checksum '%s' does not match expected checksum '%s'", strZ(pgFile),
+                        strZ(pckReadStrP(ioFilterGroupResultP(filterGroup, CRYPTO_HASH_FILTER_TYPE))), strZ(pgFileChecksum));
                 }
             }
         }
