@@ -4,25 +4,20 @@ Verify Protocol Handler
 #ifndef COMMAND_VERIFY_PROTOCOL_H
 #define COMMAND_VERIFY_PROTOCOL_H
 
-#include "common/type/string.h"
-#include "common/type/variantList.h"
+#include "common/type/pack.h"
 #include "protocol/server.h"
 
-/***********************************************************************************************************************************
-Constants
-***********************************************************************************************************************************/
-#define PROTOCOL_COMMAND_VERIFY_FILE                                "verifyFile"
-    STRING_DECLARE(PROTOCOL_COMMAND_VERIFY_FILE_STR);
-
 /***********************************************************************************************************************************
 Functions
 ***********************************************************************************************************************************/
 // Process protocol requests
-void verifyFileProtocol(const VariantList *paramList, ProtocolServer *server);
+void verifyFileProtocol(PackRead *param, ProtocolServer *server);
 
 /***********************************************************************************************************************************
 Protocol commands for ProtocolServerHandler arrays passed to protocolServerProcess()
 ***********************************************************************************************************************************/
+#define PROTOCOL_COMMAND_VERIFY_FILE                                STRID5("vf-f", 0x36cd60)
+
 #define PROTOCOL_SERVER_HANDLER_VERIFY_LIST                                                                                        \
     {.command = PROTOCOL_COMMAND_VERIFY_FILE, .handler = verifyFileProtocol},
 
