@@ -172,7 +172,7 @@ verifyFileLoad(const String *pathFileName, const String *cipherPass)
     // *read points to a location within result so update result with contents based on necessary filters
     IoRead *read = storageReadIo(result);
     cipherBlockFilterGroupAdd(
-        ioReadFilterGroup(read), cipherType(cfgOptionStr(cfgOptRepoCipherType)), cipherModeDecrypt, cipherPass);
+        ioReadFilterGroup(read), cfgOptionStrId(cfgOptRepoCipherType), cipherModeDecrypt, cipherPass);
     ioFilterGroupAdd(ioReadFilterGroup(read), cryptoHashNew(HASH_TYPE_SHA1_STR));
 
     // If the file is compressed, add a decompression filter
@@ -219,14 +219,15 @@ verifyInfoFile(const String *pathFileName, bool keepFile, const String *cipherPa
 
             MEM_CONTEXT_PRIOR_BEGIN()
             {
-                result.checksum = strDup(varStr(ioFilterGroupResult(ioReadFilterGroup(infoRead), CRYPTO_HASH_FILTER_TYPE_STR)));
+                result.checksum = strDup(
+                    pckReadStrP(ioFilterGroupResultP(ioReadFilterGroup(infoRead), CRYPTO_HASH_FILTER_TYPE)));
             }
             MEM_CONTEXT_PRIOR_END();
         }
         CATCH_ANY()
         {
             result.errorCode = errorCode();
-            String *errorMsg = strNew(errorMessage());
+            String *errorMsg = strCatZ(strNew(), errorMessage());
 
             if (result.errorCode == errorTypeCode(&ChecksumError))
                 strCat(errorMsg, strNewFmt(" %s", strZ(pathFileName)));
@@ -265,7 +266,7 @@ verifyArchiveInfoFile(void)
             VerifyInfoFile verifyArchiveInfoCopy = verifyInfoFile(
                 INFO_ARCHIVE_PATH_FILE_COPY_STR, false, cfgOptionStrNull(cfgOptRepoCipherPass));
 
-            // If the copy loaded successfuly, then check the checksums
+            // If the copy loaded successfully, then check the checksums
             if (verifyArchiveInfoCopy.errorCode == 0)
             {
                 // If the info and info.copy checksums don't match each other than one (or both) of the files could be corrupt so
@@ -318,7 +319,7 @@ verifyBackupInfoFile(void)
             VerifyInfoFile verifyBackupInfoCopy = verifyInfoFile(
                 INFO_BACKUP_PATH_FILE_COPY_STR, false, cfgOptionStrNull(cfgOptRepoCipherPass));
 
-            // If the copy loaded successfuly, then check the checksums
+            // If the copy loaded successfully, then check the checksums
             if (verifyBackupInfoCopy.errorCode == 0)
             {
                 // If the info and info.copy checksums don't match each other than one (or both) of the files could be corrupt so
@@ -385,7 +386,7 @@ verifyManifestFile(
             VerifyInfoFile verifyManifestInfoCopy = verifyInfoFile(
                 strNewFmt("%s%s", strZ(fileName), INFO_COPY_EXT), false, cipherPass);
 
-            // If the copy loaded successfuly, then check the checksums
+            // If the copy loaded successfully, then check the checksums
             if (verifyManifestInfoCopy.errorCode == 0)
             {
                 // If the manifest and manifest.copy checksums don't match each other than one (or both) of the files could be
@@ -498,7 +499,7 @@ verifyPgHistory(const InfoPg *archiveInfoPg, const InfoPg *backupInfoPg)
         unsigned int archiveInfoHistoryTotal = infoPgDataTotal(archiveInfoPg);
         unsigned int backupInfoHistoryTotal = infoPgDataTotal(backupInfoPg);
 
-        String *errMsg = strNew("archive and backup history lists do not match");
+        String *errMsg = strNewZ("archive and backup history lists do not match");
 
         if (archiveInfoHistoryTotal != backupInfoHistoryTotal)
             THROW(FormatError, strZ(errMsg));
@@ -745,36 +746,31 @@ verifyArchive(void *data)
                 // If there are WAL files, then verify them
                 if (!strLstEmpty(jobData->walFileList))
                 {
-                    do
-                    {
-                        // Get the fully qualified file name and checksum
-                        const String *fileName = strLstGet(jobData->walFileList, 0);
-                        const String *filePathName = strNewFmt(
-                            STORAGE_REPO_ARCHIVE "/%s/%s/%s", strZ(archiveResult->archiveId), strZ(walPath), strZ(fileName));
-                        String *checksum = strSubN(fileName, WAL_SEGMENT_NAME_SIZE + 1, HASH_TYPE_SHA1_SIZE_HEX);
+                    // Get the fully qualified file name and checksum
+                    const String *fileName = strLstGet(jobData->walFileList, 0);
+                    const String *filePathName = strNewFmt(
+                        STORAGE_REPO_ARCHIVE "/%s/%s/%s", strZ(archiveResult->archiveId), strZ(walPath), strZ(fileName));
+                    String *checksum = strSubN(fileName, WAL_SEGMENT_NAME_SIZE + 1, HASH_TYPE_SHA1_SIZE_HEX);
 
-                        // Set up the job
-                        ProtocolCommand *command = protocolCommandNew(PROTOCOL_COMMAND_VERIFY_FILE_STR);
-                        protocolCommandParamAdd(command, VARSTR(filePathName));
-                        protocolCommandParamAdd(command, VARSTR(checksum));
-                        protocolCommandParamAdd(command, VARUINT64(archiveResult->pgWalInfo.size));
-                        protocolCommandParamAdd(command, VARSTR(jobData->walCipherPass));
+                    // Set up the job
+                    ProtocolCommand *command = protocolCommandNew(PROTOCOL_COMMAND_VERIFY_FILE);
+                    PackWrite *const param = protocolCommandParam(command);
 
-                        // Assign job to result, prepending the archiveId to the key for consistency with backup processing
-                        result = protocolParallelJobNew(
-                            VARSTR(strNewFmt("%s/%s", strZ(archiveResult->archiveId), strZ(filePathName))), command);
+                    pckWriteStrP(param, filePathName);
+                    pckWriteStrP(param, checksum);
+                    pckWriteU64P(param, archiveResult->pgWalInfo.size);
+                    pckWriteStrP(param, jobData->walCipherPass);
 
-                        // Remove the file to process from the list
-                        strLstRemoveIdx(jobData->walFileList, 0);
+                    // Assign job to result, prepending the archiveId to the key for consistency with backup processing
+                    result = protocolParallelJobNew(
+                        VARSTR(strNewFmt("%s/%s", strZ(archiveResult->archiveId), strZ(filePathName))), command);
 
-                        // If this is the last file to process for this timeline, then remove the path
-                        if (strLstEmpty(jobData->walFileList))
-                            strLstRemoveIdx(jobData->walPathList, 0);
+                    // Remove the file to process from the list
+                    strLstRemoveIdx(jobData->walFileList, 0);
 
-                        // Return to process the job found
-                        break;
-                    }
-                    while (!strLstEmpty(jobData->walFileList));
+                    // If this is the last file to process for this timeline, then remove the path
+                    if (strLstEmpty(jobData->walFileList))
+                        strLstRemoveIdx(jobData->walPathList, 0);
                 }
                 else
                 {
@@ -829,7 +825,7 @@ verifyBackup(void *data)
     {
         result = NULL;
 
-        // If result list is empty or the last processed is not equal to the backup being processed, then intialize the backup
+        // If result list is empty or the last processed is not equal to the backup being processed, then initialize the backup
         // data and results
         if (lstEmpty(jobData->backupResultList) ||
             !strEq(((VerifyBackupResult *)lstGetLast(jobData->backupResultList))->backupLabel, strLstGet(jobData->backupList, 0)))
@@ -977,13 +973,14 @@ verifyBackup(void *data)
                 if (filePathName != NULL)
                 {
                     // Set up the job
-                    ProtocolCommand *command = protocolCommandNew(PROTOCOL_COMMAND_VERIFY_FILE_STR);
-                    protocolCommandParamAdd(command, VARSTR(filePathName));
+                    ProtocolCommand *command = protocolCommandNew(PROTOCOL_COMMAND_VERIFY_FILE);
+                    PackWrite *const param = protocolCommandParam(command);
 
+                    pckWriteStrP(param, filePathName);
                     // If the checksum is not present in the manifest, it will be calculated by manifest load
-                    protocolCommandParamAdd(command, VARSTRZ(fileData->checksumSha1));
-                    protocolCommandParamAdd(command, VARUINT64(fileData->size));
-                    protocolCommandParamAdd(command, VARSTR(jobData->backupCipherPass));
+                    pckWriteStrP(param, STR(fileData->checksumSha1));
+                    pckWriteU64P(param, fileData->size);
+                    pckWriteStrP(param, jobData->backupCipherPass);
 
                     // Assign job to result (prepend backup label being processed to the key since some files are in a prior backup)
                     result = protocolParallelJobNew(
@@ -1083,7 +1080,7 @@ verifyErrorMsg(VerifyResult verifyResult)
         FUNCTION_TEST_PARAM(ENUM, verifyResult);                    // Result code from the verifyFile() function
     FUNCTION_TEST_END();
 
-    String *result = strNew("");
+    String *result = strNew();
 
     if (verifyResult == verifyFileMissing)
         result = strCatZ(result, "file missing");
@@ -1140,7 +1137,7 @@ verifySetBackupCheckArchive(
         FUNCTION_TEST_PARAM(STRING_LIST, backupList);               // List of backup labels in the backup directory
         FUNCTION_TEST_PARAM(INFO_BACKUP, backupInfo);               // Contents of the backup.info file
         FUNCTION_TEST_PARAM(STRING_LIST, archiveIdList);            // List of archiveIds in the archive directory
-        FUNCTION_TEST_PARAM(INFO_PG, pgHistory);                    // Pointer to InfoPg of archive.info for accesing PG history
+        FUNCTION_TEST_PARAM(INFO_PG, pgHistory);                    // Pointer to InfoPg of archive.info for accessing PG history
         FUNCTION_TEST_PARAM_P(UINT, jobErrorTotal);                 // Pointer to overall job error total
     FUNCTION_TEST_END();
 
@@ -1155,7 +1152,7 @@ verifySetBackupCheckArchive(
             // Get the last backup as current if it is not in backup.info current list
             String *backupLabel = strLstGet(backupList, strLstSize(backupList) - 1);
 
-            if (infoBackupDataByLabel(backupInfo, backupLabel) == NULL)
+            if (!infoBackupLabelExists(backupInfo, backupLabel))
             {
                 // Duplicate the string into the prior context
                 MEM_CONTEXT_PRIOR_BEGIN()
@@ -1177,7 +1174,7 @@ verifySetBackupCheckArchive(
             // Sort the history list
             strLstSort(strLstComparatorSet(archiveIdHistoryList, archiveIdComparator), sortOrderAsc);
 
-            String *missingFromHistory = strNew("");
+            String *missingFromHistory = strNew();
 
             // Check if the archiveId on disk exists in the archive.info history list and report it if not
             for (unsigned int archiveIdx = 0; archiveIdx < strLstSize(archiveIdList); archiveIdx++)
@@ -1207,7 +1204,7 @@ verifySetBackupCheckArchive(
 Add the file to the invalid file list for the range in which it exists
 ***********************************************************************************************************************************/
 static void
-verifyAddInvalidWalFile(List *walRangeList, VerifyResult fileResult, String *fileName, String *walSegment)
+verifyAddInvalidWalFile(List *walRangeList, VerifyResult fileResult, const String *fileName, const String *walSegment)
 {
     FUNCTION_TEST_BEGIN();
         FUNCTION_TEST_PARAM(LIST, walRangeList);                    // List of WAL ranges for an archive Id
@@ -1255,7 +1252,7 @@ verifyRender(List *archiveIdResultList, List *backupResultList)
     ASSERT(archiveIdResultList != NULL);
     ASSERT(backupResultList != NULL);
 
-    String *result = strNew("Results:");
+    String *result = strCatZ(strNew(), "Results:");
 
     // Render archive results
     if (lstEmpty(archiveIdResultList))
@@ -1324,25 +1321,25 @@ verifyRender(List *archiveIdResultList, List *backupResultList)
             {
                 case backupValid:
                 {
-                    status = strNew("valid");
+                    status = strNewZ("valid");
                     break;
                 }
 
                 case backupInvalid:
                 {
-                    status = strNew("invalid");
+                    status = strNewZ("invalid");
                     break;
                 }
 
                 case backupMissingManifest:
                 {
-                    status = strNew("manifest missing");
+                    status = strNewZ("manifest missing");
                     break;
                 }
 
                 case backupInProgress:
                 {
-                    status = strNew("in-progress");
+                    status = strNewZ("in-progress");
                     break;
                 }
             }
@@ -1396,7 +1393,7 @@ verifyProcess(unsigned int *errorTotal)
 
     MEM_CONTEXT_TEMP_BEGIN()
     {
-        String *resultStr = strNew("");
+        String *resultStr = strNew();
 
         // Get the repo storage in case it is remote and encryption settings need to be pulled down
         const Storage *storage = storageRepo();
@@ -1491,119 +1488,127 @@ verifyProcess(unsigned int *errorTotal)
                     protocolParallelClientAdd(parallelExec, protocolLocalGet(protocolStorageTypeRepo, 0, processIdx));
 
                 // Process jobs
-                do
+                MEM_CONTEXT_TEMP_RESET_BEGIN()
                 {
-                    unsigned int completed = protocolParallelProcess(parallelExec);
-
-                    // Process completed jobs
-                    for (unsigned int jobIdx = 0; jobIdx < completed; jobIdx++)
+                    do
                     {
-                        // Get the job and job key
-                        ProtocolParallelJob *job = protocolParallelResult(parallelExec);
-                        unsigned int processId = protocolParallelJobProcessId(job);
-                        StringList *filePathLst = strLstNewSplit(varStr(protocolParallelJobKey(job)), FSLASH_STR);
+                        unsigned int completed = protocolParallelProcess(parallelExec);
 
-                        // Remove the result and file type identifier and recreate the path file name
-                        const String *resultId = strLstGet(filePathLst, 0);
-                        strLstRemoveIdx(filePathLst, 0);
-                        const String *fileType = strLstGet(filePathLst, 0);
-                        strLstRemoveIdx(filePathLst, 0);
-                        String *filePathName = strLstJoin(filePathLst, "/");
-
-                        // Initialize the result sets
-                        VerifyArchiveResult *archiveIdResult = NULL;
-                        VerifyBackupResult *backupResult = NULL;
-
-                        // Get archiveId result data
-                        if (strEq(fileType, STORAGE_REPO_ARCHIVE_STR))
+                        // Process completed jobs
+                        for (unsigned int jobIdx = 0; jobIdx < completed; jobIdx++)
                         {
-                            // Find the archiveId in the list - assert if not found since this should never happen
-                            unsigned int index = lstFindIdx(jobData.archiveIdResultList, &resultId);
-                            ASSERT(index != LIST_NOT_FOUND);
+                            // Get the job and job key
+                            ProtocolParallelJob *job = protocolParallelResult(parallelExec);
+                            unsigned int processId = protocolParallelJobProcessId(job);
+                            StringList *filePathLst = strLstNewSplit(varStr(protocolParallelJobKey(job)), FSLASH_STR);
 
-                            archiveIdResult = lstGet(jobData.archiveIdResultList, index);
-                        }
-                        // Else get the backup result data
-                        else
-                        {
-                            unsigned int index = lstFindIdx(jobData.backupResultList, &resultId);
-                            ASSERT(index != LIST_NOT_FOUND);
+                            // Remove the result and file type identifier and recreate the path file name
+                            const String *resultId = strLstGet(filePathLst, 0);
+                            strLstRemoveIdx(filePathLst, 0);
+                            const String *fileType = strLstGet(filePathLst, 0);
+                            strLstRemoveIdx(filePathLst, 0);
+                            String *filePathName = strLstJoin(filePathLst, "/");
 
-                            backupResult = lstGet(jobData.backupResultList, index);
-                        }
+                            // Initialize the result sets
+                            VerifyArchiveResult *archiveIdResult = NULL;
+                            VerifyBackupResult *backupResult = NULL;
 
-                        // The job was successful
-                        if (protocolParallelJobErrorCode(job) == 0)
-                        {
-                            const VerifyResult verifyResult = (VerifyResult)varUIntForce(protocolParallelJobResult(job));
-
-                            // Update the result set for the type of file being processed
+                            // Get archiveId result data
                             if (strEq(fileType, STORAGE_REPO_ARCHIVE_STR))
                             {
-                                if (verifyResult == verifyOk)
-                                    archiveIdResult->totalValidWal++;
+                                // Find the archiveId in the list - assert if not found since this should never happen
+                                unsigned int index = lstFindIdx(jobData.archiveIdResultList, &resultId);
+                                ASSERT(index != LIST_NOT_FOUND);
+
+                                archiveIdResult = lstGet(jobData.archiveIdResultList, index);
+                            }
+                            // Else get the backup result data
+                            else
+                            {
+                                unsigned int index = lstFindIdx(jobData.backupResultList, &resultId);
+                                ASSERT(index != LIST_NOT_FOUND);
+
+                                backupResult = lstGet(jobData.backupResultList, index);
+                            }
+
+                            // The job was successful
+                            if (protocolParallelJobErrorCode(job) == 0)
+                            {
+                                const VerifyResult verifyResult = (VerifyResult)pckReadU32P(protocolParallelJobResult(job));
+
+                                // Update the result set for the type of file being processed
+                                if (strEq(fileType, STORAGE_REPO_ARCHIVE_STR))
+                                {
+                                    if (verifyResult == verifyOk)
+                                        archiveIdResult->totalValidWal++;
+                                    else
+                                    {
+                                        jobData.jobErrorTotal += verifyLogInvalidResult(
+                                            fileType, verifyResult, processId, filePathName);
+
+                                        // Add invalid file to the WAL range
+                                        verifyAddInvalidWalFile(
+                                            archiveIdResult->walRangeList, verifyResult, filePathName,
+                                            strSubN(strLstGet(filePathLst, strLstSize(filePathLst) - 1), 0,
+                                            WAL_SEGMENT_NAME_SIZE));
+                                    }
+                                }
                                 else
                                 {
-                                    jobData.jobErrorTotal += verifyLogInvalidResult(
-                                        fileType, verifyResult, processId, filePathName);
+                                    if (verifyResult == verifyOk)
+                                        backupResult->totalFileValid++;
+                                    else
+                                    {
+                                        jobData.jobErrorTotal += verifyLogInvalidResult(
+                                            fileType, verifyResult, processId, filePathName);
+                                        backupResult->status = backupInvalid;
+                                        verifyInvalidFileAdd(backupResult->invalidFileList, verifyResult, filePathName);
+                                    }
+                                }
+                            }
+                            // Else the job errored
+                            else
+                            {
+                                // Log a protocol error and increment the jobErrorTotal
+                                LOG_ERROR_PID_FMT(
+                                    processId, errorTypeCode(&ProtocolError),
+                                    "%s %s: [%d] %s", strZ(verifyErrorMsg(verifyOtherError)), strZ(filePathName),
+                                    protocolParallelJobErrorCode(job), strZ(protocolParallelJobErrorMessage(job)));
 
+                                jobData.jobErrorTotal++;
+
+                                // Add invalid file with "OtherError" reason to invalid file list
+                                if (strEq(fileType, STORAGE_REPO_ARCHIVE_STR))
+                                {
                                     // Add invalid file to the WAL range
                                     verifyAddInvalidWalFile(
-                                        archiveIdResult->walRangeList, verifyResult, filePathName,
+                                        archiveIdResult->walRangeList, verifyOtherError, filePathName,
                                         strSubN(strLstGet(filePathLst, strLstSize(filePathLst) - 1), 0, WAL_SEGMENT_NAME_SIZE));
                                 }
-                            }
-                            else
-                            {
-                                if (verifyResult == verifyOk)
-                                    backupResult->totalFileValid++;
                                 else
                                 {
-                                    jobData.jobErrorTotal += verifyLogInvalidResult(
-                                        fileType, verifyResult, processId, filePathName);
                                     backupResult->status = backupInvalid;
-                                    verifyInvalidFileAdd(backupResult->invalidFileList, verifyResult, filePathName);
+                                    verifyInvalidFileAdd(backupResult->invalidFileList, verifyOtherError, filePathName);
                                 }
                             }
-                        }
-                        // Else the job errored
-                        else
-                        {
-                            // Log a protocol error and increment the jobErrorTotal
-                            LOG_ERROR_PID_FMT(
-                                processId, errorTypeCode(&ProtocolError),
-                                "%s %s: [%d] %s", strZ(verifyErrorMsg(verifyOtherError)), strZ(filePathName),
-                                protocolParallelJobErrorCode(job), strZ(protocolParallelJobErrorMessage(job)));
 
-                            jobData.jobErrorTotal++;
-
-                            // Add invalid file with "OtherError" reason to invalid file list
-                            if (strEq(fileType, STORAGE_REPO_ARCHIVE_STR))
+                            // Set backup verification complete for a backup if all files have run through verification
+                            if (strEq(fileType, STORAGE_REPO_BACKUP_STR) &&
+                                backupResult->totalFileVerify == backupResult->totalFileManifest)
                             {
-                                // Add invalid file to the WAL range
-                                verifyAddInvalidWalFile(
-                                    archiveIdResult->walRangeList, verifyOtherError, filePathName,
-                                    strSubN(strLstGet(filePathLst, strLstSize(filePathLst) - 1), 0, WAL_SEGMENT_NAME_SIZE));
-                            }
-                            else
-                            {
-                                backupResult->status = backupInvalid;
-                                verifyInvalidFileAdd(backupResult->invalidFileList, verifyOtherError, filePathName);
+                                backupResult->fileVerifyComplete = true;
                             }
+
+                            // Free the job
+                            protocolParallelJobFree(job);
                         }
 
-                        // Set backup verification complete for a backup if all files have run through verification
-                        if (strEq(fileType, STORAGE_REPO_BACKUP_STR) &&
-                            backupResult->totalFileVerify == backupResult->totalFileManifest)
-                        {
-                            backupResult->fileVerifyComplete = true;
-                        }
-
-                        // Free the job
-                        protocolParallelJobFree(job);
+                        // Reset the memory context occasionally so we don't use too much memory or slow down processing
+                        MEM_CONTEXT_TEMP_RESET(1000);
                     }
+                    while (!protocolParallelDone(parallelExec));
                 }
-                while (!protocolParallelDone(parallelExec));
+                MEM_CONTEXT_TEMP_END();
 
                 // ??? Need to do the final reconciliation - checking backup required WAL against, valid WAL
 
