@@ -9,25 +9,17 @@ BZ2 Compress
 #include "common/compress/bz2/common.h"
 #include "common/compress/bz2/compress.h"
 #include "common/debug.h"
-#include "common/io/filter/filter.intern.h"
+#include "common/io/filter/filter.h"
 #include "common/log.h"
-#include "common/memContext.h"
+#include "common/macro.h"
 #include "common/type/object.h"
-
-/***********************************************************************************************************************************
-Filter type constant
-***********************************************************************************************************************************/
-STRING_EXTERN(BZ2_COMPRESS_FILTER_TYPE_STR,                         BZ2_COMPRESS_FILTER_TYPE);
+#include "common/type/pack.h"
 
 /***********************************************************************************************************************************
 Object type
 ***********************************************************************************************************************************/
-#define BZ2_COMPRESS_TYPE                                           Bz2Compress
-#define BZ2_COMPRESS_PREFIX                                         bz2Compress
-
 typedef struct Bz2Compress
 {
-    MemContext *memContext;                                         // Context to store data
     bz_stream stream;                                               // Compression stream
 
     bool inputSame;                                                 // Is the same input required on the next process call?
@@ -54,11 +46,21 @@ bz2CompressToLog(const Bz2Compress *this)
 /***********************************************************************************************************************************
 Free compression stream
 ***********************************************************************************************************************************/
-OBJECT_DEFINE_FREE_RESOURCE_BEGIN(BZ2_COMPRESS, LOG, logLevelTrace)
+static void
+bz2CompressFreeResource(THIS_VOID)
 {
+    THIS(Bz2Compress);
+
+    FUNCTION_LOG_BEGIN(logLevelTrace);
+        FUNCTION_LOG_PARAM(BZ2_COMPRESS, this);
+    FUNCTION_LOG_END();
+
+    ASSERT(this != NULL);
+
     BZ2_bzCompressEnd(&this->stream);
+
+    FUNCTION_LOG_RETURN_VOID();
 }
-OBJECT_DEFINE_FREE_RESOURCE_END(LOG);
 
 /***********************************************************************************************************************************
 Compress data
@@ -165,13 +167,12 @@ bz2CompressNew(int level)
 
     IoFilter *this = NULL;
 
-    MEM_CONTEXT_NEW_BEGIN("Bz2Compress")
+    OBJ_NEW_BEGIN(Bz2Compress)
     {
-        Bz2Compress *driver = memNew(sizeof(Bz2Compress));
+        Bz2Compress *driver = OBJ_NEW_ALLOC();
 
         *driver = (Bz2Compress)
         {
-            .memContext = MEM_CONTEXT_NEW(),
             .stream = {.bzalloc = NULL},
         };
 
@@ -179,18 +180,28 @@ bz2CompressNew(int level)
         bz2Error(BZ2_bzCompressInit(&driver->stream, level, 0, 0));
 
         // Set callback to ensure bz2 stream is freed
-        memContextCallbackSet(driver->memContext, bz2CompressFreeResource, driver);
+        memContextCallbackSet(objMemContext(driver), bz2CompressFreeResource, driver);
 
         // Create param list
-        VariantList *paramList = varLstNew();
-        varLstAdd(paramList, varNewInt(level));
+        Pack *paramList = NULL;
+
+        MEM_CONTEXT_TEMP_BEGIN()
+        {
+            PackWrite *const packWrite = pckWriteNewP();
+
+            pckWriteI32P(packWrite, level);
+            pckWriteEndP(packWrite);
+
+            paramList = pckMove(pckWriteResult(packWrite), memContextPrior());
+        }
+        MEM_CONTEXT_TEMP_END();
 
         // Create filter interface
         this = ioFilterNewP(
-            BZ2_COMPRESS_FILTER_TYPE_STR, driver, paramList, .done = bz2CompressDone, .inOut = bz2CompressProcess,
+            BZ2_COMPRESS_FILTER_TYPE, driver, paramList, .done = bz2CompressDone, .inOut = bz2CompressProcess,
             .inputSame = bz2CompressInputSame);
     }
-    MEM_CONTEXT_NEW_END();
+    OBJ_NEW_END();
 
     FUNCTION_LOG_RETURN(IO_FILTER, this);
 }
