@@ -11,8 +11,7 @@ Compress IO to the bz2 format.
 /***********************************************************************************************************************************
 Filter type constant
 ***********************************************************************************************************************************/
-#define BZ2_COMPRESS_FILTER_TYPE                                    "bz2Compress"
-    STRING_DECLARE(BZ2_COMPRESS_FILTER_TYPE_STR);
+#define BZ2_COMPRESS_FILTER_TYPE                                    STRID5("bz2-cmp", 0x41a3df3420)
 
 /***********************************************************************************************************************************
 Constructors
