@@ -11,8 +11,7 @@ Decompress IO from the bz2 format.
 /***********************************************************************************************************************************
 Filter type constant
 ***********************************************************************************************************************************/
-#define BZ2_DECOMPRESS_FILTER_TYPE                                   "bz2Decompress"
-    STRING_DECLARE(BZ2_DECOMPRESS_FILTER_TYPE_STR);
+#define BZ2_DECOMPRESS_FILTER_TYPE                                   STRID5("bz2-dcmp", 0x83464df3420)
 
 /***********************************************************************************************************************************
 Constructors
