@@ -9,25 +9,16 @@ Gz Decompress
 #include "common/compress/gz/common.h"
 #include "common/compress/gz/decompress.h"
 #include "common/debug.h"
-#include "common/io/filter/filter.intern.h"
+#include "common/io/filter/filter.h"
 #include "common/log.h"
-#include "common/memContext.h"
+#include "common/macro.h"
 #include "common/type/object.h"
 
-/***********************************************************************************************************************************
-Filter type constant
-***********************************************************************************************************************************/
-STRING_EXTERN(GZ_DECOMPRESS_FILTER_TYPE_STR,                        GZ_DECOMPRESS_FILTER_TYPE);
-
 /***********************************************************************************************************************************
 Object type
 ***********************************************************************************************************************************/
-#define GZ_DECOMPRESS_TYPE                                          GzDecompress
-#define GZ_DECOMPRESS_PREFIX                                        gzDecompress
-
 typedef struct GzDecompress
 {
-    MemContext *memContext;                                         // Context to store data
     z_stream stream;                                                // Decompression stream state
 
     int result;                                                     // Result of last operation
@@ -54,11 +45,21 @@ gzDecompressToLog(const GzDecompress *this)
 /***********************************************************************************************************************************
 Free inflate stream
 ***********************************************************************************************************************************/
-OBJECT_DEFINE_FREE_RESOURCE_BEGIN(GZ_DECOMPRESS, LOG, logLevelTrace)
+static void
+gzDecompressFreeResource(THIS_VOID)
 {
+    THIS(GzDecompress);
+
+    FUNCTION_LOG_BEGIN(logLevelTrace);
+        FUNCTION_LOG_PARAM(GZ_DECOMPRESS, this);
+    FUNCTION_LOG_END();
+
+    ASSERT(this != NULL);
+
     inflateEnd(&this->stream);
+
+    FUNCTION_LOG_RETURN_VOID();
 }
-OBJECT_DEFINE_FREE_RESOURCE_END(LOG);
 
 /***********************************************************************************************************************************
 Decompress data
@@ -149,14 +150,13 @@ gzDecompressNew(void)
 
     IoFilter *this = NULL;
 
-    MEM_CONTEXT_NEW_BEGIN("GzDecompress")
+    OBJ_NEW_BEGIN(GzDecompress)
     {
         // Allocate state and set context
-        GzDecompress *driver = memNew(sizeof(GzDecompress));
+        GzDecompress *driver = OBJ_NEW_ALLOC();
 
         *driver = (GzDecompress)
         {
-            .memContext = MEM_CONTEXT_NEW(),
             .stream = {.zalloc = NULL},
         };
 
@@ -164,14 +164,14 @@ gzDecompressNew(void)
         gzError(driver->result = inflateInit2(&driver->stream, WANT_GZ | WINDOW_BITS));
 
         // Set free callback to ensure gz context is freed
-        memContextCallbackSet(driver->memContext, gzDecompressFreeResource, driver);
+        memContextCallbackSet(objMemContext(driver), gzDecompressFreeResource, driver);
 
         // Create filter interface
         this = ioFilterNewP(
-            GZ_DECOMPRESS_FILTER_TYPE_STR, driver, NULL, .done = gzDecompressDone, .inOut = gzDecompressProcess,
+            GZ_DECOMPRESS_FILTER_TYPE, driver, NULL, .done = gzDecompressDone, .inOut = gzDecompressProcess,
             .inputSame = gzDecompressInputSame);
     }
-    MEM_CONTEXT_NEW_END();
+    OBJ_NEW_END();
 
     FUNCTION_LOG_RETURN(IO_FILTER, this);
 }
