@@ -11,8 +11,7 @@ Decompress IO from the gz format.
 /***********************************************************************************************************************************
 Filter type constant
 ***********************************************************************************************************************************/
-#define GZ_DECOMPRESS_FILTER_TYPE                                   "gzDecompress"
-    STRING_DECLARE(GZ_DECOMPRESS_FILTER_TYPE_STR);
+#define GZ_DECOMPRESS_FILTER_TYPE                                   STRID5("gz-dcmp", 0x41a326f470)
 
 /***********************************************************************************************************************************
 Constructors
