@@ -14,10 +14,10 @@ Developed against version r131 using the documentation in https://github.com/lz4
 #include "common/compress/lz4/common.h"
 #include "common/compress/lz4/compress.h"
 #include "common/debug.h"
-#include "common/io/filter/filter.intern.h"
+#include "common/io/filter/filter.h"
 #include "common/log.h"
-#include "common/memContext.h"
 #include "common/type/object.h"
+#include "common/type/pack.h"
 
 /***********************************************************************************************************************************
 Older versions of lz4 do not define the max header size.  This seems to be the max for any version.
@@ -26,20 +26,11 @@ Older versions of lz4 do not define the max header size.  This seems to be the m
     #define LZ4F_HEADER_SIZE_MAX                                    19
 #endif
 
-/***********************************************************************************************************************************
-Filter type constant
-***********************************************************************************************************************************/
-STRING_EXTERN(LZ4_COMPRESS_FILTER_TYPE_STR,                         LZ4_COMPRESS_FILTER_TYPE);
-
 /***********************************************************************************************************************************
 Object type
 ***********************************************************************************************************************************/
-#define LZ4_COMPRESS_TYPE                                           Lz4Compress
-#define LZ4_COMPRESS_PREFIX                                         lz4Compress
-
 typedef struct Lz4Compress
 {
-    MemContext *memContext;                                         // Context to store data
     LZ4F_compressionContext_t context;                              // LZ4 compression context
     LZ4F_preferences_t prefs;                                       // Preferences -- just compress level set
     IoFilter *filter;                                               // Filter interface
@@ -69,11 +60,21 @@ lz4CompressToLog(const Lz4Compress *this)
 /***********************************************************************************************************************************
 Free compression context
 ***********************************************************************************************************************************/
-OBJECT_DEFINE_FREE_RESOURCE_BEGIN(LZ4_COMPRESS, LOG, logLevelTrace)
+static void
+lz4CompressFreeResource(THIS_VOID)
 {
+    THIS(Lz4Compress);
+
+    FUNCTION_LOG_BEGIN(logLevelTrace);
+        FUNCTION_LOG_PARAM(LZ4_COMPRESS, this);
+    FUNCTION_LOG_END();
+
+    ASSERT(this != NULL);
+
     LZ4F_freeCompressionContext(this->context);
+
+    FUNCTION_LOG_RETURN_VOID();
 }
-OBJECT_DEFINE_FREE_RESOURCE_END(LOG);
 
 /***********************************************************************************************************************************
 Compress data
@@ -252,13 +253,12 @@ lz4CompressNew(int level)
 
     IoFilter *this = NULL;
 
-    MEM_CONTEXT_NEW_BEGIN("Lz4Compress")
+    OBJ_NEW_BEGIN(Lz4Compress)
     {
-        Lz4Compress *driver = memNew(sizeof(Lz4Compress));
+        Lz4Compress *driver = OBJ_NEW_ALLOC();
 
         *driver = (Lz4Compress)
         {
-            .memContext = MEM_CONTEXT_NEW(),
             .prefs = {.compressionLevel = level, .frameInfo = {.contentChecksumFlag = LZ4F_contentChecksumEnabled}},
             .first = true,
             .buffer = bufNew(0),
@@ -268,18 +268,28 @@ lz4CompressNew(int level)
         lz4Error(LZ4F_createCompressionContext(&driver->context, LZ4F_VERSION));
 
         // Set callback to ensure lz4 context is freed
-        memContextCallbackSet(driver->memContext, lz4CompressFreeResource, driver);
+        memContextCallbackSet(objMemContext(driver), lz4CompressFreeResource, driver);
 
         // Create param list
-        VariantList *paramList = varLstNew();
-        varLstAdd(paramList, varNewInt(level));
+        Pack *paramList = NULL;
+
+        MEM_CONTEXT_TEMP_BEGIN()
+        {
+            PackWrite *const packWrite = pckWriteNewP();
+
+            pckWriteI32P(packWrite, level);
+            pckWriteEndP(packWrite);
+
+            paramList = pckMove(pckWriteResult(packWrite), memContextPrior());
+        }
+        MEM_CONTEXT_TEMP_END();
 
         // Create filter interface
         this = ioFilterNewP(
-            LZ4_COMPRESS_FILTER_TYPE_STR, driver, paramList, .done = lz4CompressDone, .inOut = lz4CompressProcess,
+            LZ4_COMPRESS_FILTER_TYPE, driver, paramList, .done = lz4CompressDone, .inOut = lz4CompressProcess,
             .inputSame = lz4CompressInputSame);
     }
-    MEM_CONTEXT_NEW_END();
+    OBJ_NEW_END();
 
     FUNCTION_LOG_RETURN(IO_FILTER, this);
 }
