@@ -13,8 +13,7 @@ Decompress IO from the lz4 format.
 /***********************************************************************************************************************************
 Filter type constant
 ***********************************************************************************************************************************/
-#define LZ4_DECOMPRESS_FILTER_TYPE                                  "lz4Decompress"
-    STRING_DECLARE(LZ4_DECOMPRESS_FILTER_TYPE_STR);
+#define LZ4_DECOMPRESS_FILTER_TYPE                                  STRID6("lz4-dcmp", 0x40d0c46e068c1)
 
 /***********************************************************************************************************************************
 Constructors
