@@ -13,8 +13,7 @@ Compress IO to the zst format.
 /***********************************************************************************************************************************
 Filter type constant
 ***********************************************************************************************************************************/
-#define ZST_COMPRESS_FILTER_TYPE                                    "zstCompress"
-    STRING_DECLARE(ZST_COMPRESS_FILTER_TYPE_STR);
+#define ZST_COMPRESS_FILTER_TYPE                                    STRID5("zst-cmp", 0x41a3dd27a0)
 
 /***********************************************************************************************************************************
 Constructors
