@@ -11,16 +11,10 @@ Block Cipher
 #include "common/crypto/cipherBlock.h"
 #include "common/crypto/common.h"
 #include "common/debug.h"
-#include "common/io/filter/filter.intern.h"
+#include "common/io/filter/filter.h"
 #include "common/log.h"
-#include "common/memContext.h"
 #include "common/type/object.h"
 
-/***********************************************************************************************************************************
-Filter type constant
-***********************************************************************************************************************************/
-STRING_EXTERN(CIPHER_BLOCK_FILTER_TYPE_STR,                         CIPHER_BLOCK_FILTER_TYPE);
-
 /***********************************************************************************************************************************
 Header constants and sizes
 ***********************************************************************************************************************************/
@@ -35,12 +29,8 @@ Header constants and sizes
 /***********************************************************************************************************************************
 Object type
 ***********************************************************************************************************************************/
-#define CIPHER_BLOCK_TYPE                                           CipherBlock
-#define CIPHER_BLOCK_PREFIX                                         cipherBlock
-
 typedef struct CipherBlock
 {
-    MemContext *memContext;                                         // Context to store data
     CipherMode mode;                                                // Mode encrypt/decrypt
     bool saltDone;                                                  // Has the salt been read/generated?
     bool processDone;                                               // Has any data been processed?
@@ -75,11 +65,21 @@ cipherBlockToLog(const CipherBlock *this)
 /***********************************************************************************************************************************
 Free cipher context
 ***********************************************************************************************************************************/
-OBJECT_DEFINE_FREE_RESOURCE_BEGIN(CIPHER_BLOCK, LOG, logLevelTrace)
+static void
+cipherBlockFreeResource(THIS_VOID)
 {
+    THIS(CipherBlock);
+
+    FUNCTION_LOG_BEGIN(logLevelTrace);
+        FUNCTION_LOG_PARAM(CIPHER_BLOCK, this);
+    FUNCTION_LOG_END();
+
+    ASSERT(this != NULL);
+
     EVP_CIPHER_CTX_free(this->cipherContext);
+
+    FUNCTION_LOG_RETURN_VOID();
 }
-OBJECT_DEFINE_FREE_RESOURCE_END(LOG);
 
 /***********************************************************************************************************************************
 Determine how large the destination buffer should be
@@ -187,7 +187,7 @@ cipherBlockProcessBlock(CipherBlock *this, const unsigned char *source, size_t s
             cryptoError(!(this->cipherContext = EVP_CIPHER_CTX_new()), "unable to create context");
 
             // Set free callback to ensure cipher context is freed
-            memContextCallbackSet(this->memContext, cipherBlockFreeResource, this);
+            memContextCallbackSet(objMemContext(this), cipherBlockFreeResource, this);
 
             // Initialize cipher
             cryptoError(
@@ -299,7 +299,7 @@ cipherBlockProcess(THIS_VOID, const Buffer *source, Buffer *destination)
         if (destinationSize > bufRemains(destination))
         {
             // Allocate the buffer if needed
-            MEM_CONTEXT_BEGIN(this->memContext)
+            MEM_CONTEXT_BEGIN(objMemContext(this))
             {
                 if (this->buffer == NULL)
                 {
@@ -385,8 +385,8 @@ IoFilter *
 cipherBlockNew(CipherMode mode, CipherType cipherType, const Buffer *pass, const String *digestName)
 {
     FUNCTION_LOG_BEGIN(logLevelTrace);
-        FUNCTION_LOG_PARAM(ENUM, mode);
-        FUNCTION_LOG_PARAM(ENUM, cipherType);
+        FUNCTION_LOG_PARAM(STRING_ID, mode);
+        FUNCTION_LOG_PARAM(STRING_ID, cipherType);
         FUNCTION_TEST_PARAM(BUFFER, pass);                          // Use FUNCTION_TEST so passphrase is not logged
         FUNCTION_LOG_PARAM(STRING, digestName);
     FUNCTION_LOG_END();
@@ -399,10 +399,10 @@ cipherBlockNew(CipherMode mode, CipherType cipherType, const Buffer *pass, const
 
     // Lookup cipher by name.  This means the ciphers passed in must exactly match a name expected by OpenSSL.  This is a good
     // thing since the name required by the openssl command-line tool will match what is used by pgBackRest.
-    const EVP_CIPHER *cipher = EVP_get_cipherbyname(strZ(cipherTypeName(cipherType)));
+    const EVP_CIPHER *cipher = EVP_get_cipherbyname(strZ(strIdToStr(cipherType)));
 
     if (!cipher)
-        THROW_FMT(AssertError, "unable to load cipher '%s'", strZ(cipherTypeName(cipherType)));
+        THROW_FMT(AssertError, "unable to load cipher '%s'", strZ(strIdToStr(cipherType)));
 
     // Lookup digest.  If not defined it will be set to sha1.
     const EVP_MD *digest = NULL;
@@ -418,13 +418,12 @@ cipherBlockNew(CipherMode mode, CipherType cipherType, const Buffer *pass, const
     // Allocate memory to hold process state
     IoFilter *this = NULL;
 
-    MEM_CONTEXT_NEW_BEGIN("CipherBlock")
+    OBJ_NEW_BEGIN(CipherBlock)
     {
-        CipherBlock *driver = memNew(sizeof(CipherBlock));
+        CipherBlock *driver = OBJ_NEW_ALLOC();
 
         *driver = (CipherBlock)
         {
-            .memContext = MEM_CONTEXT_NEW(),
             .mode = mode,
             .cipher = cipher,
             .digest = digest,
@@ -436,30 +435,50 @@ cipherBlockNew(CipherMode mode, CipherType cipherType, const Buffer *pass, const
         memcpy(driver->pass, bufPtrConst(pass), driver->passSize);
 
         // Create param list
-        VariantList *paramList = varLstNew();
-        varLstAdd(paramList, varNewUInt(mode));
-        varLstAdd(paramList, varNewUInt(cipherType));
-        // ??? Using a string here is not correct since the passphrase is being passed as a buffer so may contain null characters.
-        // However, since strings are used to hold the passphrase in the rest of the code this is currently valid.
-        varLstAdd(paramList, varNewStr(strNewBuf(pass)));
-        varLstAdd(paramList, digestName ? varNewStr(digestName) : NULL);
+        Pack *paramList = NULL;
+
+        MEM_CONTEXT_TEMP_BEGIN()
+        {
+            PackWrite *const packWrite = pckWriteNewP();
+
+            pckWriteU64P(packWrite, mode);
+            pckWriteU64P(packWrite, cipherType);
+            pckWriteBinP(packWrite, pass);
+            pckWriteStrP(packWrite, digestName);
+            pckWriteEndP(packWrite);
+
+            paramList = pckMove(pckWriteResult(packWrite), memContextPrior());
+        }
+        MEM_CONTEXT_TEMP_END();
 
         // Create filter interface
         this = ioFilterNewP(
-            CIPHER_BLOCK_FILTER_TYPE_STR, driver, paramList, .done = cipherBlockDone, .inOut = cipherBlockProcess,
+            CIPHER_BLOCK_FILTER_TYPE, driver, paramList, .done = cipherBlockDone, .inOut = cipherBlockProcess,
             .inputSame = cipherBlockInputSame);
     }
-    MEM_CONTEXT_NEW_END();
+    OBJ_NEW_END();
 
     FUNCTION_LOG_RETURN(IO_FILTER, this);
 }
 
 IoFilter *
-cipherBlockNewVar(const VariantList *paramList)
+cipherBlockNewPack(const Pack *const paramList)
 {
-    return cipherBlockNew(
-        (CipherMode)varUIntForce(varLstGet(paramList, 0)), (CipherType)varUIntForce(varLstGet(paramList, 1)),
-        BUFSTR(varStr(varLstGet(paramList, 2))), varLstGet(paramList, 3) == NULL ? NULL : varStr(varLstGet(paramList, 3)));
+    IoFilter *result = NULL;
+
+    MEM_CONTEXT_TEMP_BEGIN()
+    {
+        PackRead *const paramListPack = pckReadNew(paramList);
+        const CipherMode cipherMode = (CipherMode)pckReadU64P(paramListPack);
+        const CipherType cipherType = (CipherType)pckReadU64P(paramListPack);
+        const Buffer *const pass = pckReadBinP(paramListPack);
+        const String *const digestName = pckReadStrP(paramListPack);
+
+        result = ioFilterMove(cipherBlockNew(cipherMode, cipherType, pass, digestName), memContextPrior());
+    }
+    MEM_CONTEXT_TEMP_END();
+
+    return result;
 }
 
 /**********************************************************************************************************************************/
@@ -468,8 +487,8 @@ cipherBlockFilterGroupAdd(IoFilterGroup *filterGroup, CipherType type, CipherMod
 {
     FUNCTION_LOG_BEGIN(logLevelTrace);
         FUNCTION_LOG_PARAM(IO_FILTER_GROUP, filterGroup);
-        FUNCTION_LOG_PARAM(ENUM, type);
-        FUNCTION_LOG_PARAM(ENUM, mode);
+        FUNCTION_LOG_PARAM(STRING_ID, type);
+        FUNCTION_LOG_PARAM(STRING_ID, mode);
         FUNCTION_TEST_PARAM(STRING, pass);                          // Use FUNCTION_TEST so passphrase is not logged
     FUNCTION_LOG_END();
 
