@@ -7,24 +7,7 @@ Debug Routines
 #include "common/assert.h"
 #include "common/stackTrace.h"
 #include "common/type/convert.h"
-#include "common/type/stringz.h"
-
-/***********************************************************************************************************************************
-NDEBUG indicates to C library routines that debugging is off -- set a more readable flag to use when debugging is on
-***********************************************************************************************************************************/
-#ifndef NDEBUG
-    #define DEBUG
-#endif
-
-/***********************************************************************************************************************************
-Extern variables that are needed for unit testing
-***********************************************************************************************************************************/
-#ifdef DEBUG_UNIT
-    #define DEBUG_UNIT_EXTERN
-#else
-    #define DEBUG_UNIT_EXTERN                                                                                                      \
-        static
-#endif
+#include "common/type/stringZ.h"
 
 /***********************************************************************************************************************************
 Base function debugging macros
@@ -296,16 +279,25 @@ Function Test Macros
 In debug builds these macros will update the stack trace with function names and parameters but will not log. In production builds
 all test macros are compiled out (except for return statements).
 
-Ignore DEBUG_TEST_TRACE_MACRO if NDEBUG is defined because the underlying functions that support the macros will not be present.
+Ignore DEBUG_TEST_TRACE_MACRO if DEBUG is not defined because the underlying functions that support the macros will not be present.
 ***********************************************************************************************************************************/
-#ifndef NDEBUG
+#ifdef DEBUG
 #ifdef DEBUG_TEST_TRACE
     #define DEBUG_TEST_TRACE_MACRO
 #endif // DEBUG_TEST_TRACE
-#endif // NDEBUG
+#endif // DEBUG
 
 #ifdef DEBUG_TEST_TRACE_MACRO
     #define FUNCTION_TEST_BEGIN()                                                                                                  \
+        /* Ensure that FUNCTION_LOG_BEGIN() and FUNCTION_TEST_BEGIN() are not both used in a single function by declaring the */   \
+        /* same variable that FUNCTION_LOG_BEGIN() uses to track logging */                                                        \
+        LogLevel FUNCTION_LOG_LEVEL();                                                                                             \
+        (void)FUNCTION_LOG_LEVEL();                                                                                                \
+                                                                                                                                   \
+        /* Ensure that FUNCTION_TEST_RETURN*() is not used with FUNCTION_LOG_BEGIN*() by declaring a variable that will be */      \
+        /* referenced in FUNCTION_TEST_RETURN*() */                                                                                \
+        bool FUNCTION_TEST_BEGIN_exists;                                                                                           \
+                                                                                                                                   \
         if (stackTraceTest())                                                                                                      \
         {                                                                                                                          \
             STACK_TRACE_PUSH(logLevelDebug);                                                                                       \
@@ -322,6 +314,9 @@ Ignore DEBUG_TEST_TRACE_MACRO if NDEBUG is defined because the underlying functi
         FUNCTION_LOG_PARAM_PP(typeName, param)
 
     #define FUNCTION_TEST_END()                                                                                                    \
+            /* CHECK for presense of FUNCTION_TEST_BEGIN*() */                                                                     \
+            (void)FUNCTION_TEST_BEGIN_exists;                                                                                      \
+                                                                                                                                   \
             stackTraceTestStart();                                                                                                 \
         }
 
@@ -332,13 +327,23 @@ Ignore DEBUG_TEST_TRACE_MACRO if NDEBUG is defined because the underlying functi
     #define FUNCTION_TEST_RETURN(result)                                                                                           \
         do                                                                                                                         \
         {                                                                                                                          \
+            /* CHECK for presense of FUNCTION_TEST_BEGIN*() */                                                                     \
+            (void)FUNCTION_TEST_BEGIN_exists;                                                                                      \
+                                                                                                                                   \
             STACK_TRACE_POP(true);                                                                                                 \
             return result;                                                                                                         \
         }                                                                                                                          \
         while (0)
 
     #define FUNCTION_TEST_RETURN_VOID()                                                                                            \
-        STACK_TRACE_POP(true)
+        do                                                                                                                         \
+        {                                                                                                                          \
+            /* CHECK for presense of FUNCTION_TEST_BEGIN*() */                                                                     \
+            (void)FUNCTION_TEST_BEGIN_exists;                                                                                      \
+                                                                                                                                   \
+            STACK_TRACE_POP(true);                                                                                                 \
+        }                                                                                                                          \
+        while (0)
 #else
     #define FUNCTION_TEST_BEGIN()
     #define FUNCTION_TEST_PARAM(typeMacroPrefix, param)
