@@ -8,25 +8,19 @@ Ini Handler
 #include <string.h>
 
 #include "common/debug.h"
-#include "common/memContext.h"
 #include "common/log.h"
 #include "common/ini.h"
 #include "common/type/json.h"
 #include "common/type/keyValue.h"
-#include "common/type/object.h"
 
 /***********************************************************************************************************************************
 Object type
 ***********************************************************************************************************************************/
 struct Ini
 {
-    MemContext *memContext;                                         // Context that contains the ini
     KeyValue *store;                                                // Key value store that contains the ini data
 };
 
-OBJECT_DEFINE_MOVE(INI);
-OBJECT_DEFINE_FREE(INI);
-
 /**********************************************************************************************************************************/
 Ini *
 iniNew(void)
@@ -35,17 +29,16 @@ iniNew(void)
 
     Ini *this = NULL;
 
-    MEM_CONTEXT_NEW_BEGIN("Ini")
+    OBJ_NEW_BEGIN(Ini)
     {
-        this = memNew(sizeof(Ini));
+        this = OBJ_NEW_ALLOC();
 
         *this = (Ini)
         {
-            .memContext = MEM_CONTEXT_NEW(),
             .store = kvNew(),
         };
     }
-    MEM_CONTEXT_NEW_END();
+    OBJ_NEW_END();
 
     FUNCTION_TEST_RETURN(this);
 }
@@ -232,7 +225,7 @@ iniParse(Ini *this, const String *content)
 
     ASSERT(this != NULL);
 
-    MEM_CONTEXT_BEGIN(this->memContext)
+    MEM_CONTEXT_BEGIN(objMemContext(this))
     {
         kvFree(this->store);
         this->store = kvNew();
@@ -264,7 +257,7 @@ iniParse(Ini *this, const String *content)
                                 THROW_FMT(FormatError, "ini section should end with ] at line %u: %s", lineIdx + 1, linePtr);
 
                             // Assign section
-                            section = strNewN(linePtr + 1, strSize(line) - 2);
+                            section = strNewZN(linePtr + 1, strSize(line) - 2);
                         }
                         // Else it should be a key/value
                         else
@@ -279,13 +272,13 @@ iniParse(Ini *this, const String *content)
                                 THROW_FMT(FormatError, "missing '=' in key/value at line %u: %s", lineIdx + 1, linePtr);
 
                             // Extract the key
-                            String *key = strTrim(strNewN(linePtr, (size_t)(lineEqual - linePtr)));
+                            String *key = strTrim(strNewZN(linePtr, (size_t)(lineEqual - linePtr)));
 
                             if (strSize(key) == 0)
                                 THROW_FMT(FormatError, "key is zero-length at line %u: %s", lineIdx++, linePtr);
 
                             // Store the section/key/value
-                            iniSet(this, section, key, strTrim(strNew(lineEqual + 1)));
+                            iniSet(this, section, key, strTrim(strNewZ(lineEqual + 1)));
                         }
                     }
                 }
@@ -370,7 +363,7 @@ iniLoad(
                         // Assign section
                         MEM_CONTEXT_PRIOR_BEGIN()
                         {
-                            section = strNewN(linePtr + 1, strSize(line) - 2);
+                            section = strNewZN(linePtr + 1, strSize(line) - 2);
                         }
                         MEM_CONTEXT_PRIOR_END();
                     }
@@ -401,8 +394,8 @@ iniLoad(
                             retry = false;
 
                             // Get key/value
-                            key = strNewN(linePtr, (size_t)(lineEqual - linePtr));
-                            value = strNew(lineEqual + 1);
+                            key = strNewZN(linePtr, (size_t)(lineEqual - linePtr));
+                            value = strNewZ(lineEqual + 1);
 
                             // Check that the value is valid JSON
                             TRY_BEGIN()
