@@ -9,7 +9,7 @@ Write to a Buffer object using the IoWrite interface.
 #include "common/io/write.h"
 
 /***********************************************************************************************************************************
-Constructor
+Constructors
 ***********************************************************************************************************************************/
 IoWrite *ioBufferWriteNew(Buffer *buffer);
 
