@@ -14,27 +14,33 @@ Information on implementing a filter is in filter.internal.h.
 /***********************************************************************************************************************************
 Object type
 ***********************************************************************************************************************************/
-#define IO_FILTER_TYPE                                              IoFilter
-#define IO_FILTER_PREFIX                                            ioFilter
-
 typedef struct IoFilter IoFilter;
 
-#include "common/type/string.h"
-#include "common/type/variant.h"
+#include "common/io/filter/filter.intern.h"
+#include "common/type/object.h"
+#include "common/type/pack.h"
 
 /***********************************************************************************************************************************
 Getters/Setters
 ***********************************************************************************************************************************/
 // Get filter result
-Variant *ioFilterResult(const IoFilter *this);
+Pack *ioFilterResult(const IoFilter *this);
 
 // Identifies the filter and is used when pulling results from the filter group
-const String *ioFilterType(const IoFilter *this);
+__attribute__((always_inline)) static inline StringId
+ioFilterType(const IoFilter *const this)
+{
+    return THIS_PUB(IoFilter)->type;
+}
 
 /***********************************************************************************************************************************
 Destructor
 ***********************************************************************************************************************************/
-void ioFilterFree(IoFilter *this);
+__attribute__((always_inline)) static inline void
+ioFilterFree(IoFilter *const this)
+{
+    objFreeContext(this);
+}
 
 /***********************************************************************************************************************************
 Macros for function logging
