@@ -7,13 +7,11 @@ IO Filter Group
 
 #include "common/debug.h"
 #include "common/io/filter/buffer.h"
-#include "common/io/filter/filter.intern.h"
+#include "common/io/filter/filter.h"
 #include "common/io/filter/group.h"
 #include "common/io/io.h"
 #include "common/log.h"
-#include "common/memContext.h"
 #include "common/type/list.h"
-#include "common/type/object.h"
 
 /***********************************************************************************************************************************
 Filter and buffer structure
@@ -34,27 +32,29 @@ typedef struct IoFilterData
 #define FUNCTION_LOG_IO_FILTER_DATA_FORMAT(value, buffer, bufferSize)                                                              \
     objToLog(value, "IoFilterData", buffer, bufferSize)
 
+/***********************************************************************************************************************************
+Filter results
+***********************************************************************************************************************************/
+typedef struct IoFilterResult
+{
+    StringId type;                                                  // Filter type
+    Pack *result;                                                   // Filter result
+} IoFilterResult;
+
 /***********************************************************************************************************************************
 Object type
 ***********************************************************************************************************************************/
 struct IoFilterGroup
 {
-    MemContext *memContext;                                         // Mem context
-    List *filterList;                                               // List of filters to apply
+    IoFilterGroupPub pub;                                           // Publicly accessible variables
     const Buffer *input;                                            // Input buffer passed in for processing
-    KeyValue *filterResult;                                         // Filter results (if any)
-    bool inputSame;                                                 // Same input required again?
-    bool done;                                                      // Is processing done?
+    List *filterResult;                                             // Filter results (if any)
 
 #ifdef DEBUG
-    bool opened;                                                    // Has the filter set been opened?
     bool flushing;                                                  // Is output being flushed?
-    bool closed;                                                    // Has the filter set been closed?
 #endif
 };
 
-OBJECT_DEFINE_FREE(IO_FILTER_GROUP);
-
 /**********************************************************************************************************************************/
 IoFilterGroup *
 ioFilterGroupNew(void)
@@ -63,18 +63,22 @@ ioFilterGroupNew(void)
 
     IoFilterGroup *this = NULL;
 
-    MEM_CONTEXT_NEW_BEGIN("IoFilterGroup")
+    OBJ_NEW_BEGIN(IoFilterGroup)
     {
-        this = memNew(sizeof(IoFilterGroup));
+        this = OBJ_NEW_ALLOC();
 
         *this = (IoFilterGroup)
         {
-            .memContext = memContextCurrent(),
-            .done = false,
-            .filterList = lstNewP(sizeof(IoFilterData)),
+            .pub =
+            {
+                .done = false,
+                .filterList = lstNewP(sizeof(IoFilterData)),
+            },
+
+            .filterResult = lstNewP(sizeof(IoFilterResult)),
         };
     }
-    MEM_CONTEXT_NEW_END();
+    OBJ_NEW_END();
 
     FUNCTION_LOG_RETURN(IO_FILTER_GROUP, this);
 }
@@ -89,15 +93,15 @@ ioFilterGroupAdd(IoFilterGroup *this, IoFilter *filter)
     FUNCTION_LOG_END();
 
     ASSERT(this != NULL);
-    ASSERT(!this->opened && !this->closed);
+    ASSERT(!this->pub.opened && !this->pub.closed);
     ASSERT(filter != NULL);
 
     // Move the filter to this object's mem context
-    ioFilterMove(filter, this->memContext);
+    ioFilterMove(filter, objMemContext(this));
 
     // Add the filter
     IoFilterData filterData = {.filter = filter};
-    lstAdd(this->filterList, &filterData);
+    lstAdd(this->pub.filterList, &filterData);
 
     FUNCTION_LOG_RETURN(IO_FILTER_GROUP, this);
 }
@@ -112,15 +116,15 @@ ioFilterGroupInsert(IoFilterGroup *this, unsigned int listIdx, IoFilter *filter)
     FUNCTION_LOG_END();
 
     ASSERT(this != NULL);
-    ASSERT(!this->opened && !this->closed);
+    ASSERT(!this->pub.opened && !this->pub.closed);
     ASSERT(filter != NULL);
 
     // Move the filter to this object's mem context
-    ioFilterMove(filter, this->memContext);
+    ioFilterMove(filter, objMemContext(this));
 
     // Add the filter
     IoFilterData filterData = {.filter = filter};
-    lstInsert(this->filterList, listIdx, &filterData);
+    lstInsert(this->pub.filterList, listIdx, &filterData);
 
     FUNCTION_LOG_RETURN(IO_FILTER_GROUP, this);
 }
@@ -138,7 +142,7 @@ ioFilterGroupGet(const IoFilterGroup *this, unsigned int filterIdx)
 
     ASSERT(this != NULL);
 
-    FUNCTION_TEST_RETURN((IoFilterData *)lstGet(this->filterList, filterIdx));
+    FUNCTION_TEST_RETURN((IoFilterData *)lstGet(this->pub.filterList, filterIdx));
 }
 
 /**********************************************************************************************************************************/
@@ -150,12 +154,12 @@ ioFilterGroupClear(IoFilterGroup *this)
     FUNCTION_LOG_END();
 
     ASSERT(this != NULL);
-    ASSERT(!this->opened);
+    ASSERT(!this->pub.opened);
 
     for (unsigned int filterIdx = 0; filterIdx < ioFilterGroupSize(this); filterIdx++)
         ioFilterFree(ioFilterGroupGet(this, filterIdx)->filter);
 
-    lstClear(this->filterList);
+    lstClear(this->pub.filterList);
 
     FUNCTION_LOG_RETURN(IO_FILTER_GROUP, this);
 }
@@ -172,7 +176,7 @@ ioFilterGroupOpen(IoFilterGroup *this)
 
     ASSERT(this != NULL);
 
-    MEM_CONTEXT_BEGIN(this->memContext)
+    MEM_CONTEXT_BEGIN(objMemContext(this))
     {
         // If the last filter is not an output filter then add a filter to buffer/copy data.  Input filters won't copy to an output
         // buffer so we need some way to get the data to the output buffer.
@@ -217,7 +221,7 @@ ioFilterGroupOpen(IoFilterGroup *this)
 
     // Filter group is open
 #ifdef DEBUG
-    this->opened = true;
+    this->pub.opened = true;
 #endif
 
     FUNCTION_LOG_RETURN_VOID();
@@ -234,7 +238,7 @@ ioFilterGroupProcess(IoFilterGroup *this, const Buffer *input, Buffer *output)
     FUNCTION_LOG_END();
 
     ASSERT(this != NULL);
-    ASSERT(this->opened && !this->closed);
+    ASSERT(this->pub.opened && !this->pub.closed);
     ASSERT(input == NULL || !bufEmpty(input));
     ASSERT(!this->flushing || input == NULL);
     ASSERT(output != NULL);
@@ -258,9 +262,9 @@ ioFilterGroupProcess(IoFilterGroup *this, const Buffer *input, Buffer *output)
 
         // Search from the end of the list for a filter that needs the same input.  This indicates that the filter was not able to
         // empty the input buffer on the last call.  Maybe it won't this time either -- we can but try.
-        if (this->inputSame)
+        if (ioFilterGroupInputSame(this))
         {
-            this->inputSame = false;
+            this->pub.inputSame = false;
             filterIdx = ioFilterGroupSize(this);
 
             do
@@ -269,7 +273,7 @@ ioFilterGroupProcess(IoFilterGroup *this, const Buffer *input, Buffer *output)
 
                 if (ioFilterInputSame((ioFilterGroupGet(this, filterIdx))->filter))
                 {
-                    this->inputSame = true;
+                    this->pub.inputSame = true;
                     break;
                 }
             }
@@ -277,7 +281,7 @@ ioFilterGroupProcess(IoFilterGroup *this, const Buffer *input, Buffer *output)
 
             // If no filter is found that needs the same input that means we are done with the current input.  So end the loop and
             // get some more input.
-            if (!this->inputSame)
+            if (!ioFilterGroupInputSame(this))
                 break;
         }
 
@@ -299,7 +303,7 @@ ioFilterGroupProcess(IoFilterGroup *this, const Buffer *input, Buffer *output)
                     // the same input once the output buffer is cleared
                     if (ioFilterInputSame(filterData->filter))
                     {
-                        this->inputSame = true;
+                        this->pub.inputSame = true;
                     }
                     // Else clear the buffer if it was locally allocated.  If the input buffer was passed in then the caller is
                     // responsible for clearing it.
@@ -321,29 +325,29 @@ ioFilterGroupProcess(IoFilterGroup *this, const Buffer *input, Buffer *output)
                 filterData->output = NULL;
         }
     }
-    while (!bufFull(output) && this->inputSame);
+    while (!bufFull(output) && ioFilterGroupInputSame(this));
 
-    // Scan the filter list to determine if inputSame is set or done is not set for any filter.  We can't trust this->inputSame
-    // when it is true without going through the loop above again.  We need to scan to set this->done anyway so set this->inputSame
-    // in the same loop.
-    this->done = true;
-    this->inputSame = false;
+    // Scan the filter list to determine if inputSame is set or done is not set for any filter. We can't trust
+    // ioFilterGroupInputSame() when it is true without going through the loop above again. We need to scan to set this->pub.done
+    // anyway so set this->pub.inputSame in the same loop.
+    this->pub.done = true;
+    this->pub.inputSame = false;
 
     for (unsigned int filterIdx = 0; filterIdx < ioFilterGroupSize(this); filterIdx++)
     {
         IoFilterData *filterData = ioFilterGroupGet(this, filterIdx);
 
-        // When inputSame then this->done = false and we can exit the loop immediately
+        // When inputSame then this->pub.done = false and we can exit the loop immediately
         if (ioFilterInputSame(filterData->filter))
         {
-            this->done = false;
-            this->inputSame = true;
+            this->pub.done = false;
+            this->pub.inputSame = true;
             break;
         }
 
-        // Set this->done = false if any filter is not done
+        // Set this->pub.done = false if any filter is not done
         if (!ioFilterDone(filterData->filter))
-            this->done = false;
+            this->pub.done = false;
     }
 
     FUNCTION_LOG_RETURN_VOID();
@@ -358,67 +362,30 @@ ioFilterGroupClose(IoFilterGroup *this)
     FUNCTION_LOG_END();
 
     ASSERT(this != NULL);
-    ASSERT(this->opened && !this->closed);
+    ASSERT(this->pub.opened && !this->pub.closed);
 
+    // Gather results from the filters
     for (unsigned int filterIdx = 0; filterIdx < ioFilterGroupSize(this); filterIdx++)
     {
-        IoFilterData *filterData = ioFilterGroupGet(this, filterIdx);
-        const Variant *filterResult = ioFilterResult(filterData->filter);
+        IoFilter *const filter = ioFilterGroupGet(this, filterIdx)->filter;
 
-        if (this->filterResult == NULL)
+        MEM_CONTEXT_BEGIN(lstMemContext(this->filterResult))
         {
-            MEM_CONTEXT_BEGIN(this->memContext)
-            {
-                this->filterResult = kvNew();
-            }
-            MEM_CONTEXT_END();
+            lstAdd(this->filterResult, &(IoFilterResult){.type = ioFilterType(filter), .result = ioFilterResult(filter)});
         }
-
-        MEM_CONTEXT_TEMP_BEGIN()
-        {
-            kvAdd(this->filterResult, VARSTR(ioFilterType(filterData->filter)), filterResult);
-        }
-        MEM_CONTEXT_TEMP_END();
+        MEM_CONTEXT_END();
     }
 
     // Filter group is open
 #ifdef DEBUG
-    this->closed = true;
+    this->pub.closed = true;
 #endif
 
     FUNCTION_LOG_RETURN_VOID();
 }
 
 /**********************************************************************************************************************************/
-bool
-ioFilterGroupDone(const IoFilterGroup *this)
-{
-    FUNCTION_TEST_BEGIN();
-        FUNCTION_TEST_PARAM(IO_FILTER_GROUP, this);
-    FUNCTION_TEST_END();
-
-    ASSERT(this != NULL);
-    ASSERT(this->opened && !this->closed);
-
-    FUNCTION_TEST_RETURN(this->done);
-}
-
-/**********************************************************************************************************************************/
-bool
-ioFilterGroupInputSame(const IoFilterGroup *this)
-{
-    FUNCTION_TEST_BEGIN();
-        FUNCTION_TEST_PARAM(IO_FILTER_GROUP, this);
-    FUNCTION_TEST_END();
-
-    ASSERT(this != NULL);
-    ASSERT(this->opened && !this->closed);
-
-    FUNCTION_TEST_RETURN(this->inputSame);
-}
-
-/**********************************************************************************************************************************/
-Variant *
+Pack *
 ioFilterGroupParamAll(const IoFilterGroup *this)
 {
     FUNCTION_LOG_BEGIN(logLevelDebug);
@@ -426,95 +393,156 @@ ioFilterGroupParamAll(const IoFilterGroup *this)
     FUNCTION_LOG_END();
 
     ASSERT(this != NULL);
-    ASSERT(!this->opened);
-    ASSERT(this->filterList != NULL);
+    ASSERT(!this->pub.opened);
+    ASSERT(this->pub.filterList != NULL);
 
-    VariantList *result = varLstNew();
-
-    for (unsigned int filterIdx = 0; filterIdx < ioFilterGroupSize(this); filterIdx++)
-    {
-        IoFilter *filter = ioFilterGroupGet(this, filterIdx)->filter;
-        const VariantList *paramList = ioFilterParamList(filter);
-
-        KeyValue *filterParam = kvNew();
-        kvAdd(filterParam, VARSTR(ioFilterType(filter)), paramList ? varNewVarLst(paramList) : NULL);
-
-        varLstAdd(result, varNewKv(filterParam));
-    }
-
-    FUNCTION_LOG_RETURN(VARIANT, varNewVarLst(result));
-}
-
-/**********************************************************************************************************************************/
-const Variant *
-ioFilterGroupResult(const IoFilterGroup *this, const String *filterType)
-{
-    FUNCTION_LOG_BEGIN(logLevelDebug);
-        FUNCTION_LOG_PARAM(IO_FILTER_GROUP, this);
-        FUNCTION_LOG_PARAM(STRING, filterType);
-    FUNCTION_LOG_END();
-
-    ASSERT(this->opened);
-    ASSERT(filterType != NULL);
-
-    const Variant *result = NULL;
+    Pack *result = NULL;
 
     MEM_CONTEXT_TEMP_BEGIN()
     {
-        result = kvGet(this->filterResult, VARSTR(filterType));
+        PackWrite *const packWrite = pckWriteNewP();
+
+        for (unsigned int filterIdx = 0; filterIdx < ioFilterGroupSize(this); filterIdx++)
+        {
+            IoFilter *filter = ioFilterGroupGet(this, filterIdx)->filter;
+
+            pckWriteStrIdP(packWrite, ioFilterType(filter));
+            pckWritePackP(packWrite, ioFilterParamList(filter));
+        }
+
+        pckWriteEndP(packWrite);
+
+        result = pckMove(pckWriteResult(packWrite), memContextPrior());
     }
     MEM_CONTEXT_TEMP_END();
 
-    FUNCTION_LOG_RETURN_CONST(VARIANT, result);
+    FUNCTION_LOG_RETURN(PACK, result);
 }
 
 /**********************************************************************************************************************************/
-const Variant *
-ioFilterGroupResultAll(const IoFilterGroup *this)
+const Pack *
+ioFilterGroupResultPack(const IoFilterGroup *const this, const StringId filterType, const IoFilterGroupResultParam param)
+{
+    FUNCTION_LOG_BEGIN(logLevelDebug);
+        FUNCTION_LOG_PARAM(IO_FILTER_GROUP, this);
+        FUNCTION_LOG_PARAM(STRING_ID, filterType);
+        FUNCTION_LOG_PARAM(UINT, param.idx);
+    FUNCTION_LOG_END();
+
+    ASSERT(this->pub.opened);
+    ASSERT(filterType != 0);
+
+    const Pack *result = NULL;
+
+    // Search for the result
+    unsigned int foundIdx = 0;
+
+    for (unsigned int filterResultIdx = 0; filterResultIdx < lstSize(this->filterResult); filterResultIdx++)
+    {
+        const IoFilterResult *const filterResult = lstGet(this->filterResult, filterResultIdx);
+
+        // If the filter matches check the index
+        if (filterResult->type == filterType)
+        {
+            // If the index matches return the result
+            if (foundIdx == param.idx)
+            {
+                result = filterResult->result;
+                break;
+            }
+
+            // Increment the index and keep searching
+            foundIdx++;
+        }
+    }
+
+    FUNCTION_LOG_RETURN_CONST(PACK, result);
+}
+
+/**********************************************************************************************************************************/
+PackRead *
+ioFilterGroupResult(const IoFilterGroup *const this, const StringId filterType, const IoFilterGroupResultParam param)
+{
+    FUNCTION_LOG_BEGIN(logLevelDebug);
+        FUNCTION_LOG_PARAM(IO_FILTER_GROUP, this);
+        FUNCTION_LOG_PARAM(STRING_ID, filterType);
+        FUNCTION_LOG_PARAM(UINT, param.idx);
+    FUNCTION_LOG_END();
+
+    FUNCTION_LOG_RETURN(PACK_READ, pckReadNew(ioFilterGroupResultPack(this, filterType, param)));
+}
+
+/**********************************************************************************************************************************/
+Pack *
+ioFilterGroupResultAll(const IoFilterGroup *const this)
 {
     FUNCTION_LOG_BEGIN(logLevelDebug);
         FUNCTION_LOG_PARAM(IO_FILTER_GROUP, this);
     FUNCTION_LOG_END();
 
     ASSERT(this != NULL);
-    ASSERT(this->closed);
+    ASSERT(this->pub.closed);
 
-    FUNCTION_LOG_RETURN_CONST(VARIANT, varNewKv(this->filterResult));
+    Pack *result = NULL;
+
+    // Pack the result list
+    MEM_CONTEXT_TEMP_BEGIN()
+    {
+        PackWrite *const packWrite = pckWriteNewP();
+
+        for (unsigned int filterResultIdx = 0; filterResultIdx < lstSize(this->filterResult); filterResultIdx++)
+        {
+            const IoFilterResult *const filterResult = lstGet(this->filterResult, filterResultIdx);
+
+            pckWriteStrIdP(packWrite, filterResult->type);
+            pckWritePackP(packWrite, filterResult->result);
+        }
+
+        pckWriteEndP(packWrite);
+
+        result = pckMove(pckWriteResult(packWrite), memContextPrior());
+    }
+    MEM_CONTEXT_TEMP_END();
+
+    FUNCTION_LOG_RETURN(PACK, result);
 }
 
 /**********************************************************************************************************************************/
 void
-ioFilterGroupResultAllSet(IoFilterGroup *this, const Variant *filterResult)
+ioFilterGroupResultAllSet(IoFilterGroup *const this, const Pack *const filterResultPack)
 {
     FUNCTION_LOG_BEGIN(logLevelDebug);
         FUNCTION_LOG_PARAM(IO_FILTER_GROUP, this);
+        FUNCTION_LOG_PARAM(PACK, filterResultPack);
     FUNCTION_LOG_END();
 
     ASSERT(this != NULL);
 
-    if (filterResult != NULL)
+    if (filterResultPack != NULL)
     {
-        MEM_CONTEXT_BEGIN(this->memContext)
+        PackRead *const packRead = pckReadNew(filterResultPack);
+
+        // Unpack the results into a list
+        MEM_CONTEXT_TEMP_BEGIN()
         {
-            this->filterResult = kvDup(varKv(filterResult));
+            MEM_CONTEXT_BEGIN(lstMemContext(this->filterResult))
+            {
+                while (!pckReadNullP(packRead))
+                {
+                    const StringId type = pckReadStrIdP(packRead);
+                    Pack *const result = pckReadPackP(packRead);
+
+                    lstAdd(this->filterResult, &(IoFilterResult){.type = type, .result = result});
+                }
+            }
+            MEM_CONTEXT_END();
         }
-        MEM_CONTEXT_END();
+        MEM_CONTEXT_TEMP_END();
     }
 
     FUNCTION_LOG_RETURN_VOID();
 }
 
-/**********************************************************************************************************************************/
-unsigned int
-ioFilterGroupSize(const IoFilterGroup *this)
-{
-    FUNCTION_TEST_BEGIN();
-        FUNCTION_TEST_PARAM(IO_FILTER_GROUP, this);
-    FUNCTION_TEST_END();
-
-    FUNCTION_TEST_RETURN(lstSize(this->filterList));
-}
-
 /**********************************************************************************************************************************/
 String *
 ioFilterGroupToLog(const IoFilterGroup *this)
@@ -525,9 +553,9 @@ ioFilterGroupToLog(const IoFilterGroup *this)
             ", opened %s, flushing %s, closed %s"
 #endif
             "}",
-        cvtBoolToConstZ(this->inputSame), cvtBoolToConstZ(this->done)
+        cvtBoolToConstZ(this->pub.inputSame), cvtBoolToConstZ(this->pub.done)
 #ifdef DEBUG
-        , cvtBoolToConstZ(this->opened), cvtBoolToConstZ(this->flushing), cvtBoolToConstZ(this->closed)
+        , cvtBoolToConstZ(this->pub.opened), cvtBoolToConstZ(this->flushing), cvtBoolToConstZ(this->pub.closed)
 #endif
     );
 }
