@@ -12,8 +12,7 @@ no data should be returned.
 /***********************************************************************************************************************************
 Filter type constant
 ***********************************************************************************************************************************/
-#define SINK_FILTER_TYPE                                     "sink"
-    STRING_DECLARE(SINK_FILTER_TYPE_STR);
+#define SINK_FILTER_TYPE                                     STRID5("sink", 0x5b9330)
 
 /***********************************************************************************************************************************
 Constructors
