@@ -12,8 +12,7 @@ in a FilterGroup with IoWrite.
 /***********************************************************************************************************************************
 Filter type constant
 ***********************************************************************************************************************************/
-#define SIZE_FILTER_TYPE                                     "size"
-    STRING_DECLARE(SIZE_FILTER_TYPE_STR);
+#define SIZE_FILTER_TYPE                                     STRID5("size", 0x2e9330)
 
 /***********************************************************************************************************************************
 Constructors
