@@ -1,7 +1,5 @@
 /***********************************************************************************************************************************
-Http Common
-
-Http common functions.
+HTTP Common
 ***********************************************************************************************************************************/
 #ifndef COMMON_IO_HTTP_COMMON_H
 #define COMMON_IO_HTTP_COMMON_H
@@ -13,9 +11,14 @@ Http common functions.
 /***********************************************************************************************************************************
 Functions
 ***********************************************************************************************************************************/
-// Convert Last-Modified header to time_t
-time_t httpLastModifiedToTime(const String *lastModified);
+// Convert HTTP date to time_t and vice versa
+time_t httpDateToTime(const String *lastModified);
+String *httpDateFromTime(time_t time);
 
+// Encode string to conform with URI specifications. If a path is being encoded then / characters won't be encoded.
 String *httpUriEncode(const String *uri, bool path);
 
+// Decode string that conforms to URI specifications
+String *httpUriDecode(const String *uri);
+
 #endif
