@@ -7,22 +7,16 @@ HTTP Session
 #include "common/io/http/session.h"
 #include "common/io/io.h"
 #include "common/log.h"
-#include "common/memContext.h"
-#include "common/type/object.h"
 
 /***********************************************************************************************************************************
 Object type
 ***********************************************************************************************************************************/
 struct HttpSession
 {
-    MemContext *memContext;                                         // Mem context
     HttpClient *httpClient;                                         // HTTP client
     IoSession *ioSession;                                           // IO session
 };
 
-OBJECT_DEFINE_MOVE(HTTP_SESSION);
-OBJECT_DEFINE_FREE(HTTP_SESSION);
-
 /**********************************************************************************************************************************/
 HttpSession *
 httpSessionNew(HttpClient *httpClient, IoSession *ioSession)
@@ -37,18 +31,17 @@ httpSessionNew(HttpClient *httpClient, IoSession *ioSession)
 
     HttpSession *this = NULL;
 
-    MEM_CONTEXT_NEW_BEGIN("HttpSession")
+    OBJ_NEW_BEGIN(HttpSession)
     {
-        this = memNew(sizeof(HttpSession));
+        this = OBJ_NEW_ALLOC();
 
         *this = (HttpSession)
         {
-            .memContext = MEM_CONTEXT_NEW(),
             .httpClient = httpClient,
             .ioSession = ioSessionMove(ioSession, memContextCurrent()),
         };
     }
-    MEM_CONTEXT_NEW_END();
+    OBJ_NEW_END();
 
     FUNCTION_LOG_RETURN(HTTP_SESSION, this);
 }
