@@ -9,15 +9,13 @@ HTTP sessions are created by calling httpClientOpen(), which is currently done e
 /***********************************************************************************************************************************
 Object type
 ***********************************************************************************************************************************/
-#define HTTP_SESSION_TYPE                                           HttpSession
-#define HTTP_SESSION_PREFIX                                         httpSession
-
 typedef struct HttpSession HttpSession;
 
 #include "common/io/read.h"
 #include "common/io/http/client.h"
 #include "common/io/session.h"
 #include "common/io/write.h"
+#include "common/type/object.h"
 
 /***********************************************************************************************************************************
 Constructors
@@ -28,7 +26,11 @@ HttpSession *httpSessionNew(HttpClient *client, IoSession *session);
 Functions
 ***********************************************************************************************************************************/
 // Move to a new parent mem context
-HttpSession *httpSessionMove(HttpSession *this, MemContext *parentNew);
+__attribute__((always_inline)) static inline HttpSession *
+httpSessionMove(HttpSession *const this, MemContext *const parentNew)
+{
+    return objMove(this, parentNew);
+}
 
 // Work with the session has finished cleanly and it can be reused
 void httpSessionDone(HttpSession *this);
@@ -45,7 +47,11 @@ IoWrite *httpSessionIoWrite(HttpSession *this);
 /***********************************************************************************************************************************
 Destructor
 ***********************************************************************************************************************************/
-void httpSessionFree(HttpSession *this);
+__attribute__((always_inline)) static inline void
+httpSessionFree(HttpSession *const this)
+{
+    objFree(this);
+}
 
 /***********************************************************************************************************************************
 Macros for function logging
