@@ -5,8 +5,6 @@ HTTP URL
 
 #include "common/debug.h"
 #include "common/io/http/url.h"
-#include "common/memContext.h"
-#include "common/type/object.h"
 #include "common/type/stringList.h"
 #include "common/regExp.h"
 
@@ -27,11 +25,8 @@ Object type
 struct HttpUrl
 {
     HttpUrlPub pub;
-    MemContext *memContext;                                         // Mem context
 };
 
-OBJECT_DEFINE_FREE(HTTP_URL);
-
 /***********************************************************************************************************************************
 Convert protocol type to a string
 ***********************************************************************************************************************************/
@@ -67,14 +62,13 @@ httpUrlNewParse(const String *const url, HttpUrlNewParseParam param)
 
     HttpUrl *this = NULL;
 
-    MEM_CONTEXT_NEW_BEGIN("HttpUrl")
+    OBJ_NEW_BEGIN(HttpUrl)
     {
         // Allocate state and set context
-        this = memNew(sizeof(HttpUrl));
+        this = OBJ_NEW_ALLOC();
 
         *this = (HttpUrl)
         {
-            .memContext = MEM_CONTEXT_NEW(),
             .pub =
             {
                 .url = strDup(url),
@@ -195,7 +189,7 @@ httpUrlNewParse(const String *const url, HttpUrlNewParseParam param)
         }
         MEM_CONTEXT_TEMP_END();
     }
-    MEM_CONTEXT_NEW_END();
+    OBJ_NEW_END();
 
     FUNCTION_TEST_RETURN(this);
 }
