@@ -10,20 +10,14 @@ Socket Client
 
 #include "common/debug.h"
 #include "common/log.h"
-#include "common/io/client.intern.h"
+#include "common/io/client.h"
 #include "common/io/socket/client.h"
 #include "common/io/socket/common.h"
 #include "common/io/socket/session.h"
-#include "common/memContext.h"
 #include "common/stat.h"
 #include "common/type/object.h"
 #include "common/wait.h"
 
-/***********************************************************************************************************************************
-Io client type
-***********************************************************************************************************************************/
-STRING_EXTERN(IO_CLIENT_SOCKET_TYPE_STR,                            IO_CLIENT_SOCKET_TYPE);
-
 /***********************************************************************************************************************************
 Statistics constants
 ***********************************************************************************************************************************/
@@ -34,16 +28,13 @@ STRING_EXTERN(SOCKET_STAT_SESSION_STR,                              SOCKET_STAT_
 /***********************************************************************************************************************************
 Object type
 ***********************************************************************************************************************************/
-#define SOCKET_CLIENT_TYPE                                          SocketClient
-#define SOCKET_CLIENT_PREFIX                                        sckClient
-
 typedef struct SocketClient
 {
-    MemContext *memContext;                                         // Mem context
     String *host;                                                   // Hostname or IP address
     unsigned int port;                                              // Port to connect to host on
     String *name;                                                   // Socket name (host:port)
-    TimeMSec timeout;                                               // Timeout for any i/o operation (connect, read, etc.)
+    TimeMSec timeoutConnect;                                        // Timeout for connection
+    TimeMSec timeoutSession;                                        // Timeout passed to session
 } SocketClient;
 
 /***********************************************************************************************************************************
@@ -54,7 +45,9 @@ sckClientToLog(const THIS_VOID)
 {
     THIS(const SocketClient);
 
-    return strNewFmt("{host: %s, port: %u, timeout: %" PRIu64 "}", strZ(this->host), this->port, this->timeout);
+    return strNewFmt(
+        "{host: %s, port: %u, timeoutConnect: %" PRIu64 ", timeoutSession: %" PRIu64 "}", strZ(this->host), this->port,
+        this->timeoutConnect, this->timeoutSession);
 }
 
 #define FUNCTION_LOG_SOCKET_CLIENT_TYPE                                                                                            \
@@ -79,58 +72,38 @@ sckClientOpen(THIS_VOID)
     MEM_CONTEXT_TEMP_BEGIN()
     {
         bool retry;
-        Wait *wait = waitNew(this->timeout);
+        Wait *wait = waitNew(this->timeoutConnect);
 
         do
         {
             // Assume there will be no retry
             retry = false;
-            int fd = -1;
+            volatile int fd = -1;
 
             TRY_BEGIN()
             {
-                // Set hints that narrow the type of address we are looking for -- we'll take ipv4 or ipv6
-                struct addrinfo hints = (struct addrinfo)
-                {
-                    .ai_family = AF_UNSPEC,
-                    .ai_socktype = SOCK_STREAM,
-                    .ai_protocol = IPPROTO_TCP,
-                };
-
-                // Convert the port to a zero-terminated string for use with getaddrinfo()
-                char port[CVT_BASE10_BUFFER_SIZE];
-                cvtUIntToZ(this->port, port, sizeof(port));
-
-                // Get an address for the host.  We are only going to try the first address returned.
-                struct addrinfo *hostAddress;
-                int resultAddr;
-
-                if ((resultAddr = getaddrinfo(strZ(this->host), port, &hints, &hostAddress)) != 0)
-                {
-                    THROW_FMT(
-                        HostConnectError, "unable to get address for '%s': [%d] %s", strZ(this->host), resultAddr,
-                        gai_strerror(resultAddr));
-                }
+                // Get an address for the host. We are only going to try the first address returned.
+                struct addrinfo *addressFound = sckHostLookup(this->host, this->port);
 
                 // Connect to the host
                 TRY_BEGIN()
                 {
-                    fd = socket(hostAddress->ai_family, hostAddress->ai_socktype, hostAddress->ai_protocol);
+                    fd = socket(addressFound->ai_family, addressFound->ai_socktype, addressFound->ai_protocol);
                     THROW_ON_SYS_ERROR(fd == -1, HostConnectError, "unable to create socket");
 
                     sckOptionSet(fd);
-                    sckConnect(fd, this->host, this->port, hostAddress, waitRemaining(wait));
+                    sckConnect(fd, this->host, this->port, addressFound, waitRemaining(wait));
                 }
                 FINALLY()
                 {
-                    freeaddrinfo(hostAddress);
+                    freeaddrinfo(addressFound);
                 }
                 TRY_END();
 
                 // Create the session
                 MEM_CONTEXT_PRIOR_BEGIN()
                 {
-                    result = sckSessionNew(ioSessionRoleClient, fd, this->host, this->port, this->timeout);
+                    result = sckSessionNew(ioSessionRoleClient, fd, this->host, this->port, this->timeoutSession);
                 }
                 MEM_CONTEXT_PRIOR_END();
             }
@@ -179,43 +152,44 @@ sckClientName(THIS_VOID)
 /**********************************************************************************************************************************/
 static const IoClientInterface sckClientInterface =
 {
-    .type = &IO_CLIENT_SOCKET_TYPE_STR,
+    .type = IO_CLIENT_SOCKET_TYPE,
     .name = sckClientName,
     .open = sckClientOpen,
     .toLog = sckClientToLog,
 };
 
 IoClient *
-sckClientNew(const String *host, unsigned int port, TimeMSec timeout)
+sckClientNew(const String *const host, const unsigned int port, const TimeMSec timeoutConnect, const TimeMSec timeoutSession)
 {
     FUNCTION_LOG_BEGIN(logLevelDebug)
         FUNCTION_LOG_PARAM(STRING, host);
         FUNCTION_LOG_PARAM(UINT, port);
-        FUNCTION_LOG_PARAM(TIME_MSEC, timeout);
+        FUNCTION_LOG_PARAM(TIME_MSEC, timeoutConnect);
+        FUNCTION_LOG_PARAM(TIME_MSEC, timeoutSession);
     FUNCTION_LOG_END();
 
     ASSERT(host != NULL);
 
     IoClient *this = NULL;
 
-    MEM_CONTEXT_NEW_BEGIN("SocketClient")
+    OBJ_NEW_BEGIN(SocketClient)
     {
-        SocketClient *driver = memNew(sizeof(SocketClient));
+        SocketClient *driver = OBJ_NEW_ALLOC();
 
         *driver = (SocketClient)
         {
-            .memContext = MEM_CONTEXT_NEW(),
             .host = strDup(host),
             .port = port,
             .name = strNewFmt("%s:%u", strZ(host), port),
-            .timeout = timeout,
+            .timeoutConnect = timeoutConnect,
+            .timeoutSession = timeoutSession,
         };
 
         statInc(SOCKET_STAT_CLIENT_STR);
 
         this = ioClientNew(driver, &sckClientInterface);
     }
-    MEM_CONTEXT_NEW_END();
+    OBJ_NEW_END();
 
     FUNCTION_LOG_RETURN(IO_CLIENT, this);
 }
