@@ -8,27 +8,22 @@ TLS Session
 #include "common/crypto/common.h"
 #include "common/debug.h"
 #include "common/io/io.h"
-#include "common/io/read.intern.h"
-#include "common/io/session.intern.h"
+#include "common/io/read.h"
+#include "common/io/session.h"
 #include "common/io/tls/client.h"
 #include "common/io/tls/session.h"
-#include "common/io/write.intern.h"
+#include "common/io/write.h"
 #include "common/log.h"
-#include "common/memContext.h"
 #include "common/type/object.h"
 
 /***********************************************************************************************************************************
 Object type
 ***********************************************************************************************************************************/
-#define TLS_SESSION_TYPE                                            TlsSession
-#define TLS_SESSION_PREFIX                                          tlsSession
-
 typedef struct TlsSession
 {
-    MemContext *memContext;                                         // Mem context
     IoSession *ioSession;                                           // Io session
     SSL *session;                                                   // TLS session on the file descriptor
-    TimeMSec timeout;                                               // Timeout for any i/o operation (connect, read, etc.)
+    TimeMSec timeout;                                               // Timeout for any i/o operation (read, write, etc.)
     bool shutdownOnClose;                                           // Shutdown the TLS connection when closing the session
 
     IoRead *read;                                                   // Read interface
@@ -45,7 +40,7 @@ tlsSessionToLog(const THIS_VOID)
 
     return strNewFmt(
         "{ioSession: %s, timeout: %" PRIu64", shutdownOnClose: %s}",
-        memContextFreeing(this->memContext) ? NULL_Z : strZ(ioSessionToLog(this->ioSession)), this->timeout,
+        objMemContextFreeing(this) ? NULL_Z : strZ(ioSessionToLog(this->ioSession)), this->timeout,
         cvtBoolToConstZ(this->shutdownOnClose));
 }
 
@@ -57,11 +52,21 @@ tlsSessionToLog(const THIS_VOID)
 /***********************************************************************************************************************************
 Free connection
 ***********************************************************************************************************************************/
-OBJECT_DEFINE_FREE_RESOURCE_BEGIN(TLS_SESSION, LOG, logLevelTrace)
+static void
+tlsSessionFreeResource(THIS_VOID)
 {
+    THIS(TlsSession);
+
+    FUNCTION_LOG_BEGIN(logLevelTrace);
+        FUNCTION_LOG_PARAM(TLS_SESSION, this);
+    FUNCTION_LOG_END();
+
+    ASSERT(this != NULL);
+
     SSL_free(this->session);
+
+    FUNCTION_LOG_RETURN_VOID();
 }
-OBJECT_DEFINE_FREE_RESOURCE_END(LOG);
 
 /**********************************************************************************************************************************/
 static void
@@ -86,7 +91,7 @@ tlsSessionClose(THIS_VOID)
         ioSessionClose(this->ioSession);
 
         // Free the TLS session
-        memContextCallbackClear(this->memContext);
+        memContextCallbackClear(objMemContext(this));
         tlsSessionFreeResource(this);
         this->session = NULL;
     }
@@ -262,8 +267,7 @@ tlsSessionWrite(THIS_VOID, const Buffer *buffer)
 
         result = tlsSessionResult(this, SSL_write(this->session, bufPtrConst(buffer), (int)bufUsed(buffer)), false);
 
-        // Either a retry or all data was written
-        CHECK(result == 0 || (size_t)result == bufUsed(buffer));
+        CHECK(ServiceError, result == 0 || (size_t)result == bufUsed(buffer), "expected retry or complete write");
     }
 
     FUNCTION_LOG_RETURN_VOID();
@@ -334,7 +338,7 @@ tlsSessionRole(const THIS_VOID)
 /**********************************************************************************************************************************/
 static const IoSessionInterface tlsSessionInterface =
 {
-    .type = &IO_CLIENT_TLS_TYPE_STR,
+    .type = IO_CLIENT_TLS_TYPE,
     .close = tlsSessionClose,
     .ioRead = tlsSessionIoRead,
     .ioWrite = tlsSessionIoWrite,
@@ -356,13 +360,12 @@ tlsSessionNew(SSL *session, IoSession *ioSession, TimeMSec timeout)
 
     IoSession *this = NULL;
 
-    MEM_CONTEXT_NEW_BEGIN("TlsSession")
+    OBJ_NEW_BEGIN(TlsSession)
     {
-        TlsSession *driver = memNew(sizeof(TlsSession));
+        TlsSession *driver = OBJ_NEW_ALLOC();
 
         *driver = (TlsSession)
         {
-            .memContext = MEM_CONTEXT_NEW(),
             .session = session,
             .ioSession = ioSessionMove(ioSession, MEM_CONTEXT_NEW()),
             .timeout = timeout,
@@ -370,7 +373,7 @@ tlsSessionNew(SSL *session, IoSession *ioSession, TimeMSec timeout)
         };
 
         // Ensure session is freed
-        memContextCallbackSet(driver->memContext, tlsSessionFreeResource, driver);
+        memContextCallbackSet(objMemContext(driver), tlsSessionFreeResource, driver);
 
         // Assign file descriptor to TLS session
         cryptoError(SSL_set_fd(driver->session, ioSessionFd(driver->ioSession)) != 1, "unable to add fd to TLS session");
@@ -397,7 +400,7 @@ tlsSessionNew(SSL *session, IoSession *ioSession, TimeMSec timeout)
         // Create session interface
         this = ioSessionNew(driver, &tlsSessionInterface);
     }
-    MEM_CONTEXT_NEW_END();
+    OBJ_NEW_END();
 
     FUNCTION_LOG_RETURN(IO_SESSION, this);
 }
