@@ -108,7 +108,7 @@ lockAcquireFile(const String *lockFile, const String *execId, TimeMSec lockTimeo
                     THROW_ON_SYS_ERROR_FMT(actualBytes == -1, FileReadError, "unable to read '%s", strZ(lockFile));
 
                     // Parse the file and see if the exec id matches
-                    const StringList *parse = strLstNewSplitZ(strNewN(buffer, (size_t)actualBytes), LF_Z);
+                    const StringList *parse = strLstNewSplitZ(strNewZN(buffer, (size_t)actualBytes), LF_Z);
 
                     if (strLstSize(parse) == 3 && strEq(strLstGet(parse, 1), execId))
                         result = LOCK_ON_EXEC_ID;
@@ -128,7 +128,7 @@ lockAcquireFile(const String *lockFile, const String *execId, TimeMSec lockTimeo
                 const String *errorHint = NULL;
 
                 if (errNo == EWOULDBLOCK)
-                    errorHint = strNew("\nHINT: is another " PROJECT_NAME " process running?");
+                    errorHint = strNewZ("\nHINT: is another " PROJECT_NAME " process running?");
                 else if (errNo == EACCES)
                 {
                     errorHint = strNewFmt(
@@ -245,37 +245,6 @@ lockAcquire(
     FUNCTION_LOG_RETURN(BOOL, result);
 }
 
-/**********************************************************************************************************************************/
-bool
-lockClear(bool failOnNoLock)
-{
-    FUNCTION_LOG_BEGIN(logLevelTrace);
-        FUNCTION_LOG_PARAM(BOOL, failOnNoLock);
-    FUNCTION_LOG_END();
-
-    bool result = false;
-
-    if (lockTypeHeld == lockTypeNone)
-    {
-        if (failOnNoLock)
-            THROW(AssertError, "no lock is held by this process");
-    }
-    else
-    {
-        // Clear locks
-        LockType lockMin = lockTypeHeld == lockTypeAll ? lockTypeArchive : lockTypeHeld;
-        LockType lockMax = lockTypeHeld == lockTypeAll ? (lockTypeAll - 1) : lockTypeHeld;
-
-        for (LockType lockIdx = lockMin; lockIdx <= lockMax; lockIdx++)
-            strFree(lockFile[lockIdx]);
-
-        lockTypeHeld = lockTypeNone;
-        result = true;
-    }
-
-    FUNCTION_LOG_RETURN(BOOL, result);
-}
-
 /**********************************************************************************************************************************/
 bool
 lockRelease(bool failOnNoLock)
