@@ -15,8 +15,7 @@ Memory context states
 ***********************************************************************************************************************************/
 typedef enum
 {
-    memContextStateFree = 0,
-    memContextStateFreeing,
+    memContextStateFreeing = 0,
     memContextStateActive
 } MemContextState;
 
@@ -50,11 +49,12 @@ Contains information about the memory context
 ***********************************************************************************************************************************/
 struct MemContext
 {
-    MemContextState state;                                          // Current state of the context
     const char *name;                                               // Indicates what the context is being used for
+    MemContextState state:1;                                        // Current state of the context
+    size_t allocExtra:16;                                           // Size of extra allocation (1kB max)
 
-    MemContext *contextParent;                                      // All contexts have a parent except top
     unsigned int contextParentIdx;                                  // Index in the parent context list
+    MemContext *contextParent;                                      // All contexts have a parent except top
 
     MemContext **contextChildList;                                  // List of contexts created in this context
     unsigned int contextChildListSize;                              // Size of child context list (not the actual count of contexts)
@@ -74,14 +74,14 @@ Top context
 The top context always exists and can never be freed.  All other contexts are children of the top context. The top context is
 generally used to allocate memory that exists for the life of the program.
 ***********************************************************************************************************************************/
-MemContext contextTop = {.state = memContextStateActive, .name = "TOP"};
+static MemContext contextTop = {.state = memContextStateActive, .name = "TOP"};
 
 /***********************************************************************************************************************************
 Memory context stack types
 ***********************************************************************************************************************************/
 typedef enum
 {
-    memContextStackTypeSwitch = 0,                                  // Context can be switched to to allocate mem for new variables
+    memContextStackTypeSwitch = 0,                                  // Context can be switched to allocate mem for new variables
     memContextStackTypeNew,                                         // Context to be tracked for error handling - cannot switch to
 } MemContextStackType;
 
@@ -210,11 +210,10 @@ memFreeInternal(void *buffer)
 Find space for a new mem context
 ***********************************************************************************************************************************/
 static unsigned int
-memContextNewIndex(MemContext *memContext, bool allowFree)
+memContextNewIndex(MemContext *memContext)
 {
     FUNCTION_TEST_BEGIN();
         FUNCTION_TEST_PARAM(MEM_CONTEXT, memContext);
-        FUNCTION_TEST_PARAM(BOOL, allowFree);
     FUNCTION_TEST_END();
 
     ASSERT(memContext != NULL);
@@ -222,11 +221,8 @@ memContextNewIndex(MemContext *memContext, bool allowFree)
     // Try to find space for the new context
     for (; memContext->contextChildFreeIdx < memContext->contextChildListSize; memContext->contextChildFreeIdx++)
     {
-        if (memContext->contextChildList[memContext->contextChildFreeIdx] == NULL ||
-            (allowFree && memContext->contextChildList[memContext->contextChildFreeIdx]->state == memContextStateFree))
-        {
+        if (memContext->contextChildList[memContext->contextChildFreeIdx] == NULL)
             break;
-        }
     }
 
     // If no space was found then allocate more
@@ -261,37 +257,35 @@ memContextNewIndex(MemContext *memContext, bool allowFree)
 
 /**********************************************************************************************************************************/
 MemContext *
-memContextNew(const char *name)
+memContextNew(const char *const name, const MemContextNewParam param)
 {
     FUNCTION_TEST_BEGIN();
         FUNCTION_TEST_PARAM(STRINGZ, name);
+        FUNCTION_TEST_PARAM(SIZE, param.allocExtra);
     FUNCTION_TEST_END();
 
     ASSERT(name != NULL);
-
     // Check context name length
     ASSERT(name[0] != '\0');
 
     // Find space for the new context
     MemContext *contextCurrent = memContextStack[memContextCurrentStackIdx].memContext;
-    unsigned int contextIdx = memContextNewIndex(contextCurrent, true);
+    unsigned int contextIdx = memContextNewIndex(contextCurrent);
 
-    // If the context has not been allocated yet
-    if (contextCurrent->contextChildList[contextIdx] == NULL)
-        contextCurrent->contextChildList[contextIdx] = memAllocInternal(sizeof(MemContext));
+    // Allocate memory for the context
+    contextCurrent->contextChildList[contextIdx] = memAllocInternal(sizeof(MemContext) + param.allocExtra);
 
     // Get the context
     MemContext *this = contextCurrent->contextChildList[contextIdx];
 
     *this = (MemContext)
     {
-        // Create initial space for allocations
-        .allocList = memAllocPtrArrayInternal(MEM_CONTEXT_ALLOC_INITIAL_SIZE),
-        .allocListSize = MEM_CONTEXT_ALLOC_INITIAL_SIZE,
-
         // Set the context name
         .name = name,
 
+        // Set extra allocation
+        .allocExtra = param.allocExtra,
+
         // Set new context active
         .state = memContextStateActive,
 
@@ -317,6 +311,47 @@ memContextNew(const char *name)
     FUNCTION_TEST_RETURN(this);
 }
 
+/**********************************************************************************************************************************/
+void *
+memContextAllocExtra(MemContext *const this)
+{
+    FUNCTION_TEST_BEGIN();
+        FUNCTION_TEST_PARAM(MEM_CONTEXT, this);
+    FUNCTION_TEST_END();
+
+    ASSERT(this != NULL);
+    ASSERT(this->allocExtra != 0);
+
+    FUNCTION_TEST_RETURN(this + 1);
+}
+
+/**********************************************************************************************************************************/
+MemContext *
+memContextFromAllocExtra(void *const allocExtra)
+{
+    FUNCTION_TEST_BEGIN();
+        FUNCTION_TEST_PARAM_P(VOID, allocExtra);
+    FUNCTION_TEST_END();
+
+    ASSERT(allocExtra != NULL);
+    ASSERT(((MemContext *)allocExtra - 1)->allocExtra != 0);
+
+    FUNCTION_TEST_RETURN((MemContext *)allocExtra - 1);
+}
+
+const MemContext *
+memContextConstFromAllocExtra(const void *const allocExtra)
+{
+    FUNCTION_TEST_BEGIN();
+        FUNCTION_TEST_PARAM_P(VOID, allocExtra);
+    FUNCTION_TEST_END();
+
+    ASSERT(allocExtra != NULL);
+    ASSERT(((MemContext *)allocExtra - 1)->allocExtra != 0);
+
+    FUNCTION_TEST_RETURN((MemContext *)allocExtra - 1);
+}
+
 /**********************************************************************************************************************************/
 void
 memContextCallbackSet(MemContext *this, void (*callbackFunction)(void *), void *callbackArgument)
@@ -537,31 +572,15 @@ memContextMove(MemContext *this, MemContext *parentNew)
     // Only move if a valid mem context is provided and the old and new parents are not the same
     if (this != NULL && this->contextParent != parentNew)
     {
-        // Find context in the old parent and NULL it out
-        MemContext *parentOld = this->contextParent;
-        unsigned int contextIdx;
-
-        for (contextIdx = 0; contextIdx < parentOld->contextChildListSize; contextIdx++)
-        {
-            if (parentOld->contextChildList[contextIdx] == this)
-            {
-                parentOld->contextChildList[contextIdx] = NULL;
-                break;
-            }
-        }
-
-        // The memory must be found
-        if (contextIdx == parentOld->contextChildListSize)
-            THROW(AssertError, "unable to find mem context in old parent");
+        // Null out the context in the old parent
+        ASSERT(this->contextParent->contextChildList[this->contextParentIdx] == this);
+        this->contextParent->contextChildList[this->contextParentIdx] = NULL;
 
         // Find a place in the new parent context and assign it. The child list may be moved while finding a new index so store the
         // index and use it with (what might be) the new pointer.
-        contextIdx = memContextNewIndex(parentNew, false);
-        ASSERT(parentNew->contextChildList[contextIdx] == NULL);
-        parentNew->contextChildList[contextIdx] = this;
-
-        // Assign new parent
         this->contextParent = parentNew;
+        this->contextParentIdx = memContextNewIndex(parentNew);
+        parentNew->contextChildList[this->contextParentIdx] = this;
     }
 
     FUNCTION_TEST_RETURN_VOID();
@@ -688,7 +707,7 @@ memContextCurrent(void)
 
 /**********************************************************************************************************************************/
 bool
-memContextFreeing(MemContext *this)
+memContextFreeing(const MemContext *const this)
 {
     FUNCTION_TEST_BEGIN();
         FUNCTION_TEST_PARAM(MEM_CONTEXT, this);
@@ -701,7 +720,7 @@ memContextFreeing(MemContext *this)
 
 /**********************************************************************************************************************************/
 const char *
-memContextName(MemContext *this)
+memContextName(const MemContext *const this)
 {
     FUNCTION_TEST_BEGIN();
         FUNCTION_TEST_PARAM(MEM_CONTEXT, this);
@@ -742,7 +761,7 @@ memContextSize(const MemContext *this)
 
     // Size of struct and child context/alloc arrays
     size_t result =
-        sizeof(MemContext) + (this->contextChildListSize * sizeof(MemContext *)) +
+        sizeof(MemContext) + this->allocExtra + (this->contextChildListSize * sizeof(MemContext *)) +
         (this->allocListSize * sizeof(MemContextAlloc *));
 
     // Add child contexts
@@ -812,72 +831,63 @@ memContextFree(MemContext *this)
         if (this == memContextStack[memContextCurrentStackIdx].memContext && this != &contextTop)
             THROW_FMT(AssertError, "cannot free current context '%s'", this->name);
 
-        // Error if context is not active
-        if (this->state != memContextStateActive)
-            THROW(AssertError, "cannot free inactive context");
-
         // Free child contexts
-        if (this->contextChildListSize > 0)
-            for (unsigned int contextIdx = 0; contextIdx < this->contextChildListSize; contextIdx++)
-                if (this->contextChildList[contextIdx] && this->contextChildList[contextIdx]->state == memContextStateActive)
-                    memContextFree(this->contextChildList[contextIdx]);
+        for (unsigned int contextIdx = 0; contextIdx < this->contextChildListSize; contextIdx++)
+        {
+            if (this->contextChildList[contextIdx] != NULL)
+                memContextFree(this->contextChildList[contextIdx]);
+        }
 
         // Set state to freeing now that there are no child contexts.  Child contexts might need to interact with their parent while
         // freeing so the parent needs to remain active until they are all gone.
         this->state = memContextStateFreeing;
 
         // Execute callback if defined
-        bool rethrow = false;
-
-        if (this->callbackFunction)
+        TRY_BEGIN()
         {
-            TRY_BEGIN()
-            {
+            if (this->callbackFunction)
                 this->callbackFunction(this->callbackArgument);
-            }
-            CATCH_ANY()
+        }
+        // Finish cleanup even if the callback fails
+        FINALLY()
+        {
+            // Free child context allocation list
+            if (this->contextChildListSize > 0)
             {
-                rethrow = true;
+                memFreeInternal(this->contextChildList);
+                this->contextChildListSize = 0;
+            }
+
+            // Free memory allocations and list
+            if (this->allocListSize > 0)
+            {
+                for (unsigned int allocIdx = 0; allocIdx < this->allocListSize; allocIdx++)
+                    if (this->allocList[allocIdx] != NULL)
+                        memFreeInternal(this->allocList[allocIdx]);
+
+                memFreeInternal(this->allocList);
+                this->allocListSize = 0;
+            }
+
+            // If the context index is lower than the current free index in the parent then replace it
+            if (this->contextParent != NULL && this->contextParentIdx < this->contextParent->contextChildFreeIdx)
+                this->contextParent->contextChildFreeIdx = this->contextParentIdx;
+
+            // Make top context active again
+            if (this == &contextTop)
+            {
+                this->state = memContextStateActive;
+            }
+            // Else free the memory context so the slot can be reused
+            else
+            {
+                ASSERT(this->contextParent != NULL);
+
+                this->contextParent->contextChildList[this->contextParentIdx] = NULL;
+                memFreeInternal(this);
             }
-            TRY_END();
         }
-
-        // Free child context allocations
-        if (this->contextChildListSize > 0)
-        {
-            for (unsigned int contextIdx = 0; contextIdx < this->contextChildListSize; contextIdx++)
-                if (this->contextChildList[contextIdx])
-                    memFreeInternal(this->contextChildList[contextIdx]);
-
-            memFreeInternal(this->contextChildList);
-            this->contextChildListSize = 0;
-        }
-
-        // Free memory allocations
-        if (this->allocListSize > 0)
-        {
-            for (unsigned int allocIdx = 0; allocIdx < this->allocListSize; allocIdx++)
-                if (this->allocList[allocIdx] != NULL)
-                    memFreeInternal(this->allocList[allocIdx]);
-
-            memFreeInternal(this->allocList);
-            this->allocListSize = 0;
-        }
-
-        // If the context index is lower than the current free index in the parent then replace it
-        if (this->contextParent != NULL && this->contextParentIdx < this->contextParent->contextChildFreeIdx)
-            this->contextParent->contextChildFreeIdx = this->contextParentIdx;
-
-        // Make top context active again
-        if (this == &contextTop)
-            this->state = memContextStateActive;
-        // Else reset the memory context so it can be reused
-        else
-            *this = (MemContext){.state = memContextStateFree};
-
-        // Rethrow the error that was caught in the callback
-        if (rethrow)
-            RETHROW();
+        TRY_END();
     }
 
     FUNCTION_TEST_RETURN_VOID();
