@@ -7,11 +7,9 @@ Regular Expression Handler
 /***********************************************************************************************************************************
 RegExp object
 ***********************************************************************************************************************************/
-#define REGEXP_TYPE                                                 RegExp
-#define REGEXP_PREFIX                                               regExp
-
 typedef struct RegExp RegExp;
 
+#include "common/type/object.h"
 #include "common/type/string.h"
 
 /***********************************************************************************************************************************
@@ -51,7 +49,11 @@ String *regExpPrefix(const String *expression);
 /***********************************************************************************************************************************
 Destructor
 ***********************************************************************************************************************************/
-void regExpFree(RegExp *this);
+__attribute__((always_inline)) static inline void
+regExpFree(RegExp *const this)
+{
+    objFree(this);
+}
 
 /***********************************************************************************************************************************
 Macros for function logging
