@@ -111,7 +111,7 @@ jsonToNumberInternal(const char *json, unsigned int *jsonPos)
     MEM_CONTEXT_TEMP_BEGIN()
     {
         // Extract the numeric as a string
-        String *resultStr = strNewN(json + beginPos, *jsonPos - beginPos);
+        String *resultStr = strNewZN(json + beginPos, *jsonPos - beginPos);
 
         // Convert the string to a integer variant
         MEM_CONTEXT_PRIOR_BEGIN()
@@ -229,7 +229,7 @@ jsonToStrInternal(const char *json, unsigned int *jsonPos)
         FUNCTION_TEST_PARAM_P(UINT, jsonPos);
     FUNCTION_TEST_END();
 
-    String *result = strNew("");
+    String *result = strNew();
 
     if (json[*jsonPos] != '"')
         THROW_FMT(JsonFormatError, "expected '\"' at '%s'", json + *jsonPos);
@@ -300,7 +300,7 @@ jsonToStrInternal(const char *json, unsigned int *jsonPos)
 
                         // Decode char
                         (*jsonPos) += 2;
-                        strCatChr(result, (char)cvtZToUIntBase(strZ(strNewN(json + *jsonPos, 2)), 16));
+                        strCatChr(result, (char)cvtZToUIntBase(strZ(strNewZN(json + *jsonPos, 2)), 16));
                         (*jsonPos) += 1;
 
                         break;
@@ -618,7 +618,7 @@ jsonFromInt(int number)
     char working[CVT_BASE10_BUFFER_SIZE];
     cvtIntToZ(number, working, sizeof(working));
 
-    FUNCTION_TEST_RETURN(strNew(working));
+    FUNCTION_TEST_RETURN(strNewZ(working));
 }
 
 String *
@@ -631,7 +631,7 @@ jsonFromInt64(int64_t number)
     char working[CVT_BASE10_BUFFER_SIZE];
     cvtInt64ToZ(number, working, sizeof(working));
 
-    FUNCTION_TEST_RETURN(strNew(working));
+    FUNCTION_TEST_RETURN(strNewZ(working));
 }
 
 String *
@@ -644,7 +644,7 @@ jsonFromUInt(unsigned int number)
     char working[CVT_BASE10_BUFFER_SIZE];
     cvtUIntToZ(number, working, sizeof(working));
 
-    FUNCTION_TEST_RETURN(strNew(working));
+    FUNCTION_TEST_RETURN(strNewZ(working));
 }
 
 String *
@@ -657,7 +657,7 @@ jsonFromUInt64(uint64_t number)
     char working[CVT_BASE10_BUFFER_SIZE];
     cvtUInt64ToZ(number, working, sizeof(working));
 
-    FUNCTION_TEST_RETURN(strNew(working));
+    FUNCTION_TEST_RETURN(strNewZ(working));
 }
 
 /**********************************************************************************************************************************/
@@ -769,7 +769,7 @@ jsonFromStr(const String *string)
         FUNCTION_TEST_PARAM(STRING, string);
     FUNCTION_TEST_END();
 
-    String *json = strNew("");
+    String *json = strNew();
     jsonFromStrInternal(json, string);
 
     FUNCTION_TEST_RETURN(json);
@@ -787,7 +787,7 @@ jsonFromKvInternal(const KeyValue *kv)
 
     ASSERT(kv != NULL);
 
-    String *result = strNew("{");
+    String *result = strCatZ(strNew(), "{");
 
     MEM_CONTEXT_TEMP_BEGIN()
     {
@@ -930,7 +930,7 @@ jsonFromVar(const Variant *var)
 
     MEM_CONTEXT_TEMP_BEGIN()
     {
-        String *jsonStr = strNew("");
+        String *jsonStr = strNew();
 
         // If VariantList then process each item in the array. Currently the list must be KeyValue types.
         if (var == NULL)
@@ -957,8 +957,13 @@ jsonFromVar(const Variant *var)
         {
             const VariantList *vl = varVarLst(var);
 
-            // If not an empty array
-            if (!varLstEmpty(vl))
+            // If null
+            if (vl == NULL)
+            {
+                strCat(jsonStr, NULL_STR);
+            }
+            // Else if not an empty array
+            else if (!varLstEmpty(vl))
             {
                 strCatZ(jsonStr, "[");
 
