@@ -14,7 +14,7 @@ String Handler
 #include "common/memContext.h"
 #include "common/type/string.h"
 #include "common/type/stringList.h"
-#include "common/type/stringz.h"
+#include "common/type/stringZ.h"
 
 /***********************************************************************************************************************************
 Constant strings that are generally useful
@@ -39,6 +39,21 @@ STRING_EXTERN(TRUE_STR,                                             TRUE_Z);
 STRING_EXTERN(Y_STR,                                                Y_Z);
 STRING_EXTERN(ZERO_STR,                                             ZERO_Z);
 
+/***********************************************************************************************************************************
+Buffer macros
+***********************************************************************************************************************************/
+// Fixed size buffer allocated at the end of the object allocation
+#define STR_FIXED_BUFFER                                            (char *)(this + 1)
+
+// Is the string using the fixed size buffer?
+#define STR_IS_FIXED_BUFFER()                                       (this->pub.buffer == STR_FIXED_BUFFER)
+
+// Empty buffer
+#define STR_EMPTY_BUFFER                                            (EMPTY_STR->pub.buffer)
+
+// Is the string using the empty buffer?
+#define STR_IS_EMPTY_BUFFER()                                       (this->pub.buffer == STR_EMPTY_BUFFER)
+
 /***********************************************************************************************************************************
 Maximum size of a string
 ***********************************************************************************************************************************/
@@ -57,13 +72,62 @@ Object type
 ***********************************************************************************************************************************/
 struct String
 {
-    STRING_COMMON                                                   // Shared in common with constant strings
+    StringPub pub;                                                  // Publicly accessible variables
     MemContext *memContext;                                         // Required for dynamically allocated strings
 };
 
 /**********************************************************************************************************************************/
 String *
-strNew(const char *string)
+strNew(void)
+{
+    FUNCTION_TEST_VOID();
+
+    // Create object
+    String *this = memNew(sizeof(String));
+
+    *this = (String)
+    {
+        .pub =
+        {
+            // Set empty so nothing is allocated until needed
+            .buffer = STR_EMPTY_BUFFER,
+        },
+        .memContext = memContextCurrent(),
+    };
+
+    FUNCTION_TEST_RETURN(this);
+}
+
+/***********************************************************************************************************************************
+Create fixed size String
+***********************************************************************************************************************************/
+static String *
+strNewFixed(const size_t size)
+{
+    FUNCTION_TEST_BEGIN();
+        FUNCTION_TEST_PARAM(SIZE, size);
+    FUNCTION_TEST_END();
+
+    CHECK_SIZE(size);
+
+    String *this = memNew(sizeof(String) + size + 1);
+
+    *this = (String)
+    {
+        .pub =
+        {
+            .size = (unsigned int)size,
+            .buffer = STR_FIXED_BUFFER,
+        },
+        .memContext = memContextCurrent(),
+    };
+
+    FUNCTION_TEST_RETURN(this);
+}
+
+/**********************************************************************************************************************************/
+String *
+strNewZ(const char *const string)
 {
     FUNCTION_TEST_BEGIN();
         FUNCTION_TEST_PARAM(STRINGZ, string);
@@ -71,25 +135,12 @@ strNew(const char *string)
 
     ASSERT(string != NULL);
 
-    // Check size
-    size_t stringSize = strlen(string);
-    CHECK_SIZE(stringSize);
-
     // Create object
-    String *this = memNew(sizeof(String));
+    String *this = strNewFixed(strlen(string));
 
-    *this = (String)
-    {
-        .memContext = memContextCurrent(),
-        .size = (unsigned int)stringSize,
-
-        // A zero-length string is not very useful so assume this string is being created for appending and allocate extra space
-        .extra = stringSize == 0 ? STRING_EXTRA_MIN : 0,
-    };
-
-    // Allocate and assign string
-    this->buffer = memNew(this->size + this->extra + 1);
-    strcpy(this->buffer, string);
+    // Assign string
+    strncpy(this->pub.buffer, string, strSize(this));
+    this->pub.buffer[strSize(this)] = '\0';
 
     FUNCTION_TEST_RETURN(this);
 }
@@ -105,7 +156,7 @@ String *strNewDbl(double value)
 
     cvtDoubleToZ(value, working, sizeof(working));
 
-    FUNCTION_TEST_RETURN(strNew(working));
+    FUNCTION_TEST_RETURN(strNewZ(working));
 }
 
 /**********************************************************************************************************************************/
@@ -118,22 +169,12 @@ strNewBuf(const Buffer *buffer)
 
     ASSERT(buffer != NULL);
 
-    // Check size
-    CHECK_SIZE(bufUsed(buffer));
-
     // Create object
-    String *this = memNew(sizeof(String));
+    String *this = strNewFixed(bufUsed(buffer));
 
-    *this = (String)
-    {
-        .memContext = memContextCurrent(),
-        .size = (unsigned int)bufUsed(buffer),
-    };
-
-    // Allocate and assign string
-    this->buffer = memNew(this->size + 1);
-    memcpy(this->buffer, bufPtrConst(buffer), this->size);
-    this->buffer[this->size] = 0;
+    // Assign string
+    memcpy(this->pub.buffer, bufPtrConst(buffer), strSize(this));
+    this->pub.buffer[strSize(this)] = 0;
 
     FUNCTION_TEST_RETURN(this);
 }
@@ -149,22 +190,11 @@ strNewEncode(EncodeType type, const Buffer *buffer)
 
     ASSERT(buffer != NULL);
 
-    // Check encoded size
-    size_t size = encodeToStrSize(type, bufUsed(buffer));
-    CHECK_SIZE(size);
-
     // Create object
-    String *this = memNew(sizeof(String));
+    String *this = strNewFixed(encodeToStrSize(type, bufUsed(buffer)));
 
-    *this = (String)
-    {
-        .memContext = memContextCurrent(),
-        .size = (unsigned int)size,
-    };
-
-    // Allocate and encode buffer
-    this->buffer = memNew(this->size + 1);
-    encodeToStr(type, bufPtrConst(buffer), bufUsed(buffer), this->buffer);
+    // Encode buffer
+    encodeToStr(type, bufPtrConst(buffer), bufUsed(buffer), this->pub.buffer);
 
     FUNCTION_TEST_RETURN(this);
 }
@@ -179,28 +209,15 @@ strNewFmt(const char *format, ...)
 
     ASSERT(format != NULL);
 
-    // Create object
-    String *this = memNew(sizeof(String));
-
-    *this = (String)
-    {
-        .memContext = memContextCurrent(),
-    };
-
-    // Determine how long the allocated string needs to be
+    // Determine how long the allocated string needs to be and create object
     va_list argumentList;
     va_start(argumentList, format);
-    size_t formatSize = (size_t)vsnprintf(NULL, 0, format, argumentList);
+    String *this = strNewFixed((size_t)vsnprintf(NULL, 0, format, argumentList));
     va_end(argumentList);
 
-    // Check size
-    CHECK_SIZE(formatSize);
-
-    // Allocate and assign string
-    this->size = (unsigned int)formatSize;
-    this->buffer = memNew(this->size + 1);
+    // Format string
     va_start(argumentList, format);
-    vsnprintf(this->buffer, this->size + 1, format, argumentList);
+    vsnprintf(this->pub.buffer, strSize(this) + 1, format, argumentList);
     va_end(argumentList);
 
     FUNCTION_TEST_RETURN(this);
@@ -208,7 +225,7 @@ strNewFmt(const char *format, ...)
 
 /**********************************************************************************************************************************/
 String *
-strNewN(const char *string, size_t size)
+strNewZN(const char *string, size_t size)
 {
     FUNCTION_TEST_BEGIN();
         FUNCTION_TEST_PARAM_P(CHARDATA, string);
@@ -217,24 +234,13 @@ strNewN(const char *string, size_t size)
 
     ASSERT(string != NULL);
 
-    // Check size
-    CHECK_SIZE(size);
-
     // Create object
-    String *this = memNew(sizeof(String));
+    String *this = strNewFixed(size);
 
-    *this = (String)
-    {
-        .memContext = memContextCurrent(),
-        .size = (unsigned int)size,
-    };
+    // Assign string
+    strncpy(this->pub.buffer, string, strSize(this));
+    this->pub.buffer[strSize(this)] = 0;
 
-    // Allocate and assign string
-    this->buffer = memNew(this->size + 1);
-    strncpy(this->buffer, string, this->size);
-    this->buffer[this->size] = 0;
-
-    // Return buffer
     FUNCTION_TEST_RETURN(this);
 }
 
@@ -248,7 +254,7 @@ strBase(const String *this)
 
     ASSERT(this != NULL);
 
-    FUNCTION_TEST_RETURN(strNew(strBaseZ(this)));
+    FUNCTION_TEST_RETURN(strNewZ(strBaseZ(this)));
 }
 
 const char *
@@ -260,9 +266,9 @@ strBaseZ(const String *this)
 
     ASSERT(this != NULL);
 
-    const char *end = this->buffer + this->size;
+    const char *end = this->pub.buffer + strSize(this);
 
-    while (end > this->buffer && *(end - 1) != '/')
+    while (end > this->pub.buffer && *(end - 1) != '/')
         end--;
 
     FUNCTION_TEST_RETURN(end);
@@ -297,7 +303,7 @@ strBeginsWithZ(const String *this, const char *beginsWith)
     bool result = false;
     unsigned int beginsWithSize = (unsigned int)strlen(beginsWith);
 
-    if (this->size >= beginsWithSize)
+    if (strSize(this) >= beginsWithSize)
         result = strncmp(strZ(this), beginsWith, beginsWithSize) == 0;
 
     FUNCTION_TEST_RETURN(result);
@@ -314,21 +320,27 @@ strResize(String *this, size_t requested)
         FUNCTION_TEST_PARAM(SIZE, requested);
     FUNCTION_TEST_END();
 
-    if (requested > this->extra)
+    if (requested > this->pub.extra)
     {
+        // Fixed size strings may not be resized
+        CHECK(AssertError, !STR_IS_FIXED_BUFFER(), "resize of fixed size string");
+
         // Check size
-        CHECK_SIZE((size_t)this->size + requested);
+        CHECK_SIZE(strSize(this) + requested);
 
         // Calculate new extra needs to satisfy request and leave extra space for new growth
-        this->extra = (unsigned int)requested + ((this->size + (unsigned int)requested) / 2);
+        this->pub.extra = (unsigned int)(requested + ((strSize(this) + requested) / 2));
 
         // Adding too little extra space usually leads to immediate resizing so enforce a minimum
-        if (this->extra < STRING_EXTRA_MIN)
-            this->extra = STRING_EXTRA_MIN;
+        if (this->pub.extra < STRING_EXTRA_MIN)
+            this->pub.extra = STRING_EXTRA_MIN;
 
         MEM_CONTEXT_BEGIN(this->memContext)
         {
-            this->buffer = memResize(this->buffer, this->size + this->extra + 1);
+            if (STR_IS_EMPTY_BUFFER())
+                this->pub.buffer = memNew(strSize(this) + this->pub.extra + 1);
+            else
+                this->pub.buffer = memResize(this->pub.buffer, strSize(this) + this->pub.extra + 1);
         }
         MEM_CONTEXT_END();
     }
@@ -365,13 +377,16 @@ strCatZ(String *this, const char *cat)
     // Determine length of string to append
     size_t sizeGrow = strlen(cat);
 
-    // Ensure there is enough space to grow the string
-    strResize(this, sizeGrow);
+    if (sizeGrow != 0)
+    {
+        // Ensure there is enough space to grow the string
+        strResize(this, sizeGrow);
 
-    // Append the string
-    strcpy(this->buffer + this->size, cat);
-    this->size += (unsigned int)sizeGrow;
-    this->extra -= (unsigned int)sizeGrow;
+        // Append the string
+        strcpy(this->pub.buffer + strSize(this), cat);
+        this->pub.size += (unsigned int)sizeGrow;
+        this->pub.extra -= (unsigned int)sizeGrow;
+    }
 
     FUNCTION_TEST_RETURN(this);
 }
@@ -386,22 +401,41 @@ strCatZN(String *this, const char *cat, size_t size)
     FUNCTION_TEST_END();
 
     ASSERT(this != NULL);
-    ASSERT(cat != NULL);
 
-    // Ensure there is enough space to grow the string
-    strResize(this, size);
+    if (size != 0)
+    {
+        ASSERT(cat != NULL);
 
-    // Append the string
-    strncpy(this->buffer + this->size, cat, size);
-    this->buffer[this->size + size] = '\0';
+        // Ensure there is enough space to grow the string
+        strResize(this, size);
 
-    // Update size/extra
-    this->size += (unsigned int)size;
-    this->extra -= (unsigned int)size;
+        // Append the string
+        strncpy(this->pub.buffer + strSize(this), cat, size);
+        this->pub.buffer[strSize(this) + size] = '\0';
+
+        // Update size/extra
+        this->pub.size += (unsigned int)size;
+        this->pub.extra -= (unsigned int)size;
+    }
 
     FUNCTION_TEST_RETURN(this);
 }
 
+/**********************************************************************************************************************************/
+String *
+strCatBuf(String *const this, const Buffer *const buffer)
+{
+    FUNCTION_TEST_BEGIN();
+        FUNCTION_TEST_PARAM(STRING, this);
+        FUNCTION_TEST_PARAM(BUFFER, buffer);
+    FUNCTION_TEST_END();
+
+    ASSERT(this != NULL);
+    ASSERT(buffer != NULL);
+
+    FUNCTION_TEST_RETURN(strCatZN(this, (char *)bufPtrConst(buffer), bufUsed(buffer)));
+}
+
 /**********************************************************************************************************************************/
 String *
 strCatChr(String *this, char cat)
@@ -418,9 +452,9 @@ strCatChr(String *this, char cat)
     strResize(this, 1);
 
     // Append the character
-    this->buffer[this->size++] = cat;
-    this->buffer[this->size] = 0;
-    this->extra--;
+    this->pub.buffer[this->pub.size++] = cat;
+    this->pub.buffer[this->pub.size] = 0;
+    this->pub.extra--;
 
     FUNCTION_TEST_RETURN(this);
 }
@@ -438,16 +472,20 @@ strCatEncode(String *this, EncodeType type, const Buffer *buffer)
     ASSERT(this != NULL);
     ASSERT(buffer != NULL);
 
-    // Ensure there is enough space to grow the string
     size_t encodeSize = encodeToStrSize(type, bufUsed(buffer));
-    strResize(this, encodeSize);
 
-    // Append the encoded string
-    encodeToStr(type, bufPtrConst(buffer), bufUsed(buffer), this->buffer + this->size);
+    if (encodeSize != 0)
+    {
+        // Ensure there is enough space to grow the string
+        strResize(this, encodeSize);
 
-    // Update size/extra
-    this->size += (unsigned int)encodeSize;
-    this->extra -= (unsigned int)encodeSize;
+        // Append the encoded string
+        encodeToStr(type, bufPtrConst(buffer), bufUsed(buffer), this->pub.buffer + strSize(this));
+
+        // Update size/extra
+        this->pub.size += (unsigned int)encodeSize;
+        this->pub.extra -= (unsigned int)encodeSize;
+    }
 
     FUNCTION_TEST_RETURN(this);
 }
@@ -470,16 +508,19 @@ strCatFmt(String *this, const char *format, ...)
     size_t sizeGrow = (size_t)vsnprintf(NULL, 0, format, argumentList);
     va_end(argumentList);
 
-    // Ensure there is enough space to grow the string
-    strResize(this, sizeGrow);
+    if (sizeGrow != 0)
+    {
+        // Ensure there is enough space to grow the string
+        strResize(this, sizeGrow);
 
-    // Append the formatted string
-    va_start(argumentList, format);
-    vsnprintf(this->buffer + this->size, sizeGrow + 1, format, argumentList);
-    va_end(argumentList);
+        // Append the formatted string
+        va_start(argumentList, format);
+        vsnprintf(this->pub.buffer + strSize(this), sizeGrow + 1, format, argumentList);
+        va_end(argumentList);
 
-    this->size += (unsigned int)sizeGrow;
-    this->extra -= (unsigned int)sizeGrow;
+        this->pub.size += (unsigned int)sizeGrow;
+        this->pub.extra -= (unsigned int)sizeGrow;
+    }
 
     FUNCTION_TEST_RETURN(this);
 }
@@ -528,7 +569,7 @@ strDup(const String *this)
     String *result = NULL;
 
     if (this != NULL)
-        result = strNew(strZ(this));
+        result = strNewZ(strZ(this));
 
     FUNCTION_TEST_RETURN(result);
 }
@@ -573,8 +614,8 @@ strEndsWithZ(const String *this, const char *endsWith)
     bool result = false;
     unsigned int endsWithSize = (unsigned int)strlen(endsWith);
 
-    if (this->size >= endsWithSize)
-        result = strcmp(strZ(this) + (this->size - endsWithSize), endsWith) == 0;
+    if (strSize(this) >= endsWithSize)
+        result = strcmp(strZ(this) + (strSize(this) - endsWithSize), endsWith) == 0;
 
     FUNCTION_TEST_RETURN(result);
 }
@@ -595,7 +636,7 @@ strEq(const String *this, const String *compare)
 
     if (this != NULL && compare != NULL)
     {
-        if (this->size == compare->size)
+        if (strSize(this) == strSize(compare))
             result = strcmp(strZ(this), strZ(compare)) == 0;
     }
     else
@@ -628,8 +669,8 @@ strFirstUpper(String *this)
 
     ASSERT(this != NULL);
 
-    if (this->size > 0)
-        this->buffer[0] = (char)toupper(this->buffer[0]);
+    if (strSize(this) > 0)
+        this->pub.buffer[0] = (char)toupper(this->pub.buffer[0]);
 
     FUNCTION_TEST_RETURN(this);
 }
@@ -644,8 +685,8 @@ strFirstLower(String *this)
 
     ASSERT(this != NULL);
 
-    if (this->size > 0)
-        this->buffer[0] = (char)tolower(this->buffer[0]);
+    if (strSize(this) > 0)
+        this->pub.buffer[0] = (char)tolower(this->pub.buffer[0]);
 
     FUNCTION_TEST_RETURN(this);
 }
@@ -660,9 +701,8 @@ strUpper(String *this)
 
     ASSERT(this != NULL);
 
-    if (this->size > 0)
-        for (unsigned int idx = 0; idx <= this->size; idx++)
-            this->buffer[idx] = (char)toupper(this->buffer[idx]);
+    for (size_t idx = 0; idx < strSize(this); idx++)
+        this->pub.buffer[idx] = (char)toupper(this->pub.buffer[idx]);
 
     FUNCTION_TEST_RETURN(this);
 }
@@ -677,9 +717,8 @@ strLower(String *this)
 
     ASSERT(this != NULL);
 
-    if (this->size > 0)
-        for (unsigned int idx = 0; idx <= this->size; idx++)
-            this->buffer[idx] = (char)tolower(this->buffer[idx]);
+    for (size_t idx = 0; idx < strSize(this); idx++)
+        this->pub.buffer[idx] = (char)tolower(this->pub.buffer[idx]);
 
     FUNCTION_TEST_RETURN(this);
 }
@@ -694,15 +733,15 @@ strPath(const String *this)
 
     ASSERT(this != NULL);
 
-    const char *end = this->buffer + this->size;
+    const char *end = this->pub.buffer + strSize(this);
 
-    while (end > this->buffer && *(end - 1) != '/')
+    while (end > this->pub.buffer && *(end - 1) != '/')
         end--;
 
     FUNCTION_TEST_RETURN(
-        strNewN(
-            this->buffer,
-            end - this->buffer <= 1 ? (size_t)(end - this->buffer) : (size_t)(end - this->buffer - 1)));
+        strNewZN(
+            this->pub.buffer,
+            end - this->pub.buffer <= 1 ? (size_t)(end - this->pub.buffer) : (size_t)(end - this->pub.buffer - 1)));
 }
 
 /**********************************************************************************************************************************/
@@ -797,7 +836,7 @@ strZNull(const String *this)
         FUNCTION_TEST_PARAM(STRING, this);
     FUNCTION_TEST_END();
 
-    FUNCTION_TEST_RETURN(this == NULL ? NULL : this->buffer);
+    FUNCTION_TEST_RETURN(this == NULL ? NULL : strZ(this));
 }
 
 /**********************************************************************************************************************************/
@@ -841,10 +880,10 @@ strReplaceChr(String *this, char find, char replace)
 
     ASSERT(this != NULL);
 
-    for (unsigned int stringIdx = 0; stringIdx < this->size; stringIdx++)
+    for (size_t stringIdx = 0; stringIdx < strSize(this); stringIdx++)
     {
-        if (this->buffer[stringIdx] == find)
-            this->buffer[stringIdx] = replace;
+        if (this->pub.buffer[stringIdx] == find)
+            this->pub.buffer[stringIdx] = replace;
     }
 
     FUNCTION_TEST_RETURN(this);
@@ -860,9 +899,9 @@ strSub(const String *this, size_t start)
     FUNCTION_TEST_END();
 
     ASSERT(this != NULL);
-    ASSERT(start <= this->size);
+    ASSERT(start <= this->pub.size);
 
-    FUNCTION_TEST_RETURN(strSubN(this, start, this->size - start));
+    FUNCTION_TEST_RETURN(strSubN(this, start, strSize(this) - start));
 }
 
 /**********************************************************************************************************************************/
@@ -876,10 +915,10 @@ strSubN(const String *this, size_t start, size_t size)
     FUNCTION_TEST_END();
 
     ASSERT(this != NULL);
-    ASSERT(start <= this->size);
-    ASSERT(start + size <= this->size);
+    ASSERT(start <= strSize(this));
+    ASSERT(start + size <= strSize(this));
 
-    FUNCTION_TEST_RETURN(strNewN(this->buffer + start, size));
+    FUNCTION_TEST_RETURN(strNewZN(strZ(this) + start, size));
 }
 
 /**********************************************************************************************************************************/
@@ -893,16 +932,16 @@ strTrim(String *this)
     ASSERT(this != NULL);
 
     // Nothing to trim if size is zero
-    if (this->size > 0)
+    if (strSize(this) > 0)
     {
         // Find the beginning of the string skipping all whitespace
-        char *begin = this->buffer;
+        char *begin = this->pub.buffer;
 
         while (*begin != 0 && (*begin == ' ' || *begin == '\t' || *begin == '\r' || *begin == '\n'))
             begin++;
 
         // Find the end of the string skipping all whitespace
-        char *end = this->buffer + (this->size - 1);
+        char *end = this->pub.buffer + (strSize(this) - 1);
 
         while (end > begin && (*end == ' ' || *end == '\t' || *end == '\r' || *end == '\n'))
             end--;
@@ -910,22 +949,15 @@ strTrim(String *this)
         // Is there anything to trim?
         size_t newSize = (size_t)(end - begin + 1);
 
-        if (begin != this->buffer || newSize < strSize(this))
+        if (begin != this->pub.buffer || newSize < strSize(this))
         {
-            // Calculate new size
-            this->size = (unsigned int)newSize;
+            // Calculate new size and extra
+            this->pub.extra = (unsigned int)(strSize(this) - newSize);
+            this->pub.size = (unsigned int)newSize;
 
             // Move the substr to the beginning of the buffer
-            memmove(this->buffer, begin, this->size);
-            this->buffer[this->size] = 0;
-            this->extra = 0;
-
-            MEM_CONTEXT_BEGIN(this->memContext)
-            {
-                // Resize the buffer
-                this->buffer = memResize(this->buffer, this->size + 1);
-            }
-            MEM_CONTEXT_END();
+            memmove(this->pub.buffer, begin, strSize(this));
+            this->pub.buffer[strSize(this)] = 0;
         }
     }
 
@@ -945,12 +977,12 @@ strChr(const String *this, char chr)
 
     int result = -1;
 
-    if (this->size > 0)
+    if (strSize(this) > 0)
     {
-        const char *ptr = strchr(this->buffer, chr);
+        const char *ptr = strchr(this->pub.buffer, chr);
 
         if (ptr != NULL)
-            result = (int)(ptr - this->buffer);
+            result = (int)(ptr - this->pub.buffer);
     }
 
     FUNCTION_TEST_RETURN(result);
@@ -965,21 +997,14 @@ strTrunc(String *this, int idx)
     FUNCTION_TEST_END();
 
     ASSERT(this != NULL);
-    ASSERT(idx >= 0 && (size_t)idx <= this->size);
+    ASSERT(idx >= 0 && (size_t)idx <= strSize(this));
 
-    if (this->size > 0)
+    if (strSize(this) > 0)
     {
         // Reset the size to end at the index
-        this->size = (unsigned int)(idx);
-        this->buffer[this->size] = 0;
-        this->extra = 0;
-
-        MEM_CONTEXT_BEGIN(this->memContext)
-        {
-            // Resize the buffer
-            this->buffer = memResize(this->buffer, this->size + 1);
-        }
-        MEM_CONTEXT_END();
+        this->pub.extra = (unsigned int)(strSize(this) - (size_t)idx);
+        this->pub.size = (unsigned int)idx;
+        this->pub.buffer[strSize(this)] = 0;
     }
 
     FUNCTION_TEST_RETURN(this);
@@ -1060,7 +1085,9 @@ strFree(String *this)
     {
         MEM_CONTEXT_BEGIN(this->memContext)
         {
-            memFree(this->buffer);
+            if (!STR_IS_EMPTY_BUFFER() && !STR_IS_FIXED_BUFFER())
+                memFree(this->pub.buffer);
+
             memFree(this);
         }
         MEM_CONTEXT_END();
