@@ -8,7 +8,7 @@ old context and then back. Below is a simplified example:
     Variant *result = NULL;    <--- is created in the current memory context (referred to as "old context" below)
     MEM_CONTEXT_TEMP_BEGIN()   <--- begins a new temporary context
     {
-        String *resultStr = strNewN("myNewStr"); <--- creates a string in the temporary memory context
+        String *resultStr = strNewZN("myNewStr"); <--- creates a string in the temporary memory context
 
         MEM_CONTEXT_PRIOR_BEGIN() <--- switch to old context so creation of the variant from the string is in old context
         {
@@ -66,18 +66,53 @@ Variant *varNewVarLst(const VariantList *data);
 
 Variant *varDup(const Variant *this);
 
-/***********************************************************************************************************************************
-Functions
-***********************************************************************************************************************************/
-// Test if Variants are equal
-bool varEq(const Variant *this1, const Variant *this2);
-
-// Variant type
-VariantType varType(const Variant *this);
-
 /***********************************************************************************************************************************
 Getters/Setters
 ***********************************************************************************************************************************/
+#define VARIANT_COMMON                                                                                                             \
+    VariantType type;                                               /* Variant type */
+
+typedef struct VariantPub
+{
+    VARIANT_COMMON
+} VariantPub;
+
+typedef struct VariantBoolPub
+{
+    VARIANT_COMMON
+    bool data;                                                      // Boolean data
+} VariantBoolPub;
+
+typedef struct VariantIntPub
+{
+    VARIANT_COMMON
+    int data;                                                       // Signed integer data
+} VariantIntPub;
+
+typedef struct VariantInt64Pub
+{
+    VARIANT_COMMON
+    int64_t data;                                                   // 64-bit signed integer data
+} VariantInt64Pub;
+
+typedef struct VariantStringPub
+{
+    VARIANT_COMMON
+    String *data;                                                   // String data
+} VariantStringPub;
+
+typedef struct VariantUIntPub
+{
+    VARIANT_COMMON
+    unsigned int data;                                              // Unsigned integer data
+} VariantUIntPub;
+
+typedef struct VariantUInt64Pub
+{
+    VARIANT_COMMON
+    uint64_t data;                                                  // 64-bit unsigned integer data
+} VariantUInt64Pub;
+
 bool varBool(const Variant *this);
 bool varBoolForce(const Variant *this);
 
@@ -100,74 +135,24 @@ uint64_t varUInt64Force(const Variant *this);
 
 VariantList *varVarLst(const Variant *this);
 
+// Variant type
+__attribute__((always_inline)) static inline VariantType
+varType(const Variant *const this)
+{
+    return THIS_PUB(Variant)->type;
+}
+
+/***********************************************************************************************************************************
+Functions
+***********************************************************************************************************************************/
+// Test if Variants are equal
+bool varEq(const Variant *this1, const Variant *this2);
+
 /***********************************************************************************************************************************
 Destructor
 ***********************************************************************************************************************************/
 void varFree(Variant *this);
 
-/***********************************************************************************************************************************
-Fields that are common between dynamically allocated and constant variants
-
-There is nothing user-accessible here but this construct allows constant variants to be created and then handled by the same
-functions that process dynamically allocated variants.
-***********************************************************************************************************************************/
-#define VARIANT_COMMON                                                                                                             \
-    VariantType type;                                               /* Variant type */
-
-#define VARIANT_BOOL_COMMON                                                                                                        \
-    bool data;                                                      /* Boolean data */
-
-typedef struct VariantBoolConst
-{
-    VARIANT_COMMON
-    const VARIANT_BOOL_COMMON
-} VariantBoolConst;
-
-#define VARIANT_INT_COMMON                                                                                                         \
-    int data;                                                       /* Signed integer data */
-
-typedef struct VariantIntConst
-{
-    VARIANT_COMMON
-    const VARIANT_INT_COMMON
-} VariantIntConst;
-
-#define VARIANT_INT64_COMMON                                                                                                       \
-    int64_t data;                                                   /* 64-bit signed integer data */
-
-typedef struct VariantInt64Const
-{
-    VARIANT_COMMON
-    const VARIANT_INT64_COMMON
-} VariantInt64Const;
-
-#define VARIANT_STRING_COMMON                                                                                                      \
-    String *data;                                                   /* String data */
-
-typedef struct VariantStringConst
-{
-    VARIANT_COMMON
-    const VARIANT_STRING_COMMON
-} VariantStringConst;
-
-#define VARIANT_UINT_COMMON                                                                                                        \
-    unsigned int data;                                              /* unsigned integer data */
-
-typedef struct VariantUIntConst
-{
-    VARIANT_COMMON
-    const VARIANT_UINT_COMMON
-} VariantUIntConst;
-
-#define VARIANT_UINT64_COMMON                                                                                                      \
-    uint64_t data;                                                  /* 64-bit unsigned integer data */
-
-typedef struct VariantUInt64Const
-{
-    VARIANT_COMMON
-    const VARIANT_UINT64_COMMON
-} VariantUInt64Const;
-
 /***********************************************************************************************************************************
 Macros for constant variants
 
@@ -180,27 +165,27 @@ By convention all variant constant identifiers are appended with _VAR.
 ***********************************************************************************************************************************/
 // Create a Bool Variant constant inline from a bool
 #define VARBOOL(dataParam)                                                                                                         \
-    ((const Variant *)&(const VariantBoolConst){.type = varTypeBool, .data = dataParam})
+    ((const Variant *)&(const VariantBoolPub){.type = varTypeBool, .data = dataParam})
 
 // Create an Int Variant constant inline from an int
 #define VARINT(dataParam)                                                                                                          \
-    ((const Variant *)&(const VariantIntConst){.type = varTypeInt, .data = dataParam})
+    ((const Variant *)&(const VariantIntPub){.type = varTypeInt, .data = dataParam})
 
 // Create an Int64 Variant constant inline from an int64_t
 #define VARINT64(dataParam)                                                                                                        \
-    ((const Variant *)&(const VariantInt64Const){.type = varTypeInt64, .data = dataParam})
+    ((const Variant *)&(const VariantInt64Pub){.type = varTypeInt64, .data = dataParam})
 
 // Create a String Variant constant inline from any zero-terminated string
 #define VARSTRZ(dataParam)                                                                                                         \
-    ((const Variant *)&(const VariantStringConst){.type = varTypeString, .data = STR(dataParam)})
+    ((const Variant *)&(const VariantStringPub){.type = varTypeString, .data = (String *)STR(dataParam)})
 
 // Create a String Variant constant inline from a #define or inline string constant
 #define VARSTRDEF(dataParam)                                                                                                       \
-    ((const Variant *)&(const VariantStringConst){.type = varTypeString, .data = STRDEF(dataParam)})
+    ((const Variant *)&(const VariantStringPub){.type = varTypeString, .data = (String *)STRDEF(dataParam)})
 
 // Create a String Variant constant inline from a String constant
 #define VARSTR(dataParam)                                                                                                          \
-    ((const Variant *)&(const VariantStringConst){.type = varTypeString, .data = dataParam})
+    ((const Variant *)&(const VariantStringPub){.type = varTypeString, .data = (String *)(dataParam)})
 
 // Used to declare String Variant constants that will be externed using VARIANT_DECLARE().  Must be used in a .c file.
 #define VARIANT_STRDEF_EXTERN(name, dataParam)                                                                                     \
@@ -212,11 +197,11 @@ By convention all variant constant identifiers are appended with _VAR.
 
 // Create a UInt Variant constant inline from an unsigned int
 #define VARUINT(dataParam)                                                                                                         \
-    ((const Variant *)&(const VariantUIntConst){.type = varTypeUInt, .data = dataParam})
+    ((const Variant *)&(const VariantUIntPub){.type = varTypeUInt, .data = dataParam})
 
 // Create a UInt64 Variant constant inline from a uint64_t
 #define VARUINT64(dataParam)                                                                                                       \
-    ((const Variant *)&(const VariantUInt64Const){.type = varTypeUInt64, .data = dataParam})
+    ((const Variant *)&(const VariantUInt64Pub){.type = varTypeUInt64, .data = dataParam})
 
 // Used to extern String Variant constants declared with VARIANT_STRDEF_EXTERN/STATIC().  Must be used in a .h file.
 #define VARIANT_DECLARE(name)                                                                                                      \
