@@ -11,14 +11,13 @@ There are many capabilities of libxml2 that are not exposed here and may need to
 /***********************************************************************************************************************************
 Objects
 ***********************************************************************************************************************************/
-#define XML_DOCUMENT_TYPE                                           XmlDocument
-#define XML_DOCUMENT_PREFIX                                         xmlDocument
-
 typedef struct XmlDocument XmlDocument;
 typedef struct XmlNode XmlNode;
 typedef struct XmlNodeList XmlNodeList;
 
 #include "common/memContext.h"
+#include "common/type/list.h"
+#include "common/type/object.h"
 #include "common/type/string.h"
 
 /***********************************************************************************************************************************
@@ -30,25 +29,32 @@ XmlDocument *xmlDocumentNew(const String *rootNode);
 // Document from Buffer
 XmlDocument *xmlDocumentNewBuf(const Buffer *);
 
-// Document from C buffer
-XmlDocument *xmlDocumentNewC(const unsigned char *buffer, size_t bufferSize);
-
-// Document from zero-terminated string
-XmlDocument *xmlDocumentNewZ(const char *string);
-
 /***********************************************************************************************************************************
 Document Getters
 ***********************************************************************************************************************************/
+typedef struct XmlDocumentPub
+{
+    XmlNode *root;                                                  // Root node
+} XmlDocumentPub;
+
 // Dump document to a buffer
 Buffer *xmlDocumentBuf(const XmlDocument *this);
 
 // Root node
-XmlNode *xmlDocumentRoot(const XmlDocument *this);
+__attribute__((always_inline)) static inline XmlNode *
+xmlDocumentRoot(const XmlDocument *const this)
+{
+    return ((XmlDocumentPub *const)this)->root;
+}
 
 /***********************************************************************************************************************************
 Document Destructor
 ***********************************************************************************************************************************/
-void xmlDocumentFree(XmlDocument *this);
+__attribute__((always_inline)) static inline void
+xmlDocumentFree(XmlDocument *const this)
+{
+    objFree(this);
+}
 
 /***********************************************************************************************************************************
 Node Functions
@@ -63,9 +69,14 @@ Node Getters/Setters
 String *xmlNodeAttribute(const XmlNode *this, const String *name);
 
 // Node child (by name or index)
-XmlNode *xmlNodeChild(const XmlNode *this, const String *name, bool errorOnMissing);
 XmlNode *xmlNodeChildN(const XmlNode *this, const String *name, unsigned int index, bool errorOnMissing);
 
+__attribute__((always_inline)) static inline XmlNode *
+xmlNodeChild(const XmlNode *const this, const String *const name, const bool errorOnMissing)
+{
+    return xmlNodeChildN(this, name, 0, errorOnMissing);
+}
+
 // List of child nodes
 XmlNodeList *xmlNodeChildList(const XmlNode *this, const String *name);
 
@@ -85,15 +96,27 @@ void xmlNodeFree(XmlNode *this);
 Node List Getters
 ***********************************************************************************************************************************/
 // Get a node from the list
-XmlNode *xmlNodeLstGet(const XmlNodeList *this, unsigned int listIdx);
+__attribute__((always_inline)) static inline XmlNode *
+xmlNodeLstGet(const XmlNodeList *const this, const unsigned int listIdx)
+{
+    return *(XmlNode **)lstGet((List *const)this, listIdx);
+}
 
 // Node list size
-unsigned int xmlNodeLstSize(const XmlNodeList *this);
+__attribute__((always_inline)) static inline unsigned int
+xmlNodeLstSize(const XmlNodeList *const this)
+{
+    return lstSize((List *const)this);
+}
 
 /***********************************************************************************************************************************
 Node List Destructor
 ***********************************************************************************************************************************/
-void xmlNodeLstFree(XmlNodeList *this);
+__attribute__((always_inline)) static inline void
+xmlNodeLstFree(XmlNodeList *const this)
+{
+    lstFree((List *const)this);
+}
 
 /***********************************************************************************************************************************
 Macros for function logging
