@@ -7,34 +7,45 @@ Wait Handler
 /***********************************************************************************************************************************
 Wait object
 ***********************************************************************************************************************************/
-#define WAIT_TYPE                                                   Wait
-#define WAIT_PREFIX                                                 wait
-
 typedef struct Wait Wait;
 
 #include "common/time.h"
+#include "common/type/object.h"
 
 /***********************************************************************************************************************************
 Constructors
 ***********************************************************************************************************************************/
 Wait *waitNew(TimeMSec waitTime);
 
+/***********************************************************************************************************************************
+Getters/Setters
+***********************************************************************************************************************************/
+typedef struct WaitPub
+{
+    TimeMSec remainTime;                                            // Wait time remaining (in usec)
+} WaitPub;
+
+// How much time is remaining? Recalculated each time waitMore() is called.
+__attribute__((always_inline)) static inline TimeMSec
+waitRemaining(const Wait *const this)
+{
+    return THIS_PUB(Wait)->remainTime;
+}
+
 /***********************************************************************************************************************************
 Functions
 ***********************************************************************************************************************************/
 // Wait and return whether the caller has more time left
 bool waitMore(Wait *this);
 
-/***********************************************************************************************************************************
-Getters/Setters
-***********************************************************************************************************************************/
-// How much time is remaining? Recalculated each time waitMore() is called.
-TimeMSec waitRemaining(const Wait *this);
-
 /***********************************************************************************************************************************
 Destructor
 ***********************************************************************************************************************************/
-void waitFree(Wait *this);
+__attribute__((always_inline)) static inline void
+waitFree(Wait *const this)
+{
+    objFree(this);
+}
 
 /***********************************************************************************************************************************
 Macros for function logging
