@@ -19,6 +19,7 @@ Configuration Load
 #include "config/config.intern.h"
 #include "config/load.h"
 #include "config/parse.h"
+#include "info/infoBackup.h"
 #include "storage/cifs/storage.h"
 #include "storage/posix/storage.h"
 #include "storage/helper.h"
@@ -39,15 +40,13 @@ cfgLoadLogSetting(void)
     unsigned int logProcessMax = 1;
 
     if (cfgOptionValid(cfgOptLogLevelConsole))
-        logLevelConsole = logLevelEnum(strZ(cfgOptionStr(cfgOptLogLevelConsole)));
+        logLevelConsole = logLevelEnum(cfgOptionStrId(cfgOptLogLevelConsole));
 
     if (cfgOptionValid(cfgOptLogLevelStderr))
-    {
-        logLevelStdErr = logLevelEnum(strZ(cfgOptionStr(cfgOptLogLevelStderr)));
-    }
+        logLevelStdErr = logLevelEnum(cfgOptionStrId(cfgOptLogLevelStderr));
 
     if (cfgOptionValid(cfgOptLogLevelFile))
-        logLevelFile = logLevelEnum(strZ(cfgOptionStr(cfgOptLogLevelFile)));
+        logLevelFile = logLevelEnum(cfgOptionStrId(cfgOptLogLevelFile));
 
     if (cfgOptionValid(cfgOptLogTimestamp))
         logTimestamp = cfgOptionBool(cfgOptLogTimestamp);
@@ -77,7 +76,7 @@ cfgLoadUpdateOption(void)
             OptionRequiredError,
             "%s command requires option: " CFGOPT_REPO "\n"
             "HINT: this command requires a specific repository to operate on",
-            cfgCommandName(cfgCommand()));
+            cfgCommandName());
     }
 
     // If there is more than one repo configured
@@ -86,28 +85,32 @@ cfgLoadUpdateOption(void)
         for (unsigned int optionIdx = 0; optionIdx < cfgOptionGroupIdxTotal(cfgOptGrpRepo); optionIdx++)
         {
             // If the repo is local and either posix or cifs
-            if (!(cfgOptionIdxTest(cfgOptRepoHost, optionIdx)) &&
-                (strEq(cfgOptionIdxStr(cfgOptRepoType, optionIdx), STORAGE_POSIX_TYPE_STR) ||
-                strEq(cfgOptionIdxStr(cfgOptRepoType, optionIdx), STORAGE_CIFS_TYPE_STR)))
+            if (!cfgOptionIdxTest(cfgOptRepoHost, optionIdx) &&
+                (cfgOptionIdxStrId(cfgOptRepoType, optionIdx) == STORAGE_POSIX_TYPE ||
+                 cfgOptionIdxStrId(cfgOptRepoType, optionIdx) == STORAGE_CIFS_TYPE))
             {
                 // Ensure a local repo does not have the same path as another local repo of the same type
                 for (unsigned int repoIdx = 0; repoIdx < cfgOptionGroupIdxTotal(cfgOptGrpRepo); repoIdx++)
                 {
                     if (optionIdx != repoIdx && !(cfgOptionIdxTest(cfgOptRepoHost, repoIdx)) &&
-                        strEq(cfgOptionIdxStr(cfgOptRepoType, optionIdx), cfgOptionIdxStr(cfgOptRepoType, repoIdx)) &&
+                        cfgOptionIdxStrId(cfgOptRepoType, optionIdx) == cfgOptionIdxStrId(cfgOptRepoType, repoIdx) &&
                         strEq(cfgOptionIdxStr(cfgOptRepoPath, optionIdx), cfgOptionIdxStr(cfgOptRepoPath, repoIdx)))
                     {
                         THROW_FMT(
                             OptionInvalidValueError,
                             "local repo%u and repo%u paths are both '%s' but must be different",
                             cfgOptionGroupIdxToKey(cfgOptGrpRepo, optionIdx), cfgOptionGroupIdxToKey(cfgOptGrpRepo, repoIdx),
-                            strZ(cfgOptionIdxStr(cfgOptRepoPath, repoIdx)));
+                            strZ(cfgOptionIdxDisplay(cfgOptRepoPath, repoIdx)));
                     }
                 }
             }
         }
     }
 
+    // Set default for cmd
+    if (cfgOptionValid(cfgOptCmd))
+        cfgOptionDefaultSet(cfgOptCmd, VARSTR(cfgExe()));
+
     // Set default for repo-host-cmd
     if (cfgOptionValid(cfgOptRepoHostCmd))
         cfgOptionDefaultSet(cfgOptRepoHostCmd, VARSTR(cfgExe()));
@@ -145,8 +148,8 @@ cfgLoadUpdateOption(void)
                 OptionInvalidValueError,
                 "'%s' is not valid for '" CFGOPT_PROTOCOL_TIMEOUT "' option\nHINT '" CFGOPT_PROTOCOL_TIMEOUT "' option (%s)"
                     " should be greater than '" CFGOPT_DB_TIMEOUT "' option (%s).",
-                strZ(varStrForce(cfgOption(cfgOptProtocolTimeout))),  strZ(varStrForce(cfgOption(cfgOptProtocolTimeout))),
-                strZ(varStrForce(cfgOption(cfgOptDbTimeout))));
+                strZ(cfgOptionDisplay(cfgOptProtocolTimeout)),  strZ(cfgOptionDisplay(cfgOptProtocolTimeout)),
+                strZ(cfgOptionDisplay(cfgOptDbTimeout)));
         }
     }
 
@@ -186,7 +189,7 @@ cfgLoadUpdateOption(void)
                     "option '%s' is not set for '%s=%s', the repository may run out of space"
                     "\nHINT: to retain full backups indefinitely (without warning), set option '%s' to the maximum.",
                     cfgOptionIdxName(cfgOptRepoRetentionFull, optionIdx), cfgOptionIdxName(cfgOptRepoRetentionFullType, optionIdx),
-                    strZ(cfgOptionIdxStr(cfgOptRepoRetentionFullType, optionIdx)),
+                    strZ(cfgOptionIdxDisplay(cfgOptRepoRetentionFullType, optionIdx)),
                     cfgOptionIdxName(cfgOptRepoRetentionFull, optionIdx));
             }
         }
@@ -198,52 +201,57 @@ cfgLoadUpdateOption(void)
         // For each possible repo, check and adjust the settings as appropriate
         for (unsigned int optionIdx = 0; optionIdx < cfgOptionGroupIdxTotal(cfgOptGrpRepo); optionIdx++)
         {
-            const String *archiveRetentionType = cfgOptionIdxStr(cfgOptRepoRetentionArchiveType, optionIdx);
+            const BackupType archiveRetentionType = (BackupType)cfgOptionIdxStrId(cfgOptRepoRetentionArchiveType, optionIdx);
 
             const String *msgArchiveOff = strNewFmt(
                 "WAL segments will not be expired: option '%s=%s' but", cfgOptionIdxName(cfgOptRepoRetentionArchiveType, optionIdx),
-                strZ(archiveRetentionType));
+                strZ(strIdToStr(archiveRetentionType)));
 
             // If the archive retention is not explicitly set then determine what it should be defaulted to
             if (!cfgOptionIdxTest(cfgOptRepoRetentionArchive, optionIdx))
             {
                 // If repo-retention-archive-type is default (full), then if repo-retention-full is set, set the
                 // repo-retention-archive to this value when retention-full-type is 'count', else ignore archiving. If
-                // retention-full-type is 'time' then the the expire command will default the archive retention accordingly.
-                if (strEqZ(archiveRetentionType, CFGOPTVAL_TMP_REPO_RETENTION_ARCHIVE_TYPE_FULL))
+                // retention-full-type is 'time' then the expire command will default the archive retention accordingly.
+                switch (archiveRetentionType)
                 {
-                    if (strEqZ(
-                            cfgOptionIdxStr(cfgOptRepoRetentionFullType, optionIdx),
-                            CFGOPTVAL_TMP_REPO_RETENTION_FULL_TYPE_COUNT) &&
-                        cfgOptionIdxTest(cfgOptRepoRetentionFull, optionIdx))
+                    case backupTypeFull:
                     {
-                        cfgOptionIdxSet(cfgOptRepoRetentionArchive, optionIdx, cfgSourceDefault,
-                            VARUINT(cfgOptionIdxUInt(cfgOptRepoRetentionFull, optionIdx)));
-                    }
-                }
-                else if (strEqZ(archiveRetentionType, CFGOPTVAL_TMP_REPO_RETENTION_ARCHIVE_TYPE_DIFF))
-                {
-                    // if repo-retention-diff is set then user must have set it
-                    if (cfgOptionIdxTest(cfgOptRepoRetentionDiff, optionIdx))
-                    {
-                        cfgOptionIdxSet(cfgOptRepoRetentionArchive, optionIdx, cfgSourceDefault,
-                            VARUINT(cfgOptionIdxUInt(cfgOptRepoRetentionDiff, optionIdx)));
-                    }
-                    else
-                    {
-                        LOG_WARN_FMT(
-                            "%s neither option '%s' nor option '%s' is set", strZ(msgArchiveOff),
-                            cfgOptionIdxName(cfgOptRepoRetentionArchive, optionIdx),
-                            cfgOptionIdxName(cfgOptRepoRetentionDiff, optionIdx));
-                    }
-                }
-                else
-                {
-                    CHECK(strEqZ(archiveRetentionType, CFGOPTVAL_TMP_REPO_RETENTION_ARCHIVE_TYPE_INCR));
+                        if (cfgOptionIdxStrId(cfgOptRepoRetentionFullType, optionIdx) ==
+                                CFGOPTVAL_REPO_RETENTION_FULL_TYPE_COUNT &&
+                            cfgOptionIdxTest(cfgOptRepoRetentionFull, optionIdx))
+                        {
+                            cfgOptionIdxSet(cfgOptRepoRetentionArchive, optionIdx, cfgSourceDefault,
+                                VARINT64(cfgOptionIdxInt64(cfgOptRepoRetentionFull, optionIdx)));
+                        }
 
-                    LOG_WARN_FMT(
-                        "%s option '%s' is not set", strZ(msgArchiveOff),
-                        cfgOptionIdxName(cfgOptRepoRetentionArchive, optionIdx));
+                        break;
+                    }
+
+                    case backupTypeDiff:
+                    {
+                        // if repo-retention-diff is set then user must have set it
+                        if (cfgOptionIdxTest(cfgOptRepoRetentionDiff, optionIdx))
+                        {
+                            cfgOptionIdxSet(cfgOptRepoRetentionArchive, optionIdx, cfgSourceDefault,
+                                VARINT64(cfgOptionIdxInt64(cfgOptRepoRetentionDiff, optionIdx)));
+                        }
+                        else
+                        {
+                            LOG_WARN_FMT(
+                                "%s neither option '%s' nor option '%s' is set", strZ(msgArchiveOff),
+                                cfgOptionIdxName(cfgOptRepoRetentionArchive, optionIdx),
+                                cfgOptionIdxName(cfgOptRepoRetentionDiff, optionIdx));
+                        }
+
+                        break;
+                    }
+
+                    case backupTypeIncr:
+                        LOG_WARN_FMT(
+                            "%s option '%s' is not set", strZ(msgArchiveOff),
+                            cfgOptionIdxName(cfgOptRepoRetentionArchive, optionIdx));
+                        break;
                 }
             }
             else
@@ -251,14 +259,13 @@ cfgLoadUpdateOption(void)
                 // If repo-retention-archive is set then check repo-retention-archive-type and issue a warning if the
                 // corresponding setting is UNDEF since UNDEF means backups will not be expired but they should be in the
                 // practice of setting this value even though expiring the archive itself is OK and will be performed.
-                if ((strEqZ(archiveRetentionType, CFGOPTVAL_TMP_REPO_RETENTION_ARCHIVE_TYPE_DIFF)) &&
-                    (!cfgOptionIdxTest(cfgOptRepoRetentionDiff, optionIdx)))
+                if (archiveRetentionType == backupTypeDiff && !cfgOptionIdxTest(cfgOptRepoRetentionDiff, optionIdx))
                 {
-                    LOG_WARN_FMT("option '%s' is not set for '%s=%s'\n"
+                    LOG_WARN_FMT(
+                        "option '%s' is not set for '%s=" CFGOPTVAL_TYPE_DIFF_Z "'\n"
                         "HINT: to retain differential backups indefinitely (without warning), set option '%s' to the maximum.",
                         cfgOptionIdxName(cfgOptRepoRetentionDiff, optionIdx),
                         cfgOptionIdxName(cfgOptRepoRetentionArchiveType, optionIdx),
-                        CFGOPTVAL_TMP_REPO_RETENTION_ARCHIVE_TYPE_DIFF,
                         cfgOptionIdxName(cfgOptRepoRetentionDiff, optionIdx));
                 }
             }
@@ -277,7 +284,35 @@ cfgLoadUpdateOption(void)
                     "\nHINT: RFC-2818 forbids dots in wildcard matches."
                     "\nHINT: TLS/SSL verification cannot proceed with this bucket name."
                     "\nHINT: remove dots from the bucket name.",
-                strZ(cfgOptionIdxStr(cfgOptRepoS3Bucket, repoIdx)), cfgOptionIdxName(cfgOptRepoS3Bucket, repoIdx));
+                strZ(cfgOptionIdxDisplay(cfgOptRepoS3Bucket, repoIdx)), cfgOptionIdxName(cfgOptRepoS3Bucket, repoIdx));
+        }
+    }
+
+    // Set pg-host-port/repo-host-port default when pg-host-type/repo-host-type is tls. ??? This should be handled in the parser but
+    // it requires a default that depends on another option value and that is not currently possible.
+    #define HOST_PORT_TLS                                           8432
+
+    if (cfgOptionValid(cfgOptRepoHostPort))
+    {
+        for (unsigned int repoIdx = 0; repoIdx < cfgOptionGroupIdxTotal(cfgOptGrpRepo); repoIdx++)
+        {
+            if (cfgOptionIdxStrId(cfgOptRepoHostType, repoIdx) == CFGOPTVAL_REPO_HOST_TYPE_TLS &&
+                cfgOptionIdxSource(cfgOptRepoHostPort, repoIdx) == cfgSourceDefault)
+            {
+                cfgOptionIdxSet(cfgOptRepoHostPort, repoIdx, cfgSourceDefault, VARINT64(HOST_PORT_TLS));
+            }
+        }
+    }
+
+    if (cfgOptionValid(cfgOptPgHostPort))
+    {
+        for (unsigned int pgIdx = 0; pgIdx < cfgOptionGroupIdxTotal(cfgOptGrpPg); pgIdx++)
+        {
+            if (cfgOptionIdxStrId(cfgOptPgHostType, pgIdx) == CFGOPTVAL_PG_HOST_TYPE_TLS &&
+                cfgOptionIdxSource(cfgOptPgHostPort, pgIdx) == cfgSourceDefault)
+            {
+                cfgOptionIdxSet(cfgOptPgHostPort, pgIdx, cfgSourceDefault, VARINT64(HOST_PORT_TLS));
+            }
         }
     }
 
@@ -296,7 +331,7 @@ cfgLoadUpdateOption(void)
             // Set compress-type to none. Eventually the compress option will be deprecated and removed so this reduces code churn
             // when that happens.
             if (!cfgOptionBool(cfgOptCompress) && cfgOptionSource(cfgOptCompressType) == cfgSourceDefault)
-                cfgOptionSet(cfgOptCompressType, cfgSourceParam, VARSTR(compressTypeStr(compressTypeNone)));
+                cfgOptionSet(cfgOptCompressType, cfgSourceParam, VARUINT64(CFGOPTVAL_COMPRESS_TYPE_NONE));
         }
 
         // Now invalidate compress so it can't be used and won't be passed to child processes
@@ -306,14 +341,14 @@ cfgLoadUpdateOption(void)
 
     // Check that selected compress type has been compiled into this binary
     if (cfgOptionValid(cfgOptCompressType))
-        compressTypePresent(compressTypeEnum(cfgOptionStr(cfgOptCompressType)));
+        compressTypePresent(compressTypeEnum(cfgOptionStrId(cfgOptCompressType)));
 
     // Update compress-level default based on the compression type
     if (cfgOptionValid(cfgOptCompressLevel) && cfgOptionSource(cfgOptCompressLevel) == cfgSourceDefault)
     {
         cfgOptionSet(
             cfgOptCompressLevel, cfgSourceDefault,
-            VARINT(compressLevelDefault(compressTypeEnum(cfgOptionStr(cfgOptCompressType)))));
+            VARINT64(compressLevelDefault(compressTypeEnum(cfgOptionStrId(cfgOptCompressType)))));
     }
 
     FUNCTION_LOG_RETURN_VOID();
@@ -328,9 +363,10 @@ cfgLoadLogFile(void)
         MEM_CONTEXT_TEMP_BEGIN()
         {
             // Construct log filename prefix
-            String *logFile = strNewFmt(
+            String *logFile = strCatFmt(
+                strNew(),
                 "%s/%s-%s", strZ(cfgOptionStr(cfgOptLogPath)),
-                cfgOptionTest(cfgOptStanza) ? strZ(cfgOptionStr(cfgOptStanza)): "all", cfgCommandName(cfgCommand()));
+                cfgOptionTest(cfgOptStanza) ? strZ(cfgOptionStr(cfgOptStanza)): "all", cfgCommandName());
 
             // ??? Append async for local/remote archive async commands.  It would be good to find a more generic way to do this in
             // case the async role is added to more commands.
@@ -340,9 +376,9 @@ cfgLoadLogFile(void)
                     strCatFmt(logFile, "-async");
             }
 
-            // Add command role if it is not default
-            if (cfgCommandRole() != cfgCmdRoleDefault)
-                strCatFmt(logFile, "-%s", strZ(cfgCommandRoleStr(cfgCommandRole())));
+            // Add command role if it is not main
+            if (cfgCommandRole() != cfgCmdRoleMain)
+                strCatFmt(logFile, "-%s", strZ(cfgParseCommandRoleStr(cfgCommandRole())));
 
             // Add process id if local or remote role
             if (cfgCommandRole() == cfgCmdRoleLocal || cfgCommandRole() == cfgCmdRoleRemote)
@@ -353,7 +389,7 @@ cfgLoadLogFile(void)
 
             // Attempt to open log file
             if (!logFileSet(strZ(logFile)))
-                cfgOptionSet(cfgOptLogLevelFile, cfgSourceParam, varNewStrZ("off"));
+                cfgOptionSet(cfgOptLogLevelFile, cfgSourceParam, VARUINT64(CFGOPTVAL_LOG_LEVEL_CONSOLE_OFF));
         }
         MEM_CONTEXT_TEMP_END();
     }
