@@ -5,9 +5,10 @@ Database Client
 
 #include "common/debug.h"
 #include "common/log.h"
-#include "common/memContext.h"
-#include "common/type/object.h"
+#include "common/type/json.h"
 #include "common/wait.h"
+#include "config/config.h"
+#include "config/protocol.h"
 #include "db/db.h"
 #include "db/protocol.h"
 #include "postgres/interface.h"
@@ -19,68 +20,79 @@ Database Client
 Constants
 ***********************************************************************************************************************************/
 #define PG_BACKUP_ADVISORY_LOCK                                     "12340078987004321"
+#define DB_PING_SEC                                                 30
 
 /***********************************************************************************************************************************
 Object type
 ***********************************************************************************************************************************/
 struct Db
 {
-    MemContext *memContext;
+    DbPub pub;                                                      // Publicly accessible variables
     PgClient *client;                                               // Local PostgreSQL client
     ProtocolClient *remoteClient;                                   // Protocol client for remote db queries
     unsigned int remoteIdx;                                         // Index provided by the remote on open for subsequent calls
+    const Storage *storage;                                         // PostgreSQL storage
     const String *applicationName;                                  // Used to identify this connection in PostgreSQL
-
-    unsigned int pgVersion;                                         // Version as reported by the database
-    const String *pgDataPath;                                       // Data directory reported by the database
-    const String *archiveMode;                                      // The archive_mode reported by the database
-    const String *archiveCommand;                                   // The archive_command reported by the database
+    time_t pingTimeLast;                                            // Last time cluster was pinged
 };
 
-OBJECT_DEFINE_MOVE(DB);
-OBJECT_DEFINE_FREE(DB);
-
 /***********************************************************************************************************************************
 Close protocol connection.  No need to close a locally created PgClient since it has its own destructor.
 ***********************************************************************************************************************************/
-OBJECT_DEFINE_FREE_RESOURCE_BEGIN(DB, LOG, logLevelTrace)
+static void
+dbFreeResource(THIS_VOID)
 {
-    ProtocolCommand *command = protocolCommandNew(PROTOCOL_COMMAND_DB_CLOSE_STR);
-    protocolCommandParamAdd(command, VARUINT(this->remoteIdx));
+    THIS(Db);
+
+    FUNCTION_LOG_BEGIN(logLevelTrace);
+        FUNCTION_LOG_PARAM(DB, this);
+    FUNCTION_LOG_END();
+
+    ASSERT(this != NULL);
+
+    ProtocolCommand *command = protocolCommandNew(PROTOCOL_COMMAND_DB_CLOSE);
+    pckWriteU32P(protocolCommandParam(command), this->remoteIdx);
 
     protocolClientExecute(this->remoteClient, command, false);
+
+    FUNCTION_LOG_RETURN_VOID();
 }
-OBJECT_DEFINE_FREE_RESOURCE_END(LOG);
 
 /**********************************************************************************************************************************/
 Db *
-dbNew(PgClient *client, ProtocolClient *remoteClient, const String *applicationName)
+dbNew(PgClient *client, ProtocolClient *remoteClient, const Storage *const storage, const String *applicationName)
 {
     FUNCTION_LOG_BEGIN(logLevelDebug);
         FUNCTION_LOG_PARAM(PG_CLIENT, client);
         FUNCTION_LOG_PARAM(PROTOCOL_CLIENT, remoteClient);
+        FUNCTION_LOG_PARAM(STORAGE, storage);
         FUNCTION_LOG_PARAM(STRING, applicationName);
     FUNCTION_LOG_END();
 
     ASSERT((client != NULL && remoteClient == NULL) || (client == NULL && remoteClient != NULL));
+    ASSERT(storage != NULL);
     ASSERT(applicationName != NULL);
 
     Db *this = NULL;
 
-    MEM_CONTEXT_NEW_BEGIN("Db")
+    OBJ_NEW_BEGIN(Db)
     {
-        this = memNew(sizeof(Db));
+        this = OBJ_NEW_ALLOC();
 
         *this = (Db)
         {
-            .memContext = memContextCurrent(),
+            .pub =
+            {
+                .memContext = memContextCurrent(),
+            },
             .remoteClient = remoteClient,
+            .storage = storage,
             .applicationName = strDup(applicationName),
         };
 
-        this->client = pgClientMove(client, this->memContext);
+        this->client = pgClientMove(client, this->pub.memContext);
     }
-    MEM_CONTEXT_NEW_END();
+    OBJ_NEW_END();
 
     FUNCTION_LOG_RETURN(DB, this);
 }
@@ -104,11 +116,13 @@ dbQuery(Db *this, const String *query)
     // Query remotely
     if (this->remoteClient != NULL)
     {
-        ProtocolCommand *command = protocolCommandNew(PROTOCOL_COMMAND_DB_QUERY_STR);
-        protocolCommandParamAdd(command, VARUINT(this->remoteIdx));
-        protocolCommandParamAdd(command, VARSTR(query));
+        ProtocolCommand *command = protocolCommandNew(PROTOCOL_COMMAND_DB_QUERY);
+        PackWrite *const param = protocolCommandParam(command);
 
-        result = varVarLst(protocolClientExecute(this->remoteClient, command, true));
+        pckWriteU32P(param, this->remoteIdx);
+        pckWriteStrP(param, query);
+
+        result = varVarLst(jsonToVar(pckReadStrP(protocolClientExecute(this->remoteClient, command, true))));
     }
     // Else locally
     else
@@ -131,7 +145,7 @@ dbExec(Db *this, const String *command)
     ASSERT(this != NULL);
     ASSERT(command != NULL);
 
-    CHECK(dbQuery(this, command) == NULL);
+    CHECK(AssertError, dbQuery(this, command) == NULL, "exec returned data");
 
     FUNCTION_LOG_RETURN_VOID();
 }
@@ -152,8 +166,8 @@ dbQueryColumn(Db *this, const String *query)
 
     VariantList *result = dbQuery(this, query);
 
-    CHECK(varLstSize(result) == 1);
-    CHECK(varLstSize(varVarLst(varLstGet(result, 0))) == 1);
+    CHECK(AssertError, varLstSize(result) == 1, "query must return one column");
+    CHECK(AssertError, varLstSize(varVarLst(varLstGet(result, 0))) == 1, "query must return one row");
 
     FUNCTION_LOG_RETURN(VARIANT, varLstGet(varVarLst(varLstGet(result, 0)), 0));
 }
@@ -174,11 +188,31 @@ dbQueryRow(Db *this, const String *query)
 
     VariantList *result = dbQuery(this, query);
 
-    CHECK(varLstSize(result) == 1);
+    CHECK(AssertError, varLstSize(result) == 1, "query must return one row");
 
     FUNCTION_LOG_RETURN(VARIANT_LIST, varVarLst(varLstGet(result, 0)));
 }
 
+/***********************************************************************************************************************************
+Is the cluster in recovery?
+***********************************************************************************************************************************/
+static bool
+dbIsInRecovery(Db *const this)
+{
+    FUNCTION_LOG_BEGIN(logLevelDebug);
+        FUNCTION_LOG_PARAM(DB, this);
+    FUNCTION_LOG_END();
+
+    ASSERT(this != NULL);
+
+    bool result = false;
+
+    if (dbPgVersion(this) >= PG_VERSION_HOT_STANDBY)
+        result = varBool(dbQueryColumn(this, STRDEF("select pg_catalog.pg_is_in_recovery()")));
+
+    FUNCTION_LOG_RETURN(BOOL, result);
+}
+
 /**********************************************************************************************************************************/
 void
 dbOpen(Db *this)
@@ -194,14 +228,21 @@ dbOpen(Db *this)
         // Open the connection
         if (this->remoteClient != NULL)
         {
-            ProtocolCommand *command = protocolCommandNew(PROTOCOL_COMMAND_DB_OPEN_STR);
-            this->remoteIdx = varUIntForce(protocolClientExecute(this->remoteClient, command, true));
+            ProtocolCommand *command = protocolCommandNew(PROTOCOL_COMMAND_DB_OPEN);
+            this->remoteIdx = pckReadU32P(protocolClientExecute(this->remoteClient, command, true));
 
             // Set a callback to notify the remote when a connection is closed
-            memContextCallbackSet(this->memContext, dbFreeResource, this);
+            memContextCallbackSet(this->pub.memContext, dbFreeResource, this);
+
+            // Get db-timeout from the remote since it might be different than the local value
+            this->pub.dbTimeout = varUInt64Force(
+                varLstGet(configOptionRemote(this->remoteClient, varLstAdd(varLstNew(), varNewStrZ(CFGOPT_DB_TIMEOUT))), 0));
         }
         else
+        {
             pgClientOpen(this->client);
+            this->pub.dbTimeout = cfgOptionUInt64(cfgOptDbTimeout);
+        }
 
         // Set search_path to prevent overrides of the functions we expect to call.  All queries should also be schema-qualified,
         // but this is an extra level protection.
@@ -217,7 +258,8 @@ dbOpen(Db *this)
                 "select (select setting from pg_catalog.pg_settings where name = 'server_version_num')::int4,"
                 " (select setting from pg_catalog.pg_settings where name = 'data_directory')::text,"
                 " (select setting from pg_catalog.pg_settings where name = 'archive_mode')::text,"
-                " (select setting from pg_catalog.pg_settings where name = 'archive_command')::text"));
+                " (select setting from pg_catalog.pg_settings where name = 'archive_command')::text,"
+                " (select setting from pg_catalog.pg_settings where name = 'checkpoint_timeout')::int4"));
 
         // Check that none of the return values are null, which indicates the user cannot select some rows in pg_settings
         for (unsigned int columnIdx = 0; columnIdx < varLstSize(row); columnIdx++)
@@ -234,26 +276,34 @@ dbOpen(Db *this)
 
         // Strip the minor version off since we don't need it.  In the future it might be a good idea to warn users when they are
         // running an old minor version.
-        this->pgVersion = varUIntForce(varLstGet(row, 0)) / 100 * 100;
+        this->pub.pgVersion = varUIntForce(varLstGet(row, 0)) / 100 * 100;
 
         // Store the data directory that PostgreSQL is running in, the archive mode, and archive command. These can be compared to
         // the configured pgBackRest directory, and archive settings checked for validity, when validating the configuration.
-        MEM_CONTEXT_BEGIN(this->memContext)
+        // Also store the checkpoint timeout to warn in case a backup is requested without using the start-fast option.
+        MEM_CONTEXT_BEGIN(this->pub.memContext)
         {
-            this->pgDataPath = strDup(varStr(varLstGet(row, 1)));
-            this->archiveMode = strDup(varStr(varLstGet(row, 2)));
-            this->archiveCommand = strDup(varStr(varLstGet(row, 3)));
+            this->pub.pgDataPath = strDup(varStr(varLstGet(row, 1)));
+            this->pub.archiveMode = strDup(varStr(varLstGet(row, 2)));
+            this->pub.archiveCommand = strDup(varStr(varLstGet(row, 3)));
+            this->pub.checkpointTimeout = (TimeMSec)(varUIntForce(varLstGet(row, 4))) * MSEC_PER_SEC;
         }
         MEM_CONTEXT_END();
 
         // Set application name to help identify the backup session
-        if (this->pgVersion >= PG_VERSION_APPLICATION_NAME)
+        if (dbPgVersion(this) >= PG_VERSION_APPLICATION_NAME)
             dbExec(this, strNewFmt("set application_name = '%s'", strZ(this->applicationName)));
 
         // There is no need to have parallelism enabled in a backup session. In particular, 9.6 marks pg_stop_backup() as
         // parallel-safe but an error will be thrown if pg_stop_backup() is run in a worker.
-        if (this->pgVersion >= PG_VERSION_PARALLEL_QUERY)
+        if (dbPgVersion(this) >= PG_VERSION_PARALLEL_QUERY)
             dbExec(this, STRDEF("set max_parallel_workers_per_gather = 0"));
+
+        // Is the cluster a standby?
+        this->pub.standby = dbIsInRecovery(this);
+
+        // Get control file
+        this->pub.pgControl = pgControlFromFile(this->storage);
     }
     MEM_CONTEXT_TEMP_END();
 
@@ -271,7 +321,8 @@ dbBackupStartQuery(unsigned int pgVersion, bool startFast)
     FUNCTION_TEST_END();
 
     // Build query to return start lsn and WAL segment name
-    String *result = strNewFmt(
+    String *result = strCatFmt(
+        strNew(),
         "select lsn::text as lsn,\n"
         "       pg_catalog.pg_%sfile_name(lsn)::text as wal_segment_name\n"
         "  from pg_catalog.pg_start_backup('" PROJECT_NAME " backup started at ' || current_timestamp",
@@ -297,12 +348,13 @@ dbBackupStartQuery(unsigned int pgVersion, bool startFast)
 }
 
 DbBackupStartResult
-dbBackupStart(Db *this, bool startFast, bool stopAuto)
+dbBackupStart(Db *const this, const bool startFast, const bool stopAuto, const bool archiveCheck)
 {
     FUNCTION_LOG_BEGIN(logLevelDebug);
         FUNCTION_LOG_PARAM(DB, this);
         FUNCTION_LOG_PARAM(BOOL, startFast);
         FUNCTION_LOG_PARAM(BOOL, stopAuto);
+        FUNCTION_LOG_PARAM(BOOL, archiveCheck);
     FUNCTION_LOG_END();
 
     ASSERT(this != NULL);
@@ -324,8 +376,7 @@ dbBackupStart(Db *this, bool startFast, bool stopAuto)
         // If stop-auto is enabled check for a running backup
         if (stopAuto)
         {
-            // Feature is not supported in PostgreSQL < 9.3
-            CHECK(dbPgVersion(this) >= PG_VERSION_93);
+            CHECK(AssertError, dbPgVersion(this) >= PG_VERSION_93, "feature not supported in PostgreSQL < " PG_VERSION_93_STR);
 
             // Feature is not needed for PostgreSQL >= 9.6 since backups are run in non-exclusive mode
             if (dbPgVersion(this) < PG_VERSION_96)
@@ -341,14 +392,74 @@ dbBackupStart(Db *this, bool startFast, bool stopAuto)
             }
         }
 
+        // When the start-fast option is disabled and db-timeout is smaller than checkpoint_timeout, the command may timeout
+        // before the backup actually starts
+        if (!startFast && dbDbTimeout(this) <= dbCheckpointTimeout(this))
+        {
+            LOG_WARN_FMT(
+                CFGOPT_START_FAST " is disabled and " CFGOPT_DB_TIMEOUT " (%" PRIu64 "s) is smaller than the " PG_NAME
+                    " checkpoint_timeout (%" PRIu64 "s) - timeout may occur before the backup starts",
+                dbDbTimeout(this) / MSEC_PER_SEC, dbCheckpointTimeout(this) / MSEC_PER_SEC);
+        }
+
+        // If archive check then get the current WAL segment
+        const String *walSegmentCheck = NULL;
+
+        if (archiveCheck)
+        {
+            walSegmentCheck = varStr(
+                dbQueryColumn(
+                    this,
+                    strNewFmt(
+                        "select pg_catalog.pg_%sfile_name(pg_catalog.pg_current_%s_insert_%s())::text",
+                        strZ(pgWalName(dbPgVersion(this))), strZ(pgWalName(dbPgVersion(this))),
+                        strZ(pgLsnName(dbPgVersion(this))))));
+        }
+
         // Start backup
         VariantList *row = dbQueryRow(this, dbBackupStartQuery(dbPgVersion(this), startFast));
 
+        // Make sure the backup start checkpoint was written to pg_control. This helps ensure that we have a consistent view of the
+        // storage with PostgreSQL.
+        const PgControl pgControl = pgControlFromFile(this->storage);
+        const String *const lsnStart = varStr(varLstGet(row, 0));
+
+        if (pgControl.checkpoint < pgLsnFromStr(lsnStart))
+        {
+            THROW_FMT(
+                DbMismatchError, "current checkpoint '%s' is less than backup start '%s'", strZ(pgLsnToStr(pgControl.checkpoint)),
+                strZ(lsnStart));
+        }
+
+        // If archive check then make sure WAL segment was switched on start backup
+        const String *const walSegmentName = varStr(varLstGet(row, 1));
+
+        if (archiveCheck && strEq(walSegmentCheck, walSegmentName))
+        {
+            // If the version supports restore points then force a WAL switch
+            if (dbPgVersion(this) >= PG_VERSION_RESTORE_POINT)
+            {
+                dbWalSwitch(this);
+            }
+            // Else disable the check. All WAL will still be checked at the end of the backup.
+            else
+                walSegmentCheck = NULL;
+        }
+
+        // Check that the WAL timeline matches what is in pg_control
+        if (pgTimelineFromWalSegment(walSegmentName) != dbPgControl(this).timeline)
+        {
+            THROW_FMT(
+                DbMismatchError, "WAL timeline %u does not match " PG_FILE_PGCONTROL " timeline %u",
+                pgTimelineFromWalSegment(walSegmentName), dbPgControl(this).timeline);
+        }
+
         // Return results
         MEM_CONTEXT_PRIOR_BEGIN()
         {
-            result.lsn = strDup(varStr(varLstGet(row, 0)));
-            result.walSegmentName = strDup(varStr(varLstGet(row, 1)));
+            result.lsn = strDup(lsnStart);
+            result.walSegmentName = strDup(walSegmentName);
+            result.walSegmentCheck = strDup(walSegmentCheck);
         }
         MEM_CONTEXT_PRIOR_END();
     }
@@ -356,6 +467,7 @@ dbBackupStart(Db *this, bool startFast, bool stopAuto)
 
     FUNCTION_LOG_RETURN_STRUCT(result);
 }
+
 /**********************************************************************************************************************************/
 // Helper to build stop backup query
 static String *
@@ -366,7 +478,8 @@ dbBackupStopQuery(unsigned int pgVersion)
     FUNCTION_TEST_END();
 
     // Build query to return start lsn and WAL segment name
-    String *result = strNewFmt(
+    String *result = strCatFmt(
+        strNew(),
         "select lsn::text as lsn,\n"
         "       pg_catalog.pg_%sfile_name(lsn)::text as wal_segment_name",
         strZ(pgWalName(pgVersion)));
@@ -445,26 +558,6 @@ dbBackupStop(Db *this)
     FUNCTION_LOG_RETURN_STRUCT(result);
 }
 
-/**********************************************************************************************************************************/
-bool
-dbIsStandby(Db *this)
-{
-    FUNCTION_LOG_BEGIN(logLevelDebug);
-        FUNCTION_LOG_PARAM(DB, this);
-    FUNCTION_LOG_END();
-
-    ASSERT(this != NULL);
-
-    bool result = false;
-
-    if (this->pgVersion >= PG_VERSION_HOT_STANDBY)
-    {
-        result = varBool(dbQueryColumn(this, STRDEF("select pg_catalog.pg_is_in_recovery()")));
-    }
-
-    FUNCTION_LOG_RETURN(BOOL, result);
-}
-
 /**********************************************************************************************************************************/
 VariantList *
 dbList(Db *this)
@@ -479,20 +572,35 @@ dbList(Db *this)
 
 /**********************************************************************************************************************************/
 void
-dbReplayWait(Db *this, const String *targetLsn, TimeMSec timeout)
+dbReplayWait(Db *const this, const String *const targetLsn, const uint32_t targetTimeline, const TimeMSec timeout)
 {
     FUNCTION_LOG_BEGIN(logLevelDebug);
         FUNCTION_LOG_PARAM(DB, this);
         FUNCTION_LOG_PARAM(STRING, targetLsn);
+        FUNCTION_LOG_PARAM(UINT, targetTimeline);
         FUNCTION_LOG_PARAM(TIME_MSEC, timeout);
     FUNCTION_LOG_END();
 
     ASSERT(this != NULL);
     ASSERT(targetLsn != NULL);
+    ASSERT(targetTimeline != 0);
     ASSERT(timeout > 0);
 
     MEM_CONTEXT_TEMP_BEGIN()
     {
+        // Check that the timeline matches the primary
+        if (dbPgControl(this).timeline != targetTimeline)
+            THROW_FMT(DbMismatchError, "standby is on timeline %u but expected %u", dbPgControl(this).timeline, targetTimeline);
+
+        // Standby checkpoint before the backup started must be <= the target LSN. If not, it indicates that the standby was ahead
+        // of the primary and cannot be following it.
+        if (dbPgControl(this).checkpoint > pgLsnFromStr(targetLsn))
+        {
+            THROW_FMT(
+                DbMismatchError, "standby checkpoint '%s' is ahead of target '%s'", strZ(pgLsnToStr(dbPgControl(this).checkpoint)),
+                strZ(targetLsn));
+        }
+
         // Loop until lsn has been reached or timeout
         Wait *wait = waitNew(timeout);
         bool targetReached = false;
@@ -504,7 +612,8 @@ dbReplayWait(Db *this, const String *targetLsn, TimeMSec timeout)
         do
         {
             // Build the query
-            String *query = strNewFmt(
+            String *query = strCatFmt(
+                strNew(),
                 "select replayLsn::text,\n"
                 "       (replayLsn > '%s')::bool as targetReached",
                 strZ(targetLsn));
@@ -529,7 +638,7 @@ dbReplayWait(Db *this, const String *targetLsn, TimeMSec timeout)
             replayLsn = varStr(varLstGet(row, 0));
 
             // Error when replayLsn is null which indicates that this is not a standby.  This should have been sorted out before we
-            // connected but it's possible that the standy was promoted in the meantime.
+            // connected but it's possible that the standby was promoted in the meantime.
             if (replayLsn == NULL)
             {
                 THROW_FMT(
@@ -553,37 +662,47 @@ dbReplayWait(Db *this, const String *targetLsn, TimeMSec timeout)
         if (!targetReached)
         {
             THROW_FMT(
-                ArchiveTimeoutError, "timeout before standby replayed to %s - only reached %s", strZ(targetLsn),
-                strZ(replayLsn));
+                ArchiveTimeoutError,
+                "timeout before standby replayed to %s - only reached %s\n"
+                "HINT: is replication running and current on the standby?\n"
+                "HINT: disable the 'backup-standby' option to backup directly from the primary.",
+                strZ(targetLsn), strZ(replayLsn));
         }
 
         // Perform a checkpoint
         dbExec(this, STRDEF("checkpoint"));
 
-        // On PostgreSQL >= 9.6 the checkpoint location can be verified
-        //
-        // ??? We have seen one instance where this check failed.  Is there any chance that the replayed position could be ahead of
-        // the checkpoint recorded in pg_control?  It seems possible since it would be safer if the checkpoint in pg_control was
-        // behind rather than ahead, so add a loop to keep checking until the checkpoint has been recorded or timeout.
+        // On PostgreSQL >= 9.6 the checkpoint location can be verified so loop until lsn has been reached or timeout
         if (dbPgVersion(this) >= PG_VERSION_96)
         {
-            // Build the query
-            const String *query = strNewFmt(
-                "select (checkpoint_%s > '%s')::bool as targetReached,\n"
-                "       checkpoint_%s::text as checkpointLsn\n"
-                "  from pg_catalog.pg_control_checkpoint()",
-                lsnName, strZ(targetLsn), lsnName);
+            wait = waitNew(timeout);
+            targetReached = false;
+            const String *checkpointLsn = NULL;
 
-            // Execute query
-            VariantList *row = dbQueryRow(this, query);
+            do
+            {
+                // Build the query
+                const String *query = strNewFmt(
+                    "select (checkpoint_%s > '%s')::bool as targetReached,\n"
+                    "       checkpoint_%s::text as checkpointLsn\n"
+                    "  from pg_catalog.pg_control_checkpoint()",
+                    lsnName, strZ(targetLsn), lsnName);
 
-            // Verify target was reached
-            if (!varBool(varLstGet(row, 0)))
+                // Execute the query and get checkpointLsn
+                VariantList *row = dbQueryRow(this, query);
+                targetReached = varBool(varLstGet(row, 0));
+                checkpointLsn = varStr(varLstGet(row, 1));
+
+                protocolKeepAlive();
+            }
+            while (!targetReached && waitMore(wait));
+
+            // Error if a timeout occurred before the target lsn was reached
+            if (!targetReached)
             {
                 THROW_FMT(
-                    ArchiveTimeoutError,
-                    "the checkpoint lsn %s is less than the target lsn %s even though the replay lsn is %s",
-                    strZ(varStr(varLstGet(row, 1))), strZ(targetLsn), strZ(replayLsn));
+                    ArchiveTimeoutError, "timeout before standby checkpoint lsn reached %s - only reached %s", strZ(targetLsn),
+                    strZ(checkpointLsn));
             }
         }
     }
@@ -592,6 +711,54 @@ dbReplayWait(Db *this, const String *targetLsn, TimeMSec timeout)
     FUNCTION_LOG_RETURN_VOID();
 }
 
+/**********************************************************************************************************************************/
+void
+dbPing(Db *const this, const bool force)
+{
+    FUNCTION_LOG_BEGIN(logLevelDebug);
+        FUNCTION_LOG_PARAM(DB, this);
+        FUNCTION_LOG_PARAM(BOOL, force);
+    FUNCTION_LOG_END();
+
+    ASSERT(this != NULL);
+
+    MEM_CONTEXT_TEMP_BEGIN()
+    {
+        // Ping if forced or interval has elapsed
+        time_t timeNow = time(NULL);
+
+        if (force || timeNow - this->pingTimeLast > DB_PING_SEC)
+        {
+            // Make sure recovery state has not changed for versions that support recovery
+            if (dbPgVersion(this) >= PG_VERSION_90)
+            {
+                if (dbIsInRecovery(this) != dbIsStandby(this))
+                {
+                    // If this is the standby then it must have been promoted
+                    if (dbIsStandby(this))
+                    {
+                        THROW(
+                            DbMismatchError,
+                            "standby is no longer is recovery\n"
+                            "HINT: was the standby promoted during the backup?");
+                    }
+                    // Else if a primary then something has gone seriously wrong
+                    else
+                        THROW(AssertError, "primary has switched to recovery");
+                }
+            }
+            // Else just make sure the cluster is still running
+            else
+                dbTimeMSec(this);
+
+            this->pingTimeLast = timeNow;
+        }
+    }
+    MEM_CONTEXT_TEMP_END();
+
+    FUNCTION_LOG_RETURN_VOID();
+}
+
 /**********************************************************************************************************************************/
 VariantList *
 dbTablespaceList(Db *this)
@@ -631,11 +798,11 @@ dbWalSwitch(Db *this)
     {
         // Create a restore point to ensure current WAL will be archived.  For versions < 9.1 activity will need to be generated by
         // the user if there have been no writes since the last WAL switch.
-        if (this->pgVersion >= PG_VERSION_RESTORE_POINT)
+        if (dbPgVersion(this) >= PG_VERSION_RESTORE_POINT)
             dbQueryColumn(this, STRDEF("select pg_catalog.pg_create_restore_point('" PROJECT_NAME " Archive Check')::text"));
 
         // Request a WAL segment switch
-        const char *walName = strZ(pgWalName(this->pgVersion));
+        const char *walName = strZ(pgWalName(dbPgVersion(this)));
         const String *walFileName = varStr(
             dbQueryColumn(this, strNewFmt("select pg_catalog.pg_%sfile_name(pg_catalog.pg_switch_%s())::text", walName, walName)));
 
@@ -651,58 +818,6 @@ dbWalSwitch(Db *this)
     FUNCTION_LOG_RETURN(STRING, result);
 }
 
-/**********************************************************************************************************************************/
-const String *
-dbPgDataPath(const Db *this)
-{
-    FUNCTION_TEST_BEGIN();
-        FUNCTION_TEST_PARAM(DB, this);
-    FUNCTION_TEST_END();
-
-    ASSERT(this != NULL);
-
-    FUNCTION_TEST_RETURN(this->pgDataPath);
-}
-
-/**********************************************************************************************************************************/
-unsigned int
-dbPgVersion(const Db *this)
-{
-    FUNCTION_TEST_BEGIN();
-        FUNCTION_TEST_PARAM(DB, this);
-    FUNCTION_TEST_END();
-
-    ASSERT(this != NULL);
-
-    FUNCTION_TEST_RETURN(this->pgVersion);
-}
-
-/**********************************************************************************************************************************/
-const String *
-dbArchiveMode(const Db *this)
-{
-    FUNCTION_TEST_BEGIN();
-        FUNCTION_TEST_PARAM(DB, this);
-    FUNCTION_TEST_END();
-
-    ASSERT(this != NULL);
-
-    FUNCTION_TEST_RETURN(this->archiveMode);
-}
-
-/**********************************************************************************************************************************/
-const String *
-dbArchiveCommand(const Db *this)
-{
-    FUNCTION_TEST_BEGIN();
-        FUNCTION_TEST_PARAM(DB, this);
-    FUNCTION_TEST_END();
-
-    ASSERT(this != NULL);
-
-    FUNCTION_TEST_RETURN(this->archiveCommand);
-}
-
 /**********************************************************************************************************************************/
 String *
 dbToLog(const Db *this)
