@@ -15,11 +15,9 @@ Backup Info Handler
 #include "common/io/bufferWrite.h"
 #include "common/io/io.h"
 #include "common/log.h"
-#include "common/memContext.h"
 #include "common/regExp.h"
 #include "common/type/json.h"
 #include "common/type/list.h"
-#include "common/type/object.h"
 #include "info/infoBackup.h"
 #include "info/manifest.h"
 #include "postgres/interface.h"
@@ -45,6 +43,7 @@ VARIANT_STRDEF_STATIC(INFO_BACKUP_KEY_BACKUP_REFERENCE_VAR,         "backup-refe
 VARIANT_STRDEF_STATIC(INFO_BACKUP_KEY_BACKUP_TIMESTAMP_START_VAR,   "backup-timestamp-start");
 VARIANT_STRDEF_STATIC(INFO_BACKUP_KEY_BACKUP_TIMESTAMP_STOP_VAR,    "backup-timestamp-stop");
 VARIANT_STRDEF_STATIC(INFO_BACKUP_KEY_BACKUP_TYPE_VAR,              "backup-type");
+VARIANT_STRDEF_STATIC(INFO_BACKUP_KEY_BACKUP_ERROR_VAR,             "backup-error");
 VARIANT_STRDEF_STATIC(INFO_BACKUP_KEY_OPT_ARCHIVE_CHECK_VAR,        "option-archive-check");
 VARIANT_STRDEF_STATIC(INFO_BACKUP_KEY_OPT_ARCHIVE_COPY_VAR,         "option-archive-copy");
 VARIANT_STRDEF_STATIC(INFO_BACKUP_KEY_OPT_BACKUP_STANDBY_VAR,       "option-backup-standby");
@@ -61,14 +60,9 @@ Object type
 ***********************************************************************************************************************************/
 struct InfoBackup
 {
-    MemContext *memContext;                                         // Mem context
-    InfoPg *infoPg;                                                 // Contents of the DB data
-    List *backup;                                                   // List of current backups and their associated data
+    InfoBackupPub pub;                                              // Publicly accessible variables
 };
 
-OBJECT_DEFINE_MOVE(INFO_BACKUP);
-OBJECT_DEFINE_FREE(INFO_BACKUP);
-
 /***********************************************************************************************************************************
 Internal constructor
 ***********************************************************************************************************************************/
@@ -77,12 +71,15 @@ infoBackupNewInternal(void)
 {
     FUNCTION_TEST_VOID();
 
-    InfoBackup *this = memNew(sizeof(InfoBackup));
+    InfoBackup *this = OBJ_NEW_ALLOC();
 
     *this = (InfoBackup)
     {
-        .memContext = memContextCurrent(),
-        .backup = lstNewP(sizeof(InfoBackupData), .comparator =  lstComparatorStr),
+        .pub =
+        {
+            .memContext = memContextCurrent(),
+            .backup = lstNewP(sizeof(InfoBackupData), .comparator =  lstComparatorStr),
+        },
     };
 
     FUNCTION_TEST_RETURN(this);
@@ -103,15 +100,15 @@ infoBackupNew(unsigned int pgVersion, uint64_t pgSystemId, unsigned int pgCatalo
 
     InfoBackup *this = NULL;
 
-    MEM_CONTEXT_NEW_BEGIN("InfoBackup")
+    OBJ_NEW_BEGIN(InfoBackup)
     {
         this = infoBackupNewInternal();
 
         // Initialize the pg data
-        this->infoPg = infoPgNew(infoPgBackup, cipherPassSub);
+        this->pub.infoPg = infoPgNew(infoPgBackup, cipherPassSub);
         infoBackupPgSet(this, pgVersion, pgSystemId, pgCatalogVersion);
     }
-    MEM_CONTEXT_NEW_END();
+    OBJ_NEW_END();
 
     FUNCTION_LOG_RETURN(INFO_BACKUP, this);
 }
@@ -141,7 +138,7 @@ infoBackupLoadCallback(void *data, const String *section, const String *key, con
     {
         const KeyValue *backupKv = varKv(value);
 
-        MEM_CONTEXT_BEGIN(lstMemContext(infoBackup->backup))
+        MEM_CONTEXT_BEGIN(lstMemContext(infoBackup->pub.backup))
         {
             InfoBackupData infoBackupData =
             {
@@ -157,7 +154,7 @@ infoBackupLoadCallback(void *data, const String *section, const String *key, con
                 // When reading timestamps, read as uint64 to ensure always positive value (guarantee no backups before 1970)
                 .backupTimestampStart = (time_t)varUInt64(kvGet(backupKv, INFO_BACKUP_KEY_BACKUP_TIMESTAMP_START_VAR)),
                 .backupTimestampStop= (time_t)varUInt64(kvGet(backupKv, INFO_BACKUP_KEY_BACKUP_TIMESTAMP_STOP_VAR)),
-                .backupType = varStrForce(kvGet(backupKv, INFO_BACKUP_KEY_BACKUP_TYPE_VAR)),
+                .backupType = (BackupType)strIdFromStr(varStr(kvGet(backupKv, INFO_BACKUP_KEY_BACKUP_TYPE_VAR))),
 
                 // Possible NULL values
                 .backupArchiveStart = strDup(varStr(kvGet(backupKv, INFO_BACKUP_KEY_BACKUP_ARCHIVE_START_VAR))),
@@ -167,6 +164,9 @@ infoBackupLoadCallback(void *data, const String *section, const String *key, con
                     kvGet(backupKv, INFO_BACKUP_KEY_BACKUP_REFERENCE_VAR) != NULL ?
                         strLstNewVarLst(varVarLst(kvGet(backupKv, INFO_BACKUP_KEY_BACKUP_REFERENCE_VAR))) : NULL,
 
+                // Report errors detected during the backup. The key may not exist in older versions.
+                .backupError = varDup(kvGet(backupKv, INFO_BACKUP_KEY_BACKUP_ERROR_VAR)),
+
                 // Options
                 .optionArchiveCheck = varBool(kvGet(backupKv, INFO_BACKUP_KEY_OPT_ARCHIVE_CHECK_VAR)),
                 .optionArchiveCopy = varBool(kvGet(backupKv, INFO_BACKUP_KEY_OPT_ARCHIVE_COPY_VAR)),
@@ -177,8 +177,12 @@ infoBackupLoadCallback(void *data, const String *section, const String *key, con
                 .optionOnline = varBool(kvGet(backupKv, INFO_BACKUP_KEY_OPT_ONLINE_VAR)),
             };
 
+            ASSERT(
+                infoBackupData.backupType == backupTypeFull || infoBackupData.backupType == backupTypeDiff ||
+                infoBackupData.backupType == backupTypeIncr);
+
             // Add the backup data to the list
-            lstAdd(infoBackup->backup, &infoBackupData);
+            lstAdd(infoBackup->pub.backup, &infoBackupData);
         }
         MEM_CONTEXT_END();
     }
@@ -198,12 +202,12 @@ infoBackupNewLoad(IoRead *read)
 
     InfoBackup *this = NULL;
 
-    MEM_CONTEXT_NEW_BEGIN("InfoBackup")
+    OBJ_NEW_BEGIN(InfoBackup)
     {
         this = infoBackupNewInternal();
-        this->infoPg = infoPgNewLoad(read, infoPgBackup, infoBackupLoadCallback, this);
+        this->pub.infoPg = infoPgNewLoad(read, infoPgBackup, infoBackupLoadCallback, this);
     }
-    MEM_CONTEXT_NEW_END();
+    OBJ_NEW_END();
 
     FUNCTION_LOG_RETURN(INFO_BACKUP, this);
 }
@@ -258,7 +262,12 @@ infoBackupSaveCallback(void *data, const String *sectionNext, InfoSave *infoSave
             // When storing time_t treat as signed int to avoid casting
             kvPut(backupDataKv, INFO_BACKUP_KEY_BACKUP_TIMESTAMP_START_VAR, VARINT64(backupData.backupTimestampStart));
             kvPut(backupDataKv, INFO_BACKUP_KEY_BACKUP_TIMESTAMP_STOP_VAR, VARINT64(backupData.backupTimestampStop));
-            kvPut(backupDataKv, INFO_BACKUP_KEY_BACKUP_TYPE_VAR, VARSTR(backupData.backupType));
+            kvPut(backupDataKv, INFO_BACKUP_KEY_BACKUP_TYPE_VAR, VARSTR(strIdToStr(backupData.backupType)));
+
+            // Do not save backup-error if it was not loaded. This prevents backups that were added before the backup-error flag
+            // was introduced from being saved with an incorrect value.
+            if (backupData.backupError != NULL)
+                kvPut(backupDataKv, INFO_BACKUP_KEY_BACKUP_ERROR_VAR, backupData.backupError);
 
             kvPut(backupDataKv, INFO_BACKUP_KEY_OPT_ARCHIVE_CHECK_VAR, VARBOOL(backupData.optionArchiveCheck));
             kvPut(backupDataKv, INFO_BACKUP_KEY_OPT_ARCHIVE_COPY_VAR, VARBOOL(backupData.optionArchiveCopy));
@@ -297,18 +306,6 @@ infoBackupSave(InfoBackup *this, IoWrite *write)
 }
 
 /**********************************************************************************************************************************/
-InfoPg *
-infoBackupPg(const InfoBackup *this)
-{
-    FUNCTION_TEST_BEGIN();
-        FUNCTION_TEST_PARAM(INFO_BACKUP, this);
-    FUNCTION_TEST_END();
-
-    ASSERT(this != NULL);
-
-    FUNCTION_TEST_RETURN(this->infoPg);
-}
-
 InfoBackup *
 infoBackupPgSet(InfoBackup *this, unsigned int pgVersion, uint64_t pgSystemId, unsigned int pgCatalogVersion)
 {
@@ -319,24 +316,11 @@ infoBackupPgSet(InfoBackup *this, unsigned int pgVersion, uint64_t pgSystemId, u
         FUNCTION_LOG_PARAM(UINT, pgCatalogVersion);
     FUNCTION_LOG_END();
 
-    this->infoPg = infoPgSet(this->infoPg, infoPgBackup, pgVersion, pgSystemId, pgCatalogVersion);
+    this->pub.infoPg = infoPgSet(infoBackupPg(this), infoPgBackup, pgVersion, pgSystemId, pgCatalogVersion);
 
     FUNCTION_LOG_RETURN(INFO_BACKUP, this);
 }
 
-/**********************************************************************************************************************************/
-unsigned int
-infoBackupDataTotal(const InfoBackup *this)
-{
-    FUNCTION_TEST_BEGIN();
-        FUNCTION_TEST_PARAM(INFO_BACKUP, this);
-    FUNCTION_TEST_END();
-
-    ASSERT(this != NULL);
-
-    FUNCTION_TEST_RETURN(lstSize(this->backup));
-}
-
 /**********************************************************************************************************************************/
 InfoBackupData
 infoBackupData(const InfoBackup *this, unsigned int backupDataIdx)
@@ -348,22 +332,7 @@ infoBackupData(const InfoBackup *this, unsigned int backupDataIdx)
 
     ASSERT(this != NULL);
 
-    FUNCTION_LOG_RETURN(INFO_BACKUP_DATA, *(InfoBackupData *)lstGet(this->backup, backupDataIdx));
-}
-
-/**********************************************************************************************************************************/
-InfoBackupData *
-infoBackupDataByLabel(const InfoBackup *this, const String *backupLabel)
-{
-    FUNCTION_TEST_BEGIN();
-        FUNCTION_TEST_PARAM(INFO_BACKUP, this);
-        FUNCTION_TEST_PARAM(STRING, backupLabel);
-    FUNCTION_TEST_END();
-
-    ASSERT(this != NULL);
-    ASSERT(backupLabel != NULL);
-
-    FUNCTION_TEST_RETURN(lstFind(this->backup, &backupLabel));
+    FUNCTION_LOG_RETURN(INFO_BACKUP_DATA, *(InfoBackupData *)lstGet(this->pub.backup, backupDataIdx));
 }
 
 /**********************************************************************************************************************************/
@@ -382,12 +351,13 @@ infoBackupDataAdd(const InfoBackup *this, const Manifest *manifest)
     {
         const ManifestData *manData = manifestData(manifest);
 
-        // Calculate backup sizes and references
+        // Calculate backup sizes, references and report errors
         uint64_t backupSize = 0;
         uint64_t backupSizeDelta = 0;
         uint64_t backupRepoSize = 0;
         uint64_t backupRepoSizeDelta = 0;
         StringList *referenceList = strLstNew();
+        bool backupError = false;
 
         for (unsigned int fileIdx = 0; fileIdx < manifestFileTotal(manifest); fileIdx++)
         {
@@ -404,9 +374,13 @@ infoBackupDataAdd(const InfoBackup *this, const Manifest *manifest)
                 backupSizeDelta += file->size;
                 backupRepoSizeDelta += file->sizeRepo > 0 ? file->sizeRepo : file->size;
             }
+
+            // Is there an error in the file?
+            if (file->checksumPageError)
+                backupError = true;
         }
 
-        MEM_CONTEXT_BEGIN(lstMemContext(this->backup))
+        MEM_CONTEXT_BEGIN(lstMemContext(this->pub.backup))
         {
             InfoBackupData infoBackupData =
             {
@@ -420,7 +394,8 @@ infoBackupDataAdd(const InfoBackup *this, const Manifest *manifest)
                 .backupPgId = manData->pgId,
                 .backupTimestampStart = manData->backupTimestampStart,
                 .backupTimestampStop= manData->backupTimestampStop,
-                .backupType = backupTypeStr(manData->backupType),
+                .backupType = manData->backupType,
+                .backupError = varNewBool(backupError),
 
                 .backupArchiveStart = strDup(manData->archiveStart),
                 .backupArchiveStop = strDup(manData->archiveStop),
@@ -443,10 +418,10 @@ infoBackupDataAdd(const InfoBackup *this, const Manifest *manifest)
             }
 
             // Add the backup data to the current backup list
-            lstAdd(this->backup, &infoBackupData);
+            lstAdd(this->pub.backup, &infoBackupData);
 
             // Ensure the list is sorted ascending by the backupLabel
-            lstSort(this->backup, sortOrderAsc);
+            lstSort(this->pub.backup, sortOrderAsc);
         }
         MEM_CONTEXT_END();
     }
@@ -471,7 +446,7 @@ infoBackupDataDelete(const InfoBackup *this, const String *backupDeleteLabel)
         InfoBackupData backupData = infoBackupData(this, idx);
 
         if (strCmp(backupData.backupLabel, backupDeleteLabel) == 0)
-            lstRemoveIdx(this->backup, idx);
+            lstRemoveIdx(this->pub.backup, idx);
     }
 
     FUNCTION_LOG_RETURN_VOID();
@@ -545,19 +520,6 @@ infoBackupDataDependentList(const InfoBackup *this, const String *backupLabel)
     FUNCTION_LOG_RETURN(STRING_LIST, result);
 }
 
-/**********************************************************************************************************************************/
-const String *
-infoBackupCipherPass(const InfoBackup *this)
-{
-    FUNCTION_TEST_BEGIN();
-        FUNCTION_TEST_PARAM(INFO_BACKUP, this);
-    FUNCTION_TEST_END();
-
-    ASSERT(this != NULL);
-
-    FUNCTION_TEST_RETURN(infoPgCipherPass(this->infoPg));
-}
-
 /**********************************************************************************************************************************/
 typedef struct InfoBackupLoadFileData
 {
@@ -608,7 +570,7 @@ infoBackupLoadFile(const Storage *storage, const String *fileName, CipherType ci
     FUNCTION_LOG_BEGIN(logLevelDebug);
         FUNCTION_LOG_PARAM(STORAGE, storage);
         FUNCTION_LOG_PARAM(STRING, fileName);
-        FUNCTION_LOG_PARAM(ENUM, cipherType);
+        FUNCTION_LOG_PARAM(STRING_ID, cipherType);
         FUNCTION_TEST_PARAM(STRING, cipherPass);
     FUNCTION_LOG_END();
 
@@ -658,7 +620,7 @@ infoBackupLoadFileReconstruct(const Storage *storage, const String *fileName, Ci
     FUNCTION_LOG_BEGIN(logLevelDebug);
         FUNCTION_LOG_PARAM(STORAGE, storage);
         FUNCTION_LOG_PARAM(STRING, fileName);
-        FUNCTION_LOG_PARAM(ENUM, cipherType);
+        FUNCTION_LOG_PARAM(STRING_ID, cipherType);
         FUNCTION_TEST_PARAM(STRING, cipherPass);
     FUNCTION_LOG_END();
 
@@ -687,7 +649,7 @@ infoBackupLoadFileReconstruct(const Storage *storage, const String *fileName, Ci
 
             // If the manifest does not exist on disk and this backup has not already been deleted from the current list in the
             // infoBackup object, then remove it and its dependencies
-            if (!storageExistsP(storage, manifestFileName) && infoBackupDataByLabel(infoBackup, backupLabel) != NULL)
+            if (!storageExistsP(storage, manifestFileName) && infoBackupLabelExists(infoBackup, backupLabel))
             {
                 StringList *backupList = strLstSort(infoBackupDataDependentList(infoBackup, backupLabel), sortOrderDesc);
 
@@ -720,21 +682,20 @@ infoBackupLoadFileReconstruct(const Storage *storage, const String *fileName, Ci
                 {
                     bool found = false;
                     const Manifest *manifest = manifestLoadFile(
-                        storage, manifestFileName, cipherType, infoPgCipherPass(infoBackup->infoPg));
+                        storage, manifestFileName, cipherType, infoPgCipherPass(infoBackupPg(infoBackup)));
                     const ManifestData *manData = manifestData(manifest);
 
                     // If the pg data for the manifest exists in the history, then add it to current, but if something doesn't match
                     // then warn that the backup is not valid
-                    for (unsigned int pgIdx = 0; pgIdx < infoPgDataTotal(infoBackup->infoPg); pgIdx++)
+                    for (unsigned int pgIdx = 0; pgIdx < infoPgDataTotal(infoBackupPg(infoBackup)); pgIdx++)
                     {
-                        InfoPgData pgHistory = infoPgData(infoBackup->infoPg, pgIdx);
+                        InfoPgData pgHistory = infoPgData(infoBackupPg(infoBackup), pgIdx);
 
                         // If there is an exact match with the history, system and version and there is no backup-prior dependency
                         // or there is a backup-prior and it is in the list, then add this backup to the current backup list
                         if (manData->pgId == pgHistory.id && manData->pgSystemId == pgHistory.systemId &&
                             manData->pgVersion == pgHistory.version &&
-                            (manData->backupLabelPrior == NULL ||
-                                infoBackupDataByLabel(infoBackup, manData->backupLabelPrior) != NULL))
+                            (manData->backupLabelPrior == NULL || infoBackupLabelExists(infoBackup, manData->backupLabelPrior)))
                         {
                             LOG_WARN_FMT("backup '%s' found in repository added to " INFO_BACKUP_FILE, strZ(backupLabel));
                             infoBackupDataAdd(infoBackup, manifest);
@@ -763,7 +724,7 @@ infoBackupSaveFile(
         FUNCTION_LOG_PARAM(INFO_BACKUP, infoBackup);
         FUNCTION_LOG_PARAM(STORAGE, storage);
         FUNCTION_LOG_PARAM(STRING, fileName);
-        FUNCTION_LOG_PARAM(ENUM, cipherType);
+        FUNCTION_LOG_PARAM(STRING_ID, cipherType);
         FUNCTION_TEST_PARAM(STRING, cipherPass);
     FUNCTION_LOG_END();
 
