@@ -7,9 +7,7 @@ Postgres Client
 
 #include "common/debug.h"
 #include "common/log.h"
-#include "common/memContext.h"
 #include "common/type/list.h"
-#include "common/type/object.h"
 #include "common/wait.h"
 #include "postgres/client.h"
 
@@ -18,38 +16,39 @@ Object type
 ***********************************************************************************************************************************/
 struct PgClient
 {
-    MemContext *memContext;
-    const String *host;
-    unsigned int port;
-    const String *database;
-    const String *user;
-    TimeMSec queryTimeout;
-
-    PGconn *connection;
+    PgClientPub pub;                                                // Publicly accessible variables
+    PGconn *connection;                                             // Pg connection
 };
 
-OBJECT_DEFINE_MOVE(PG_CLIENT);
-OBJECT_DEFINE_FREE(PG_CLIENT);
-
 /***********************************************************************************************************************************
 Close protocol connection
 ***********************************************************************************************************************************/
-OBJECT_DEFINE_FREE_RESOURCE_BEGIN(PG_CLIENT, LOG, logLevelTrace)
+static void
+pgClientFreeResource(THIS_VOID)
 {
+    THIS(PgClient);
+
+    FUNCTION_LOG_BEGIN(logLevelTrace);
+        FUNCTION_LOG_PARAM(PG_CLIENT, this);
+    FUNCTION_LOG_END();
+
+    ASSERT(this != NULL);
+
     PQfinish(this->connection);
+
+    FUNCTION_LOG_RETURN_VOID();
 }
-OBJECT_DEFINE_FREE_RESOURCE_END(LOG);
 
 /**********************************************************************************************************************************/
 PgClient *
-pgClientNew(const String *host, const unsigned int port, const String *database, const String *user, const TimeMSec queryTimeout)
+pgClientNew(const String *host, const unsigned int port, const String *database, const String *user, const TimeMSec timeout)
 {
     FUNCTION_LOG_BEGIN(logLevelDebug);
         FUNCTION_LOG_PARAM(STRING, host);
         FUNCTION_LOG_PARAM(UINT, port);
         FUNCTION_LOG_PARAM(STRING, database);
         FUNCTION_LOG_PARAM(STRING, user);
-        FUNCTION_LOG_PARAM(TIME_MSEC, queryTimeout);
+        FUNCTION_LOG_PARAM(TIME_MSEC, timeout);
     FUNCTION_LOG_END();
 
     ASSERT(port >= 1 && port <= 65535);
@@ -57,21 +56,23 @@ pgClientNew(const String *host, const unsigned int port, const String *database,
 
     PgClient *this = NULL;
 
-    MEM_CONTEXT_NEW_BEGIN("PgClient")
+    OBJ_NEW_BEGIN(PgClient)
     {
-        this = memNew(sizeof(PgClient));
+        this = OBJ_NEW_ALLOC();
 
         *this = (PgClient)
         {
-            .memContext = MEM_CONTEXT_NEW(),
-            .host = strDup(host),
-            .port = port,
-            .database = strDup(database),
-            .user = strDup(user),
-            .queryTimeout = queryTimeout,
+            .pub =
+            {
+                .host = strDup(host),
+                .port = port,
+                .database = strDup(database),
+                .user = strDup(user),
+                .timeout = timeout,
+            },
         };
     }
-    MEM_CONTEXT_NEW_END();
+    OBJ_NEW_END();
 
     FUNCTION_LOG_RETURN(PG_CLIENT, this);
 }
@@ -98,7 +99,7 @@ pgClientEscape(const String *string)
 
     ASSERT(string != NULL);
 
-    String *result = strNew("'");
+    String *result = strCatZ(strNew(), "'");
 
     // Iterate all characters in the string
     for (unsigned stringIdx = 0; stringIdx < strSize(string); stringIdx++)
@@ -126,33 +127,34 @@ pgClientOpen(PgClient *this)
     FUNCTION_LOG_END();
 
     ASSERT(this != NULL);
-    CHECK(this->connection == NULL);
+    CHECK(AssertError, this->connection == NULL, "invalid connection");
 
     MEM_CONTEXT_TEMP_BEGIN()
     {
         // Base connection string
-        String *connInfo = strNewFmt("dbname=%s port=%u", strZ(pgClientEscape(this->database)), this->port);
+        String *connInfo = strCatFmt(
+            strNew(), "dbname=%s port=%u", strZ(pgClientEscape(pgClientDatabase(this))), pgClientPort(this));
 
         // Add user if specified
-        if (this->user != NULL)
-            strCatFmt(connInfo, " user=%s", strZ(pgClientEscape(this->user)));
+        if (pgClientUser(this) != NULL)
+            strCatFmt(connInfo, " user=%s", strZ(pgClientEscape(pgClientUser(this))));
 
         // Add host if specified
-        if (this->host != NULL)
-            strCatFmt(connInfo, " host=%s", strZ(pgClientEscape(this->host)));
+        if (pgClientHost(this) != NULL)
+            strCatFmt(connInfo, " host=%s", strZ(pgClientEscape(pgClientHost(this))));
 
         // Make the connection
         this->connection = PQconnectdb(strZ(connInfo));
 
         // Set a callback to shutdown the connection
-        memContextCallbackSet(this->memContext, pgClientFreeResource, this);
+        memContextCallbackSet(objMemContext(this), pgClientFreeResource, this);
 
         // Handle errors
         if (PQstatus(this->connection) != CONNECTION_OK)
         {
             THROW_FMT(
                 DbConnectError, "unable to connect to '%s': %s", strZ(connInfo),
-                strZ(strTrim(strNew(PQerrorMessage(this->connection)))));
+                strZ(strTrim(strNewZ(PQerrorMessage(this->connection)))));
         }
 
         // Set notice and warning processor
@@ -173,7 +175,7 @@ pgClientQuery(PgClient *this, const String *query)
     FUNCTION_LOG_END();
 
     ASSERT(this != NULL);
-    CHECK(this->connection != NULL);
+    CHECK(AssertError, this->connection != NULL, "invalid connection");
     ASSERT(query != NULL);
 
     VariantList *result = NULL;
@@ -185,11 +187,11 @@ pgClientQuery(PgClient *this, const String *query)
         {
             THROW_FMT(
                 DbQueryError, "unable to send query '%s': %s", strZ(query),
-                strZ(strTrim(strNew(PQerrorMessage(this->connection)))));
+                strZ(strTrim(strNewZ(PQerrorMessage(this->connection)))));
         }
 
         // Wait for a result
-        Wait *wait = waitNew(this->queryTimeout);
+        Wait *wait = waitNew(pgClientTimeout(this));
         bool busy = false;
 
         do
@@ -213,7 +215,7 @@ pgClientQuery(PgClient *this, const String *query)
                 char error[256];
 
                 if (!PQcancel(cancel, error, sizeof(error)))
-                    THROW_FMT(DbQueryError, "unable to cancel query '%s': %s", strZ(query), strZ(strTrim(strNew(error))));
+                    THROW_FMT(DbQueryError, "unable to cancel query '%s': %s", strZ(query), strZ(strTrim(strNewZ(error))));
             }
             FINALLY()
             {
@@ -229,7 +231,7 @@ pgClientQuery(PgClient *this, const String *query)
         {
             // Throw timeout error if cancelled
             if (busy)
-                THROW_FMT(DbQueryError, "query '%s' timed out after %" PRIu64 "ms", strZ(query), this->queryTimeout);
+                THROW_FMT(DbQueryError, "query '%s' timed out after %" PRIu64 "ms", strZ(query), pgClientTimeout(this));
 
             // If this was a command that returned no results then we are done
             ExecStatusType resultStatus = PQresultStatus(pgResult);
@@ -241,7 +243,7 @@ pgClientQuery(PgClient *this, const String *query)
                 {
                     THROW_FMT(
                         DbQueryError, "unable to execute query '%s': %s", strZ(query),
-                        strZ(strTrim(strNew(PQresultErrorMessage(pgResult)))));
+                        strZ(strTrim(strNewZ(PQresultErrorMessage(pgResult)))));
                 }
 
                 // Fetch row and column values
@@ -317,8 +319,7 @@ pgClientQuery(PgClient *this, const String *query)
             // Free the result
             PQclear(pgResult);
 
-            // Need to get a NULL result to complete the request
-            CHECK(PQgetResult(this->connection) == NULL);
+            CHECK(ServiceError, PQgetResult(this->connection) == NULL, "NULL result required to complete request");
         }
         TRY_END();
 
@@ -341,7 +342,7 @@ pgClientClose(PgClient *this)
 
     if (this->connection != NULL)
     {
-        memContextCallbackClear(this->memContext);
+        memContextCallbackClear(objMemContext(this));
         PQfinish(this->connection);
         this->connection = NULL;
     }
@@ -354,6 +355,6 @@ String *
 pgClientToLog(const PgClient *this)
 {
     return strNewFmt(
-        "{host: %s, port: %u, database: %s, user: %s, queryTimeout %" PRIu64 "}", strZ(strToLog(this->host)), this->port,
-        strZ(strToLog(this->database)), strZ(strToLog(this->user)), this->queryTimeout);
+        "{host: %s, port: %u, database: %s, user: %s, queryTimeout %" PRIu64 "}", strZ(strToLog(pgClientHost(this))),
+        pgClientPort(this), strZ(strToLog(pgClientDatabase(this))), strZ(strToLog(pgClientUser(this))), pgClientTimeout(this));
 }
