@@ -8,6 +8,7 @@ casts to queries to output one of these types.
 #ifndef POSTGRES_QUERY_H
 #define POSTGRES_QUERY_H
 
+#include "common/type/object.h"
 #include "common/type/string.h"
 #include "common/type/variantList.h"
 #include "common/time.h"
@@ -15,16 +16,60 @@ casts to queries to output one of these types.
 /***********************************************************************************************************************************
 Object type
 ***********************************************************************************************************************************/
-#define PG_CLIENT_TYPE                                               PgClient
-#define PG_CLIENT_PREFIX                                             pgClient
-
 typedef struct PgClient PgClient;
 
 /***********************************************************************************************************************************
 Constructors
 ***********************************************************************************************************************************/
 PgClient *pgClientNew(
-    const String *host, const unsigned int port, const String *database, const String *user, const TimeMSec queryTimeout);
+    const String *host, const unsigned int port, const String *database, const String *user, const TimeMSec timeout);
+
+/***********************************************************************************************************************************
+Getters/Setters
+***********************************************************************************************************************************/
+typedef struct PgClientPub
+{
+    const String *host;                                             // Pg host
+    unsigned int port;                                              // Pg port
+    const String *database;                                         // Pg database
+    const String *user;                                             // Pg user
+    TimeMSec timeout;                                               // Timeout for statements/queries
+} PgClientPub;
+
+// Pg host
+__attribute__((always_inline)) static inline const String *
+pgClientHost(const PgClient *const this)
+{
+    return THIS_PUB(PgClient)->host;
+}
+
+// Pg port
+__attribute__((always_inline)) static inline unsigned int
+pgClientPort(const PgClient *const this)
+{
+    return THIS_PUB(PgClient)->port;
+}
+
+// Pg database
+__attribute__((always_inline)) static inline const String *
+pgClientDatabase(const PgClient *const this)
+{
+    return THIS_PUB(PgClient)->database;
+}
+
+// Pg user
+__attribute__((always_inline)) static inline const String *
+pgClientUser(const PgClient *const this)
+{
+    return THIS_PUB(PgClient)->user;
+}
+
+// Timeout for statements/queries
+__attribute__((always_inline)) static inline TimeMSec
+pgClientTimeout(const PgClient *const this)
+{
+    return THIS_PUB(PgClient)->timeout;
+}
 
 /***********************************************************************************************************************************
 Functions
@@ -33,7 +78,11 @@ Functions
 PgClient *pgClientOpen(PgClient *this);
 
 // Move to a new parent mem context
-PgClient *pgClientMove(PgClient *this, MemContext *parentNew);
+__attribute__((always_inline)) static inline PgClient *
+pgClientMove(PgClient *const this, MemContext *const parentNew)
+{
+    return objMove(this, parentNew);
+}
 
 // Execute a query and return results
 VariantList *pgClientQuery(PgClient *this, const String *query);
@@ -44,7 +93,11 @@ void pgClientClose(PgClient *this);
 /***********************************************************************************************************************************
 Destructor
 ***********************************************************************************************************************************/
-void pgClientFree(PgClient *this);
+__attribute__((always_inline)) static inline void
+pgClientFree(PgClient *const this)
+{
+    objFree(this);
+}
 
 /***********************************************************************************************************************************
 Macros for function logging
