@@ -24,7 +24,21 @@ Determine if the supplied pg_control is for this version of PostgreSQL
 
 #elif PG_VERSION >= PG_VERSION_83
 
-#ifdef CATALOG_VERSION_NO
+#ifdef CATALOG_VERSION_NO_MAX
+
+#define PG_INTERFACE_CONTROL_IS(version)                                                                                           \
+    bool                                                                                                                           \
+    pgInterfaceControlIs##version(const unsigned char *controlFile)                                                                \
+    {                                                                                                                              \
+        ASSERT(controlFile != NULL);                                                                                               \
+                                                                                                                                   \
+        return                                                                                                                     \
+            ((ControlFileData *)controlFile)->pg_control_version == PG_CONTROL_VERSION &&                                          \
+            ((ControlFileData *)controlFile)->catalog_version_no >= CATALOG_VERSION_NO &&                                          \
+            ((ControlFileData *)controlFile)->catalog_version_no < (CATALOG_VERSION_NO / 100000 + 1) * 100000;                     \
+    }
+
+#else
 
 #define PG_INTERFACE_CONTROL_IS(version)                                                                                           \
     bool                                                                                                                           \
@@ -37,18 +51,7 @@ Determine if the supplied pg_control is for this version of PostgreSQL
             ((ControlFileData *)controlFile)->catalog_version_no == CATALOG_VERSION_NO;                                            \
     }
 
-#else
-
-#define PG_INTERFACE_CONTROL_IS(version)                                                                                           \
-    bool                                                                                                                           \
-    pgInterfaceControlIs##version(const unsigned char *controlFile)                                                                \
-    {                                                                                                                              \
-        ASSERT(controlFile != NULL);                                                                                               \
-                                                                                                                                   \
-        return ((ControlFileData *)controlFile)->pg_control_version == PG_CONTROL_VERSION;                                         \
-    }
-
-#endif // CATALOG_VERSION_NO
+#endif
 
 #endif
 
@@ -70,6 +73,8 @@ Read the version specific pg_control into a general data structure
         {                                                                                                                          \
             .systemId = ((ControlFileData *)controlFile)->system_identifier,                                                       \
             .catalogVersion = ((ControlFileData *)controlFile)->catalog_version_no,                                                \
+            .checkpoint = ((ControlFileData *)controlFile)->checkPoint,                                                            \
+            .timeline = ((ControlFileData *)controlFile)->checkPointCopy.ThisTimeLineID,                                           \
             .pageSize = ((ControlFileData *)controlFile)->blcksz,                                                                  \
             .walSegmentSize = ((ControlFileData *)controlFile)->xlog_seg_size,                                                     \
             .pageChecksum = ((ControlFileData *)controlFile)->data_checksum_version != 0,                                          \
@@ -89,6 +94,10 @@ Read the version specific pg_control into a general data structure
         {                                                                                                                          \
             .systemId = ((ControlFileData *)controlFile)->system_identifier,                                                       \
             .catalogVersion = ((ControlFileData *)controlFile)->catalog_version_no,                                                \
+            .checkpoint =                                                                                                          \
+                (uint64_t)((ControlFileData *)controlFile)->checkPoint.xlogid << 32 |                                              \
+                ((ControlFileData *)controlFile)->checkPoint.xrecoff,                                                              \
+            .timeline = ((ControlFileData *)controlFile)->checkPointCopy.ThisTimeLineID,                                           \
             .pageSize = ((ControlFileData *)controlFile)->blcksz,                                                                  \
             .walSegmentSize = ((ControlFileData *)controlFile)->xlog_seg_size,                                                     \
         };                                                                                                                         \
@@ -112,51 +121,6 @@ Get the control version
 
 #endif
 
-/***********************************************************************************************************************************
-Create a pg_control file for testing
-***********************************************************************************************************************************/
-#if PG_VERSION > PG_VERSION_MAX
-
-#elif PG_VERSION >= PG_VERSION_93
-
-#define PG_INTERFACE_CONTROL_TEST(version)                                                                                         \
-    void                                                                                                                           \
-    pgInterfaceControlTest##version(PgControl pgControl, unsigned char *buffer)                                                    \
-    {                                                                                                                              \
-        ASSERT(buffer != NULL);                                                                                                    \
-                                                                                                                                   \
-        *(ControlFileData *)buffer = (ControlFileData)                                                                             \
-        {                                                                                                                          \
-            .system_identifier = pgControl.systemId,                                                                               \
-            .pg_control_version = PG_CONTROL_VERSION,                                                                              \
-            .catalog_version_no = pgControl.catalogVersion,                                                                        \
-            .blcksz = pgControl.pageSize,                                                                                          \
-            .xlog_seg_size = pgControl.walSegmentSize,                                                                             \
-            .data_checksum_version = pgControl.pageChecksum,                                                                       \
-        };                                                                                                                         \
-    }
-
-#elif PG_VERSION >= PG_VERSION_83
-
-#define PG_INTERFACE_CONTROL_TEST(version)                                                                                         \
-    void                                                                                                                           \
-    pgInterfaceControlTest##version(PgControl pgControl, unsigned char *buffer)                                                    \
-    {                                                                                                                              \
-        ASSERT(buffer != NULL);                                                                                                    \
-        ASSERT(!pgControl.pageChecksum);                                                                                           \
-                                                                                                                                   \
-        *(ControlFileData *)buffer = (ControlFileData)                                                                             \
-        {                                                                                                                          \
-            .system_identifier = pgControl.systemId,                                                                               \
-            .pg_control_version = PG_CONTROL_VERSION,                                                                              \
-            .catalog_version_no = pgControl.catalogVersion,                                                                        \
-            .blcksz = pgControl.pageSize,                                                                                          \
-            .xlog_seg_size = pgControl.walSegmentSize,                                                                             \
-        };                                                                                                                         \
-    }
-
-#endif
-
 /***********************************************************************************************************************************
 Determine if the supplied WAL is for this version of PostgreSQL
 ***********************************************************************************************************************************/
@@ -198,47 +162,14 @@ Read the version specific WAL header into a general data structure
 
 #endif
 
-/***********************************************************************************************************************************
-Create a WAL file file for testing
-***********************************************************************************************************************************/
-#if PG_VERSION > PG_VERSION_MAX
-
-#elif PG_VERSION >= PG_VERSION_83
-
-#define PG_INTERFACE_WAL_TEST(version)                                                                                             \
-    void                                                                                                                           \
-    pgInterfaceWalTest##version(PgWal pgWal, unsigned char *buffer)                                                                \
-    {                                                                                                                              \
-        ((XLogLongPageHeaderData *)buffer)->std.xlp_magic = XLOG_PAGE_MAGIC;                                                       \
-        ((XLogLongPageHeaderData *)buffer)->std.xlp_info = XLP_LONG_HEADER;                                                        \
-        ((XLogLongPageHeaderData *)buffer)->xlp_sysid = pgWal.systemId;                                                            \
-        ((XLogLongPageHeaderData *)buffer)->xlp_seg_size = pgWal.size;                                                             \
-    }
-
-#endif
-
 /***********************************************************************************************************************************
 Call all macros with a single macro to make the vXXX.c files as simple as possible
 ***********************************************************************************************************************************/
-#define PG_INTERFACE_BASE(version)                                                                                                 \
+#define PG_INTERFACE(version)                                                                                                      \
     PG_INTERFACE_CONTROL_IS(version)                                                                                               \
     PG_INTERFACE_CONTROL(version)                                                                                                  \
     PG_INTERFACE_CONTROL_VERSION(version)                                                                                          \
     PG_INTERFACE_WAL_IS(version)                                                                                                   \
     PG_INTERFACE_WAL(version)
 
-#ifdef DEBUG
-
-#define PG_INTERFACE(version)                                                                                                      \
-    PG_INTERFACE_BASE(version)                                                                                                     \
-    PG_INTERFACE_CONTROL_TEST(version)                                                                                             \
-    PG_INTERFACE_WAL_TEST(version)
-
-#else
-
-#define PG_INTERFACE(version)                                                                                                      \
-    PG_INTERFACE_BASE(version)
-
-#endif
-
 #endif
