@@ -5,116 +5,105 @@ Protocol Command
 
 #include "common/debug.h"
 #include "common/log.h"
-#include "common/memContext.h"
-#include "common/type/json.h"
 #include "common/type/keyValue.h"
-#include "common/type/object.h"
 #include "protocol/command.h"
-
-/***********************************************************************************************************************************
-Constants
-***********************************************************************************************************************************/
-STRING_EXTERN(PROTOCOL_KEY_COMMAND_STR,                             PROTOCOL_KEY_COMMAND);
-STRING_EXTERN(PROTOCOL_KEY_PARAMETER_STR,                           PROTOCOL_KEY_PARAMETER);
+#include "protocol/client.h"
 
 /***********************************************************************************************************************************
 Object type
 ***********************************************************************************************************************************/
 struct ProtocolCommand
 {
-    MemContext *memContext;
-    const String *command;
-    Variant *parameterList;
+    StringId command;
+    PackWrite *pack;
 };
 
-OBJECT_DEFINE_MOVE(PROTOCOL_COMMAND);
-OBJECT_DEFINE_FREE(PROTOCOL_COMMAND);
-
 /**********************************************************************************************************************************/
 ProtocolCommand *
-protocolCommandNew(const String *command)
+protocolCommandNew(const StringId command)
 {
     FUNCTION_TEST_BEGIN();
-        FUNCTION_TEST_PARAM(STRING, command);
+        FUNCTION_TEST_PARAM(STRING_ID, command);
     FUNCTION_TEST_END();
 
-    ASSERT(command != NULL);
+    ASSERT(command != 0);
 
     ProtocolCommand *this = NULL;
 
-    MEM_CONTEXT_NEW_BEGIN("ProtocolCommand")
+    OBJ_NEW_BEGIN(ProtocolCommand)
     {
-        this = memNew(sizeof(ProtocolCommand));
+        this = OBJ_NEW_ALLOC();
 
         *this = (ProtocolCommand)
         {
-            .memContext = memContextCurrent(),
-            .command = strDup(command),
+            .command = command,
         };
     }
-    MEM_CONTEXT_NEW_END();
+    OBJ_NEW_END();
 
     FUNCTION_TEST_RETURN(this);
 }
 
 /**********************************************************************************************************************************/
-ProtocolCommand *
-protocolCommandParamAdd(ProtocolCommand *this, const Variant *param)
-{
-    FUNCTION_TEST_BEGIN();
-        FUNCTION_TEST_PARAM(PROTOCOL_COMMAND, this);
-        FUNCTION_TEST_PARAM(VARIANT, param);
-    FUNCTION_TEST_END();
-
-    ASSERT(this != NULL);
-
-    MEM_CONTEXT_BEGIN(this->memContext)
-    {
-        // Create parameter list if not already created
-        if (this->parameterList == NULL)
-            this->parameterList = varNewVarLst(varLstNew());
-
-        // Add parameter to the list
-        varLstAdd(varVarLst(this->parameterList), varDup(param));
-    }
-    MEM_CONTEXT_END();
-
-    FUNCTION_TEST_RETURN(this);
-}
-
-/**********************************************************************************************************************************/
-String *
-protocolCommandJson(const ProtocolCommand *this)
+void
+protocolCommandPut(ProtocolCommand *const this, IoWrite *const write)
 {
     FUNCTION_TEST_BEGIN();
         FUNCTION_TEST_PARAM(PROTOCOL_COMMAND, this);
     FUNCTION_TEST_END();
 
     ASSERT(this != NULL);
-
-    String *result = NULL;
+    ASSERT(write != NULL);
 
     MEM_CONTEXT_TEMP_BEGIN()
     {
-        KeyValue *command = kvPut(kvNew(), VARSTR(PROTOCOL_KEY_COMMAND_STR), VARSTR(this->command));
+        // Write the command and flush to be sure the command gets sent immediately
+        PackWrite *commandPack = pckWriteNewIo(write);
+        pckWriteU32P(commandPack, protocolMessageTypeCommand, .defaultWrite = true);
+        pckWriteStrIdP(commandPack, this->command);
 
-        if (this->parameterList != NULL)
-            kvPut(command, VARSTR(PROTOCOL_KEY_PARAMETER_STR), this->parameterList);
-
-        MEM_CONTEXT_PRIOR_BEGIN()
+        // Only write params if there were any
+        if (this->pack != NULL)
         {
-            result = jsonFromKv(command);
+            pckWriteEndP(this->pack);
+            pckWritePackP(commandPack, pckWriteResult(this->pack));
         }
-        MEM_CONTEXT_PRIOR_END();
+
+        pckWriteEndP(commandPack);
+
+        // Flush to send command immediately
+        ioWriteFlush(write);
     }
     MEM_CONTEXT_TEMP_END();
 
-    FUNCTION_TEST_RETURN(result);
+    FUNCTION_TEST_RETURN_VOID();
+}
+
+/**********************************************************************************************************************************/
+PackWrite *
+protocolCommandParam(ProtocolCommand *this)
+{
+    FUNCTION_TEST_BEGIN();
+        FUNCTION_TEST_PARAM(PROTOCOL_COMMAND, this);
+    FUNCTION_TEST_END();
+
+    ASSERT(this != NULL);
+
+    if (this->pack == NULL)
+    {
+        MEM_CONTEXT_BEGIN(objMemContext(this))
+        {
+            this->pack = protocolPackNew();
+        }
+        MEM_CONTEXT_END();
+    }
+
+    FUNCTION_TEST_RETURN(this->pack);
 }
 
 /**********************************************************************************************************************************/
 String *
 protocolCommandToLog(const ProtocolCommand *this)
 {
-    return strNewFmt("{command: %s}", strZ(this->command));
+    return strNewFmt("{command: %s}", strZ(strIdToStr(this->command)));
 }
