@@ -7,45 +7,41 @@ Protocol Command
 /***********************************************************************************************************************************
 Object type
 ***********************************************************************************************************************************/
-#define PROTOCOL_COMMAND_TYPE                                       ProtocolCommand
-#define PROTOCOL_COMMAND_PREFIX                                     protocolCommand
-
 typedef struct ProtocolCommand ProtocolCommand;
 
-#include "common/type/variant.h"
-
-/***********************************************************************************************************************************
-Constants
-***********************************************************************************************************************************/
-#define PROTOCOL_KEY_COMMAND                                        "cmd"
-    STRING_DECLARE(PROTOCOL_KEY_COMMAND_STR);
-#define PROTOCOL_KEY_PARAMETER                                      "param"
-    STRING_DECLARE(PROTOCOL_KEY_PARAMETER_STR);
+#include "common/type/object.h"
+#include "common/type/pack.h"
 
 /***********************************************************************************************************************************
 Constructors
 ***********************************************************************************************************************************/
-ProtocolCommand *protocolCommandNew(const String *command);
+ProtocolCommand *protocolCommandNew(const StringId command);
 
 /***********************************************************************************************************************************
 Functions
 ***********************************************************************************************************************************/
 // Move to a new parent mem context
-ProtocolCommand *protocolCommandMove(ProtocolCommand *this, MemContext *parentNew);
+// Move to a new parent mem context
+__attribute__((always_inline)) static inline ProtocolCommand *
+protocolCommandMove(ProtocolCommand *const this, MemContext *const parentNew)
+{
+    return objMove(this, parentNew);
+}
 
 // Read the command output
-ProtocolCommand *protocolCommandParamAdd(ProtocolCommand *this, const Variant *param);
+PackWrite *protocolCommandParam(ProtocolCommand *this);
 
-/***********************************************************************************************************************************
-Getters/Setters
-***********************************************************************************************************************************/
-// Command JSON
-String *protocolCommandJson(const ProtocolCommand *this);
+// Write protocol command
+void protocolCommandPut(ProtocolCommand *this, IoWrite *write);
 
 /***********************************************************************************************************************************
 Destructor
 ***********************************************************************************************************************************/
-void protocolCommandFree(ProtocolCommand *this);
+__attribute__((always_inline)) static inline void
+protocolCommandFree(ProtocolCommand *const this)
+{
+    objFree(this);
+}
 
 /***********************************************************************************************************************************
 Macros for function logging
