@@ -4,12 +4,11 @@ Protocol Parallel Job
 #ifndef PROTOCOL_PARALLEL_JOB_H
 #define PROTOCOL_PARALLEL_JOB_H
 
+#include "common/type/stringId.h"
+
 /***********************************************************************************************************************************
 Object type
 ***********************************************************************************************************************************/
-#define PROTOCOL_PARALLEL_JOB_TYPE                                  ProtocolParallelJob
-#define PROTOCOL_PARALLEL_JOB_PREFIX                                protocolParallelJob
-
 typedef struct ProtocolParallelJob ProtocolParallelJob;
 
 /***********************************************************************************************************************************
@@ -17,12 +16,14 @@ Job state enum
 ***********************************************************************************************************************************/
 typedef enum
 {
-    protocolParallelJobStatePending,
-    protocolParallelJobStateRunning,
-    protocolParallelJobStateDone,
+    protocolParallelJobStatePending = STRID5("pending", 0x1dc9238b00),
+    protocolParallelJobStateRunning = STRID5("running", 0x1dc973ab20),
+    protocolParallelJobStateDone = STRID5("done", 0x2b9e40),
 } ProtocolParallelJobState;
 
 #include "common/time.h"
+#include "common/type/object.h"
+#include "common/type/pack.h"
 #include "protocol/client.h"
 
 /***********************************************************************************************************************************
@@ -30,47 +31,98 @@ Constructors
 ***********************************************************************************************************************************/
 ProtocolParallelJob *protocolParallelJobNew(const Variant *key, ProtocolCommand *command);
 
-/***********************************************************************************************************************************
-Functions
-***********************************************************************************************************************************/
-// Move to new parent mem context
-ProtocolParallelJob *protocolParallelJobMove(ProtocolParallelJob *this, MemContext *parentNew);
-
 /***********************************************************************************************************************************
 Getters/Setters
 ***********************************************************************************************************************************/
+typedef struct ProtocolParallelJobPub
+{
+    const Variant *key;                                             // Unique key used to identify the job
+    ProtocolCommand *command;                                       // Command to be executed
+    unsigned int processId;                                         // Process that executed this job
+    ProtocolParallelJobState state;                                 // Current state of the job
+    int code;                                                       // Non-zero result indicates an error
+    String *message;                                                // Message if there was a error
+    PackRead *result;                                               // Result if job was successful
+} ProtocolParallelJobPub;
+
 // Job command
-const ProtocolCommand *protocolParallelJobCommand(const ProtocolParallelJob *this);
+__attribute__((always_inline)) static inline ProtocolCommand *
+protocolParallelJobCommand(const ProtocolParallelJob *const this)
+{
+    return THIS_PUB(ProtocolParallelJob)->command;
+}
 
 // Job error
-int protocolParallelJobErrorCode(const ProtocolParallelJob *this);
-const String *protocolParallelJobErrorMessage(const ProtocolParallelJob *this);
+__attribute__((always_inline)) static inline int
+protocolParallelJobErrorCode(const ProtocolParallelJob *const this)
+{
+    return THIS_PUB(ProtocolParallelJob)->code;
+}
+
+__attribute__((always_inline)) static inline const String *
+protocolParallelJobErrorMessage(const ProtocolParallelJob *const this)
+{
+    return THIS_PUB(ProtocolParallelJob)->message;
+}
+
 void protocolParallelJobErrorSet(ProtocolParallelJob *this, int code, const String *message);
 
 // Job key
-const Variant *protocolParallelJobKey(const ProtocolParallelJob *this);
+__attribute__((always_inline)) static inline const Variant *
+protocolParallelJobKey(const ProtocolParallelJob *const this)
+{
+    return THIS_PUB(ProtocolParallelJob)->key;
+}
 
 // Process Id
-unsigned int protocolParallelJobProcessId(const ProtocolParallelJob *this);
+__attribute__((always_inline)) static inline unsigned int
+protocolParallelJobProcessId(const ProtocolParallelJob *const this)
+{
+    return THIS_PUB(ProtocolParallelJob)->processId;
+}
+
 void protocolParallelJobProcessIdSet(ProtocolParallelJob *this, unsigned int processId);
 
 // Job result
-const Variant *protocolParallelJobResult(const ProtocolParallelJob *this);
-void protocolParallelJobResultSet(ProtocolParallelJob *this, const Variant *result);
+__attribute__((always_inline)) static inline PackRead *
+protocolParallelJobResult(const ProtocolParallelJob *const this)
+{
+    return THIS_PUB(ProtocolParallelJob)->result;
+}
+
+void protocolParallelJobResultSet(ProtocolParallelJob *const this, PackRead *const result);
 
 // Job state
-ProtocolParallelJobState protocolParallelJobState(const ProtocolParallelJob *this);
+__attribute__((always_inline)) static inline ProtocolParallelJobState
+protocolParallelJobState(const ProtocolParallelJob *const this)
+{
+    return THIS_PUB(ProtocolParallelJob)->state;
+}
+
 void protocolParallelJobStateSet(ProtocolParallelJob *this, ProtocolParallelJobState state);
 
+/***********************************************************************************************************************************
+Functions
+***********************************************************************************************************************************/
+// Move to new parent mem context
+__attribute__((always_inline)) static inline ProtocolParallelJob *
+protocolParallelJobMove(ProtocolParallelJob *const this, MemContext *const parentNew)
+{
+    return objMove(this, parentNew);
+}
+
 /***********************************************************************************************************************************
 Destructor
 ***********************************************************************************************************************************/
-void protocolParallelJobFree(ProtocolParallelJob *this);
+__attribute__((always_inline)) static inline void
+protocolParallelJobFree(ProtocolParallelJob *const this)
+{
+    objFree(this);
+}
 
 /***********************************************************************************************************************************
 Macros for function logging
 ***********************************************************************************************************************************/
-const char *protocolParallelJobToConstZ(ProtocolParallelJobState state);
 String *protocolParallelJobToLog(const ProtocolParallelJob *this);
 
 #define FUNCTION_LOG_PROTOCOL_PARALLEL_JOB_TYPE                                                                                    \
