@@ -13,7 +13,6 @@ Azure Storage
 #include "common/io/socket/client.h"
 #include "common/io/tls/client.h"
 #include "common/log.h"
-#include "common/memContext.h"
 #include "common/regExp.h"
 #include "common/type/object.h"
 #include "common/type/xml.h"
@@ -21,11 +20,6 @@ Azure Storage
 #include "storage/azure/storage.intern.h"
 #include "storage/azure/write.h"
 
-/***********************************************************************************************************************************
-Storage type
-***********************************************************************************************************************************/
-STRING_EXTERN(STORAGE_AZURE_TYPE_STR,                               STORAGE_AZURE_TYPE);
-
 /***********************************************************************************************************************************
 Azure http headers
 ***********************************************************************************************************************************/
@@ -63,7 +57,6 @@ Object type
 struct StorageAzure
 {
     STORAGE_COMMON_MEMBER;
-    MemContext *memContext;
     HttpClient *httpClient;                                         // Http client to service requests
     StringList *headerRedactList;                                   // List of headers to redact from logging
     StringList *queryRedactList;                                    // List of query keys to redact from logging
@@ -117,7 +110,7 @@ storageAzureAuth(
             httpHeaderPut(httpHeader, AZURE_HEADER_VERSION_STR, AZURE_HEADER_VERSION_VALUE_STR);
 
             // Generate canonical headers
-            String *headerCanonical = strNew("");
+            String *headerCanonical = strNew();
             StringList *headerKeyList = httpHeaderList(httpHeader);
 
             for (unsigned int headerKeyIdx = 0; headerKeyIdx < strLstSize(headerKeyList); headerKeyIdx++)
@@ -131,7 +124,7 @@ storageAzureAuth(
             }
 
             // Generate canonical query
-            String *queryCanonical = strNew("");
+            String *queryCanonical = strNew();
 
             if (query != NULL)
             {
@@ -689,9 +682,10 @@ static const StorageInterface storageInterfaceAzure =
 
 Storage *
 storageAzureNew(
-    const String *path, bool write, StoragePathExpressionCallback pathExpressionFunction, const String *container,
-    const String *account, StorageAzureKeyType keyType, const String *key, size_t blockSize, const String *host,
-    const String *endpoint, unsigned int port, TimeMSec timeout, bool verifyPeer, const String *caFile, const String *caPath)
+    const String *const path, const bool write, StoragePathExpressionCallback pathExpressionFunction, const String *const container,
+    const String *const account, const StorageAzureKeyType keyType, const String *const key, const size_t blockSize,
+    const String *const endpoint, const StorageAzureUriStyle uriStyle, const unsigned int port, const TimeMSec timeout,
+    const bool verifyPeer, const String *const caFile, const String *const caPath)
 {
     FUNCTION_LOG_BEGIN(logLevelDebug);
         FUNCTION_LOG_PARAM(STRING, path);
@@ -699,11 +693,11 @@ storageAzureNew(
         FUNCTION_LOG_PARAM(FUNCTIONP, pathExpressionFunction);
         FUNCTION_LOG_PARAM(STRING, container);
         FUNCTION_TEST_PARAM(STRING, account);
-        FUNCTION_LOG_PARAM(ENUM, keyType);
+        FUNCTION_LOG_PARAM(STRING_ID, keyType);
         FUNCTION_TEST_PARAM(STRING, key);
         FUNCTION_LOG_PARAM(SIZE, blockSize);
-        FUNCTION_LOG_PARAM(STRING, host);
         FUNCTION_LOG_PARAM(STRING, endpoint);
+        FUNCTION_LOG_PARAM(ENUM, uriStyle);
         FUNCTION_LOG_PARAM(UINT, port);
         FUNCTION_LOG_PARAM(TIME_MSEC, timeout);
         FUNCTION_LOG_PARAM(BOOL, verifyPeer);
@@ -714,24 +708,25 @@ storageAzureNew(
     ASSERT(path != NULL);
     ASSERT(container != NULL);
     ASSERT(account != NULL);
+    ASSERT(endpoint != NULL);
     ASSERT(key != NULL);
     ASSERT(blockSize != 0);
 
     Storage *this = NULL;
 
-    MEM_CONTEXT_NEW_BEGIN("StorageAzure")
+    OBJ_NEW_BEGIN(StorageAzure)
     {
-        StorageAzure *driver = memNew(sizeof(StorageAzure));
+        StorageAzure *driver = OBJ_NEW_ALLOC();
 
         *driver = (StorageAzure)
         {
-            .memContext = MEM_CONTEXT_NEW(),
             .interface = storageInterfaceAzure,
             .container = strDup(container),
             .account = strDup(account),
             .blockSize = blockSize,
-            .host = host == NULL ? strNewFmt("%s.%s", strZ(account), strZ(endpoint)) : host,
-            .pathPrefix = host == NULL ? strNewFmt("/%s", strZ(container)) : strNewFmt("/%s/%s", strZ(account), strZ(container)),
+            .host = uriStyle == storageAzureUriStyleHost ? strNewFmt("%s.%s", strZ(account), strZ(endpoint)) : endpoint,
+            .pathPrefix = uriStyle == storageAzureUriStyleHost ?
+                strNewFmt("/%s", strZ(container)) : strNewFmt("/%s/%s", strZ(account), strZ(container)),
         };
 
         // Store shared key or parse sas query
@@ -742,7 +737,10 @@ storageAzureNew(
 
         // Create the http client used to service requests
         driver->httpClient = httpClientNew(
-            tlsClientNew(sckClientNew(driver->host, port, timeout), driver->host, timeout, verifyPeer, caFile, caPath), timeout);
+            tlsClientNewP(
+                sckClientNew(driver->host, port, timeout, timeout), driver->host, timeout, timeout, verifyPeer, .caFile = caFile,
+                .caPath = caPath),
+            timeout);
 
         // Create list of redacted headers
         driver->headerRedactList = strLstNew();
@@ -756,9 +754,9 @@ storageAzureNew(
         // Generate starting file id
         cryptoRandomBytes((unsigned char *)&driver->fileId, sizeof(driver->fileId));
 
-        this = storageNew(STORAGE_AZURE_TYPE_STR, path, 0, 0, write, pathExpressionFunction, driver, driver->interface);
+        this = storageNew(STORAGE_AZURE_TYPE, path, 0, 0, write, pathExpressionFunction, driver, driver->interface);
     }
-    MEM_CONTEXT_NEW_END();
+    OBJ_NEW_END();
 
     FUNCTION_LOG_RETURN(STORAGE, this);
 }
