@@ -5,16 +5,10 @@ CIFS Storage
 
 #include "common/debug.h"
 #include "common/log.h"
-#include "common/memContext.h"
 #include "common/regExp.h"
 #include "storage/cifs/storage.h"
 #include "storage/posix/storage.intern.h"
 
-/***********************************************************************************************************************************
-Storage type
-***********************************************************************************************************************************/
-STRING_EXTERN(STORAGE_CIFS_TYPE_STR,                                STORAGE_CIFS_TYPE);
-
 /**********************************************************************************************************************************/
 Storage *
 storageCifsNew(
@@ -29,5 +23,5 @@ storageCifsNew(
     FUNCTION_LOG_END();
 
     FUNCTION_LOG_RETURN(
-        STORAGE, storagePosixNewInternal(STORAGE_CIFS_TYPE_STR, path, modeFile, modePath, write, pathExpressionFunction, false));
+        STORAGE, storagePosixNewInternal(STORAGE_CIFS_TYPE, path, modeFile, modePath, write, pathExpressionFunction, false));
 }
