@@ -18,7 +18,6 @@ GCS Storage
 #include "common/io/socket/client.h"
 #include "common/io/tls/client.h"
 #include "common/log.h"
-#include "common/memContext.h"
 #include "common/regExp.h"
 #include "common/type/json.h"
 #include "common/type/object.h"
@@ -27,15 +26,12 @@ GCS Storage
 #include "storage/gcs/write.h"
 #include "storage/posix/storage.h"
 
-/***********************************************************************************************************************************
-Storage type
-***********************************************************************************************************************************/
-STRING_EXTERN(STORAGE_GCS_TYPE_STR,                                 STORAGE_GCS_TYPE);
-
 /***********************************************************************************************************************************
 HTTP headers
 ***********************************************************************************************************************************/
 STRING_EXTERN(GCS_HEADER_UPLOAD_ID_STR,                             GCS_HEADER_UPLOAD_ID);
+STRING_STATIC(GCS_HEADER_METADATA_FLAVOR_STR,                       "metadata-flavor");
+STRING_STATIC(GCS_HEADER_GOOGLE_STR,                                "Google");
 
 /***********************************************************************************************************************************
 Query tokens
@@ -84,7 +80,6 @@ Object type
 struct StorageGcs
 {
     STORAGE_COMMON_MEMBER;
-    MemContext *memContext;
     HttpClient *httpClient;                                         // Http client to service requests
     StringList *headerRedactList;                                   // List of headers to redact from logging
     StringList *queryRedactList;                                    // List of query keys to redact from logging
@@ -103,6 +98,61 @@ struct StorageGcs
     HttpClient *authClient;                                         // Client to service auth requests
 };
 
+/***********************************************************************************************************************************
+Parse HTTP JSON response containing an authentication token and expiration
+
+Note that the function is intended to run directly in the caller's mem context and results will be placed in the caller's prior mem
+context.
+***********************************************************************************************************************************/
+typedef struct
+{
+    String *tokenType;
+    String *token;
+    time_t timeExpire;
+} StorageGcsAuthTokenResult;
+
+static StorageGcsAuthTokenResult
+storageGcsAuthToken(HttpRequest *request, time_t timeBegin)
+{
+    FUNCTION_TEST_BEGIN();
+        FUNCTION_TEST_PARAM(HTTP_REQUEST, request);
+        FUNCTION_TEST_PARAM(TIME, timeBegin);
+    FUNCTION_TEST_END();
+
+    StorageGcsAuthTokenResult result = {0};
+
+    // Get the response
+    KeyValue *kvResponse = jsonToKv(strNewBuf(httpResponseContent(httpRequestResponse(request, true))));
+
+    // Check for an error
+    const String *error = varStr(kvGet(kvResponse, GCS_JSON_ERROR_VAR));
+
+    if (error != NULL)
+    {
+        THROW_FMT(
+            ProtocolError, "unable to get authentication token: [%s] %s", strZ(error),
+            strZNull(varStr(kvGet(kvResponse, GCS_JSON_ERROR_DESCRIPTION_VAR))));
+    }
+
+    MEM_CONTEXT_PRIOR_BEGIN()
+    {
+        // Get token
+        result.tokenType = strDup(varStr(kvGet(kvResponse, GCS_JSON_TOKEN_TYPE_VAR)));
+        CHECK(FormatError, result.tokenType != NULL, "token type missing");
+        result.token = strDup(varStr(kvGet(kvResponse, GCS_JSON_ACCESS_TOKEN_VAR)));
+        CHECK(FormatError, result.token != NULL, "access token missing");
+
+        // Get expiration
+        const Variant *const expiresIn = kvGet(kvResponse, GCS_JSON_EXPIRES_IN_VAR);
+        CHECK(FormatError, expiresIn != NULL, "expiry missing");
+
+        result.timeExpire = timeBegin + (time_t)varInt64Force(expiresIn);
+    }
+    MEM_CONTEXT_PRIOR_END();
+
+    FUNCTION_TEST_RETURN(result);
+}
+
 /***********************************************************************************************************************************
 Get authentication header for service keys
 
@@ -118,7 +168,7 @@ storageGcsAuthJwt(StorageGcs *this, time_t timeBegin)
     FUNCTION_TEST_END();
 
     // Static header with dot delimiter
-    String *result = strNew("eyJhbGciOiJSUzI1NiIsInR5cCI6IkpXVCJ9.");
+    String *result = strCatZ(strNew(), "eyJhbGciOiJSUzI1NiIsInR5cCI6IkpXVCJ9.");
 
     MEM_CONTEXT_TEMP_BEGIN()
     {
@@ -185,15 +235,8 @@ storageGcsAuthJwt(StorageGcs *this, time_t timeBegin)
     FUNCTION_TEST_RETURN(result);
 }
 
-typedef struct
-{
-    String *tokenType;
-    String *token;
-    time_t timeExpire;
-} StorageGcsAuthTokenResult;
-
 static StorageGcsAuthTokenResult
-storageGcsAuthToken(StorageGcs *this, time_t timeBegin)
+storageGcsAuthService(StorageGcs *this, time_t timeBegin)
 {
     FUNCTION_TEST_BEGIN();
         FUNCTION_TEST_PARAM(STORAGE_GCS, this);
@@ -218,35 +261,43 @@ storageGcsAuthToken(StorageGcs *this, time_t timeBegin)
 
         HttpRequest *request = httpRequestNewP(
             this->authClient, HTTP_VERB_POST_STR, httpUrlPath(this->authUrl), NULL, .header = header, .content = BUFSTR(content));
-        HttpResponse *response = httpRequestResponse(request, true);
 
-        KeyValue *kvResponse = jsonToKv(strNewBuf(httpResponseContent(response)));
+        result = storageGcsAuthToken(request, timeBegin);
+    }
+    MEM_CONTEXT_TEMP_END();
 
-        // Check for an error
-        const String *error = varStr(kvGet(kvResponse, GCS_JSON_ERROR_VAR));
+    FUNCTION_TEST_RETURN(result);
+}
 
-        if (error != NULL)
-        {
-            THROW_FMT(
-                ProtocolError, "unable to get authentication token: [%s] %s", strZ(error),
-                strZNull(varStr(kvGet(kvResponse, GCS_JSON_ERROR_DESCRIPTION_VAR))));
-        }
+/***********************************************************************************************************************************
+Get authentication token automatically for instances running in GCE.
 
-        MEM_CONTEXT_PRIOR_BEGIN()
-        {
-            // Get token
-            result.tokenType = strDup(varStr(kvGet(kvResponse, GCS_JSON_TOKEN_TYPE_VAR)));
-            CHECK(result.tokenType != NULL);
-            result.token = strDup(varStr(kvGet(kvResponse, GCS_JSON_ACCESS_TOKEN_VAR)));
-            CHECK(result.token != NULL);
+Based on the documentation at https://cloud.google.com/compute/docs/access/create-enable-service-accounts-for-instances#applications
+***********************************************************************************************************************************/
+static StorageGcsAuthTokenResult
+storageGcsAuthAuto(StorageGcs *this, time_t timeBegin)
+{
+    FUNCTION_TEST_BEGIN();
+        FUNCTION_TEST_PARAM(STORAGE_GCS, this);
+        FUNCTION_TEST_PARAM(TIME, timeBegin);
+    FUNCTION_TEST_END();
 
-            // Get expiration
-            const Variant *const expiresIn = kvGet(kvResponse, GCS_JSON_EXPIRES_IN_VAR);
-            CHECK(expiresIn != NULL);
+    ASSERT(this != NULL);
+    ASSERT(timeBegin > 0);
 
-            result.timeExpire = timeBegin + (time_t)varInt64Force(expiresIn);
-        }
-        MEM_CONTEXT_PRIOR_END();
+    StorageGcsAuthTokenResult result = {0};
+
+    MEM_CONTEXT_TEMP_BEGIN()
+    {
+        HttpHeader *header = httpHeaderNew(NULL);
+        httpHeaderAdd(header, HTTP_HEADER_HOST_STR, httpUrlHost(this->authUrl));
+        httpHeaderAdd(header, GCS_HEADER_METADATA_FLAVOR_STR, GCS_HEADER_GOOGLE_STR);
+        httpHeaderAdd(header, HTTP_HEADER_CONTENT_LENGTH_STR, ZERO_STR);
+
+        HttpRequest *request = httpRequestNewP(
+            this->authClient, HTTP_VERB_GET_STR, httpUrlPath(this->authUrl), NULL, .header = header);
+
+        result = storageGcsAuthToken(request, timeBegin);
     }
     MEM_CONTEXT_TEMP_END();
 
@@ -270,37 +321,34 @@ storageGcsAuth(StorageGcs *this, HttpHeader *httpHeader)
 
     MEM_CONTEXT_TEMP_BEGIN()
     {
-        // Process authentication type
-        switch (this->keyType)
+        // Get the token if it was not supplied by the user
+        if (this->keyType != storageGcsKeyTypeToken)
         {
-            // Service key authentication requests a token then drops through to normal token authentication
-            case storageGcsKeyTypeService:
+            ASSERT(this->keyType == storageGcsKeyTypeAuto || this->keyType == storageGcsKeyTypeService);
+
+            time_t timeBegin = time(NULL);
+
+            // If the current token has expired then request a new one
+            if (timeBegin >= this->tokenTimeExpire)
             {
-                time_t timeBegin = time(NULL);
+                StorageGcsAuthTokenResult tokenResult = this->keyType == storageGcsKeyTypeAuto ?
+                    storageGcsAuthAuto(this, timeBegin) : storageGcsAuthService(this, timeBegin);
 
-                // If the current token has expired then request a new one
-                if (timeBegin >= this->tokenTimeExpire)
+                MEM_CONTEXT_BEGIN(THIS_MEM_CONTEXT())
                 {
-                    StorageGcsAuthTokenResult tokenResult = storageGcsAuthToken(this, timeBegin);
+                    strFree(this->token);
+                    this->token = strNewFmt("%s %s", strZ(tokenResult.tokenType), strZ(tokenResult.token));
 
-                    MEM_CONTEXT_BEGIN(this->memContext)
-                    {
-                        strFree(this->token);
-                        this->token = strNewFmt("%s %s", strZ(tokenResult.tokenType), strZ(tokenResult.token));
-
-                        // Subtract http client timeout * 2 so the token does not expire in the middle of http retries
-                        this->tokenTimeExpire =
-                            tokenResult.timeExpire - ((time_t)(httpClientTimeout(this->httpClient) / MSEC_PER_SEC * 2));
-                    }
-                    MEM_CONTEXT_END();
+                    // Subtract http client timeout * 2 so the token does not expire in the middle of http retries
+                    this->tokenTimeExpire =
+                        tokenResult.timeExpire - ((time_t)(httpClientTimeout(this->httpClient) / MSEC_PER_SEC * 2));
                 }
+                MEM_CONTEXT_END();
             }
-
-            // Token authentication
-            case storageGcsKeyTypeToken:
-                httpHeaderPut(httpHeader, HTTP_HEADER_AUTHORIZATION_STR, this->token);
-                break;
         }
+
+        // Add authorization header
+        httpHeaderPut(httpHeader, HTTP_HEADER_AUTHORIZATION_STR, this->token);
     }
     MEM_CONTEXT_TEMP_END();
 
@@ -334,7 +382,7 @@ storageGcsRequestAsync(StorageGcs *this, const String *verb, StorageGcsRequestAs
     MEM_CONTEXT_TEMP_BEGIN()
     {
         // Generate path
-        String *path = strNewFmt("%s/storage/v1/b", param.upload ? "/upload" : "");
+        String *path = strCatFmt(strNew(), "%s/storage/v1/b", param.upload ? "/upload" : "");
 
         if (!param.noBucket)
             strCatFmt(path, "/%s/o", strZ(this->bucket));
@@ -600,7 +648,7 @@ storageGcsListInternal(
                     for (unsigned int fileIdx = 0; fileIdx < varLstSize(fileList); fileIdx++)
                     {
                         const KeyValue *file = varKv(varLstGet(fileList, fileIdx));
-                        CHECK(file != NULL);
+                        CHECK(FormatError, file != NULL, "file missing");
 
                         // Get file name
                         StorageInfo info =
@@ -610,7 +658,7 @@ storageGcsListInternal(
                             .exists = true,
                         };
 
-                        CHECK(info.name != NULL);
+                        CHECK(FormatError, info.name != NULL, "file name missing");
 
                         // Strip off the base prefix when present
                         if (!strEmpty(basePrefix))
@@ -867,7 +915,7 @@ storageGcsNew(
         FUNCTION_LOG_PARAM(BOOL, write);
         FUNCTION_LOG_PARAM(FUNCTIONP, pathExpressionFunction);
         FUNCTION_LOG_PARAM(STRING, bucket);
-        FUNCTION_LOG_PARAM(ENUM, keyType);
+        FUNCTION_LOG_PARAM(STRING_ID, keyType);
         FUNCTION_TEST_PARAM(STRING, key);
         FUNCTION_LOG_PARAM(SIZE, chunkSize);
         FUNCTION_LOG_PARAM(STRING, endpoint);
@@ -879,18 +927,17 @@ storageGcsNew(
 
     ASSERT(path != NULL);
     ASSERT(bucket != NULL);
-    ASSERT(key != NULL);
+    ASSERT(keyType == storageGcsKeyTypeAuto || key != NULL);
     ASSERT(chunkSize != 0);
 
     Storage *this = NULL;
 
-    MEM_CONTEXT_NEW_BEGIN("StorageGcs")
+    OBJ_NEW_BEGIN(StorageGcs)
     {
-        StorageGcs *driver = memNew(sizeof(StorageGcs));
+        StorageGcs *driver = OBJ_NEW_ALLOC();
 
         *driver = (StorageGcs)
         {
-            .memContext = MEM_CONTEXT_NEW(),
             .interface = storageInterfaceGcs,
             .write = write,
             .bucket = strDup(bucket),
@@ -901,18 +948,34 @@ storageGcsNew(
         // Handle auth key types
         switch (keyType)
         {
+            // Auto authentication for GCE instances
+            case storageGcsKeyTypeAuto:
+            {
+                driver->authUrl = httpUrlNewParseP(
+                    STRDEF("metadata.google.internal/computeMetadata/v1/instance/service-accounts/default/token"),
+                    .type = httpProtocolTypeHttp);
+                driver->authClient = httpClientNew(
+                    sckClientNew(httpUrlHost(driver->authUrl), httpUrlPort(driver->authUrl), timeout, timeout), timeout);
+
+                break;
+            }
+
             // Read data from file for service keys
             case storageGcsKeyTypeService:
             {
                 KeyValue *kvKey = jsonToKv(strNewBuf(storageGetP(storageNewReadP(storagePosixNewP(FSLASH_STR), key))));
                 driver->credential = varStr(kvGet(kvKey, GCS_JSON_CLIENT_EMAIL_VAR));
                 driver->privateKey = varStr(kvGet(kvKey, GCS_JSON_PRIVATE_KEY_VAR));
-                driver->authUrl = httpUrlNewParseP(varStr(kvGet(kvKey, GCS_JSON_TOKEN_URI_VAR)), .type = httpProtocolTypeHttps);
+                const String *const uri = varStr(kvGet(kvKey, GCS_JSON_TOKEN_URI_VAR));
+
+                CHECK(FormatError, driver->credential != NULL && driver->privateKey != NULL && uri != NULL, "credentials missing");
+
+                driver->authUrl = httpUrlNewParseP(uri, .type = httpProtocolTypeHttps);
 
                 driver->authClient = httpClientNew(
-                    tlsClientNew(
-                        sckClientNew(httpUrlHost(driver->authUrl), httpUrlPort(driver->authUrl), timeout),
-                        httpUrlHost(driver->authUrl), timeout, verifyPeer, caFile, caPath),
+                    tlsClientNewP(
+                        sckClientNew(httpUrlHost(driver->authUrl), httpUrlPort(driver->authUrl), timeout, timeout),
+                        httpUrlHost(driver->authUrl), timeout, timeout, verifyPeer, .caFile = caFile, .caPath = caPath),
                     timeout);
 
                 break;
@@ -930,8 +993,9 @@ storageGcsNew(
 
         // Create the http client used to service requests
         driver->httpClient = httpClientNew(
-            tlsClientNew(
-                sckClientNew(driver->endpoint, httpUrlPort(url), timeout), driver->endpoint, timeout, verifyPeer, caFile, caPath),
+            tlsClientNewP(
+                sckClientNew(driver->endpoint, httpUrlPort(url), timeout, timeout), driver->endpoint, timeout, timeout, verifyPeer,
+                .caFile = caFile, .caPath = caPath),
             timeout);
 
         // Create list of redacted headers
@@ -943,9 +1007,9 @@ storageGcsNew(
         driver->queryRedactList = strLstNew();
         strLstAdd(driver->queryRedactList, GCS_QUERY_UPLOAD_ID_STR);
 
-        this = storageNew(STORAGE_GCS_TYPE_STR, path, 0, 0, write, pathExpressionFunction, driver, driver->interface);
+        this = storageNew(STORAGE_GCS_TYPE, path, 0, 0, write, pathExpressionFunction, driver, driver->interface);
     }
-    MEM_CONTEXT_NEW_END();
+    OBJ_NEW_END();
 
     FUNCTION_LOG_RETURN(STORAGE, this);
 }
