@@ -11,17 +11,14 @@ Storage Helper
 #include "common/regExp.h"
 #include "config/config.h"
 #include "protocol/helper.h"
-#include "storage/azure/storage.h"
-#include "storage/cifs/storage.h"
-#include "storage/gcs/storage.h"
 #include "storage/posix/storage.h"
 #include "storage/remote/storage.h"
-#include "storage/s3/storage.h"
 #include "storage/helper.h"
 
 /***********************************************************************************************************************************
 Storage path constants
 ***********************************************************************************************************************************/
+STRING_EXTERN(STORAGE_SPOOL_ARCHIVE_STR,                            STORAGE_SPOOL_ARCHIVE);
 STRING_EXTERN(STORAGE_SPOOL_ARCHIVE_IN_STR,                         STORAGE_SPOOL_ARCHIVE_IN);
 STRING_EXTERN(STORAGE_SPOOL_ARCHIVE_OUT_STR,                        STORAGE_SPOOL_ARCHIVE_OUT);
 
@@ -40,10 +37,12 @@ Error message when writable storage is requested in dry-run mode
 /***********************************************************************************************************************************
 Local variables
 ***********************************************************************************************************************************/
-static struct StorageHelper
+static struct StorageHelperLocal
 {
     MemContext *memContext;                                         // Mem context for storage helper
 
+    const StorageHelper *helperList;                                // List of helpers to create storage
+
     Storage *storageLocal;                                          // Local read-only storage
     Storage *storageLocalWrite;                                     // Local write storage
     Storage **storagePg;                                            // PostgreSQL read-only storage
@@ -64,7 +63,7 @@ static struct StorageHelper
 Create the storage helper memory context
 ***********************************************************************************************************************************/
 static void
-storageHelperInit(void)
+storageHelperContextInit(void)
 {
     FUNCTION_TEST_VOID();
 
@@ -84,6 +83,18 @@ storageHelperInit(void)
     FUNCTION_TEST_RETURN_VOID();
 }
 
+/**********************************************************************************************************************************/
+void storageHelperInit(const StorageHelper *const helperList)
+{
+    FUNCTION_TEST_BEGIN();
+        FUNCTION_TEST_PARAM_P(VOID, helperList);
+    FUNCTION_TEST_END();
+
+    storageHelper.helperList = helperList;
+
+    FUNCTION_TEST_RETURN_VOID();
+}
+
 /**********************************************************************************************************************************/
 void
 storageHelperDryRunInit(bool dryRun)
@@ -129,7 +140,7 @@ storageLocal(void)
 
     if (storageHelper.storageLocal == NULL)
     {
-        storageHelperInit();
+        storageHelperContextInit();
 
         MEM_CONTEXT_BEGIN(storageHelper.memContext)
         {
@@ -148,7 +159,7 @@ storageLocalWrite(void)
 
     if (storageHelper.storageLocalWrite == NULL)
     {
-        storageHelperInit();
+        storageHelperContextInit();
 
         MEM_CONTEXT_BEGIN(storageHelper.memContext)
         {
@@ -199,7 +210,7 @@ storagePgIdx(unsigned int pgIdx)
 
     if (storageHelper.storagePg == NULL || storageHelper.storagePg[pgIdx] == NULL)
     {
-        storageHelperInit();
+        storageHelperContextInit();
 
         MEM_CONTEXT_BEGIN(storageHelper.memContext)
         {
@@ -234,7 +245,7 @@ storagePgIdxWrite(unsigned int pgIdx)
 
     if (storageHelper.storagePgWrite == NULL || storageHelper.storagePgWrite[pgIdx] == NULL)
     {
-        storageHelperInit();
+        storageHelperContextInit();
 
         MEM_CONTEXT_BEGIN(storageHelper.memContext)
         {
@@ -295,9 +306,9 @@ storageRepoPathExpression(const String *expression, const String *path)
     {
         // Construct the base path
         if (storageHelper.stanza != NULL)
-            result = strNewFmt(STORAGE_PATH_ARCHIVE "/%s", strZ(storageHelper.stanza));
+            result = strCatFmt(strNew(), STORAGE_PATH_ARCHIVE "/%s", strZ(storageHelper.stanza));
         else
-            result = strNew(STORAGE_PATH_ARCHIVE);
+            result = strCatZ(strNew(), STORAGE_PATH_ARCHIVE);
 
         // If a subpath should be appended, determine if it is WAL path, else just append the subpath
         if (path != NULL)
@@ -315,9 +326,9 @@ storageRepoPathExpression(const String *expression, const String *path)
     {
         // Construct the base path
         if (storageHelper.stanza != NULL)
-            result = strNewFmt(STORAGE_PATH_BACKUP "/%s", strZ(storageHelper.stanza));
+            result = strCatFmt(strNew(), STORAGE_PATH_BACKUP "/%s", strZ(storageHelper.stanza));
         else
-            result = strNew(STORAGE_PATH_BACKUP);
+            result = strCatZ(strNew(), STORAGE_PATH_BACKUP);
 
         // Append subpath if provided
         if (path != NULL)
@@ -352,78 +363,29 @@ storageRepoGet(unsigned int repoIdx, bool write)
     // Use local storage
     else
     {
-        const String *type = cfgOptionIdxStr(cfgOptRepoType, repoIdx);
+        // Search for the helper
+        const StringId type = cfgOptionIdxStrId(cfgOptRepoType, repoIdx);
 
-        // Use Azure storage
-        if (strEqZ(type, STORAGE_AZURE_TYPE))
+        if (storageHelper.helperList != NULL)
         {
-            result = storageAzureNew(
-                cfgOptionIdxStr(cfgOptRepoPath, repoIdx), write, storageRepoPathExpression,
-                cfgOptionIdxStr(cfgOptRepoAzureContainer, repoIdx), cfgOptionIdxStr(cfgOptRepoAzureAccount, repoIdx),
-                strEqZ(cfgOptionIdxStr(cfgOptRepoAzureKeyType, repoIdx), STORAGE_AZURE_KEY_TYPE_SHARED) ?
-                    storageAzureKeyTypeShared : storageAzureKeyTypeSas,
-                cfgOptionIdxStr(cfgOptRepoAzureKey, repoIdx), STORAGE_AZURE_BLOCKSIZE_MIN,
-                cfgOptionIdxStrNull(cfgOptRepoStorageHost, repoIdx), cfgOptionIdxStr(cfgOptRepoAzureEndpoint, repoIdx),
-                cfgOptionIdxUInt(cfgOptRepoStoragePort, repoIdx), ioTimeoutMs(),
-                cfgOptionIdxBool(cfgOptRepoStorageVerifyTls, repoIdx), cfgOptionIdxStrNull(cfgOptRepoStorageCaFile, repoIdx),
-                cfgOptionIdxStrNull(cfgOptRepoStorageCaPath, repoIdx));
+            for (const StorageHelper *helper = storageHelper.helperList; helper->type != 0; helper++)
+            {
+                if (helper->type == type)
+                {
+                    result = helper->helper(repoIdx, write, storageRepoPathExpression);
+                    break;
+                }
+            }
         }
-        // Use CIFS storage
-        else if (strEqZ(type, STORAGE_CIFS_TYPE))
-        {
-            result = storageCifsNew(
-                cfgOptionIdxStr(cfgOptRepoPath, repoIdx), STORAGE_MODE_FILE_DEFAULT, STORAGE_MODE_PATH_DEFAULT, write,
-                storageRepoPathExpression);
-        }
-        // Use GCS storage
-        else if (strEqZ(type, STORAGE_GCS_TYPE))
-        {
-            result = storageGcsNew(
-                cfgOptionIdxStr(cfgOptRepoPath, repoIdx), write, storageRepoPathExpression,
-                cfgOptionIdxStr(cfgOptRepoGcsBucket, repoIdx),
-                strEqZ(cfgOptionIdxStr(cfgOptRepoGcsKeyType, repoIdx), STORAGE_GCS_KEY_TYPE_SERVICE) ?
-                    storageGcsKeyTypeService : storageGcsKeyTypeToken,
-                cfgOptionIdxStr(cfgOptRepoGcsKey, repoIdx), STORAGE_GCS_CHUNKSIZE_DEFAULT,
-                cfgOptionIdxStr(cfgOptRepoGcsEndpoint, repoIdx), ioTimeoutMs(),
-                cfgOptionIdxBool(cfgOptRepoStorageVerifyTls, repoIdx),
-                cfgOptionIdxStrNull(cfgOptRepoStorageCaFile, repoIdx), cfgOptionIdxStrNull(cfgOptRepoStorageCaPath, repoIdx));
-        }
-        // Use Posix storage
-        else if (strEqZ(type, STORAGE_POSIX_TYPE))
+
+        // If no helper was found it try Posix
+        if (result == NULL)
         {
+            CHECK(AssertError, type == STORAGE_POSIX_TYPE, "invalid storage type");
+
             result = storagePosixNewP(
                 cfgOptionIdxStr(cfgOptRepoPath, repoIdx), .write = write, .pathExpressionFunction = storageRepoPathExpression);
         }
-        // Use S3 storage
-        else
-        {
-            // Storage must be S3
-            CHECK(strEqZ(type, STORAGE_S3_TYPE));
-
-            // Set the default port
-            unsigned int port = cfgOptionIdxUInt(cfgOptRepoStoragePort, repoIdx);
-
-            // Extract port from the endpoint and host if it is present
-            const String *endPoint = cfgOptionIdxHostPort(cfgOptRepoS3Endpoint, repoIdx, &port);
-            const String *host = cfgOptionIdxHostPort(cfgOptRepoStorageHost, repoIdx, &port);
-
-            // If the port option was set explicitly then use it in preference to appended ports
-            if (cfgOptionIdxSource(cfgOptRepoStoragePort, repoIdx) != cfgSourceDefault)
-                port = cfgOptionIdxUInt(cfgOptRepoStoragePort, repoIdx);
-
-            result = storageS3New(
-                cfgOptionIdxStr(cfgOptRepoPath, repoIdx), write, storageRepoPathExpression,
-                cfgOptionIdxStr(cfgOptRepoS3Bucket, repoIdx), endPoint,
-                strEqZ(cfgOptionIdxStr(cfgOptRepoS3UriStyle, repoIdx), STORAGE_S3_URI_STYLE_HOST) ?
-                    storageS3UriStyleHost : storageS3UriStylePath,
-                cfgOptionIdxStr(cfgOptRepoS3Region, repoIdx),
-                strEqZ(cfgOptionIdxStr(cfgOptRepoS3KeyType, repoIdx), STORAGE_S3_KEY_TYPE_SHARED) ?
-                    storageS3KeyTypeShared : storageS3KeyTypeAuto,
-                cfgOptionIdxStrNull(cfgOptRepoS3Key, repoIdx), cfgOptionIdxStrNull(cfgOptRepoS3KeySecret, repoIdx),
-                cfgOptionIdxStrNull(cfgOptRepoS3Token, repoIdx), cfgOptionIdxStrNull(cfgOptRepoS3Role, repoIdx),
-                STORAGE_S3_PARTSIZE_MIN, host, port, ioTimeoutMs(), cfgOptionIdxBool(cfgOptRepoStorageVerifyTls, repoIdx),
-                cfgOptionIdxStrNull(cfgOptRepoStorageCaFile, repoIdx), cfgOptionIdxStrNull(cfgOptRepoStorageCaPath, repoIdx));
-        }
     }
 
     FUNCTION_TEST_RETURN(result);
@@ -439,7 +401,7 @@ storageRepoIdx(unsigned int repoIdx)
 
     if (storageHelper.storageRepo == NULL)
     {
-        storageHelperInit();
+        storageHelperContextInit();
         storageHelperStanzaInit(false);
         storageHelperRepoInit();
 
@@ -482,7 +444,7 @@ storageRepoIdxWrite(unsigned int repoIdx)
 
     if (storageHelper.storageRepoWrite == NULL)
     {
-        storageHelperInit();
+        storageHelperContextInit();
         storageHelperStanzaInit(false);
         storageHelperRepoInit();
 
@@ -528,7 +490,14 @@ storageSpoolPathExpression(const String *expression, const String *path)
 
     String *result = NULL;
 
-    if (strEqZ(expression, STORAGE_SPOOL_ARCHIVE_IN))
+    if (strEqZ(expression, STORAGE_SPOOL_ARCHIVE))
+    {
+        if (path == NULL)
+            result = strNewFmt(STORAGE_PATH_ARCHIVE "/%s", strZ(storageHelper.stanza));
+        else
+            result = strNewFmt(STORAGE_PATH_ARCHIVE "/%s/%s", strZ(storageHelper.stanza), strZ(path));
+    }
+    else if (strEqZ(expression, STORAGE_SPOOL_ARCHIVE_IN))
     {
         if (path == NULL)
             result = strNewFmt(STORAGE_PATH_ARCHIVE "/%s/in", strZ(storageHelper.stanza));
@@ -556,7 +525,7 @@ storageSpool(void)
 
     if (storageHelper.storageSpool == NULL)
     {
-        storageHelperInit();
+        storageHelperContextInit();
         storageHelperStanzaInit(true);
 
         MEM_CONTEXT_BEGIN(storageHelper.memContext)
@@ -581,7 +550,7 @@ storageSpoolWrite(void)
 
     if (storageHelper.storageSpoolWrite == NULL)
     {
-        storageHelperInit();
+        storageHelperContextInit();
         storageHelperStanzaInit(true);
 
         MEM_CONTEXT_BEGIN(storageHelper.memContext)
@@ -604,7 +573,7 @@ storageHelperFree(void)
     if (storageHelper.memContext != NULL)
         memContextFree(storageHelper.memContext);
 
-    storageHelper = (struct StorageHelper){.memContext = NULL};
+    storageHelper = (struct StorageHelperLocal){.memContext = NULL, .helperList = storageHelper.helperList};
 
     FUNCTION_TEST_RETURN_VOID();
 }
