@@ -7,9 +7,8 @@ Posix Storage Read
 #include <unistd.h>
 
 #include "common/debug.h"
-#include "common/io/read.intern.h"
+#include "common/io/read.h"
 #include "common/log.h"
-#include "common/memContext.h"
 #include "common/type/object.h"
 #include "storage/posix/read.h"
 #include "storage/posix/storage.intern.h"
@@ -18,12 +17,8 @@ Posix Storage Read
 /***********************************************************************************************************************************
 Object types
 ***********************************************************************************************************************************/
-#define STORAGE_READ_POSIX_TYPE                                     StorageReadPosix
-#define STORAGE_READ_POSIX_PREFIX                                   storageReadPosix
-
 typedef struct StorageReadPosix
 {
-    MemContext *memContext;                                         // Object mem context
     StorageReadInterface interface;                                 // Interface
     StoragePosix *storage;                                          // Storage that created this object
 
@@ -44,12 +39,22 @@ Macros for function logging
 /***********************************************************************************************************************************
 Close file descriptor
 ***********************************************************************************************************************************/
-OBJECT_DEFINE_FREE_RESOURCE_BEGIN(STORAGE_READ_POSIX, LOG, logLevelTrace)
+static void
+storageReadPosixFreeResource(THIS_VOID)
 {
+    THIS(StorageReadPosix);
+
+    FUNCTION_LOG_BEGIN(logLevelTrace);
+        FUNCTION_LOG_PARAM(STORAGE_READ_POSIX, this);
+    FUNCTION_LOG_END();
+
+    ASSERT(this != NULL);
+
     if (this->fd != -1)
         THROW_ON_SYS_ERROR_FMT(close(this->fd) == -1, FileCloseError, STORAGE_ERROR_READ_CLOSE, strZ(this->interface.name));
+
+    FUNCTION_LOG_RETURN_VOID();
 }
-OBJECT_DEFINE_FREE_RESOURCE_END(LOG);
 
 /***********************************************************************************************************************************
 Open the file
@@ -86,7 +91,7 @@ storageReadPosixOpen(THIS_VOID)
     // On success set free callback to ensure the file descriptor is freed
     if (this->fd != -1)
     {
-        memContextCallbackSet(this->memContext, storageReadPosixFreeResource, this);
+        memContextCallbackSet(THIS_MEM_CONTEXT(), storageReadPosixFreeResource, this);
         result = true;
     }
 
@@ -155,7 +160,7 @@ storageReadPosixClose(THIS_VOID)
 
     ASSERT(this != NULL);
 
-    memContextCallbackClear(this->memContext);
+    memContextCallbackClear(THIS_MEM_CONTEXT());
     storageReadPosixFreeResource(this);
     this->fd = -1;
 
@@ -210,13 +215,12 @@ storageReadPosixNew(StoragePosix *storage, const String *name, bool ignoreMissin
 
     StorageRead *this = NULL;
 
-    MEM_CONTEXT_NEW_BEGIN("StorageReadPosix")
+    OBJ_NEW_BEGIN(StorageReadPosix)
     {
-        StorageReadPosix *driver = memNew(sizeof(StorageReadPosix));
+        StorageReadPosix *driver = OBJ_NEW_ALLOC();
 
         *driver = (StorageReadPosix)
         {
-            .memContext = MEM_CONTEXT_NEW(),
             .storage = storage,
             .fd = -1,
 
@@ -227,7 +231,7 @@ storageReadPosixNew(StoragePosix *storage, const String *name, bool ignoreMissin
 
             .interface = (StorageReadInterface)
             {
-                .type = STORAGE_POSIX_TYPE_STR,
+                .type = STORAGE_POSIX_TYPE,
                 .name = strDup(name),
                 .ignoreMissing = ignoreMissing,
                 .limit = varDup(limit),
@@ -245,7 +249,7 @@ storageReadPosixNew(StoragePosix *storage, const String *name, bool ignoreMissin
 
         this = storageReadNew(driver, &driver->interface);
     }
-    MEM_CONTEXT_NEW_END();
+    OBJ_NEW_END();
 
     FUNCTION_LOG_RETURN(STORAGE_READ, this);
 }
