@@ -14,18 +14,12 @@ Posix Storage
 
 #include "common/debug.h"
 #include "common/log.h"
-#include "common/memContext.h"
 #include "common/regExp.h"
 #include "common/user.h"
 #include "storage/posix/read.h"
 #include "storage/posix/storage.intern.h"
 #include "storage/posix/write.h"
 
-/***********************************************************************************************************************************
-Storage type
-***********************************************************************************************************************************/
-STRING_EXTERN(STORAGE_POSIX_TYPE_STR,                               STORAGE_POSIX_TYPE);
-
 /***********************************************************************************************************************************
 Define PATH_MAX if it is not defined
 ***********************************************************************************************************************************/
@@ -39,7 +33,6 @@ Object type
 struct StoragePosix
 {
     STORAGE_COMMON_MEMBER;
-    MemContext *memContext;                                         // Object memory context
 };
 
 /**********************************************************************************************************************************/
@@ -111,7 +104,7 @@ storagePosixInfo(THIS_VOID, const String *file, StorageInfoLevel level, StorageI
                     (linkDestinationSize = readlink(strZ(file), linkDestination, sizeof(linkDestination) - 1)) == -1,
                     FileReadError, "unable to get destination for link '%s'", strZ(file));
 
-                result.linkDestination = strNewN(linkDestination, (size_t)linkDestinationSize);
+                result.linkDestination = strNewZN(linkDestination, (size_t)linkDestinationSize);
             }
         }
     }
@@ -567,11 +560,11 @@ static const StorageInterface storageInterfacePosix =
 
 Storage *
 storagePosixNewInternal(
-    const String *type, const String *path, mode_t modeFile, mode_t modePath, bool write,
+    StringId type, const String *path, mode_t modeFile, mode_t modePath, bool write,
     StoragePathExpressionCallback pathExpressionFunction, bool pathSync)
 {
     FUNCTION_LOG_BEGIN(logLevelDebug);
-        FUNCTION_LOG_PARAM(STRING, type);
+        FUNCTION_LOG_PARAM(STRING_ID, type);
         FUNCTION_LOG_PARAM(STRING, path);
         FUNCTION_LOG_PARAM(MODE, modeFile);
         FUNCTION_LOG_PARAM(MODE, modePath);
@@ -580,24 +573,23 @@ storagePosixNewInternal(
         FUNCTION_LOG_PARAM(BOOL, pathSync);
     FUNCTION_LOG_END();
 
-    ASSERT(type != NULL);
+    ASSERT(type != 0);
     ASSERT(path != NULL);
     ASSERT(modeFile != 0);
     ASSERT(modePath != 0);
 
-    // Initialze user module
+    // Initialize user module
     userInit();
 
     // Create the object
     Storage *this = NULL;
 
-    MEM_CONTEXT_NEW_BEGIN("StoragePosix")
+    OBJ_NEW_BEGIN(StoragePosix)
     {
-        StoragePosix *driver = memNew(sizeof(StoragePosix));
+        StoragePosix *driver = OBJ_NEW_ALLOC();
 
         *driver = (StoragePosix)
         {
-            .memContext = MEM_CONTEXT_NEW(),
             .interface = storageInterfacePosix,
         };
 
@@ -606,14 +598,14 @@ storagePosixNewInternal(
             driver->interface.pathSync = NULL;
 
         // If this is a posix driver then add link features
-        if (strEq(type, STORAGE_POSIX_TYPE_STR))
+        if (type == STORAGE_POSIX_TYPE)
             driver->interface.feature |=
                 1 << storageFeatureHardLink | 1 << storageFeatureSymLink | 1 << storageFeaturePathSync |
                 1 << storageFeatureInfoDetail;
 
         this = storageNew(type, path, modeFile, modePath, write, pathExpressionFunction, driver, driver->interface);
     }
-    MEM_CONTEXT_NEW_END();
+    OBJ_NEW_END();
 
     FUNCTION_LOG_RETURN(STORAGE, this);
 }
@@ -632,6 +624,6 @@ storagePosixNew(const String *path, StoragePosixNewParam param)
     FUNCTION_LOG_RETURN(
         STORAGE,
         storagePosixNewInternal(
-            STORAGE_POSIX_TYPE_STR, path, param.modeFile == 0 ? STORAGE_MODE_FILE_DEFAULT : param.modeFile,
+            STORAGE_POSIX_TYPE, path, param.modeFile == 0 ? STORAGE_MODE_FILE_DEFAULT : param.modeFile,
             param.modePath == 0 ? STORAGE_MODE_PATH_DEFAULT : param.modePath, param.write, param.pathExpressionFunction, true));
 }
