@@ -9,13 +9,12 @@ Object type
 ***********************************************************************************************************************************/
 typedef struct StoragePosix StoragePosix;
 
-#include "storage/storage.intern.h"
+#include "storage/storage.h"
 
 /***********************************************************************************************************************************
 Storage type
 ***********************************************************************************************************************************/
-#define STORAGE_POSIX_TYPE                                          "posix"
-    STRING_DECLARE(STORAGE_POSIX_TYPE_STR);
+#define STORAGE_POSIX_TYPE                                          STRID5("posix", 0x184cdf00)
 
 /***********************************************************************************************************************************
 Constructors
