@@ -4,15 +4,14 @@ Storage Read Interface Internal
 #ifndef STORAGE_READ_INTERN_H
 #define STORAGE_READ_INTERN_H
 
-#include "common/io/read.intern.h"
-#include "storage/read.h"
+#include "common/io/read.h"
 
 /***********************************************************************************************************************************
 Constructors
 ***********************************************************************************************************************************/
 typedef struct StorageReadInterface
 {
-    const String *type;
+    StringId type;                                                  // Storage type
     const String *name;
     bool compressible;                                              // Is this file compressible?
     unsigned int compressLevel;                                     // Level to use for compression
