@@ -12,7 +12,6 @@ S3 Storage
 #include "common/io/socket/client.h"
 #include "common/io/tls/client.h"
 #include "common/log.h"
-#include "common/memContext.h"
 #include "common/regExp.h"
 #include "common/type/object.h"
 #include "common/type/json.h"
@@ -21,11 +20,6 @@ S3 Storage
 #include "storage/s3/storage.intern.h"
 #include "storage/s3/write.h"
 
-/***********************************************************************************************************************************
-Storage type
-***********************************************************************************************************************************/
-STRING_EXTERN(STORAGE_S3_TYPE_STR,                                  STORAGE_S3_TYPE);
-
 /***********************************************************************************************************************************
 Defaults
 ***********************************************************************************************************************************/
@@ -66,24 +60,6 @@ STRING_STATIC(S3_XML_TAG_PREFIX_STR,                                "Prefix");
 STRING_STATIC(S3_XML_TAG_QUIET_STR,                                 "Quiet");
 STRING_STATIC(S3_XML_TAG_SIZE_STR,                                  "Size");
 
-/***********************************************************************************************************************************
-Constants for automatically fetching the current role and credentials
-
-Documentation for the response format is found at: https://docs.aws.amazon.com/AWSEC2/latest/UserGuide/iam-roles-for-amazon-ec2.html
-***********************************************************************************************************************************/
-STRING_STATIC(S3_CREDENTIAL_HOST_STR,                               "169.254.169.254");
-#define S3_CREDENTIAL_PORT                                          80
-#define S3_CREDENTIAL_PATH                                          "/latest/meta-data/iam/security-credentials"
-#define S3_CREDENTIAL_RENEW_SEC                                     (5 * 60)
-
-VARIANT_STRDEF_STATIC(S3_JSON_TAG_ACCESS_KEY_ID_VAR,                "AccessKeyId");
-VARIANT_STRDEF_STATIC(S3_JSON_TAG_CODE_VAR,                         "Code");
-VARIANT_STRDEF_STATIC(S3_JSON_TAG_EXPIRATION_VAR,                   "Expiration");
-VARIANT_STRDEF_STATIC(S3_JSON_TAG_SECRET_ACCESS_KEY_VAR,            "SecretAccessKey");
-VARIANT_STRDEF_STATIC(S3_JSON_TAG_TOKEN_VAR,                        "Token");
-
-VARIANT_STRDEF_STATIC(S3_JSON_VALUE_SUCCESS_VAR,                    "Success");
-
 /***********************************************************************************************************************************
 AWS authentication v4 constants
 ***********************************************************************************************************************************/
@@ -105,13 +81,12 @@ Object type
 struct StorageS3
 {
     STORAGE_COMMON_MEMBER;
-    MemContext *memContext;
     HttpClient *httpClient;                                         // HTTP client to service requests
     StringList *headerRedactList;                                   // List of headers to redact from logging
 
     const String *bucket;                                           // Bucket to store data in
     const String *region;                                           // e.g. us-east-1
-    StorageS3KeyType keyType;                                       // Key type (shared or temp)
+    StorageS3KeyType keyType;                                       // Key type (e.g. storageS3KeyTypeShared)
     String *accessKey;                                              // Access key
     String *secretAccessKey;                                        // Secret access key
     String *securityToken;                                          // Security token, if any
@@ -124,6 +99,7 @@ struct StorageS3
     HttpClient *credHttpClient;                                     // HTTP client to service credential requests
     const String *credHost;                                         // Credentials host
     const String *credRole;                                         // Role to use for credential requests
+    const String *webIdToken;                                       // Token to use for credential requests
     time_t credExpirationTime;                                      // Time the temporary credentials expire
 
     // Current signing key and date it is valid for
@@ -146,13 +122,14 @@ storageS3DateTime(time_t authTime)
         FUNCTION_TEST_PARAM(TIME, authTime);
     FUNCTION_TEST_END();
 
+    struct tm timePart;
     char buffer[ISO_8601_DATE_TIME_SIZE + 1];
 
     THROW_ON_SYS_ERROR(
-        strftime(buffer, sizeof(buffer), "%Y%m%dT%H%M%SZ", gmtime(&authTime)) != ISO_8601_DATE_TIME_SIZE, AssertError,
+        strftime(buffer, sizeof(buffer), "%Y%m%dT%H%M%SZ", gmtime_r(&authTime, &timePart)) != ISO_8601_DATE_TIME_SIZE, AssertError,
         "unable to format date");
 
-    FUNCTION_TEST_RETURN(strNew(buffer));
+    FUNCTION_TEST_RETURN(strNewZ(buffer));
 }
 
 /***********************************************************************************************************************************
@@ -198,8 +175,8 @@ storageS3Auth(
         const StringList *headerList = strLstSort(strLstDup(httpHeaderList(httpHeader)), sortOrderAsc);
         String *signedHeaders = NULL;
 
-        String *canonicalRequest = strNewFmt(
-            "%s\n%s\n%s\n", strZ(verb), strZ(path), query == NULL ? "" : strZ(httpQueryRenderP(query)));
+        String *canonicalRequest = strCatFmt(
+            strNew(), "%s\n%s\n%s\n", strZ(verb), strZ(path), query == NULL ? "" : strZ(httpQueryRenderP(query)));
 
         for (unsigned int headerIdx = 0; headerIdx < strLstSize(headerList); headerIdx++)
         {
@@ -213,7 +190,7 @@ storageS3Auth(
             strCatFmt(canonicalRequest, "%s:%s\n", strZ(headerKeyLower), strZ(httpHeaderGet(httpHeader, headerKey)));
 
             if (signedHeaders == NULL)
-                signedHeaders = strDup(headerKeyLower);
+                signedHeaders = strCat(strNew(), headerKeyLower);
             else
                 strCatFmt(signedHeaders, ";%s", strZ(headerKeyLower));
         }
@@ -236,7 +213,7 @@ storageS3Auth(
             const Buffer *serviceKey = cryptoHmacOne(HASH_TYPE_SHA256_STR, regionKey, S3_BUF);
 
             // Switch to the object context so signing key and date are not lost
-            MEM_CONTEXT_BEGIN(this->memContext)
+            MEM_CONTEXT_BEGIN(THIS_MEM_CONTEXT())
             {
                 this->signingKey = cryptoHmacOne(HASH_TYPE_SHA256_STR, serviceKey, AWS4_REQUEST_BUF);
                 this->signingKeyDate = strDup(date);
@@ -258,10 +235,9 @@ storageS3Auth(
 }
 
 /***********************************************************************************************************************************
-Process S3 request
+Convert YYYY-MM-DDTHH:MM:SS.MSECZ format to time_t. This format is very nearly ISO-8601 except for the inclusion of milliseconds,
+which are discarded here.
 ***********************************************************************************************************************************/
-// Helper to convert YYYY-MM-DDTHH:MM:SS.MSECZ format to time_t.  This format is very nearly ISO-8601 except for the inclusion of
-// milliseconds, which are discarded here.
 static time_t
 storageS3CvtTime(const String *time)
 {
@@ -276,6 +252,167 @@ storageS3CvtTime(const String *time)
             cvtZToInt(strZ(strSubN(time, 14, 2))), cvtZToInt(strZ(strSubN(time, 17, 2))), 0));
 }
 
+/***********************************************************************************************************************************
+Automatically get credentials for an associated IAM role
+
+Documentation for the response format is found at: https://docs.aws.amazon.com/AWSEC2/latest/UserGuide/iam-roles-for-amazon-ec2.html
+***********************************************************************************************************************************/
+STRING_STATIC(S3_CREDENTIAL_HOST_STR,                               "169.254.169.254");
+#define S3_CREDENTIAL_PORT                                          80
+#define S3_CREDENTIAL_PATH                                          "/latest/meta-data/iam/security-credentials"
+#define S3_CREDENTIAL_RENEW_SEC                                     (5 * 60)
+
+VARIANT_STRDEF_STATIC(S3_JSON_TAG_ACCESS_KEY_ID_VAR,                "AccessKeyId");
+VARIANT_STRDEF_STATIC(S3_JSON_TAG_CODE_VAR,                         "Code");
+VARIANT_STRDEF_STATIC(S3_JSON_TAG_EXPIRATION_VAR,                   "Expiration");
+VARIANT_STRDEF_STATIC(S3_JSON_TAG_SECRET_ACCESS_KEY_VAR,            "SecretAccessKey");
+VARIANT_STRDEF_STATIC(S3_JSON_TAG_TOKEN_VAR,                        "Token");
+
+VARIANT_STRDEF_STATIC(S3_JSON_VALUE_SUCCESS_VAR,                    "Success");
+
+static void
+storageS3AuthAuto(StorageS3 *const this, const HttpHeader *const header)
+{
+    FUNCTION_LOG_BEGIN(logLevelDebug);
+        FUNCTION_LOG_PARAM(STORAGE_S3, this);
+        FUNCTION_LOG_PARAM(HTTP_HEADER, header);
+    FUNCTION_LOG_END();
+
+    // If the role was not set explicitly or retrieved previously then retrieve it
+    if (this->credRole == NULL)
+    {
+        // Request the role
+        HttpRequest *request = httpRequestNewP(
+            this->credHttpClient, HTTP_VERB_GET_STR, STRDEF(S3_CREDENTIAL_PATH), .header = header);
+        HttpResponse *response = httpRequestResponse(request, true);
+
+        // Not found likely means no role is associated with this instance
+        if (httpResponseCode(response) == HTTP_RESPONSE_CODE_NOT_FOUND)
+        {
+            THROW(
+                ProtocolError,
+                "role to retrieve temporary credentials not found\n"
+                    "HINT: is a valid IAM role associated with this instance?");
+        }
+        // Else an error that we can't handle
+        else if (!httpResponseCodeOk(response))
+            httpRequestError(request, response);
+
+        // Get role from the text response
+        MEM_CONTEXT_BEGIN(THIS_MEM_CONTEXT())
+        {
+            this->credRole = strNewBuf(httpResponseContent(response));
+        }
+        MEM_CONTEXT_END();
+    }
+
+    // Retrieve the temp credentials
+    HttpRequest *request = httpRequestNewP(
+        this->credHttpClient, HTTP_VERB_GET_STR, strNewFmt(S3_CREDENTIAL_PATH "/%s", strZ(this->credRole)), .header = header);
+    HttpResponse *response = httpRequestResponse(request, true);
+
+    // Not found likely means the role is not valid
+    if (httpResponseCode(response) == HTTP_RESPONSE_CODE_NOT_FOUND)
+    {
+        THROW_FMT(
+            ProtocolError,
+            "role '%s' not found\n"
+                "HINT: is '%s' a valid IAM role associated with this instance?",
+            strZ(this->credRole), strZ(this->credRole));
+    }
+    // Else an error that we can't handle
+    else if (!httpResponseCodeOk(response))
+        httpRequestError(request, response);
+
+    // Get credentials from the JSON response
+    KeyValue *credential = jsonToKv(strNewBuf(httpResponseContent(response)));
+
+    MEM_CONTEXT_BEGIN(THIS_MEM_CONTEXT())
+    {
+        // Check the code field for errors
+        const Variant *code = kvGetDefault(credential, S3_JSON_TAG_CODE_VAR, VARSTRDEF("code field is missing"));
+        CHECK(FormatError, code != NULL, "error code missing");
+
+        if (!varEq(code, S3_JSON_VALUE_SUCCESS_VAR))
+            THROW_FMT(FormatError, "unable to retrieve temporary credentials: %s", strZ(varStr(code)));
+
+        // Make sure the required values are present
+        CHECK(FormatError, kvGet(credential, S3_JSON_TAG_ACCESS_KEY_ID_VAR) != NULL, "access key missing");
+        CHECK(FormatError, kvGet(credential, S3_JSON_TAG_SECRET_ACCESS_KEY_VAR) != NULL, "secret access key missing");
+        CHECK(FormatError, kvGet(credential, S3_JSON_TAG_TOKEN_VAR) != NULL, "token missing");
+
+        // Copy credentials
+        this->accessKey = strDup(varStr(kvGet(credential, S3_JSON_TAG_ACCESS_KEY_ID_VAR)));
+        this->secretAccessKey = strDup(varStr(kvGet(credential, S3_JSON_TAG_SECRET_ACCESS_KEY_VAR)));
+        this->securityToken = strDup(varStr(kvGet(credential, S3_JSON_TAG_TOKEN_VAR)));
+    }
+    MEM_CONTEXT_END();
+
+    // Update expiration time
+    CHECK(FormatError, kvGet(credential, S3_JSON_TAG_EXPIRATION_VAR) != NULL, "expiration missing");
+    this->credExpirationTime = storageS3CvtTime(varStr(kvGet(credential, S3_JSON_TAG_EXPIRATION_VAR)));
+
+    FUNCTION_LOG_RETURN_VOID();
+}
+
+/***********************************************************************************************************************************
+Automatically get credentials for an associated web identity service account
+
+Documentation is found at: https://docs.aws.amazon.com/STS/latest/APIReference/API_AssumeRoleWithWebIdentity.html
+***********************************************************************************************************************************/
+STRING_STATIC(S3_STS_HOST_STR,                                      "sts.amazonaws.com");
+#define S3_STS_PORT                                                 443
+
+static void
+storageS3AuthWebId(StorageS3 *const this, const HttpHeader *const header)
+{
+    FUNCTION_LOG_BEGIN(logLevelDebug);
+        FUNCTION_LOG_PARAM(STORAGE_S3, this);
+        FUNCTION_LOG_PARAM(HTTP_HEADER, header);
+    FUNCTION_LOG_END();
+
+    // Get credentials
+    HttpQuery *const query = httpQueryNewP();
+    httpQueryAdd(query, STRDEF("Action"), STRDEF("AssumeRoleWithWebIdentity"));
+    httpQueryAdd(query, STRDEF("RoleArn"), this->credRole);
+    httpQueryAdd(query, STRDEF("RoleSessionName"), STRDEF(PROJECT_NAME));
+    httpQueryAdd(query, STRDEF("Version"), STRDEF("2011-06-15"));
+    httpQueryAdd(query, STRDEF("WebIdentityToken"), this->webIdToken);
+
+    HttpRequest *const request = httpRequestNewP(
+        this->credHttpClient, HTTP_VERB_GET_STR, FSLASH_STR, .header = header, .query = query);
+    HttpResponse *const response = httpRequestResponse(request, true);
+
+    CHECK(FormatError, httpResponseCode(response) != HTTP_RESPONSE_CODE_NOT_FOUND, "invalid response code");
+
+    // Copy credentials
+    const XmlNode *const xmlCred =
+        xmlNodeChild(
+            xmlNodeChild(
+                xmlDocumentRoot(xmlDocumentNewBuf(httpResponseContent(response))), STRDEF("AssumeRoleWithWebIdentityResult"), true),
+            STRDEF("Credentials"), true);
+
+    const XmlNode *const accessKeyNode = xmlNodeChild(xmlCred, STRDEF("AccessKeyId"), true);
+    const XmlNode *const secretAccessKeyNode = xmlNodeChild(xmlCred, STRDEF("SecretAccessKey"), true);
+    const XmlNode *const securityTokenNode = xmlNodeChild(xmlCred, STRDEF("SessionToken"), true);
+
+    MEM_CONTEXT_BEGIN(THIS_MEM_CONTEXT())
+    {
+        this->accessKey = xmlNodeContent(accessKeyNode);
+        this->secretAccessKey = xmlNodeContent(secretAccessKeyNode);
+        this->securityToken = xmlNodeContent(securityTokenNode);
+    }
+    MEM_CONTEXT_END();
+
+    // Update expiration time
+    this->credExpirationTime = storageS3CvtTime(xmlNodeContent(xmlNodeChild(xmlCred, STRDEF("Expiration"), true)));
+
+    FUNCTION_LOG_RETURN_VOID();
+}
+
+/***********************************************************************************************************************************
+Process S3 request
+***********************************************************************************************************************************/
 HttpRequest *
 storageS3RequestAsync(StorageS3 *this, const String *verb, const String *path, StorageS3RequestAsyncParam param)
 {
@@ -314,93 +451,36 @@ storageS3RequestAsync(StorageS3 *this, const String *verb, const String *path, S
         if (this->uriStyle == storageS3UriStylePath)
             path = strNewFmt("/%s%s", strZ(this->bucket), strZ(path));
 
-        // If temp crendentials will be expiring soon then renew them
-        if (this->keyType == storageS3KeyTypeAuto && (this->credExpirationTime - time(NULL)) < S3_CREDENTIAL_RENEW_SEC)
+        // If temp credentials will be expiring soon then renew them
+        if (this->credExpirationTime != 0 && (this->credExpirationTime - time(NULL)) < S3_CREDENTIAL_RENEW_SEC)
         {
-            // Set content-length and host headers
-            HttpHeader *credHeader = httpHeaderNew(NULL);
-            httpHeaderAdd(credHeader, HTTP_HEADER_CONTENT_LENGTH_STR, ZERO_STR);
-            httpHeaderAdd(credHeader, HTTP_HEADER_HOST_STR, this->credHost);
-
-            // If the role was not set explicitly or retrieved previously then retrieve it
-            if (this->credRole == NULL)
-            {
-                // Request the role
-                HttpRequest *request = httpRequestNewP(
-                    this->credHttpClient, HTTP_VERB_GET_STR, STRDEF(S3_CREDENTIAL_PATH), .header = credHeader);
-                HttpResponse *response = httpRequestResponse(request, true);
-
-                // Not found likely means no role is associated with this instance
-                if (httpResponseCode(response) == HTTP_RESPONSE_CODE_NOT_FOUND)
-                {
-                    THROW(
-                        ProtocolError,
-                        "role to retrieve temporary credentials not found\n"
-                            "HINT: is a valid IAM role associated with this instance?");
-                }
-                // Else an error that we can't handle
-                else if (!httpResponseCodeOk(response))
-                    httpRequestError(request, response);
-
-                // Get role from the text response
-                MEM_CONTEXT_BEGIN(this->memContext)
-                {
-                    this->credRole = strNewBuf(httpResponseContent(response));
-                }
-                MEM_CONTEXT_END();
-            }
-
-            // Retrieve the temp credentials
-            HttpRequest *request = httpRequestNewP(
-                this->credHttpClient, HTTP_VERB_GET_STR, strNewFmt(S3_CREDENTIAL_PATH "/%s", strZ(this->credRole)),
-                .header = credHeader);
-            HttpResponse *response = httpRequestResponse(request, true);
-
-            // Not found likely means the role is not valid
-            if (httpResponseCode(response) == HTTP_RESPONSE_CODE_NOT_FOUND)
-            {
-                THROW_FMT(
-                    ProtocolError,
-                    "role '%s' not found\n"
-                        "HINT: is '%s' a valid IAM role associated with this instance?",
-                    strZ(this->credRole), strZ(this->credRole));
-            }
-            // Else an error that we can't handle
-            else if (!httpResponseCodeOk(response))
-                httpRequestError(request, response);
-
             // Free old credentials
             strFree(this->accessKey);
             strFree(this->secretAccessKey);
             strFree(this->securityToken);
 
-            // Get credentials from the JSON response
-            KeyValue *credential = jsonToKv(strNewBuf(httpResponseContent(response)));
+            // Set content-length and host headers
+            HttpHeader *credHeader = httpHeaderNew(NULL);
+            httpHeaderAdd(credHeader, HTTP_HEADER_CONTENT_LENGTH_STR, ZERO_STR);
+            httpHeaderAdd(credHeader, HTTP_HEADER_HOST_STR, this->credHost);
 
-            MEM_CONTEXT_BEGIN(this->memContext)
+            // Get credentials
+            switch (this->keyType)
             {
-                // Check the code field for errors
-                const Variant *code = kvGetDefault(credential, S3_JSON_TAG_CODE_VAR, VARSTRDEF("code field is missing"));
-                CHECK(code != NULL);
+                // Auto authentication
+                case storageS3KeyTypeAuto:
+                    storageS3AuthAuto(this, credHeader);
+                    break;
 
-                if (!varEq(code, S3_JSON_VALUE_SUCCESS_VAR))
-                    THROW_FMT(FormatError, "unable to retrieve temporary credentials: %s", strZ(varStr(code)));
+                // Web identity authentication
+                default:
+                {
+                    ASSERT(this->keyType == storageS3KeyTypeWebId);
 
-                // Make sure the required values are present
-                CHECK(kvGet(credential, S3_JSON_TAG_ACCESS_KEY_ID_VAR) != NULL);
-                CHECK(kvGet(credential, S3_JSON_TAG_SECRET_ACCESS_KEY_VAR) != NULL);
-                CHECK(kvGet(credential, S3_JSON_TAG_TOKEN_VAR) != NULL);
-
-                // Copy credentials
-                this->accessKey = strDup(varStr(kvGet(credential, S3_JSON_TAG_ACCESS_KEY_ID_VAR)));
-                this->secretAccessKey = strDup(varStr(kvGet(credential, S3_JSON_TAG_SECRET_ACCESS_KEY_VAR)));
-                this->securityToken = strDup(varStr(kvGet(credential, S3_JSON_TAG_TOKEN_VAR)));
+                    storageS3AuthWebId(this, credHeader);
+                    break;
+                }
             }
-            MEM_CONTEXT_END();
-
-            // Update expiration time
-            CHECK(kvGet(credential, S3_JSON_TAG_EXPIRATION_VAR) != NULL);
-            this->credExpirationTime = storageS3CvtTime(varStr(kvGet(credential, S3_JSON_TAG_EXPIRATION_VAR)));
 
             // Reset the signing key date so the signing key gets regenerated
             this->signingKeyDate = YYYYMMDD_STR;
@@ -674,11 +754,11 @@ storageS3Info(THIS_VOID, const String *file, StorageInfoLevel level, StorageInte
         const HttpHeader *httpHeader = httpResponseHeader(httpResponse);
 
         const String *const contentLength = httpHeaderGet(httpHeader, HTTP_HEADER_CONTENT_LENGTH_STR);
-        CHECK(contentLength != NULL);
+        CHECK(FormatError, contentLength != NULL, "content length missing");
         result.size = cvtZToUInt64(strZ(contentLength));
 
         const String *const lastModified = httpHeaderGet(httpHeader, HTTP_HEADER_LAST_MODIFIED_STR);
-        CHECK(lastModified != NULL);
+        CHECK(FormatError, lastModified != NULL, "last modified missing");
         result.timeModified = httpDateToTime(lastModified);
     }
 
@@ -937,8 +1017,9 @@ Storage *
 storageS3New(
     const String *path, bool write, StoragePathExpressionCallback pathExpressionFunction, const String *bucket,
     const String *endPoint, StorageS3UriStyle uriStyle, const String *region, StorageS3KeyType keyType, const String *accessKey,
-    const String *secretAccessKey, const String *securityToken, const String *credRole, size_t partSize, const String *host,
-    unsigned int port, TimeMSec timeout, bool verifyPeer, const String *caFile, const String *caPath)
+    const String *secretAccessKey, const String *securityToken, const String *credRole, const String *const webIdToken,
+    size_t partSize, const String *host, unsigned int port, TimeMSec timeout, bool verifyPeer, const String *caFile,
+    const String *caPath)
 {
     FUNCTION_LOG_BEGIN(logLevelDebug);
         FUNCTION_LOG_PARAM(STRING, path);
@@ -946,13 +1027,14 @@ storageS3New(
         FUNCTION_LOG_PARAM(FUNCTIONP, pathExpressionFunction);
         FUNCTION_LOG_PARAM(STRING, bucket);
         FUNCTION_LOG_PARAM(STRING, endPoint);
-        FUNCTION_LOG_PARAM(ENUM, uriStyle);
+        FUNCTION_LOG_PARAM(STRING_ID, uriStyle);
         FUNCTION_LOG_PARAM(STRING, region);
-        FUNCTION_LOG_PARAM(ENUM, keyType);
+        FUNCTION_LOG_PARAM(STRING_ID, keyType);
         FUNCTION_TEST_PARAM(STRING, accessKey);
         FUNCTION_TEST_PARAM(STRING, secretAccessKey);
         FUNCTION_TEST_PARAM(STRING, securityToken);
         FUNCTION_TEST_PARAM(STRING, credRole);
+        FUNCTION_TEST_PARAM(STRING, webIdToken);
         FUNCTION_LOG_PARAM(SIZE, partSize);
         FUNCTION_LOG_PARAM(STRING, host);
         FUNCTION_LOG_PARAM(UINT, port);
@@ -966,34 +1048,25 @@ storageS3New(
     ASSERT(bucket != NULL);
     ASSERT(endPoint != NULL);
     ASSERT(region != NULL);
-    ASSERT(
-        (keyType == storageS3KeyTypeShared && accessKey != NULL && secretAccessKey != NULL) ||
-        (keyType == storageS3KeyTypeAuto && accessKey == NULL && secretAccessKey == NULL && securityToken == NULL));
     ASSERT(partSize != 0);
 
     Storage *this = NULL;
 
-    MEM_CONTEXT_NEW_BEGIN("StorageS3")
+    OBJ_NEW_BEGIN(StorageS3)
     {
-        StorageS3 *driver = memNew(sizeof(StorageS3));
+        StorageS3 *driver = OBJ_NEW_ALLOC();
 
         *driver = (StorageS3)
         {
-            .memContext = MEM_CONTEXT_NEW(),
             .interface = storageInterfaceS3,
             .bucket = strDup(bucket),
             .region = strDup(region),
             .keyType = keyType,
-            .accessKey = strDup(accessKey),
-            .secretAccessKey = strDup(secretAccessKey),
-            .securityToken = strDup(securityToken),
             .partSize = partSize,
             .deleteMax = STORAGE_S3_DELETE_MAX,
             .uriStyle = uriStyle,
             .bucketEndpoint = uriStyle == storageS3UriStyleHost ?
                 strNewFmt("%s.%s", strZ(bucket), strZ(endPoint)) : strDup(endPoint),
-            .credHost = S3_CREDENTIAL_HOST_STR,
-            .credRole = strDup(credRole),
 
             // Force the signing key to be generated on the first run
             .signingKeyDate = YYYYMMDD_STR,
@@ -1004,11 +1077,60 @@ storageS3New(
             host = driver->bucketEndpoint;
 
         driver->httpClient = httpClientNew(
-            tlsClientNew(sckClientNew(host, port, timeout), host, timeout, verifyPeer, caFile, caPath), timeout);
+            tlsClientNewP(
+                sckClientNew(host, port, timeout, timeout), host, timeout, timeout, verifyPeer, .caFile = caFile, .caPath = caPath),
+            timeout);
 
-        // Create the HTTP client used to retreive temporary security credentials
-        if (driver->keyType == storageS3KeyTypeAuto)
-            driver->credHttpClient = httpClientNew(sckClientNew(driver->credHost, S3_CREDENTIAL_PORT, timeout), timeout);
+        // Initialize authentication
+        switch (driver->keyType)
+        {
+            // Create the HTTP client used to retrieve temporary security credentials
+            case storageS3KeyTypeAuto:
+            {
+                ASSERT(accessKey == NULL && secretAccessKey == NULL && securityToken == NULL);
+
+                driver->credRole = strDup(credRole);
+                driver->credHost = S3_CREDENTIAL_HOST_STR;
+                driver->credExpirationTime = time(NULL);
+                driver->credHttpClient = httpClientNew(
+                    sckClientNew(driver->credHost, S3_CREDENTIAL_PORT, timeout, timeout), timeout);
+
+                break;
+            }
+
+            // Create the HTTP client used to retrieve web identity security credentials
+            case storageS3KeyTypeWebId:
+            {
+                ASSERT(accessKey == NULL && secretAccessKey == NULL && securityToken == NULL);
+                ASSERT(credRole != NULL);
+                ASSERT(webIdToken != NULL);
+
+                driver->credRole = strDup(credRole);
+                driver->webIdToken = strDup(webIdToken);
+                driver->credHost = S3_STS_HOST_STR;
+                driver->credExpirationTime = time(NULL);
+                driver->credHttpClient = httpClientNew(
+                    tlsClientNewP(
+                        sckClientNew(driver->credHost, S3_STS_PORT, timeout, timeout), driver->credHost, timeout, timeout, true,
+                        .caFile = caFile, .caPath = caPath),
+                    timeout);
+
+                break;
+            }
+
+            // Set shared key credentials
+            default:
+            {
+                ASSERT(driver->keyType == storageS3KeyTypeShared);
+                ASSERT(accessKey != NULL && secretAccessKey != NULL);
+
+                driver->accessKey = strDup(accessKey);
+                driver->secretAccessKey = strDup(secretAccessKey);
+                driver->securityToken = strDup(securityToken);
+
+                break;
+            }
+        }
 
         // Create list of redacted headers
         driver->headerRedactList = strLstNew();
@@ -1016,10 +1138,9 @@ storageS3New(
         strLstAdd(driver->headerRedactList, S3_HEADER_DATE_STR);
         strLstAdd(driver->headerRedactList, S3_HEADER_TOKEN_STR);
 
-        this = storageNew(
-            STORAGE_S3_TYPE_STR, path, 0, 0, write, pathExpressionFunction, driver, driver->interface);
+        this = storageNew(STORAGE_S3_TYPE, path, 0, 0, write, pathExpressionFunction, driver, driver->interface);
     }
-    MEM_CONTEXT_NEW_END();
+    OBJ_NEW_END();
 
     FUNCTION_LOG_RETURN(STORAGE, this);
 }
