@@ -14,9 +14,9 @@ in the description of each function.
 #define STORAGE_STORAGE_INTERN_H
 
 #include "common/type/param.h"
-#include "storage/read.intern.h"
-#include "storage/storage.h"
-#include "storage/write.intern.h"
+#include "storage/info.h"
+#include "storage/read.h"
+#include "storage/write.h"
 
 /***********************************************************************************************************************************
 Default file and path modes
@@ -157,8 +157,8 @@ typedef struct StorageInterfaceInfoListParam
 } StorageInterfaceInfoListParam;
 
 typedef bool StorageInterfaceInfoList(
-    void *thisVoid, const String *path, StorageInfoLevel level, StorageInfoListCallback callback, void *callbackData,
-    StorageInterfaceInfoListParam param);
+    void *thisVoid, const String *path, StorageInfoLevel level, void (*callback)(void *callbackData, const StorageInfo *info),
+    void *callbackData, StorageInterfaceInfoListParam param);
 
 #define storageInterfaceInfoListP(thisVoid, path, level, callback, callbackData, ...)                                              \
     STORAGE_COMMON_INTERFACE(thisVoid).infoList(                                                                                   \
@@ -234,6 +234,21 @@ typedef void StorageInterfacePathSync(void *thisVoid, const String *path, Storag
 #define storageInterfacePathSyncP(thisVoid, path, ...)                                                                             \
     STORAGE_COMMON_INTERFACE(thisVoid).pathSync(thisVoid, path, (StorageInterfacePathSyncParam){VAR_PARAM_INIT, __VA_ARGS__})
 
+/***********************************************************************************************************************************
+Storage type and helper function struct
+
+An array of this struct must be passed to storageHelperInit() to enable storage drivers other than built-in Posix.
+***********************************************************************************************************************************/
+typedef Storage *(*StorageHelperFunction)(unsigned int repoIdx, bool write, StoragePathExpressionCallback pathExpressionCallback);
+
+typedef struct StorageHelper
+{
+    StringId type;                                                  // StringId that identifies the storage driver
+    StorageHelperFunction helper;                                   // Function that creates the storage
+} StorageHelper;
+
+#define STORAGE_END_HELPER                                          {.type = 0}
+
 /***********************************************************************************************************************************
 Constructors
 ***********************************************************************************************************************************/
@@ -260,7 +275,7 @@ typedef struct StorageInterface
     storageNew(type, path, modeFile, modePath, write, pathExpressionFunction, driver, (StorageInterface){__VA_ARGS__})
 
 Storage *storageNew(
-    const String *type, const String *path, mode_t modeFile, mode_t modePath, bool write,
+    StringId type, const String *path, mode_t modeFile, mode_t modePath, bool write,
     StoragePathExpressionCallback pathExpressionFunction, void *driver, StorageInterface interface);
 
 /***********************************************************************************************************************************
@@ -282,11 +297,26 @@ typedef struct StorageCommon
 /***********************************************************************************************************************************
 Getters/Setters
 ***********************************************************************************************************************************/
+typedef struct StoragePub
+{
+    StringId type;                                                  // Storage type
+    void *driver;                                                   // Storage driver
+    StorageInterface interface;                                     // Storage interface
+} StoragePub;
+
 // Storage driver
-void *storageDriver(const Storage *this);
+__attribute__((always_inline)) static inline void *
+storageDriver(const Storage *const this)
+{
+    return THIS_PUB(Storage)->driver;
+}
 
 // Storage interface
-StorageInterface storageInterface(const Storage *this);
+__attribute__((always_inline)) static inline StorageInterface
+storageInterface(const Storage *const this)
+{
+    return THIS_PUB(Storage)->interface;
+}
 
 /***********************************************************************************************************************************
 Macros for function logging
