@@ -56,10 +56,20 @@ use constant TESTDEF_DEFINE                                         => 'define';
     push @EXPORT, qw(TESTDEF_DEFINE);
 use constant TESTDEF_FEATURE                                        => 'feature';
     push @EXPORT, qw(TESTDEF_FEATURE);
-use constant TESTDEF_DEBUG_UNIT_SUPPRESS                            => 'debugUnitSuppress';
-    push @EXPORT, qw(TESTDEF_DEBUG_UNIT_SUPPRESS);
 use constant TESTDEF_HARNESS                                        => 'harness';
     push @EXPORT, qw(TESTDEF_HARNESS);
+# Harness name which must match the harness implementation file name
+use constant TESTDEF_HARNESS_NAME                                   => 'name';
+    push @EXPORT, qw(TESTDEF_HARNESS_NAME);
+# The harness contains shimmed elements
+use constant TESTDEF_HARNESS_SHIM                                   => 'shim';
+    push @EXPORT, qw(TESTDEF_HARNESS_SHIM);
+# The harness shim was first defined in the module/test
+use constant TESTDEF_HARNESS_SHIM_DEF                               => 'harnessShimDef';
+    push @EXPORT, qw(TESTDEF_HARNESS_SHIM_DEF);
+# List of shimmed functions for a C module
+use constant TESTDEF_HARNESS_SHIM_FUNCTION                          => 'function';
+    push @EXPORT, qw(TESTDEF_HARNESS_SHIM_FUNCTION);
 use constant TESTDEF_INCLUDE                                        => 'include';
     push @EXPORT, qw(TESTDEF_INCLUDE);
 use constant TESTDEF_INDIVIDUAL                                     => 'individual';
@@ -98,7 +108,7 @@ sub testDefLoad
     my $hTestDef = Load($strDefineYaml);
 
     # Keep a list of all harnesses added so far. These will make up the harness list for subsequent tests.
-    my @stryHarnessFile = ();
+    my @rhyHarnessFile = ();
 
     # Keep a list of all modules added for coverage so far. These will make up the core list for subsequent tests.
     my @stryCoreFile = ();
@@ -140,8 +150,7 @@ sub testDefLoad
 
                 # Resolve variables that can be set in the module or the test
                 foreach my $strVar (
-                    TESTDEF_DEFINE, TESTDEF_DEBUG_UNIT_SUPPRESS, TESTDEF_DB, TESTDEF_BIN_REQ, TESTDEF_VM,
-                    TESTDEF_CONTAINER_REQUIRED)
+                    TESTDEF_DEFINE, TESTDEF_DB, TESTDEF_BIN_REQ, TESTDEF_VM, TESTDEF_CONTAINER_REQUIRED)
                 {
                     $hTestDefHash->{$strModule}{$strTest}{$strVar} = coalesce(
                         $hModuleTest->{$strVar}, $hModule->{$strVar}, $strVar eq TESTDEF_VM ? undef : false);
@@ -180,12 +189,46 @@ sub testDefLoad
                     push(@{$hTestDefHash->{$strModule}{$strTest}{&TESTDEF_CORE}}, @stryCoreFile);
 
                     # Add harness files
+                    my $rhHarnessShimDef = {};
+
                     if (defined($hModuleTest->{&TESTDEF_HARNESS}))
                     {
-                        push(@stryHarnessFile, $hModuleTest->{&TESTDEF_HARNESS});
+                        my $rhHarness = {};
+
+                        # If the harness is a hash then it contains shims
+                        if (ref($hModuleTest->{&TESTDEF_HARNESS}))
+                        {
+                            # Harness name must be set
+                            if (!defined($hModuleTest->{&TESTDEF_HARNESS}{&TESTDEF_HARNESS_NAME}))
+                            {
+                                confess &log(ERROR, "must define 'name' for harness in test '$strTest'");
+                            }
+
+                            # Don't use hash syntax when there are no shims
+                            if (!defined($hModuleTest->{&TESTDEF_HARNESS}{&TESTDEF_HARNESS_SHIM}))
+                            {
+                                confess &log(
+                                    ERROR,
+                                    "use 'harness: $hModuleTest->{&TESTDEF_HARNESS}{&TESTDEF_HARNESS_NAME}' if there are no shims");
+                            }
+
+                            # Note that this shim is defined in the module
+                            $rhHarnessShimDef->{$hModuleTest->{&TESTDEF_HARNESS}{&TESTDEF_HARNESS_NAME}} = true;
+
+                            # Set the harness
+                            $rhHarness = $hModuleTest->{&TESTDEF_HARNESS};
+                        }
+                        # Else set the harness with just a name
+                        else
+                        {
+                            $rhHarness->{&TESTDEF_HARNESS_NAME} = $hModuleTest->{&TESTDEF_HARNESS};
+                        }
+
+                        push(@rhyHarnessFile, $rhHarness);
                     }
 
-                    push(@{$hTestDefHash->{$strModule}{$strTest}{&TESTDEF_HARNESS}}, @stryHarnessFile);
+                    push(@{$hTestDefHash->{$strModule}{$strTest}{&TESTDEF_HARNESS}}, @rhyHarnessFile);
+                    $hTestDefHash->{$strModule}{$strTest}{&TESTDEF_HARNESS_SHIM_DEF} = $rhHarnessShimDef;
 
                     # Add test defines
                     $hTestDefHash->{$strModule}{$strTest}{&TESTDEF_FEATURE} =
