@@ -52,7 +52,6 @@ sub new
         $self->{strTestPath},
         $self->{oTest},
         $self->{bDryRun},
-        $self->{strVmHost},
         $self->{bVmOut},
         $self->{iVmIdx},
         $self->{iVmMax},
@@ -87,7 +86,6 @@ sub new
             {name => 'strTestPath'},
             {name => 'oTest'},
             {name => 'bDryRun'},
-            {name => 'strVmHost'},
             {name => 'bVmOut'},
             {name => 'iVmIdx'},
             {name => 'iVmMax'},
@@ -177,7 +175,7 @@ sub run
         my $strVmTestPath = '/home/' . TEST_USER . "/test/${strImage}";
         my $strHostTestPath = "$self->{strTestPath}/${strImage}";
 
-        # Don't create the container if this is a dry run unless output from the VM is required.  Ouput can be requested
+        # Don't create the container if this is a dry run unless output from the VM is required. Output can be requested
         # to get more information about the specific tests that will be run.
         if (!$self->{bDryRun} || $self->{bVmOut})
         {
@@ -237,6 +235,8 @@ sub run
                 my $strRepoCopyPath = $self->{strTestPath} . '/repo';           # Path to repo copy
                 my $strRepoCopySrcPath = $strRepoCopyPath . '/src';             # Path to repo copy src
                 my $strRepoCopyTestSrcPath = $strRepoCopyPath . '/test/src';    # Path to repo copy test src
+                my $strShimSrcPath = $self->{strGCovPath} . '/src';             # Path to shim src
+                my $strShimTestSrcPath = $self->{strGCovPath} . '/test/src';    # Path to shim test src
 
                 my $bCleanAll = false;                              # Do all object files need to be cleaned?
                 my $bConfigure = false;                             # Does configure need to be run?
@@ -262,7 +262,7 @@ sub run
                     "CFLAGS_CONFIG = \@CFLAGS\@\n" .
                     "CPPFLAGS_CONFIG = \@CPPFLAGS\@\n" .
                     "LDFLAGS_CONFIG = \@LDFLAGS\@\n" .
-                    "LIBS_CONFIG = \@LIBS\@\n";
+                    "LIBS_CONFIG = \@LIBS\@ \@LIBS_BUILD\@\n";
 
                 # If Makefile.in has changed then configure needs to be run and all files cleaned
                 if (buildPutDiffers($self->{oStorageTest}, $self->{strGCovPath} . "/Makefile.in", $strMakefileIn))
@@ -289,12 +289,11 @@ sub run
                 # Generate Makefile.param
                 my $strMakefileParam =
                     "CFLAGS =" .
-                        " \\\n\t-Werror -Wfatal-errors -g" .
+                        " \\\n\t-DERROR_MESSAGE_BUFFER_SIZE=131072" .
                         ($self->{bProfile} ? " \\\n\t-pg" : '') .
                         (vmArchBits($self->{oTest}->{&TEST_VM}) == 32 ? " \\\n\t-D_FILE_OFFSET_BITS=64" : '') .
                         ($self->{bDebug} ? '' : " \\\n\t-DNDEBUG") .
-                        ($self->{oTest}->{&TEST_DEBUG_UNIT_SUPPRESS} ? '' : " \\\n\t-DDEBUG_UNIT") .
-                        ($self->{oTest}->{&TEST_VM} eq VM_CO7 ? " \\\n\t-DDEBUG_EXEC_TIME" : '') .
+                        ($self->{oTest}->{&TEST_VM} eq VM_RH7 ? " \\\n\t-DDEBUG_EXEC_TIME" : '') .
                         ($bCoverage ? " \\\n\t-DDEBUG_COVERAGE" : '') .
                         ($self->{bDebugTestTrace} && $self->{bDebug} ? " \\\n\t-DDEBUG_TEST_TRACE" : '') .
                         (vmWithBackTrace($self->{oTest}->{&TEST_VM}) && $self->{bBackTrace} ? " \\\n\t-DWITH_BACKTRACE" : '') .
@@ -329,11 +328,13 @@ sub run
                         "\n" .
                     "\n" .
                     "INCLUDE =" .
+                        " \\\n\t-I\"${strShimSrcPath}\"" .
+                        " \\\n\t-I\"${strShimTestSrcPath}\"" .
                         " \\\n\t-I\"${strRepoCopySrcPath}\"" .
                         " \\\n\t-I\"${strRepoCopyTestSrcPath}\"" .
                         "\n" .
                     "\n" .
-                    "vpath \%.c ${strRepoCopySrcPath}:${strRepoCopyTestSrcPath}\n";
+                    "vpath \%.c ${strShimSrcPath}:${strShimTestSrcPath}:${strRepoCopySrcPath}:${strRepoCopyTestSrcPath}\n";
 
                 # If Makefile.param has changed then clean all files
                 if (buildPutDiffers($self->{oStorageTest}, $self->{strGCovPath} . "/Makefile.param", $strMakefileParam))
@@ -346,11 +347,148 @@ sub run
                 my $hTest = (testDefModuleTest($self->{oTest}->{&TEST_MODULE}, $self->{oTest}->{&TEST_NAME}));
                 my $strRepoCopyTestSrcHarnessPath = $strRepoCopyTestSrcPath . '/common';
 
+                # C modules included in harness files that should not be added to the make list
+                my $rhHarnessCModule = {};
+
+                # List of harness files to include in make
                 my @stryHarnessFile = ('common/harnessTest');
 
-                foreach my $strFile (@{$hTest->{&TESTDEF_HARNESS}})
+                foreach my $rhHarness (@{$hTest->{&TESTDEF_HARNESS}})
                 {
-                    push(@stryHarnessFile, "common/harness" . ucfirst($strFile));
+                    my $bFound = false;
+                    my $strFile = "common/harness" . ucfirst($rhHarness->{&TESTDEF_HARNESS_NAME});
+
+                    # Include harness file if present
+                    my $strHarnessSrcFile = "${strRepoCopyTestSrcPath}/${strFile}.c";
+
+                    if ($self->{oStorageTest}->exists($strHarnessSrcFile))
+                    {
+                        $bFound = true;
+
+                        if (!defined($hTest->{&TESTDEF_HARNESS_SHIM_DEF}{$rhHarness->{&TESTDEF_HARNESS_NAME}}))
+                        {
+                            push(@stryHarnessFile, $strFile);
+                        }
+
+                        # Install shim
+                        my $rhShim = $rhHarness->{&TESTDEF_HARNESS_SHIM};
+
+                        if (defined($rhShim))
+                        {
+                            my $strHarnessSrc = ${$self->{oStorageTest}->get($strHarnessSrcFile)};
+
+                            # Error if there is no placeholder for the shimmed modules
+                            if ($strHarnessSrc !~ /\{\[SHIM\_MODULE\]\}/)
+                            {
+                                confess &log(ERROR, "{[SHIM_MODULE]} tag not found in '${strFile}' harness with shims");
+                            }
+
+                            # Build list of shimmed C modules
+                            my $strShimModuleList = undef;
+
+                            foreach my $strShimModule (sort(keys(%{$rhShim})))
+                            {
+                                # If there are shimmed elements the C module will need to be updated and saved to the test path
+                                if (defined($rhShim->{$strShimModule}))
+                                {
+                                    my $strShimModuleSrc = ${$self->{oStorageTest}->get(
+                                        "${strRepoCopySrcPath}/${strShimModule}.c")};
+                                    my @stryShimModuleSrcRenamed;
+                                    my $strFunctionDeclaration = undef;
+                                    my $strFunctionShim = undef;
+
+                                    foreach my $strLine (split("\n", $strShimModuleSrc))
+                                    {
+                                        # If shimmed function declaration construction is in progress
+                                        if (defined($strFunctionShim))
+                                        {
+                                            # When the beginning of the function block is found, output both the constructed
+                                            # declaration and the renamed implementation.
+                                            if ($strLine =~ /^{/)
+                                            {
+                                                push(
+                                                    @stryShimModuleSrcRenamed,
+                                                    trim($strFunctionDeclaration) . "; " . $strFunctionShim);
+                                                push(@stryShimModuleSrcRenamed, $strLine);
+
+                                                $strFunctionShim = undef;
+                                            }
+                                            # Else keep constructing the declaration and implementation
+                                            else
+                                            {
+                                                $strFunctionDeclaration .= trim($strLine);
+                                                $strFunctionShim .= "${strLine}\n";
+                                            }
+                                        }
+                                        # Else search for shimmed functions
+                                        else
+                                        {
+                                            # Rename shimmed functions
+                                            my $bFound = false;
+
+                                            foreach my $strFunction (@{$rhShim->{$strShimModule}{&TESTDEF_HARNESS_SHIM_FUNCTION}})
+                                            {
+                                                # If the function to shim is static then we need to create a declaration with the
+                                                # original name so references to the original name in the C module will compile.
+                                                # This is not necessary for externed functions since they should already have a
+                                                # declaration in the header file.
+                                                if ($strLine =~ /^${strFunction}\(/ && $stryShimModuleSrcRenamed[-1] =~ /^static /)
+                                                {
+                                                    my $strLineLast = pop(@stryShimModuleSrcRenamed);
+
+                                                    $strFunctionDeclaration = "${strLineLast} ${strLine}";
+
+                                                    $strLine =~ s/^${strFunction}\(/${strFunction}_SHIMMED\(/;
+                                                    $strFunctionShim = "${strLineLast}\n${strLine}";
+
+                                                    $bFound = true;
+                                                    last;
+                                                }
+                                            }
+
+                                            # If the function was not found then just append the line
+                                            if (!$bFound)
+                                            {
+                                                push(@stryShimModuleSrcRenamed, $strLine);
+                                            }
+                                        }
+                                    }
+
+                                    buildPutDiffers(
+                                        $self->{oStorageTest}, "${strShimSrcPath}/${strShimModule}.c",
+                                        join("\n", @stryShimModuleSrcRenamed));
+                                }
+
+                                # Build list to include in the harness
+                                if (defined($strShimModuleList))
+                                {
+                                    $strShimModuleList .= "\n";
+                                }
+
+                                $rhHarnessCModule->{$strShimModule} = true;
+                                $strShimModuleList .= "#include \"${strShimModule}.c\"";
+                            }
+
+                            # Replace modules and save
+                            $strHarnessSrc =~ s/\{\[SHIM\_MODULE\]\}/${strShimModuleList}/g;
+                            buildPutDiffers($self->{oStorageTest}, "${strShimTestSrcPath}/${strFile}.c", $strHarnessSrc);
+                        }
+                    }
+
+                    # Include files in the harness directory if present
+                    for my $strFileSub (
+                        $self->{oStorageTest}->list("${strRepoCopyTestSrcPath}/${strFile}",
+                        {bIgnoreMissing => true, strExpression => '\.c$'}))
+                    {
+                        push(@stryHarnessFile, "${strFile}/" . substr($strFileSub, 0, length($strFileSub) - 2));
+                        $bFound = true;
+                    }
+
+                    # Error when no harness files were found
+                    if (!$bFound)
+                    {
+                        confess &log(ERROR, "no files found for harness '$rhHarness->{&TESTDEF_HARNESS_NAME}'");
+                    }
                 }
 
                 # Generate list of core files (files to be tested/included in this unit will be excluded)
@@ -367,6 +505,9 @@ sub run
                     # Skip if no C file exists
                     next if !$self->{oStorageTest}->exists("${strRepoCopySrcPath}/${strFile}.c");
 
+                    # Skip if the C file is included in the harness
+                    next if defined($rhHarnessCModule->{$strFile});
+
                     if (!defined($hTestCoverage->{$strFile}) && !grep(/^$strFile$/, @{$hTest->{&TESTDEF_INCLUDE}}))
                     {
                         push(@stryCoreFile, $strFile);
@@ -426,6 +567,9 @@ sub run
                     # Don't include vendor files as they are included in regular C files
                     next if $strFile =~ /vendor$/;
 
+                    # Skip if the C file is included in the harness
+                    next if defined($rhHarnessCModule->{$strFile});
+
                     # Include the C file if it exists
                     my $strCIncludeFile = "${strFile}.c";
 
@@ -445,6 +589,13 @@ sub run
                     $strTestDepend .= " ${strCIncludeFile}";
                 }
 
+                # Add harnesses with shims that are first defined in this module
+                foreach my $strHarness (sort(keys(%{$hTest->{&TESTDEF_HARNESS_SHIM_DEF}})))
+                {
+                    $strCInclude .=
+                        (defined($strCInclude) ? "\n" : '') . "#include \"common/harness" . ucfirst($strHarness) . ".c\"";
+                }
+
                 # Update C test file with test module
                 my $strTestC = ${$self->{oStorageTest}->get("${strRepoCopyTestSrcPath}/test.c")};
 
@@ -474,10 +625,14 @@ sub run
                 $strTestC =~ s/\{\[C\_TEST\_CONTAINER\]\}/$strContainer/g;
                 $strTestC =~ s/\{\[C\_TEST\_PROJECT\_EXE\]\}/$strProjectExePath/g;
                 $strTestC =~ s/\{\[C\_TEST\_PATH\]\}/$strTestPathC/g;
+                $strTestC =~ s/\{\[C\_TEST\_USER\]\}/${\TEST_USER}/g;
+                $strTestC =~ s/\{\[C\_TEST\_USER\_ID\]\}/${\TEST_USER_ID}/g;
+                $strTestC =~ s/\{\[C\_TEST\_GROUP\]\}/${\TEST_GROUP}/g;
+                $strTestC =~ s/\{\[C\_TEST\_GROUP\_ID\]\}/${\TEST_GROUP_ID}/g;
                 $strTestC =~ s/\{\[C\_TEST\_PGB\_PATH\]\}/$strRepoCopyPath/g;
-                $strTestC =~ s/\{\[C\_TEST\_DATA_PATH\]\}/$self->{strDataPath}/g;
+                $strTestC =~ s/\{\[C\_HRN\_PATH\]\}/$self->{strDataPath}/g;
                 $strTestC =~ s/\{\[C\_TEST\_IDX\]\}/$self->{iVmIdx}/g;
-                $strTestC =~ s/\{\[C\_TEST\_REPO_PATH\]\}/$self->{strBackRestBase}/g;
+                $strTestC =~ s/\{\[C\_HRN\_PATH\_REPO\]\}/$self->{strBackRestBase}/g;
                 $strTestC =~ s/\{\[C\_TEST\_SCALE\]\}/$self->{iScale}/g;
 
                 my $strLogTimestampC = $self->{bLogTimestamp} ? 'true' : 'false';
@@ -571,7 +726,7 @@ sub run
                     ($self->{bValgrindUnit} && $self->{oTest}->{&TEST_TYPE} ne TESTDEF_PERFORMANCE ?
                         'valgrind -q --gen-suppressions=all' .
                         ($self->{oStorageTest}->exists($strValgrindSuppress) ? " --suppressions=${strValgrindSuppress}" : '') .
-                        " --leak-check=full --leak-resolution=high --error-exitcode=25" . ' ' : '') .
+                        " --exit-on-first-error=yes --leak-check=full --leak-resolution=high --error-exitcode=25" . ' ' : '') .
                         "./test.bin 2>&1" .
                     ($self->{oTest}->{&TEST_VM} ne VM_NONE ? "'" : '');
             }
@@ -581,7 +736,6 @@ sub run
                     ($self->{oTest}->{&TEST_CONTAINER} ? 'docker exec -i -u ' . TEST_USER . " ${strImage} " : '') .
                     abs_path($0) .
                     " --test-path=${strVmTestPath}" .
-                    " --vm-host=$self->{strVmHost}" .
                     " --vm=$self->{oTest}->{&TEST_VM}" .
                     " --vm-id=$self->{iVmIdx}" .
                     " --module=" . $self->{oTest}->{&TEST_MODULE} .
