@@ -48,6 +48,7 @@ sub new
         $self->{strCommandMain},
         $self->{strPgSqlBin},
         $self->{strTestPath},
+        $self->{strRepoPath},
     ) =
         logDebugParam
         (
@@ -60,6 +61,7 @@ sub new
             {name => 'strCommandMain', trace => true},
             {name => 'strPgSqlBin', required => false, trace => true},
             {name => 'strTestPath', trace => true},
+            {name => 'strRepoPath', trace => true},
         );
 
     # Initialize the test log
@@ -167,7 +169,7 @@ sub supplementalAdd
         close($hFile);
     }
 
-    # Only ouput when the content of this file has changed
+    # Only output when the content of this file has changed
     if (!defined($hyExpectCache->{$strFileName}) || $hyExpectCache->{$strFileName} ne $strContent)
     {
         # $hyExpectCache->{$strFileName} = $strContent;
@@ -366,6 +368,9 @@ sub regExpReplaceAll
     # Replace the test path
     $strLine =~ s/$self->{strTestPath}/[TEST_PATH]/g;
 
+    # Replace the repo path
+    $strLine =~ s/$self->{strRepoPath}/[REPO_PATH]/g;
+
     # Replace the pgsql path (if exists)
     if (defined($self->{strPgSqlBin}))
     {
@@ -395,6 +400,8 @@ sub regExpReplaceAll
         $strLine = 'P00 DETAIL: statistics: STATISTICS'
     }
 
+    $strLine = $self->regExpReplace($strLine, 'PRIMARY', 'mas'.'ter', undef, false);
+
     $strLine = $self->regExpReplace($strLine, 'GROUP', 'strGroup = [^ \n,\[\]]+', '[^ \n,\[\]]+$');
     $strLine = $self->regExpReplace($strLine, 'GROUP', 'unknown group in backup manifest mapped to \'[^\']+', '[^\']+$');
     $strLine = $self->regExpReplace($strLine, 'GROUP', 'group"[ ]{0,1}:[ ]{0,1}"[^"]+', '[^"]+$');
