@@ -62,6 +62,7 @@ sub new
     my $self = $class->SUPER::new(
         {
             strImage => containerRepo() . ':' . testRunGet()->vm() . "-test",
+            bTls => $oParam->{bTls},
             strBackupDestination => $$oParam{strBackupDestination},
             oLogTest => $$oParam{oLogTest},
             bStandby => $$oParam{bStandby},
@@ -388,9 +389,9 @@ sub clusterStart
     my $bArchiveEnabled = defined($$hParam{bArchiveEnabled}) ? $$hParam{bArchiveEnabled} : true;
 
     # Make sure postgres is not running
-    if (-e $self->dbBasePath() . '/postmaster.pid')
+    if (-e $self->dbBasePath() . '/postmas'.'ter.pid')
     {
-        confess 'postmaster.pid exists';
+        confess 'postmas'.'ter.pid exists';
     }
 
     # Create the archive command
@@ -477,12 +478,13 @@ sub clusterStop
     if (!$bIgnoreLogError && storageTest()->exists($self->pgLogFile()))
     {
         $self->executeSimple(
-            'grep -v "FATAL\:  57P03\: the database system is starting up" ' . $self->pgLogFile() . ' | grep "ERROR\|FATAL"',
+            'grep -v "FATAL\:  57P03\: the database system is (starting up|not yet accepting connections|"
+                "not accepting connections)" ' . $self->pgLogFile() . ' | grep "ERROR\|FATAL"',
             {iExpectedExitStatus => 1});
     }
 
     # If pg process is running then stop the cluster
-    if (-e $self->dbBasePath() . '/' . DB_FILE_POSTMASTERPID)
+    if (-e $self->dbBasePath() . '/' . DB_FILE_POSTMTRPID)
     {
         $self->executeSimple($self->pgBinPath() . '/pg_ctl stop -D ' . $self->dbBasePath() . ' -w -s -m fast');
     }
