@@ -67,7 +67,7 @@ sub new
     my $strFakeCertPath = "${strProjectPath}/doc/resource/fake-cert";
 
     my $self = $class->SUPER::new(
-        HOST_S3, 'test-' . testRunGet()->vmId() . '-s3-server', 'minio/minio:RELEASE.2020-05-06T23-23-25Z', 'root', 'u18',
+        HOST_S3, 'test-' . testRunGet()->vmId() . '-s3-server', 'minio/minio', 'root', 'u18',
         ["${strFakeCertPath}/s3-server.crt:/root/.minio/certs/public.crt:ro",
             "${strFakeCertPath}/s3-server.key:/root/.minio/certs/private.key:ro"],
         '-e MINIO_REGION=' . HOST_S3_REGION . ' -e MINIO_DOMAIN=' . HOST_S3_ENDPOINT . ' -e MINIO_BROWSER=off' .
