@@ -18,11 +18,22 @@ void hrnLogReplaceAdd(const char *expression, const char *expressionSub, const c
 void hrnLogReplaceClear(void);
 
 void harnessLogResult(const char *expected);
-void harnessLogResultRegExp(const char *expression);
 
 /***********************************************************************************************************************************
 Getters/Setters
 ***********************************************************************************************************************************/
+// Get/set log levels
+unsigned int hrnLogLevelFile(void);
+void hrnLogLevelFileSet(unsigned int logLevel);
+unsigned int hrnLogLevelStdOut(void);
+void hrnLogLevelStdOutSet(unsigned int logLevel);
+unsigned int hrnLogLevelStdErr(void);
+void hrnLogLevelStdErrSet(unsigned int logLevel);
+
+// Get/set log timestamp
+bool hrnLogTimestamp(void);
+void hrnLogTimestampSet(bool log);
+
 void harnessLogLevelReset(void);
 void harnessLogLevelSet(LogLevel logLevel);
 
