@@ -1,6 +1,8 @@
 /***********************************************************************************************************************************
 Server Test Harness
 ***********************************************************************************************************************************/
+#include "build.auto.h"
+
 #include <arpa/inet.h>
 #include <netinet/in.h>
 #include <string.h>
@@ -12,8 +14,8 @@ Server Test Harness
 
 #include "common/crypto/common.h"
 #include "common/error.h"
-#include "common/io/socket/common.h"
-#include "common/io/socket/session.h"
+#include "common/io/socket/server.h"
+#include "common/io/tls/server.h"
 #include "common/io/tls/session.h"
 #include "common/log.h"
 #include "common/type/buffer.h"
@@ -42,9 +44,29 @@ typedef enum
 Constants
 ***********************************************************************************************************************************/
 #define HRN_SERVER_HOST                                             "tls.test.pgbackrest.org"
-#define HRN_SERVER_FAKE_CERT_PATH                                   "/etc/fake-cert"
-#define HRN_SERVER_FAKE_KEY_FILE                                    HRN_SERVER_FAKE_CERT_PATH "/pgbackrest-test.key"
-#define HRN_SERVER_FAKE_CERT_FILE                                   HRN_SERVER_FAKE_CERT_PATH "/pgbackrest-test.crt"
+
+/**********************************************************************************************************************************/
+void hrnServerInit(void)
+{
+    FUNCTION_HARNESS_VOID();
+
+    // Set correct permissions on private keys
+    THROW_ON_SYS_ERROR(
+        chmod(strZ(strNewFmt("%s/" HRN_SERVER_CERT_PREFIX "server.key", hrnPathRepo())), 0600) == -1, FileModeError,
+        "unable to set mode on server key");
+    THROW_ON_SYS_ERROR(
+        chmod(strZ(strNewFmt("%s/" HRN_SERVER_CERT_PREFIX "client.key", hrnPathRepo())), 0600) == -1, FileModeError,
+        "unable to set mode on client key");
+
+    // Add hostname when running in a container
+    if (testContainer())
+    {
+        if (system("echo \"127.0.0.1 " HRN_SERVER_HOST "\" | sudo tee -a /etc/hosts > /dev/null") != 0)
+            THROW(AssertError, "unable to add test host to /etc/hosts");
+    }
+
+    FUNCTION_HARNESS_RETURN_VOID();
+}
 
 /***********************************************************************************************************************************
 Send commands to the server
@@ -76,8 +98,6 @@ IoWrite *hrnServerScriptBegin(IoWrite *write)
 
     ASSERT(write != NULL);
 
-    ioWriteOpen(write);
-
     FUNCTION_HARNESS_RETURN(IO_WRITE, write);
 }
 
@@ -223,18 +243,8 @@ void hrnServerRun(IoRead *read, HrnServerProtocol protocol, HrnServerRunParam pa
     if (param.port == 0)
         param.port = hrnServerPort(0);
 
-    // Open read connection to client
-    ioReadOpen(read);
-
-    // Add test hosts
-    if (testContainer())
-    {
-        if (system("echo \"127.0.0.1 " HRN_SERVER_HOST "\" | sudo tee -a /etc/hosts > /dev/null") != 0)
-            THROW(AssertError, "unable to add test host to /etc/hosts");
-    }
-
     // Initialize ssl and create a context
-    SSL_CTX *serverContext = NULL;
+    IoServer *tlsServer = NULL;
 
     if (protocol == hrnServerProtocolTls)
     {
@@ -243,70 +253,14 @@ void hrnServerRun(IoRead *read, HrnServerProtocol protocol, HrnServerRunParam pa
         // If certificate and key are not set then use defaults
         if (param.certificate == NULL)
         {
-            // If running in a container use the installed certificate
-            if (testContainer())
-            {
-                param.certificate = strNew(HRN_SERVER_FAKE_CERT_FILE);
-                param.key = strNew(HRN_SERVER_FAKE_KEY_FILE);
-            }
-            // Else use a certificate from the test path -- tests will need to disable verify
-            else
-            {
-                param.certificate = strNewFmt("%s/" HRN_SERVER_CERT_PREFIX ".crt", testRepoPath());
-                param.key = strNewFmt("%s/" HRN_SERVER_CERT_PREFIX ".key", testRepoPath());
-            }
+            param.certificate = strNewFmt("%s/" HRN_SERVER_CERT_PREFIX "server.crt", hrnPathRepo());
+            param.key = strNewFmt("%s/" HRN_SERVER_CERT_PREFIX "server.key", hrnPathRepo());
         }
 
-        // Initialize TLS
-        cryptoInit();
-
-        const SSL_METHOD *method = SSLv23_method();
-        cryptoError(method == NULL, "unable to load TLS method");
-
-        serverContext = SSL_CTX_new(method);
-        cryptoError(serverContext == NULL, "unable to create TLS context");
-
-        // Configure the context by setting key and cert
-        cryptoError(
-            SSL_CTX_use_certificate_file(serverContext, strZ(param.certificate), SSL_FILETYPE_PEM) <= 0,
-            "unable to load server certificate");
-        cryptoError(
-            SSL_CTX_use_PrivateKey_file(serverContext, strZ(param.key), SSL_FILETYPE_PEM) <= 0,
-            "unable to load server private key");
+        tlsServer = tlsServerNew(STRDEF(HRN_SERVER_HOST), param.ca, param.key, param.certificate, 5000);
     }
 
-    // Create the socket
-    int serverSocket;
-
-    struct sockaddr_in address;
-
-    address.sin_family = AF_INET;
-    address.sin_port = htons((uint16_t)param.port);
-    address.sin_addr.s_addr = htonl(INADDR_ANY);
-
-    if ((serverSocket = socket(AF_INET, SOCK_STREAM, 0)) < 0)
-        THROW_SYS_ERROR(AssertError, "unable to create socket");
-
-    // Set the address as reusable so we can bind again in the same process for testing
-    int reuseAddr = 1;
-    setsockopt(serverSocket, SOL_SOCKET, SO_REUSEADDR, &reuseAddr, sizeof(reuseAddr));
-
-    // Bind the address.  It might take a bit to bind if another process was recently using it so retry a few times.
-    Wait *wait = waitNew(2000);
-    int result;
-
-    do
-    {
-        result = bind(serverSocket, (struct sockaddr *)&address, sizeof(address));
-    }
-    while (result < 0 && waitMore(wait));
-
-    if (result < 0)
-        THROW_SYS_ERROR(AssertError, "unable to bind socket");
-
-    // Listen for client connections
-    if (listen(serverSocket, 1) < 0)
-        THROW_SYS_ERROR(AssertError, "unable to listen on socket");
+    IoServer *socketServer = sckServerNew(STRDEF("localhost"), param.port, 5000);
 
     // Loop until no more commands
     IoSession *serverSession = NULL;
@@ -332,25 +286,11 @@ void hrnServerRun(IoRead *read, HrnServerProtocol protocol, HrnServerRunParam pa
 
             case hrnServerCmdAccept:
             {
-                // Accept the socket connection
-                struct sockaddr_in addr;
-                unsigned int len = sizeof(addr);
-
-                int testClientSocket = accept(serverSocket, (struct sockaddr *)&addr, &len);
-
-                if (testClientSocket < 0)
-                    THROW_SYS_ERROR(AssertError, "unable to accept socket");
-
-                // Create socket session
-                sckOptionSet(testClientSocket);
-                serverSession = sckSessionNew(ioSessionRoleServer, testClientSocket, STRDEF("localhost"), param.port, 5000);
+                serverSession = ioServerAccept(socketServer, NULL);
 
                 // Start TLS if requested
                 if (protocol == hrnServerProtocolTls)
-                {
-                    SSL *testClientSSL = SSL_new(serverContext);
-                    serverSession = tlsSessionNew(testClientSSL, serverSession, 5000);
-                }
+                    serverSession = ioServerAccept(tlsServer, serverSession);
 
                 break;
             }
@@ -418,9 +358,9 @@ void hrnServerRun(IoRead *read, HrnServerProtocol protocol, HrnServerRunParam pa
     }
     while (!done);
 
-    // Free TLS context
-    if (protocol == hrnServerProtocolTls)
-        SSL_CTX_free(serverContext);
+    // Free servers
+    ioServerFree(tlsServer);
+    ioServerFree(socketServer);
 
     FUNCTION_HARNESS_RETURN_VOID();
 }
@@ -428,7 +368,7 @@ void hrnServerRun(IoRead *read, HrnServerProtocol protocol, HrnServerRunParam pa
 /**********************************************************************************************************************************/
 const String *hrnServerHost(void)
 {
-    return strNew(testContainer() ? HRN_SERVER_HOST : "127.0.0.1");
+    return strNewZ(testContainer() ? HRN_SERVER_HOST : "127.0.0.1");
 }
 
 /**********************************************************************************************************************************/
