@@ -1,6 +1,8 @@
 /***********************************************************************************************************************************
 Storage Test Harness
 ***********************************************************************************************************************************/
+#include "build.auto.h"
+
 #include <inttypes.h>
 #include <stdio.h>
 #include <string.h>
@@ -112,8 +114,14 @@ hrnStorageInfoListCallback(void *callbackData, const StorageInfo *info)
             }
 
             case storageTypeLink:
-                strCatFmt(data->content, "link, d=%s", strZ(info->linkDestination));
+            {
+                strCatZ(data->content, "link");
+
+                if (info->linkDestination != NULL)
+                    strCatFmt(data->content, ", d=%s", strZ(info->linkDestination));
+
                 break;
+            }
 
             case storageTypePath:
                 strCatZ(data->content, "path");
@@ -173,58 +181,174 @@ hrnStorageInfoListCallback(void *callbackData, const StorageInfo *info)
 
 /**********************************************************************************************************************************/
 void
-testStorageGet(
-    const int line, const Storage *const storage, const char *const file, const char *const expected, TestStorageGetParam param)
+testStorageGet(const Storage *const storage, const char *const file, const char *const expected, TestStorageGetParam param)
 {
-    hrnTestLogPrefix(line, true);
-    hrnTestResultBegin(__func__, line, false);
+    hrnTestResultBegin(__func__, false);
 
-    const String *const fileFull = storagePathP(storage, STR(file));
-    printf("test content of '%s'\n", strZ(fileFull));
-    fflush(stdout);
+    ASSERT(storage != NULL);
+    ASSERT(file != NULL);
 
-    hrnTestResultZ(strZ(strNewBuf(storageGetP(storageNewReadP(storage, fileFull)))), expected, harnessTestResultOperationEq);
+    String *fileFull = strCat(strNew(), storagePathP(storage, STR(file)));
+
+    // Add compression extension if one exists
+    compressExtCat(fileFull, param.compressType);
+
+    // Declare an information filter for displaying paramaters to the output
+    String *const filter = strNew();
+
+    StorageRead *read = storageNewReadP(storage, fileFull);
+    IoFilterGroup *filterGroup = ioReadFilterGroup(storageReadIo(read));
+
+    // Add decrypt filter
+    if (param.cipherType != 0 && param.cipherType != cipherTypeNone)
+    {
+        // Default to main cipher pass
+        if (param.cipherPass == NULL)
+            param.cipherPass = TEST_CIPHER_PASS;
+
+        ioFilterGroupAdd(filterGroup, cipherBlockNew(cipherModeDecrypt, param.cipherType, BUFSTRZ(param.cipherPass), NULL));
+
+        strCatFmt(filter, "enc[%s,%s] ", strZ(strIdToStr(param.cipherType)), param.cipherPass);
+    }
+
+    // Add decompress filter
+    if (param.compressType != compressTypeNone)
+    {
+        ASSERT(param.compressType == compressTypeGz || param.compressType == compressTypeBz2);
+        ioFilterGroupAdd(filterGroup, decompressFilter(param.compressType));
+    }
+
+    printf("test content of %s'%s'", strEmpty(filter) ? "" : strZ(filter), strZ(fileFull));
+    hrnTestResultComment(param.comment);
+
+    hrnTestResultZ(strZ(strNewBuf(storageGetP(read))), expected, harnessTestResultOperationEq);
 
     if (param.remove)
         storageRemoveP(storage, fileFull, .errorOnMissing = true);
 }
 
 /**********************************************************************************************************************************/
-StringList *
-hrnStorageList(const Storage *storage, const char *path, HrnStorageListParam param)
+void
+testStorageExists(const Storage *const storage, const char *const file, const TestStorageExistsParam param)
 {
-    StringList *list = strLstSort(storageListP(storage, STR(path)), sortOrderAsc);
+    hrnTestResultBegin(__func__, false);
+
+    ASSERT(storage != NULL);
+    ASSERT(file != NULL);
+
+    const String *const fileFull = storagePathP(storage, STR(file));
+
+    printf("file exists '%s'", strZ(fileFull));
+    hrnTestResultComment(param.comment);
+
+    hrnTestResultBool(storageExistsP(storage, fileFull), true);
+
+    if (param.remove)
+        storageRemoveP(storage, fileFull, .errorOnMissing = true);
+}
+
+/**********************************************************************************************************************************/
+static void
+hrnStorageListCallback(void *list, const StorageInfo *info)
+{
+    if (!strEq(info->name, DOT_STR))
+    {
+        MEM_CONTEXT_BEGIN(lstMemContext(list))
+        {
+            StorageInfo infoCopy = *info;
+            infoCopy.name = strDup(infoCopy.name);
+            infoCopy.user = strDup(infoCopy.user);
+            infoCopy.group = strDup(infoCopy.group);
+            infoCopy.linkDestination = strDup(infoCopy.linkDestination);
+
+            lstAdd(list, &infoCopy);
+        }
+        MEM_CONTEXT_END();
+    }
+}
+
+void
+hrnStorageList(const Storage *const storage, const char *const path, const char *const expected, const HrnStorageListParam param)
+{
+    // Log list test
+    hrnTestResultBegin(__func__, false);
+
+    ASSERT(storage != NULL);
+    ASSERT(storagePathExistsP(storage, path == NULL ? NULL : STR(path)));
+
+    const String *const pathFull = storagePathP(storage, path == NULL ? NULL : STR(path));
+    printf("list%s contents of '%s'", param.remove ? "/remove": "", strZ(pathFull));
+    hrnTestResultComment(param.comment);
+
+    // Generate a list of files/paths/etc
+    List *list = lstNewP(sizeof(StorageInfo));
+
+    storageInfoListP(
+        storage, pathFull, hrnStorageListCallback, list, .sortOrder = sortOrderAsc, .recurse = !param.noRecurse,
+        .expression = param.expression != NULL ? STR(param.expression) : NULL);
 
     // Remove files if requested
     if (param.remove)
     {
-        for (unsigned int listIdx = 0; listIdx < strLstSize(list); listIdx++)
-            storageRemoveP(storage, strNewFmt("%s/%s", path, strZ(strLstGet(list, listIdx))), .errorOnMissing = true);
+        for (unsigned int listIdx = 0; listIdx < lstSize(list); listIdx++)
+        {
+            const StorageInfo *const info = lstGet(list, listIdx);
+
+            // Only remove at the top level since path remove will recurse
+            if (strChr(info->name, '/') == -1)
+            {
+                // Remove a path recursively
+                if (info->type == storageTypePath)
+                {
+                    storagePathRemoveP(
+                        storage, strNewFmt("%s/%s", path, strZ(info->name)), .errorOnMissing = true, .recurse = true);
+                }
+                // Remove file, link, or special
+                else
+                    storageRemoveP(storage, strNewFmt("%s/%s", path, strZ(info->name)), .errorOnMissing = true);
+            }
+        }
     }
 
     // Return list for comparison
-    return list;
-}
+    StringList *listStr = strLstNew();
 
-const char *
-hrnStorageListLog(const Storage *storage, const char *path, HrnStorageListParam param)
-{
-    StringList *list = strLstSort(storageListP(storage, STR(path)), sortOrderAsc);
+    for (unsigned int listIdx = 0; listIdx < lstSize(list); listIdx++)
+    {
+        const StorageInfo *const info = lstGet(list, listIdx);
 
-    return strZ(
-        strNewFmt(
-            "list%s %u file%s in '%s'", param.remove ? "/remove": "", strLstSize(list), strLstSize(list) == 1 ? "" : "s",
-            strZ(storagePathP(storage, STR(path)))));
+        switch (info->type)
+        {
+            case storageTypeFile:
+                strLstAdd(listStr, info->name);
+                break;
+
+            case storageTypeLink:
+                strLstAdd(listStr, strNewFmt("%s>", strZ(info->name)));
+                break;
+
+            case storageTypePath:
+                strLstAdd(listStr, strNewFmt("%s/", strZ(info->name)));
+                break;
+
+            case storageTypeSpecial:
+                strLstAdd(listStr, strNewFmt("%s*", strZ(info->name)));
+                break;
+        }
+    }
+
+    hrnTestResultStringList(listStr, expected, harnessTestResultOperationEq);
 }
 
 /**********************************************************************************************************************************/
 void
-hrnStorageMode(const int line, const Storage *const storage, const char *const path, HrnStorageModeParam param)
+hrnStorageMode(const Storage *const storage, const char *const path, HrnStorageModeParam param)
 {
-    hrnTestLogPrefix(line, true);
-    hrnTestResultBegin(__func__, line, false);
+    hrnTestResultBegin(__func__, false);
 
-    const char *const pathFull = strZ(storagePathP(storage, STR(path)));
+    ASSERT(storage != NULL);
+
+    const char *const pathFull = strZ(storagePathP(storage, path == NULL ? NULL : STR(path)));
 
     // If no mode specified then default the mode based on the file type
     if (param.mode == 0)
@@ -239,8 +363,8 @@ hrnStorageMode(const int line, const Storage *const storage, const char *const p
             param.mode = STORAGE_MODE_FILE_DEFAULT;
     }
 
-    printf("chmod '%04o' on '%s'\n", param.mode, pathFull);
-    fflush(stdout);
+    printf("chmod '%04o' on '%s'", param.mode, pathFull);
+    hrnTestResultComment(param.comment);
 
     THROW_ON_SYS_ERROR_FMT(chmod(pathFull, param.mode) == -1, FileModeError, "unable to set mode on '%s'", pathFull);
 
@@ -249,25 +373,95 @@ hrnStorageMode(const int line, const Storage *const storage, const char *const p
 
 /**********************************************************************************************************************************/
 void
-hrnStoragePut(const Storage *storage, const char *file, const Buffer *buffer, HrnStoragePutParam param)
+hrnStorageMove(
+    const Storage *const storage, const char *const fileSource, const char *const fileDest, HrnStorageMoveParam param)
 {
+    hrnTestResultBegin(__func__, false);
+
+    ASSERT(storage != NULL);
+    ASSERT(fileSource != NULL);
+    ASSERT(fileDest != NULL);
+
+    const String *const fileSourceStr = storagePathP(storage, STR(fileSource));
+    const String *const fileDestStr = storagePathP(storage, STR(fileDest));
+
+    printf("move '%s' to '%s'", strZ(fileSourceStr), strZ(fileDestStr));
+
+    hrnTestResultComment(param.comment);
+
+    // Move (rename) the file
+    storageMoveP(storage, storageNewReadP(storage, fileSourceStr), storageNewWriteP(storage,fileDestStr));
+
+    hrnTestResultEnd();
+}
+
+/**********************************************************************************************************************************/
+void
+hrnStorageCopy(
+    const Storage *const storageSource, const char *const fileSource, const Storage *const storageDest, const char *const fileDest,
+    HrnStorageCopyParam param)
+{
+    hrnTestResultBegin(__func__, false);
+
+    ASSERT(storageSource != NULL);
+    ASSERT(fileSource != NULL);
+    ASSERT(storageDest != NULL);
+    ASSERT(fileDest != NULL);
+
+    const String *const fileSourceStr = storagePathP(storageSource, STR(fileSource));
+    const String *const fileDestStr = storagePathP(storageDest, STR(fileDest));
+
+    printf("copy '%s' to '%s'", strZ(fileSourceStr), strZ(fileDestStr));
+
+    hrnTestResultComment(param.comment);
+
+    // Copy the file
+    storageCopyP(storageNewReadP(storageSource, fileSourceStr), storageNewWriteP(storageDest, fileDestStr));
+
+    hrnTestResultEnd();
+}
+
+/**********************************************************************************************************************************/
+void
+hrnStoragePut(
+    const Storage *const storage, const char *const file, const Buffer *const buffer, const char *const logPrefix,
+    HrnStoragePutParam param)
+{
+    hrnTestResultBegin(__func__, false);
+
+    ASSERT(storage != NULL);
+    ASSERT(file != NULL);
+
     // Add compression extension to file name
-    String *fileStr = strNew(file);
+    String *fileStr = strCatZ(strNew(), file);
     compressExtCat(fileStr, param.compressType);
 
     // Create file
-    StorageWrite *destination = storageNewWriteP(storage, fileStr);
+    StorageWrite *destination = storageNewWriteP(storage, fileStr, .modeFile = param.modeFile, .timeModified = param.timeModified);
     IoFilterGroup *filterGroup = ioWriteFilterGroup(storageWriteIo(destination));
 
+    // Declare an information filter for displaying paramaters to the output
+    String *const filter = strNew();
+
+    // Add mode to output information filter
+    if (param.modeFile != 0)
+        strCatFmt(filter, "mode[%04o]", param.modeFile);
+
+    // Add modified time to output information filter
+    if (param.timeModified != 0)
+        strCatFmt(filter, "%stime[%" PRIu64 "]",  strEmpty(filter) ? "" : "/", (uint64_t)param.timeModified);
+
     // Add compression filter
     if (param.compressType != compressTypeNone)
     {
         ASSERT(param.compressType == compressTypeGz || param.compressType == compressTypeBz2);
         ioFilterGroupAdd(filterGroup, compressFilter(param.compressType, 1));
+
+        strCatFmt(filter, "%scmp[%s]", strEmpty(filter) ? "" : "/", strZ(compressTypeStr(param.compressType)));
     }
 
     // Add encrypted filter
-    if (param.cipherType != cipherTypeNone)
+    if (param.cipherType != 0 && param.cipherType != cipherTypeNone)
     {
         // Default to main cipher pass
         if (param.cipherPass == NULL)
@@ -276,53 +470,88 @@ hrnStoragePut(const Storage *storage, const char *file, const Buffer *buffer, Hr
         ioFilterGroupAdd(filterGroup, cipherBlockNew(cipherModeEncrypt, param.cipherType, BUFSTRZ(param.cipherPass), NULL));
     }
 
+    // Add file name
+    printf(
+        "%s %s%s%s'%s'", logPrefix != NULL ? logPrefix : "put file", buffer == NULL || bufEmpty(buffer) ? "(empty) " : "",
+        strZ(filter), strEmpty(filter) ? "" : " ", strZ(storagePathP(storage, fileStr)));
+    hrnTestResultComment(param.comment);
+
     // Put file
     storagePutP(destination, buffer);
-}
 
-const char *
-hrnStoragePutLog(const Storage *storage, const char *file, const Buffer *buffer, HrnStoragePutParam param)
-{
-    // Empty if buffer is NULL
-    String *log = strNew(buffer == NULL || bufEmpty(buffer) ? "(empty) " : "");
-
-    // Add compression detail
-    if (param.compressType != compressTypeNone)
-        strCatFmt(log, "cmp[%s]", strZ(compressTypeStr(param.compressType)));
-
-    // Add encryption detail
-    if (param.cipherType != cipherTypeNone)
-    {
-        if (param.cipherPass == NULL)
-            param.cipherPass = TEST_CIPHER_PASS;
-
-        if (param.compressType != compressTypeNone)
-            strCatZ(log, "/");
-
-        strCatFmt(log, "enc[%s,%s]", strZ(cipherTypeName(param.cipherType)), param.cipherPass);
-    }
-
-    // Add a space if compression/encryption defined
-    if (param.compressType != compressTypeNone || param.cipherType != cipherTypeNone)
-        strCatZ(log, " ");
-
-    // Add file name
-    strCatFmt(log, "'%s%s'", strZ(storagePathP(storage, STR(file))), strZ(compressExtStr(param.compressType)));
-
-    return strZ(log);
+    hrnTestResultEnd();
 }
 
 /**********************************************************************************************************************************/
 void
-hrnStorageTime(const int line, const Storage *const storage, const char *const path, const time_t modified)
+hrnStoragePathCreate(const Storage *const storage, const char *const path, HrnStoragePathCreateParam param)
 {
-    hrnTestLogPrefix(line, true);
-    hrnTestResultBegin(__func__, line, false);
+    hrnTestResultBegin(__func__, false);
+
+    ASSERT(storage != NULL);
+
+    const String *const pathFull = storagePathP(storage, path == NULL ? NULL : STR(path));
+
+    printf("create path '%s'", strZ(pathFull));
+
+    if (param.mode != 0)
+        printf(" mode '%04o'", param.mode);
+
+    hrnTestResultComment(param.comment);
+
+    storagePathCreateP(
+        storage, pathFull, .mode = param.mode, .errorOnExists = !param.noErrorOnExists, .noParentCreate = param.noParentCreate);
+
+    hrnTestResultEnd();
+}
+
+/**********************************************************************************************************************************/
+void
+hrnStoragePathRemove(const Storage *const storage, const char *const path, HrnStoragePathRemoveParam param)
+{
+    hrnTestResultBegin(__func__, false);
+
+    ASSERT(storage != NULL);
+
+    const String *const pathFull = storagePathP(storage, path == NULL ? NULL : STR(path));
+
+    printf("remove path '%s'", strZ(pathFull));
+    hrnTestResultComment(param.comment);
+
+    storagePathRemoveP(storage, pathFull, .recurse = param.recurse, .errorOnMissing = param.errorOnMissing);
+
+    hrnTestResultEnd();
+}
+
+/**********************************************************************************************************************************/
+void
+hrnStorageRemove(const Storage *const storage, const char *const file, const HrnStorageRemoveParam param)
+{
+    hrnTestResultBegin(__func__, false);
+
+    ASSERT(storage != NULL);
+    ASSERT(file != NULL);
+
+    printf("remove file '%s'", strZ(storagePathP(storage, STR(file))));
+    hrnTestResultComment(param.comment);
+
+    storageRemoveP(storage, STR(file), .errorOnMissing = param.errorOnMissing);
+
+    hrnTestResultEnd();
+}
+
+/**********************************************************************************************************************************/
+void
+hrnStorageTime(const Storage *const storage, const char *const path, const time_t modified, const HrnStorageTimeParam param)
+{
+    hrnTestResultBegin(__func__, false);
+
+    ASSERT(storage != NULL);
 
     const char *const pathFull = strZ(storagePathP(storage, path == NULL ? NULL : STR(path)));
 
-    printf("time '%" PRId64 "' on '%s'\n", (int64_t)modified, pathFull);
-    fflush(stdout);
+    printf("time '%" PRId64 "' on '%s'", (int64_t)modified, pathFull);
+    hrnTestResultComment(param.comment);
 
     THROW_ON_SYS_ERROR_FMT(
         utime(pathFull, &((struct utimbuf){.actime = modified, .modtime = modified})) == -1, FileInfoError,
