@@ -1,9 +1,9 @@
 /***********************************************************************************************************************************
 C Test Harness
 ***********************************************************************************************************************************/
+#include "build.auto.h"
+
 #include <fcntl.h>
-#include <grp.h>
-#include <pwd.h>
 #include <stdio.h>
 #include <stdlib.h>
 #include <string.h>
@@ -35,19 +35,14 @@ static const char *testProjectExeData = NULL;
 static bool testContainerData = false;
 static unsigned int testIdxData = 0;
 static bool testTiming = true;
-static uint64_t testScaleData = 1;
 static const char *testPathData = NULL;
 static const char *testDataPathData = NULL;
 static const char *testRepoPathData = NULL;
 
-static char testUserIdData[32];
-static char testUserData[64];
-static char testGroupIdData[32];
-static char testGroupData[64];
-
 static struct HarnessTestLocal
 {
     uint64_t logLastBeginTime;                                      // Store the begin time of the last log for deltas
+    int logLastLineNo;                                              // Store the line number to be used in debugging
 
     struct HarnessTestResult
     {
@@ -71,8 +66,8 @@ Initialize harness
 ***********************************************************************************************************************************/
 void
 hrnInit(
-    const char *testExe, const char *testProjectExe, bool testContainer, unsigned int testIdx, bool timing, uint64_t testScale,
-    const char *testPath, const char *testDataPath, const char *testRepoPath)
+    const char *testExe, const char *testProjectExe, bool testContainer, unsigned int testIdx, bool timing, const char *testPath,
+    const char *testDataPath, const char *testRepoPath)
 {
     FUNCTION_HARNESS_VOID();
 
@@ -82,41 +77,10 @@ hrnInit(
     testContainerData = testContainer;
     testIdxData = testIdx;
     testTiming = timing;
-    testScaleData = testScale;
     testPathData = testPath;
     testDataPathData = testDataPath;
     testRepoPathData = testRepoPath;
 
-    // Set test user id
-    snprintf(testUserIdData, sizeof(testUserIdData), "%u", getuid());
-
-    // Set test user
-    const char *testUserTemp = getpwuid(getuid())->pw_name;
-
-    if (strlen(testUserTemp) > sizeof(testUserData) - 1)
-    {
-        fprintf(stderr, "ERROR: test user name must be less than %zu characters", sizeof(testUserData) - 1);
-        fflush(stderr);
-        exit(255);
-    }
-
-    strcpy(testUserData, testUserTemp);
-
-    // Set test group id
-    snprintf(testGroupIdData, sizeof(testGroupIdData), "%u", getgid());
-
-    // Set test group
-    const char *testGroupTemp = getgrgid(getgid())->gr_name;
-
-    if (strlen(testGroupTemp) > sizeof(testGroupData) - 1)
-    {
-        fprintf(stderr, "ERROR: test group name must be less than %zu characters", sizeof(testGroupData) - 1);
-        fflush(stderr);
-        exit(255);
-    }
-
-    strcpy(testGroupData, testGroupTemp);
-
     FUNCTION_HARNESS_RETURN_VOID();
 }
 
@@ -183,11 +147,11 @@ testBegin(const char *name)
             // Clear out the data directory so the next test starts clean
             snprintf(
                 buffer, sizeof(buffer), "%schmod -R 700 %s/" "* > /dev/null 2>&1;%srm -rf %s/" "*", testContainer() ? "sudo " : "",
-                testDataPath(), testContainer() ? "sudo " : "", testDataPath());
+                hrnPath(), testContainer() ? "sudo " : "", hrnPath());
 
             if (system(buffer) != 0)
             {
-                fprintf(stderr, "ERROR: unable to clear data path '%s'\n", testDataPath());
+                fprintf(stderr, "ERROR: unable to clear data path '%s'\n", hrnPath());
                 fflush(stderr);
                 exit(255);
             }
@@ -245,72 +209,6 @@ hrnComplete(void)
     FUNCTION_HARNESS_RETURN_VOID();
 }
 
-/***********************************************************************************************************************************
-Replace a substring with another string
-***********************************************************************************************************************************/
-static void
-hrnReplaceStr(char *string, size_t bufferSize, const char *substring, const char *replace)
-{
-    FUNCTION_HARNESS_BEGIN();
-        FUNCTION_HARNESS_PARAM(STRINGZ, string);
-        FUNCTION_HARNESS_PARAM(SIZE, bufferSize);
-        FUNCTION_HARNESS_PARAM(STRINGZ, substring);
-        FUNCTION_HARNESS_PARAM(STRINGZ, replace);
-    FUNCTION_HARNESS_END();
-
-    ASSERT(string != NULL);
-    ASSERT(substring != NULL);
-
-    // Find substring
-    char *begin = strstr(string, substring);
-
-    while (begin != NULL)
-    {
-        // Find end of substring and calculate replace size difference
-        char *end = begin + strlen(substring);
-        int diff = (int)strlen(replace) - (int)strlen(substring);
-
-        // Make sure we won't overflow the buffer
-        CHECK((size_t)((int)strlen(string) + diff) < bufferSize - 1);
-
-        // Move data from end of string enough to make room for the replacement and copy replacement
-        memmove(end + diff, end, strlen(end) + 1);
-        memcpy(begin, replace, strlen(replace));
-
-        // Find next substring
-        begin = strstr(begin + strlen(replace), substring);
-    }
-
-    FUNCTION_HARNESS_RETURN_VOID();
-}
-
-/**********************************************************************************************************************************/
-char harnessReplaceKeyBuffer[256 * 1024];
-
-const char *
-hrnReplaceKey(const char *string)
-{
-    FUNCTION_HARNESS_BEGIN();
-        FUNCTION_HARNESS_PARAM(STRINGZ, string);
-    FUNCTION_HARNESS_END();
-
-    ASSERT(string != NULL);
-
-    // Make sure we won't overflow the buffer
-    ASSERT(strlen(string) < sizeof(harnessReplaceKeyBuffer) - 1);
-
-    strcpy(harnessReplaceKeyBuffer, string);
-    hrnReplaceStr(harnessReplaceKeyBuffer, sizeof(harnessReplaceKeyBuffer), "{[path]}", testPath());
-    hrnReplaceStr(harnessReplaceKeyBuffer, sizeof(harnessReplaceKeyBuffer), "{[path-data]}", testDataPath());
-    hrnReplaceStr(harnessReplaceKeyBuffer, sizeof(harnessReplaceKeyBuffer), "{[user-id]}", testUserIdData);
-    hrnReplaceStr(harnessReplaceKeyBuffer, sizeof(harnessReplaceKeyBuffer), "{[user]}", testUser());
-    hrnReplaceStr(harnessReplaceKeyBuffer, sizeof(harnessReplaceKeyBuffer), "{[group-id]}", testGroupIdData);
-    hrnReplaceStr(harnessReplaceKeyBuffer, sizeof(harnessReplaceKeyBuffer), "{[group]}", testGroup());
-    hrnReplaceStr(harnessReplaceKeyBuffer, sizeof(harnessReplaceKeyBuffer), "{[project-exe]}", testProjectExe());
-
-    FUNCTION_HARNESS_RETURN(STRINGZ, harnessReplaceKeyBuffer);
-}
-
 /**********************************************************************************************************************************/
 void
 hrnFileRead(const char *fileName, unsigned char *buffer, size_t bufferSize)
@@ -376,17 +274,17 @@ hrnDiff(const char *expected, const char *actual)
 
     // Write expected file
     char expectedFile[1024];
-    snprintf(expectedFile, sizeof(expectedFile), "%s/diff.expected", testDataPath());
+    snprintf(expectedFile, sizeof(expectedFile), "%s/diff.expected", hrnPath());
     hrnFileWrite(expectedFile, (unsigned char *)expected, strlen(expected));
 
     // Write actual file
     char actualFile[1024];
-    snprintf(actualFile, sizeof(actualFile), "%s/diff.actual", testDataPath());
+    snprintf(actualFile, sizeof(actualFile), "%s/diff.actual", hrnPath());
     hrnFileWrite(actualFile, (unsigned char *)actual, strlen(actual));
 
     // Perform diff
     char command[2560];
-    snprintf(command, sizeof(command), "diff -u %s %s > %s/diff.result", expectedFile, actualFile, testDataPath());
+    snprintf(command, sizeof(command), "diff -u %s %s > %s/diff.result", expectedFile, actualFile, hrnPath());
 
     if (system(command) == 2)
     {
@@ -397,7 +295,7 @@ hrnDiff(const char *expected, const char *actual)
 
     // Read result
     char resultFile[1024];
-    snprintf(resultFile, sizeof(resultFile), "%s/diff.result", testDataPath());
+    snprintf(resultFile, sizeof(resultFile), "%s/diff.result", hrnPath());
     hrnFileRead(resultFile, (unsigned char *)harnessDiffBuffer, sizeof(harnessDiffBuffer));
 
     // Remove last linefeed from diff output
@@ -421,7 +319,7 @@ hrnTestLogTitle(int lineNo)
         putchar('-');
 
     // Output line number
-    printf(" l%04d", lineNo);
+    printf(" L%04d", lineNo);
 
     // Increment testSub and reset log time
     testRunSub++;
@@ -429,11 +327,10 @@ hrnTestLogTitle(int lineNo)
 
 /**********************************************************************************************************************************/
 void
-hrnTestLogPrefix(int lineNo, bool padding)
+hrnTestLogPrefix(const int lineNo)
 {
     FUNCTION_HARNESS_BEGIN();
         FUNCTION_HARNESS_PARAM(INT, lineNo);
-        FUNCTION_HARNESS_PARAM(BOOL, padding);
     FUNCTION_HARNESS_END();
 
     // Always indent at the beginning
@@ -462,26 +359,48 @@ hrnTestLogPrefix(int lineNo, bool padding)
         harnessTestLocal.logLastBeginTime = currentTime;
     }
 
+    // Store line number for
+    harnessTestLocal.logLastLineNo = lineNo;
+
     // Add line number and padding
-    printf("l%04d %s", lineNo, padding ? "    " : "");
+    printf("L%04d     ", lineNo);
+    fflush(stdout);
 
     FUNCTION_HARNESS_RETURN_VOID();
 }
 
 /**********************************************************************************************************************************/
 void
-hrnTestResultBegin(const char *statement, int lineNo, bool result)
+hrnTestResultBegin(const char *const statement, const bool result)
 {
     ASSERT(!harnessTestLocal.result.running);
+    ASSERT(harnessTestLocal.logLastLineNo != 0);
 
     // Set the line number for the current function in the stack trace
-    FUNCTION_HARNESS_STACK_TRACE_LINE_SET(lineNo);
+    FUNCTION_HARNESS_STACK_TRACE_LINE_SET(harnessTestLocal.logLastLineNo);
 
     // Set info to report if an error is thrown
     harnessTestLocal.result =
-        (struct HarnessTestResult){.running = true, .statement = statement, .lineNo = lineNo, .result = result};
+        (struct HarnessTestResult){
+            .running = true, .statement = statement, .lineNo = harnessTestLocal.logLastLineNo, .result = result};
+
+    // Reset line number so it is not used by another test
+    harnessTestLocal.logLastLineNo = 0;
 }
 
+/**********************************************************************************************************************************/
+void
+hrnTestResultComment(const char *const comment)
+{
+    if (comment != NULL)
+        printf(" (%s)\n", comment);
+    else
+        puts("");
+
+    fflush(stdout);
+}
+
+/**********************************************************************************************************************************/
 bool
 hrnTestResultException(void)
 {
@@ -490,7 +409,7 @@ hrnTestResultException(void)
     if (harnessTestLocal.result.running)
     {
         THROW_FMT(
-#ifndef NDEBUG
+#ifdef DEBUG
             TestError,
 #else
             AssertError,
@@ -520,7 +439,7 @@ static void hrnTestResultDiff(const char *actual, const char *expected)
     if (actual != NULL && expected != NULL && (strstr(actual, "\n") != NULL || strstr(expected, "\n") != NULL))
     {
         THROW_FMT(
-#ifndef NDEBUG
+#ifdef DEBUG
             TestError,
 #else
             AssertError,
@@ -531,7 +450,7 @@ static void hrnTestResultDiff(const char *actual, const char *expected)
     else
     {
         THROW_FMT(
-#ifndef NDEBUG
+#ifdef DEBUG
             TestError,
 #else
             AssertError,
@@ -653,7 +572,7 @@ hrnTestResultPtr(const void *actual, const void *expected, HarnessTestResultOper
 #ifdef HRN_FEATURE_STRING
 
 void
-hrnTestResultStringList(const StringList *actual, const void *expected, HarnessTestResultOperation operation)
+hrnTestResultStringList(const StringList *actual, const char *expected, HarnessTestResultOperation operation)
 {
     // Return NULL if list is empty
     if (strLstEmpty(actual))
@@ -778,14 +697,6 @@ testIdx(void)
     FUNCTION_HARNESS_RETURN(UINT, testIdxData);
 }
 
-/**********************************************************************************************************************************/
-uint64_t
-testScale(void)
-{
-    FUNCTION_HARNESS_VOID();
-    FUNCTION_HARNESS_RETURN(UINT64, testScaleData);
-}
-
 /**********************************************************************************************************************************/
 const char *
 testPath(void)
@@ -796,7 +707,7 @@ testPath(void)
 
 /**********************************************************************************************************************************/
 const char *
-testDataPath(void)
+hrnPath(void)
 {
     FUNCTION_HARNESS_VOID();
     FUNCTION_HARNESS_RETURN(STRINGZ, testDataPathData);
@@ -804,26 +715,12 @@ testDataPath(void)
 
 /**********************************************************************************************************************************/
 const char *
-testRepoPath(void)
+hrnPathRepo(void)
 {
     FUNCTION_HARNESS_VOID();
     FUNCTION_HARNESS_RETURN(STRINGZ, testRepoPathData);
 }
 
-/**********************************************************************************************************************************/
-const char *
-testUser(void)
-{
-    return testUserData;
-}
-
-/**********************************************************************************************************************************/
-const char *
-testGroup(void)
-{
-    return testGroupData;
-}
-
 /**********************************************************************************************************************************/
 uint64_t
 testTimeMSec(void)
