@@ -1,21 +1,46 @@
 /***********************************************************************************************************************************
 Test Help Command
 ***********************************************************************************************************************************/
+#include "config/load.h"
 #include "config/parse.h"
+#include "storage/helper.h"
 #include "storage/posix/storage.h"
-#include "storage/storage.h"
 #include "version.h"
 
 #include "common/harnessConfig.h"
+#include "common/harnessStorage.h"
+
+/***********************************************************************************************************************************
+Configuration load with just enough funcionality to test help
+***********************************************************************************************************************************/
+static void
+testCfgLoad(const StringList *const argList)
+{
+    FUNCTION_HARNESS_BEGIN();
+        FUNCTION_HARNESS_PARAM(STRING_LIST, argList);
+    FUNCTION_HARNESS_END();
+
+    // Parse config
+    configParse(storageLocal(), strLstSize(argList), strLstPtr(argList), false);
+
+    // Apply special option rules
+    cfgLoadUpdateOption();
+
+    FUNCTION_HARNESS_RETURN_VOID();
+}
 
 /***********************************************************************************************************************************
 Test Run
 ***********************************************************************************************************************************/
-void
+static void
 testRun(void)
 {
     FUNCTION_HARNESS_VOID();
 
+    // Create help data
+    const BldCfg bldCfg = bldCfgParse(storagePosixNewP(HRN_PATH_REPO_STR));
+    const Buffer *const helpData = bldHlpRenderHelpAutoCCmp(bldCfg, bldHlpParse(storagePosixNewP(HRN_PATH_REPO_STR), bldCfg));
+
     // Program name a version are used multiple times
     const char *helpVersion = PROJECT_NAME " " PROJECT_VERSION;
 
@@ -37,6 +62,8 @@ testRun(void)
         "    repo-get        Get a file from a repository.\n"
         "    repo-ls         List files in a repository.\n"
         "    restore         Restore a database cluster.\n"
+        "    server          pgBackRest server.\n"
+        "    server-ping     Ping pgBackRest server.\n"
         "    stanza-create   Create the required stanza data.\n"
         "    stanza-delete   Delete a stanza.\n"
         "    stanza-upgrade  Upgrade a stanza.\n"
@@ -47,37 +74,51 @@ testRun(void)
         "Use 'pgbackrest help [command]' for more information.\n",
         helpVersion));
 
+    // *****************************************************************************************************************************
+    if (testBegin("helpRenderSplitSize()"))
+    {
+        TEST_RESULT_STRLST_Z(helpRenderSplitSize(STRDEF("abc def"), " ", 3), "abc\ndef\n", "two items");
+        TEST_RESULT_STRLST_Z(helpRenderSplitSize(STRDEF("abc def"), " ", 4), "abc\ndef\n", "two items, size > each item");
+        TEST_RESULT_STRLST_Z(helpRenderSplitSize(STRDEF("abc def ghi"), " ", 4), "abc\ndef\nghi\n", "three items");
+        TEST_RESULT_STRLST_Z(helpRenderSplitSize(STRDEF("abc def ghi"), " ", 8), "abc def\nghi\n", "three items, size > first two");
+        TEST_RESULT_STRLST_Z(helpRenderSplitSize(STRDEF("abc def "), " ", 4), "abc\ndef \n", "two items, size includes space");
+        TEST_RESULT_STRLST_Z(helpRenderSplitSize(STRDEF(""), " ", 1), "\n", "empty list");
+
+        TEST_RESULT_STRLST_Z(
+            helpRenderSplitSize(STRDEF("this is a short sentence"), " ", 10),
+            "this is a\n"
+            "short\n"
+            "sentence\n",
+            "variable word sizes");
+    }
+
     // *****************************************************************************************************************************
     if (testBegin("helpRenderText()"))
     {
-        TEST_RESULT_STR_Z(helpRenderText(strNew("this is a short sentence"), 0, false, 80), "this is a short sentence", "one line");
+        TEST_RESULT_STR_Z(
+            helpRenderText(STRDEF("this is a short sentence"), false, 0, false, 80), "this is a short sentence", "one line");
 
         TEST_RESULT_STR_Z(
-            helpRenderText(strNew("this is a short sentence"), 4, false, 14),
+            helpRenderText(STRDEF("this is a short sentence"), false, 4, false, 14),
             "this is a\n"
             "    short\n"
             "    sentence",
             "three lines, no indent first");
 
         TEST_RESULT_STR_Z(
-            helpRenderText(strNew("This is a short paragraph.\n\nHere is another one."), 2, true, 16),
+            helpRenderText(STRDEF("This is a short paragraph.\n\nHere is another one."), true, 2, true, 16),
             "  This is a\n"
             "  short\n"
             "  paragraph.\n"
             "\n"
             "  Here is\n"
-            "  another one.",
-            "two paragraphs, indent first");
-    }
-
-    // *****************************************************************************************************************************
-    if (testBegin("helpRenderValue()"))
-    {
-        TEST_RESULT_STR_Z(helpRenderValue(varNewBool(true), cfgOptTypeBoolean), "y", "boolean y");
-        TEST_RESULT_STR_Z(helpRenderValue(varNewBool(false), cfgOptTypeBoolean), "n", "boolean n");
-        TEST_RESULT_STR_Z(helpRenderValue(varNewStrZ("test-string"), cfgOptTypeString), "test-string", "string");
-        TEST_RESULT_STR_Z(helpRenderValue(varNewInt64(1234), cfgOptTypeInteger), "1234", "int");
-        TEST_RESULT_STR_Z(helpRenderValue(varNewInt64(1234000), cfgOptTypeTime), "1234", "time");
+            "  another one.\n"
+            "\n"
+            "  FOR INTERNAL\n"
+            "  USE ONLY. DO\n"
+            "  NOT USE IN\n"
+            "  PRODUCTION.",
+            "two paragraphs, indent first, internal");
     }
 
     // *****************************************************************************************************************************
@@ -86,18 +127,22 @@ testRun(void)
         StringList *argList = NULL;
 
         // -------------------------------------------------------------------------------------------------------------------------
+        TEST_TITLE("general invocation");
+
         argList = strLstNew();
         strLstAddZ(argList, "/path/to/pgbackrest");
-        TEST_RESULT_VOID(harnessCfgLoadRaw(strLstSize(argList), strLstPtr(argList)), "help from empty command line");
-        TEST_RESULT_STR_Z(helpRender(), generalHelp, "    check text");
+        TEST_RESULT_VOID(testCfgLoad(argList), "help from empty command line");
+        TEST_RESULT_STR_Z(helpRender(helpData), generalHelp, "check text");
 
         argList = strLstNew();
         strLstAddZ(argList, "/path/to/pgbackrest");
         strLstAddZ(argList, "help");
-        TEST_RESULT_VOID(harnessCfgLoadRaw(strLstSize(argList), strLstPtr(argList)), "help from help command");
-        TEST_RESULT_STR_Z(helpRender(), generalHelp, "    check text");
+        TEST_RESULT_VOID(testCfgLoad(argList), "help from help command");
+        TEST_RESULT_STR_Z(helpRender(helpData), generalHelp, "check text");
 
         // -------------------------------------------------------------------------------------------------------------------------
+        TEST_TITLE("version command");
+
         const char *commandHelp = strZ(strNewFmt(
             "%s%s",
             helpVersion,
@@ -111,11 +156,13 @@ testRun(void)
         strLstAddZ(argList, "/path/to/pgbackrest");
         strLstAddZ(argList, "help");
         strLstAddZ(argList, "version");
-        TEST_RESULT_VOID(harnessCfgLoadRaw(strLstSize(argList), strLstPtr(argList)), "help for version command");
-        TEST_RESULT_STR_Z(helpRender(), commandHelp, "    check text");
+        TEST_RESULT_VOID(testCfgLoad(argList), "help for version command");
+        TEST_RESULT_STR_Z(helpRender(helpData), commandHelp, "check text");
 
         // This test is broken up into multiple strings because C99 does not require compilers to support const strings > 4095 bytes
         // -------------------------------------------------------------------------------------------------------------------------
+        TEST_TITLE("restore command");
+
         commandHelp = strZ(strNewFmt(
             "%s%s%s",
             helpVersion,
@@ -130,17 +177,19 @@ testRun(void)
             "specific repository, the --repo option can be passed (e.g. --repo=1). The --set\n"
             "option can be passed if a backup other than the latest is desired.\n"
             "\n"
-            "For PITR, --type=time must be provided and the target time specified with the\n"
-            "--target option. If a backup is not specified via the --set option, then the\n"
-            "configured repositories will be checked, in order, for a backup that contains\n"
-            "the requested time. If no backup can be found, the latest backup from the first\n"
-            "repository containing backups will be used. See Point-in-Time Recovery for more\n"
-            "details and examples.\n"
+            "When PITR of --type=time is specified, then the target time must be specified\n"
+            "with the --target option. If a backup is not specified via the --set option,\n"
+            "then the configured repositories will be checked, in order, for a backup that\n"
+            "contains the requested time. If no backup can be found, the latest backup from\n"
+            "the first repository containing backups will be used. For other types of PITR,\n"
+            "e.g. xid, the --set option must be provided if the target is prior to the\n"
+            "latest backup. See Point-in-Time Recovery for more details and examples.\n"
             "\n"
             "Command Options:\n"
             "\n"
             "  --archive-mode                   preserve or disable archiving on restored\n"
             "                                   cluster [default=preserve]\n"
+            "  --db-exclude                     restore excluding the specified databases\n"
             "  --db-include                     restore only specified databases\n"
             "                                   [current=db1, db2]\n"
             "  --force                          force a restore [default=n]\n"
@@ -163,9 +212,11 @@ testRun(void)
             "\n"
             "General Options:\n"
             "\n"
-            "  --buffer-size                    buffer size for file operations\n"
-            "                                   [current=32768, default=1048576]\n"
-            "  --cmd-ssh                        path to ssh client executable [default=ssh]\n"
+            "  --buffer-size                    buffer size for I/O operations\n"
+            "                                   [current=32768, default=1MiB]\n"
+            "  --cmd                            pgBackRest command\n"
+            "                                   [default=/path/to/pgbackrest]\n"
+            "  --cmd-ssh                        SSH client command [default=ssh]\n"
             "  --compress-level-network         network compression level [default=3]\n"
             "  --config                         pgBackRest configuration file\n"
             "                                   [default=/etc/pgbackrest/pgbackrest.conf]\n"
@@ -174,7 +225,7 @@ testRun(void)
             "  --config-path                    base path of pgBackRest configuration files\n"
             "                                   [default=/etc/pgbackrest]\n"
             "  --delta                          restore or backup using checksums [default=n]\n"
-            "  --io-timeout                     i/O timeout [default=60]\n"
+            "  --io-timeout                     I/O timeout [default=60]\n"
             "  --lock-path                      path where lock files are stored\n"
             "                                   [default=/tmp/pgbackrest]\n"
             "  --neutral-umask                  use a neutral umask [default=y]\n"
@@ -206,6 +257,7 @@ testRun(void)
             "                                   [default=blob.core.windows.net]\n"
             "  --repo-azure-key                 azure repository key\n"
             "  --repo-azure-key-type            azure repository key type [default=shared]\n"
+            "  --repo-azure-uri-style           azure URI Style [default=host]\n"
             "  --repo-cipher-pass               repository cipher passphrase\n"
             "                                   [current=<redacted>]\n"
             "  --repo-cipher-type               cipher used to encrypt the repository\n"
@@ -217,7 +269,10 @@ testRun(void)
             "  --repo-gcs-key-type              GCS repository key type [default=service]\n"
             "  --repo-host                      repository host when operating remotely via\n"
             "                                   SSH [current=backup.example.net]\n"
-            "  --repo-host-cmd                  pgBackRest exe path on the repository host\n"
+            "  --repo-host-ca-file              repository host certificate authority file\n"
+            "  --repo-host-ca-path              repository host certificate authority path\n"
+            "  --repo-host-cert-file            repository host certificate file\n"
+            "  --repo-host-cmd                  repository host pgBackRest command\n"
             "                                   [default=/path/to/pgbackrest]\n"
             "  --repo-host-config               pgBackRest repository host configuration\n"
             "                                   file\n"
@@ -226,7 +281,9 @@ testRun(void)
             "                                   include path [default=/etc/pgbackrest/conf.d]\n"
             "  --repo-host-config-path          pgBackRest repository host configuration\n"
             "                                   path [default=/etc/pgbackrest]\n"
+            "  --repo-host-key-file             repository host key file\n"
             "  --repo-host-port                 repository host port when repo-host is set\n"
+            "  --repo-host-type                 repository host protocol type [default=ssh]\n"
             "  --repo-host-user                 repository host user when repo-host is set\n"
             "                                   [default=pgbackrest]\n"
             "  --repo-path                      path where backups and archive are stored\n"
@@ -259,52 +316,65 @@ testRun(void)
         strLstAddZ(argList, "/path/to/pgbackrest");
         strLstAddZ(argList, "help");
         strLstAddZ(argList, "restore");
-        strLstAddZ(argList, "--buffer-size=32768");
-        strLstAddZ(argList, "--repo1-cipher-type=aes-256-cbc");
-        setenv("PGBACKREST_REPO1_CIPHER_PASS", "supersecret", true);
-        strLstAddZ(argList, "--repo1-host=backup.example.net");
-        strLstAddZ(argList, "--link-map=/link1=/dest1");
-        strLstAddZ(argList, "--link-map=/link2=/dest2");
-        strLstAddZ(argList, "--db-include=db1");
-        strLstAddZ(argList, "--db-include=db2");
-        TEST_RESULT_VOID(harnessCfgLoadRaw(strLstSize(argList), strLstPtr(argList)), "help for restore command");
-        unsetenv("PGBACKREST_REPO1_CIPHER_PASS");
-        TEST_RESULT_STR_Z(helpRender(), commandHelp, "    check text");
+        hrnCfgArgRawZ(argList, cfgOptBufferSize, "32768");
+        hrnCfgArgRawZ(argList, cfgOptRepoCipherType, "aes-256-cbc");
+        hrnCfgEnvRawZ(cfgOptRepoCipherPass, TEST_CIPHER_PASS);
+        hrnCfgArgRawZ(argList, cfgOptRepoHost, "backup.example.net");
+        hrnCfgArgRawZ(argList, cfgOptLinkMap, "/link1=/dest1");
+        hrnCfgArgRawZ(argList, cfgOptLinkMap, "/link2=/dest2");
+        hrnCfgArgRawZ(argList, cfgOptDbInclude, "db1");
+        hrnCfgArgRawZ(argList, cfgOptDbInclude, "db2");
+        TEST_RESULT_VOID(testCfgLoad(argList), "help for restore command");
+        TEST_RESULT_STR_Z(helpRender(helpData), commandHelp, "check text");
+        hrnCfgEnvRemoveRaw(cfgOptRepoCipherPass);
 
         // -------------------------------------------------------------------------------------------------------------------------
+        TEST_TITLE("errors with specified options");
+
         argList = strLstNew();
         strLstAddZ(argList, "/path/to/pgbackrest");
         strLstAddZ(argList, "help");
         strLstAddZ(argList, "archive-push");
         strLstAddZ(argList, "buffer-size");
         strLstAddZ(argList, "buffer-size");
-        TEST_RESULT_VOID(harnessCfgLoadRaw(strLstSize(argList), strLstPtr(argList)), "parse too many options");
-        TEST_ERROR(helpRender(), ParamInvalidError, "only one option allowed for option help");
+        TEST_RESULT_VOID(testCfgLoad(argList), "parse too many options");
+        TEST_ERROR(helpRender(helpData), ParamInvalidError, "only one option allowed for option help");
 
         argList = strLstNew();
         strLstAddZ(argList, "/path/to/pgbackrest");
         strLstAddZ(argList, "help");
         strLstAddZ(argList, "archive-push");
         strLstAddZ(argList, BOGUS_STR);
-        TEST_RESULT_VOID(harnessCfgLoadRaw(strLstSize(argList), strLstPtr(argList)), "parse bogus option");
-        TEST_ERROR(helpRender(), OptionInvalidError, "option 'BOGUS' is not valid for command 'archive-push'");
+        TEST_RESULT_VOID(testCfgLoad(argList), "parse bogus option");
+        TEST_ERROR(helpRender(helpData), OptionInvalidError, "option 'BOGUS' is not valid for command 'archive-push'");
+
+        argList = strLstNew();
+        strLstAddZ(argList, "/path/to/pgbackrest");
+        strLstAddZ(argList, CFGCMD_HELP);
+        strLstAddZ(argList, CFGCMD_ARCHIVE_PUSH);
+        strLstAddZ(argList, CFGOPT_PROCESS);
+        TEST_RESULT_VOID(testCfgLoad(argList), "parse option invalid for command");
+        TEST_ERROR(helpRender(helpData), OptionInvalidError, "option 'process' is not valid for command 'archive-push'");
 
         // -------------------------------------------------------------------------------------------------------------------------
+        TEST_TITLE("default and current option value");
+
         const char *optionHelp = strZ(strNewFmt(
             "%s - 'archive-push' command - 'buffer-size' option help\n"
             "\n"
-            "Buffer size for file operations.\n"
+            "Buffer size for I/O operations.\n"
             "\n"
-            "Set the buffer size used for copy, compress, and uncompress functions. A\n"
-            "maximum of 3 buffers will be in use at a time per process. An additional\n"
-            "maximum of 256K per process may be used for zlib buffers.\n"
+            "Buffer size used for copy, compress, encrypt, and other operations. The number\n"
+            "of buffers used depends on options and each operation may use additional\n"
+            "memory, e.g. gz compression may use an additional 256KiB of memory.\n"
             "\n"
-            "Size can be entered in bytes (default) or KB, MB, GB, TB, or PB where the\n"
-            "multiplier is a power of 1024. For example, the case-insensitive value 32k (or\n"
-            "32KB) can be used instead of 32768.\n"
+            "Size can be entered in bytes (default) or KiB, MiB, GiB, TiB, or PiB where the\n"
+            "multiplier is a power of 1024. For example, the case-insensitive value 5GiB (or\n"
+            "5GB, 5g) can be used instead of 5368709120. Fractional values such as 2.5GiB\n"
+            "are not allowed, use 2560MiB instead.\n"
             "\n"
-            "Allowed values, in bytes, are 16384, 32768, 65536, 131072, 262144, 524288,\n"
-            "1048576, 2097152, 4194304, 8388608, and 16777216.\n",
+            "Allowed values are 16KiB, 32KiB, 64KiB, 128KiB, 256KiB, 512KiB, 1MiB, 2MiB,\n"
+            "4MiB, 8MiB, and 16MiB.\n",
             helpVersion));
 
         argList = strLstNew();
@@ -312,16 +382,18 @@ testRun(void)
         strLstAddZ(argList, "help");
         strLstAddZ(argList, "archive-push");
         strLstAddZ(argList, "buffer-size");
-        TEST_RESULT_VOID(
-            harnessCfgLoadRaw(strLstSize(argList), strLstPtr(argList)), "help for archive-push command, buffer-size option");
-        TEST_RESULT_STR(helpRender(), strNewFmt("%s\ndefault: 1048576\n", optionHelp), "    check text");
+        TEST_RESULT_VOID(testCfgLoad(argList), "help for archive-push command, buffer-size option");
+        TEST_RESULT_STR(helpRender(helpData), strNewFmt("%s\ndefault: 1MiB\n", optionHelp), "check text");
 
-        strLstAddZ(argList, "--buffer-size=32768");
-        TEST_RESULT_VOID(
-            harnessCfgLoadRaw(strLstSize(argList), strLstPtr(argList)), "help for archive-push command, buffer-size option");
-        TEST_RESULT_STR(helpRender(), strNewFmt("%s\ncurrent: 32768\ndefault: 1048576\n", optionHelp), "    check text");
+        // Set a current value
+        hrnCfgArgRawZ(argList, cfgOptBufferSize, "32k");
+        TEST_RESULT_VOID(testCfgLoad(argList), "help for archive-push command, buffer-size option");
+        TEST_RESULT_STR(
+            helpRender(helpData), strNewFmt("%s\ncurrent: 32k\ndefault: 1MiB\n", optionHelp), "check text, current value");
 
         // -------------------------------------------------------------------------------------------------------------------------
+        TEST_TITLE("deprecated host option names");
+
         #define HELP_OPTION                                                                                                        \
             "%s - 'archive-push' command - 'repo-storage-host' option help\n"                                                      \
             "\n"                                                                                                                   \
@@ -344,9 +416,8 @@ testRun(void)
         strLstAddZ(argList, "help");
         strLstAddZ(argList, "archive-push");
         strLstAddZ(argList, "repo1-s3-host");
-        TEST_RESULT_VOID(
-            harnessCfgLoadRaw(strLstSize(argList), strLstPtr(argList)), "help for archive-push command, repo1-s3-host option");
-        TEST_RESULT_STR_Z(helpRender(), optionHelp, "    check text");
+        TEST_RESULT_VOID(testCfgLoad(argList), "help for archive-push command, repo1-s3-host option");
+        TEST_RESULT_STR_Z(helpRender(helpData), optionHelp, "check text");
 
         optionHelp = strZ(strNewFmt(
             HELP_OPTION
@@ -355,13 +426,15 @@ testRun(void)
             HELP_OPTION_DEPRECATED_NAMES,
             helpVersion));
 
-        strLstAddZ(argList, "--repo1-type=s3");
+        // Set a current value for deprecated option name
+        hrnCfgArgRawZ(argList, cfgOptRepoType, "s3");
         strLstAddZ(argList, "--repo1-s3-host=s3-host");
-        TEST_RESULT_VOID(
-            harnessCfgLoadRaw(strLstSize(argList), strLstPtr(argList)), "help for archive-push command, repo1-s3-host option");
-        TEST_RESULT_STR_Z(helpRender(), optionHelp, "    check text");
+        TEST_RESULT_VOID(testCfgLoad(argList), "help for archive-push command, repo1-s3-host option");
+        TEST_RESULT_STR_Z(helpRender(helpData), optionHelp, "check text, current value");
 
         // -------------------------------------------------------------------------------------------------------------------------
+        TEST_TITLE("cipher pass redacted");
+
         optionHelp = strZ(strNewFmt(
             "%s - 'archive-push' command - 'repo-cipher-pass' option help\n"
             "\n"
@@ -375,16 +448,17 @@ testRun(void)
         argList = strLstNew();
         strLstAddZ(argList, "/path/to/pgbackrest");
         strLstAddZ(argList, "help");
-        strLstAddZ(argList, "--repo1-cipher-type=aes-256-cbc");
-        setenv("PGBACKREST_REPO1_CIPHER_PASS", "supersecret", true);
+        hrnCfgArgRawZ(argList, cfgOptRepoCipherType, "aes-256-cbc");
+        hrnCfgEnvRawZ(cfgOptRepoCipherPass, TEST_CIPHER_PASS);
         strLstAddZ(argList, "archive-push");
         strLstAddZ(argList, "repo-cipher-pass");
-        TEST_RESULT_VOID(
-            harnessCfgLoadRaw(strLstSize(argList), strLstPtr(argList)), "help for archive-push command, repo1-s3-host option");
-        unsetenv("PGBACKREST_REPO1_CIPHER_PASS");
-        TEST_RESULT_STR_Z(helpRender(), optionHelp, "    check text");
+        TEST_RESULT_VOID(testCfgLoad(argList), "help for archive-push command, repo1-s3-host option");
+        TEST_RESULT_STR_Z(helpRender(helpData), optionHelp, "check text");
+        hrnCfgEnvRemoveRaw(cfgOptRepoCipherPass);
 
         // -------------------------------------------------------------------------------------------------------------------------
+        TEST_TITLE("deprecated and new option name produce same results");
+
         optionHelp = strZ(strNewFmt(
             "%s - 'backup' command - 'repo-hardlink' option help\n"
             "\n"
@@ -405,21 +479,20 @@ testRun(void)
         strLstAddZ(argList, "help");
         strLstAddZ(argList, "backup");
         strLstAddZ(argList, "repo-hardlink");
-        TEST_RESULT_VOID(
-            harnessCfgLoadRaw(strLstSize(argList), strLstPtr(argList)), "help for backup command, repo-hardlink option");
-        TEST_RESULT_STR_Z(helpRender(), optionHelp, "    check text");
+        TEST_RESULT_VOID(testCfgLoad(argList), "help for backup command, repo-hardlink option");
+        TEST_RESULT_STR_Z(helpRender(helpData), optionHelp, "check text");
 
         argList = strLstNew();
         strLstAddZ(argList, "/path/to/pgbackrest");
         strLstAddZ(argList, "help");
         strLstAddZ(argList, "backup");
         strLstAddZ(argList, "hardlink");
-        TEST_RESULT_VOID(
-            harnessCfgLoadRaw(strLstSize(argList), strLstPtr(argList)), "help for backup command, deprecated hardlink option");
-        TEST_RESULT_STR_Z(helpRender(), optionHelp, "    check text");
+        TEST_RESULT_VOID(testCfgLoad(argList), "help for backup command, deprecated hardlink option");
+        TEST_RESULT_STR_Z(helpRender(helpData), optionHelp, "check text");
 
-        // Check admonition
         // -------------------------------------------------------------------------------------------------------------------------
+        TEST_TITLE("check admonition");
+
         optionHelp = strZ(strNewFmt(
             "%s - 'backup' command - 'repo-retention-archive' option help\n"
             "\n"
@@ -450,32 +523,30 @@ testRun(void)
         strLstAddZ(argList, "help");
         strLstAddZ(argList, "backup");
         strLstAddZ(argList, "repo-retention-archive");
-        TEST_RESULT_VOID(
-            harnessCfgLoadRaw(strLstSize(argList), strLstPtr(argList)), "help for backup command, repo-retention-archive option");
-        TEST_RESULT_STR_Z(helpRender(), optionHelp, "    check admonition text");
+        TEST_RESULT_VOID(testCfgLoad(argList), "help for backup command, repo-retention-archive option");
+        TEST_RESULT_STR_Z(helpRender(helpData), optionHelp, "check admonition text");
     }
 
     // *****************************************************************************************************************************
-    if (testBegin("cmdHelp()"))
+    if (testBegin("cmdHelp() to file"))
     {
         StringList *argList = strLstNew();
         strLstAddZ(argList, "/path/to/pgbackrest");
-        TEST_RESULT_VOID(harnessCfgLoadRaw(strLstSize(argList), strLstPtr(argList)), "parse help from empty command line");
+        TEST_RESULT_VOID(testCfgLoad(argList), "parse help from empty command line");
 
         // Redirect stdout to a file
         int stdoutSave = dup(STDOUT_FILENO);
-        String *stdoutFile = strNewFmt("%s/stdout.help", testPath());
 
-        THROW_ON_SYS_ERROR(freopen(strZ(stdoutFile), "w", stdout) == NULL, FileWriteError, "unable to reopen stdout");
+        THROW_ON_SYS_ERROR(freopen(TEST_PATH "/stdout.help", "w", stdout) == NULL, FileWriteError, "unable to reopen stdout");
 
         // Not in a test wrapper to avoid writing to stdout
-        cmdHelp();
+        cmdHelp(helpData);
 
         // Restore normal stdout
         dup2(stdoutSave, STDOUT_FILENO);
 
-        Storage *storage = storagePosixNewP(strNew(testPath()));
-        TEST_RESULT_STR_Z(strNewBuf(storageGetP(storageNewReadP(storage, stdoutFile))), generalHelp, "    check text");
+        Storage *storage = storagePosixNewP(TEST_PATH_STR);
+        TEST_STORAGE_GET(storage, TEST_PATH "/stdout.help", generalHelp, .comment = "check text sent to file");
     }
 
     FUNCTION_HARNESS_RETURN_VOID();
