@@ -19,11 +19,11 @@ ERROR_DEFINE(200, TestChildError, TestParent2Error);
 /***********************************************************************************************************************************
 testTryRecurse - test to blow up try stack
 ***********************************************************************************************************************************/
-volatile int testTryRecurseTotal = 0;
-bool testTryRecurseCatch = false;
-bool testTryRecurseFinally = false;
+static volatile int testTryRecurseTotal = 0;
+static bool testTryRecurseCatch = false;
+static bool testTryRecurseFinally = false;
 
-void
+static void
 testTryRecurse(void)
 {
     TRY_BEGIN()
@@ -58,7 +58,7 @@ testErrorHandler(unsigned int tryDepth)
 /***********************************************************************************************************************************
 Test Run
 ***********************************************************************************************************************************/
-void
+static void
 testRun(void)
 {
     FUNCTION_HARNESS_VOID();
@@ -96,7 +96,7 @@ testRun(void)
         }
         FINALLY()
         {
-            assert(errorContext.tryList[1].state == errorStateFinal);
+            assert(errorContext.tryList[1].state == errorStateTry);
             finallyDone = true;
         }
         TRY_END();
@@ -107,6 +107,22 @@ testRun(void)
         assert(errorContext.tryTotal == 0);
     }
 
+    // *****************************************************************************************************************************
+    if (testBegin("errorInternalThrow()"))
+    {
+        TEST_TITLE("specify all parameters");
+
+        TRY_BEGIN()
+        {
+            errorInternalThrow(&FormatError, "file77", "function88", 99, "message100", "stacktrace200");
+        }
+        CATCH_ANY()
+        {
+            assert(errorType() == &FormatError);
+        }
+        TRY_END();
+    }
+
     // *****************************************************************************************************************************
     if (testBegin("TRY with multiple catches"))
     {
@@ -143,7 +159,7 @@ testRun(void)
                         assert(errorTryDepth() == 4);
                         tryDone = true;
 
-                        char bigMessage[sizeof(messageBuffer) * 32];
+                        char bigMessage[sizeof(messageBuffer) + 128];
                         memset(bigMessage, 'A', sizeof(bigMessage));
 
                         THROW(AssertError, bigMessage);
@@ -179,7 +195,7 @@ testRun(void)
         {
             assert(testErrorHandlerTryDepth == 1);
             assert(errorTryDepth() == 1);
-            assert(errorContext.tryList[1].state == errorStateCatch);
+            assert(errorContext.tryList[1].state == errorStateEnd);
             assert(strlen(errorMessage()) == sizeof(messageBuffer) - 1);
 
             catchDone = true;
@@ -187,6 +203,7 @@ testRun(void)
         TRY_END();
 
         assert(errorTryDepth() == 0);
+        assert(memcmp(&errorContext.error, &(Error){0}, sizeof(Error)) == 0);
 
         assert(tryDone);
         assert(catchDone);
@@ -231,6 +248,8 @@ testRun(void)
         }
         TRY_END();
 
+        assert(memcmp(&errorContext.error, &(Error){0}, sizeof(Error)) == 0);
+
         assert(tryDone);
         assert(catchDone);
         assert(finallyDone);
@@ -375,15 +394,15 @@ testRun(void)
     if (testBegin("Uncaught error"))
     {
         // Test in a fork so the process does not actually exit
-        HARNESS_FORK_BEGIN()
+        HRN_FORK_BEGIN()
         {
-            HARNESS_FORK_CHILD_BEGIN(UnhandledError.code, false)
+            HRN_FORK_CHILD_BEGIN(.expectedExitStatus = UnhandledError.code)
             {
                 THROW(TestChildError, "does not get caught!");
             }
-            HARNESS_FORK_CHILD_END();
+            HRN_FORK_CHILD_END();
         }
-        HARNESS_FORK_END();
+        HRN_FORK_END();
     }
 
     FUNCTION_HARNESS_RETURN_VOID();
