@@ -7,6 +7,7 @@ Test IO
 #include "common/type/json.h"
 
 #include "common/harnessFork.h"
+#include "common/harnessPack.h"
 
 /***********************************************************************************************************************************
 Test functions for IoRead that are not covered by testing the IoBufferRead object
@@ -56,7 +57,7 @@ static void
 testIoWrite(void *driver, const Buffer *buffer)
 {
     ASSERT(driver == (void *)999);
-    ASSERT(strEq(strNewBuf(buffer), strNew("ABC")));
+    ASSERT(strEq(strNewBuf(buffer), STRDEF("ABC")));
 }
 
 static bool testIoWriteCloseCalled = false;
@@ -73,7 +74,6 @@ Test filter that counts total bytes
 ***********************************************************************************************************************************/
 typedef struct IoTestFilterSize
 {
-    MemContext *memContext;
     size_t size;
 } IoTestFilterSize;
 
@@ -96,31 +96,32 @@ ioTestFilterSizeProcess(THIS_VOID, const Buffer *buffer)
     FUNCTION_LOG_RETURN_VOID();
 }
 
-static Variant *
+static Pack *
 ioTestFilterSizeResult(THIS_VOID)
 {
     THIS(IoTestFilterSize);
 
-    return varNewUInt64(this->size);
+    PackWrite *const packWrite = pckWriteNewP();
+
+    pckWriteU64P(packWrite, this->size);
+    pckWriteEndP(packWrite);
+
+    return pckWriteResult(packWrite);
 }
 
 static IoFilter *
-ioTestFilterSizeNew(const char *type)
+ioTestFilterSizeNew(const StringId type)
 {
     IoFilter *this = NULL;
 
-    MEM_CONTEXT_NEW_BEGIN("IoTestFilterSize")
+    OBJ_NEW_BEGIN(IoTestFilterSize)
     {
-        IoTestFilterSize *driver = memNew(sizeof(IoTestFilterSize));
+        IoTestFilterSize *driver = OBJ_NEW_ALLOC();
+        *driver = (IoTestFilterSize){0};
 
-        *driver = (IoTestFilterSize)
-        {
-            .memContext = MEM_CONTEXT_NEW(),
-        };
-
-        this = ioFilterNewP(strNew(type), driver, NULL, .in = ioTestFilterSizeProcess, .result = ioTestFilterSizeResult);
+        this = ioFilterNewP(type, driver, NULL, .in = ioTestFilterSizeProcess, .result = ioTestFilterSizeResult);
     }
-    MEM_CONTEXT_NEW_END();
+    OBJ_NEW_END();
 
     return this;
 }
@@ -130,7 +131,6 @@ Test filter to multiply input to the output.  It can also flush out a variable n
 ***********************************************************************************************************************************/
 typedef struct IoTestFilterMultiply
 {
-    MemContext *memContext;
     unsigned int flushTotal;
     bool writeZero;
     char flushChar;
@@ -210,33 +210,33 @@ ioTestFilterMultiplyInputSame(const THIS_VOID)
 }
 
 static IoFilter *
-ioTestFilterMultiplyNew(const char *type, unsigned int multiplier, unsigned int flushTotal, char flushChar)
+ioTestFilterMultiplyNew(const StringId type, unsigned int multiplier, unsigned int flushTotal, char flushChar)
 {
     IoFilter *this = NULL;
 
-    MEM_CONTEXT_NEW_BEGIN("IoTestFilterMultiply")
+    OBJ_NEW_BEGIN(IoTestFilterMultiply)
     {
-        IoTestFilterMultiply *driver = memNew(sizeof(IoTestFilterMultiply));
+        IoTestFilterMultiply *driver = OBJ_NEW_ALLOC();
 
         *driver = (IoTestFilterMultiply)
         {
-            .memContext = MEM_CONTEXT_NEW(),
             .bufferFilter = ioBufferNew(),
             .multiplier = multiplier,
             .flushTotal = flushTotal,
             .flushChar = flushChar,
         };
 
-        VariantList *paramList = varLstNew();
-        varLstAdd(paramList, varNewStrZ(type));
-        varLstAdd(paramList, varNewUInt(multiplier));
-        varLstAdd(paramList, varNewUInt(flushTotal));
+        PackWrite *const packWrite = pckWriteNewP();
+        pckWriteStrIdP(packWrite, type);
+        pckWriteU32P(packWrite, multiplier);
+        pckWriteU32P(packWrite, flushTotal);
+        pckWriteEndP(packWrite);
 
         this = ioFilterNewP(
-            strNew(type), driver, paramList, .done = ioTestFilterMultiplyDone, .inOut = ioTestFilterMultiplyProcess,
+            type, driver, pckWriteResult(packWrite), .done = ioTestFilterMultiplyDone, .inOut = ioTestFilterMultiplyProcess,
             .inputSame = ioTestFilterMultiplyInputSame);
     }
-    MEM_CONTEXT_NEW_END();
+    OBJ_NEW_END();
 
     return this;
 }
@@ -244,7 +244,7 @@ ioTestFilterMultiplyNew(const char *type, unsigned int multiplier, unsigned int
 /***********************************************************************************************************************************
 Test Run
 ***********************************************************************************************************************************/
-void
+static void
 testRun(void)
 {
     FUNCTION_HARNESS_VOID();
@@ -313,18 +313,19 @@ testRun(void)
 
         IoFilter *sizeFilter = ioSizeNew();
         TEST_RESULT_VOID(
-            ioFilterGroupAdd(ioReadFilterGroup(bufferRead), ioTestFilterMultiplyNew("double", 2, 3, 'X')),
+            ioFilterGroupAdd(ioReadFilterGroup(bufferRead), ioTestFilterMultiplyNew(STRID5("double", 0xac155e40), 2, 3, 'X')),
             "    add filter to filter group");
         TEST_RESULT_PTR(
-            ioFilterGroupInsert(ioReadFilterGroup(bufferRead), 0, sizeFilter), bufferRead->filterGroup,
+            ioFilterGroupInsert(ioReadFilterGroup(bufferRead), 0, sizeFilter), bufferRead->pub.filterGroup,
             "    add filter to filter group");
         TEST_RESULT_VOID(ioFilterGroupAdd(ioReadFilterGroup(bufferRead), ioSizeNew()), "    add filter to filter group");
         IoFilter *bufferFilter = ioBufferNew();
         TEST_RESULT_VOID(ioFilterGroupAdd(ioReadFilterGroup(bufferRead), bufferFilter), "    add filter to filter group");
         TEST_RESULT_PTR(ioFilterMove(NULL, memContextTop()), NULL, "    move NULL filter to top context");
         TEST_RESULT_STR_Z(
-            jsonFromVar(ioFilterGroupParamAll(ioReadFilterGroup(bufferRead))),
-            "[{\"size\":null},{\"double\":[\"double\",2,3]},{\"size\":null},{\"buffer\":null}]", "    check filter params");
+            hrnPackToStr(ioFilterGroupParamAll(ioReadFilterGroup(bufferRead))),
+            "1:strid:size, 3:strid:double, 4:pack:<1:strid:double, 2:u32:2, 3:u32:3>, 5:strid:size, 7:strid:buffer",
+            "    check filter params");
 
         TEST_RESULT_BOOL(ioReadOpen(bufferRead), true, "    open");
         TEST_RESULT_INT(ioReadFd(bufferRead), -1, "    fd invalid");
@@ -332,7 +333,7 @@ testRun(void)
         TEST_RESULT_UINT(ioRead(bufferRead, buffer), 2, "    read 2 bytes");
         TEST_RESULT_UINT(ioRead(bufferRead, buffer), 0, "    read 0 bytes (full buffer)");
         TEST_RESULT_STR_Z(strNewBuf(buffer), "11", "    check read");
-        TEST_RESULT_STR_Z(ioFilterType(sizeFilter), "size", "check filter type");
+        TEST_RESULT_STR_Z(strIdToStr(ioFilterType(sizeFilter)), "size", "check filter type");
         TEST_RESULT_BOOL(ioReadEof(bufferRead), false, "    not eof");
 
         TEST_RESULT_VOID(bufUsedZero(buffer), "    zero buffer");
@@ -351,22 +352,26 @@ testRun(void)
         TEST_RESULT_UINT(ioRead(bufferRead, buffer), 0, "    read 0 bytes");
         TEST_RESULT_VOID(ioReadClose(bufferRead), " close buffer read object");
         TEST_RESULT_STR_Z(
-            jsonFromVar(ioFilterGroupResultAll(ioReadFilterGroup(bufferRead))),
-            "{\"buffer\":null,\"double\":null,\"size\":[3,9]}",
+            hrnPackToStr(ioFilterGroupResultAll(ioReadFilterGroup(bufferRead))),
+            "1:strid:size, 2:pack:<1:u64:3>, 3:strid:double, 5:strid:size, 6:pack:<1:u64:9>, 7:strid:buffer",
             "    check filter result all");
 
         TEST_RESULT_PTR(ioReadFilterGroup(bufferRead), ioReadFilterGroup(bufferRead), "    check filter group");
         TEST_RESULT_UINT(
-            varUInt64(varLstGet(varVarLst(ioFilterGroupResult(ioReadFilterGroup(bufferRead), ioFilterType(sizeFilter))), 0)), 3,
+            pckReadU64P(ioFilterGroupResultP(ioReadFilterGroup(bufferRead), ioFilterType(sizeFilter))), 3,
             "    check filter result");
         TEST_RESULT_PTR(
-            ioFilterGroupResult(ioReadFilterGroup(bufferRead), strNew("double")), NULL, "    check filter result is NULL");
+            ioFilterGroupResultP(ioReadFilterGroup(bufferRead), STRID5("double", 0xac155e40)), NULL,
+            "    check filter result is NULL");
         TEST_RESULT_UINT(
-            varUInt64(varLstGet(varVarLst(ioFilterGroupResult(ioReadFilterGroup(bufferRead), ioFilterType(sizeFilter))), 1)), 9,
+            pckReadU64P(ioFilterGroupResultP(ioReadFilterGroup(bufferRead), ioFilterType(sizeFilter), .idx = 1)), 9,
             "    check filter result");
+        TEST_RESULT_PTR(
+            ioFilterGroupResultP(ioReadFilterGroup(bufferRead), STRID5("bogus", 0x13a9de20)), NULL,
+            "    check missing filter result");
 
-        TEST_RESULT_PTR(ioFilterDriver(bufferFilter), bufferFilter->driver, "    check filter driver");
-        TEST_RESULT_PTR(ioFilterInterface(bufferFilter), &bufferFilter->interface, "    check filter interface");
+        TEST_RESULT_PTR(ioFilterDriver(bufferFilter), bufferFilter->pub.driver, "    check filter driver");
+        TEST_RESULT_PTR(ioFilterInterface(bufferFilter), &bufferFilter->pub.interface, "    check filter interface");
 
         TEST_RESULT_VOID(ioFilterFree(bufferFilter), "    free buffer filter");
         TEST_RESULT_VOID(ioFilterGroupFree(ioReadFilterGroup(bufferRead)), "    free filter group object");
@@ -374,11 +379,21 @@ testRun(void)
         // Set filter group results
         // -------------------------------------------------------------------------------------------------------------------------
         IoFilterGroup *filterGroup = ioFilterGroupNew();
-        filterGroup->opened = true;
+        filterGroup->pub.opened = true;
         TEST_RESULT_VOID(ioFilterGroupResultAllSet(filterGroup, NULL), "null result");
-        TEST_RESULT_VOID(ioFilterGroupResultAllSet(filterGroup, jsonToVar(strNew("{\"test\":777}"))), "add result");
-        filterGroup->closed = true;
-        TEST_RESULT_UINT(varUInt64(ioFilterGroupResult(filterGroup, strNew("test"))), 777, "    check filter result");
+
+        PackWrite *filterResult = pckWriteNewP(.size = 256);
+        pckWriteU64P(filterResult, 777);
+        pckWriteEndP(filterResult);
+
+        PackWrite *filterResultAll = pckWriteNewP(.size = 256);
+        pckWriteStrIdP(filterResultAll, STRID5("test", 0xa4cb40));
+        pckWritePackP(filterResultAll, pckWriteResult(filterResult));
+        pckWriteEndP(filterResultAll);
+
+        TEST_RESULT_VOID(ioFilterGroupResultAllSet(filterGroup, pckWriteResult(filterResultAll)), "add result");
+        filterGroup->pub.closed = true;
+        TEST_RESULT_UINT(pckReadU64P(ioFilterGroupResultP(filterGroup, STRID5("test", 0xa4cb40))), 777, "    check filter result");
 
         // Read a zero-size buffer to ensure filters are still processed even when there is no input.  Some filters (e.g. encryption
         // and compression) will produce output even if there is no input.
@@ -389,7 +404,7 @@ testRun(void)
 
         TEST_ASSIGN(bufferRead, ioBufferReadNew(bufferOriginal), "create buffer read object");
         TEST_RESULT_VOID(
-            ioFilterGroupAdd(ioReadFilterGroup(bufferRead), ioTestFilterMultiplyNew("double", 2, 5, 'Y')),
+            ioFilterGroupAdd(ioReadFilterGroup(bufferRead), ioTestFilterMultiplyNew(STRID5("double", 0xac155e40), 2, 5, 'Y')),
             "    add filter that produces output with no input");
         TEST_RESULT_BOOL(ioReadOpen(bufferRead), true, "    open read");
         TEST_RESULT_UINT(ioRead(bufferRead, buffer), 5, "    read 5 chars");
@@ -440,6 +455,7 @@ testRun(void)
         // Nothing left to read
         TEST_ERROR(ioReadLine(read), FileReadError, "unexpected eof while reading line");
         TEST_RESULT_UINT(ioRead(read, buffer), 0, "read buffer");
+        TEST_RESULT_UINT(ioReadSmall(read, bufNew(55)), 0, "read buffer");
 
         // Error if buffer is full and there is no linefeed
         ioBufferSizeSet(10);
@@ -467,7 +483,8 @@ testRun(void)
         ioFilterGroupAdd(ioReadFilterGroup(bufferRead), ioSizeNew());
 
         TEST_RESULT_BOOL(ioReadDrain(bufferRead), true, "drain read io");
-        TEST_RESULT_UINT(varUInt64(ioFilterGroupResult(ioReadFilterGroup(bufferRead), SIZE_FILTER_TYPE_STR)), 20, "check length");
+        TEST_RESULT_UINT(
+            pckReadU64P(ioFilterGroupResultP(ioReadFilterGroup(bufferRead), SIZE_FILTER_TYPE)), 20, "check length");
 
         // Cannot open file
         TEST_ASSIGN(
@@ -505,11 +522,13 @@ testRun(void)
         IoFilter *sizeFilter = ioSizeNew();
         TEST_RESULT_VOID(ioFilterGroupAdd(filterGroup, sizeFilter), "    add filter to filter group");
         TEST_RESULT_VOID(
-            ioFilterGroupAdd(filterGroup, ioTestFilterMultiplyNew("double", 2, 3, 'X')), "    add filter to filter group");
-        TEST_RESULT_VOID(
-            ioFilterGroupAdd(filterGroup, ioTestFilterMultiplyNew("single", 1, 1, 'Y')),
+            ioFilterGroupAdd(filterGroup, ioTestFilterMultiplyNew(STRID5("double", 0xac155e40), 2, 3, 'X')),
             "    add filter to filter group");
-        TEST_RESULT_VOID(ioFilterGroupAdd(filterGroup, ioTestFilterSizeNew("size2")), "    add filter to filter group");
+        TEST_RESULT_VOID(
+            ioFilterGroupAdd(filterGroup, ioTestFilterMultiplyNew(STRID5("single", 0xac3b9330), 1, 1, 'Y')),
+            "    add filter to filter group");
+        TEST_RESULT_VOID(
+            ioFilterGroupAdd(filterGroup, ioTestFilterSizeNew(STRID5("size2", 0x1c2e9330))), "    add filter to filter group");
 
         TEST_RESULT_VOID(ioWriteOpen(bufferWrite), "    open buffer write object");
         TEST_RESULT_INT(ioWriteFd(bufferWrite), -1, "    fd invalid");
@@ -528,8 +547,9 @@ testRun(void)
 
         TEST_RESULT_PTR(ioWriteFilterGroup(bufferWrite), filterGroup, "    check filter group");
         TEST_RESULT_UINT(
-            varUInt64(ioFilterGroupResult(filterGroup, ioFilterType(sizeFilter))), 9, "    check filter result");
-        TEST_RESULT_UINT(varUInt64(ioFilterGroupResult(filterGroup, strNew("size2"))), 22, "    check filter result");
+            pckReadU64P(ioFilterGroupResultP(filterGroup, ioFilterType(sizeFilter))), 9, "    check filter result");
+        TEST_RESULT_UINT(
+            pckReadU64P(ioFilterGroupResultP(filterGroup, STRID5("size2", 0x1c2e9330))), 22, "    check filter result");
     }
 
     // *****************************************************************************************************************************
@@ -537,19 +557,18 @@ testRun(void)
     {
         ioBufferSizeSet(16);
 
-        HARNESS_FORK_BEGIN()
+        HRN_FORK_BEGIN()
         {
-            HARNESS_FORK_CHILD_BEGIN(0, true)
+            HRN_FORK_CHILD_BEGIN()
             {
                 IoWrite *write = NULL;
 
-                TEST_ASSIGN(write, ioFdWriteNew(strNew("write test"), HARNESS_FORK_CHILD_WRITE(), 1000), "move write");
-                ioWriteOpen(write);
+                TEST_ASSIGN(write, ioFdWriteNewOpen(STRDEF("write test"), HRN_FORK_CHILD_WRITE_FD(), 1000), "move write");
                 TEST_RESULT_BOOL(ioWriteReadyP(write), true, "write is ready");
                 TEST_RESULT_INT(ioWriteFd(write), ((IoFdWrite *)write->driver)->fd, "check write fd");
 
                 // Write a line to be read
-                TEST_RESULT_VOID(ioWriteStrLine(write, strNew("test string 1")), "write test string");
+                TEST_RESULT_VOID(ioWriteStrLine(write, STRDEF("test string 1")), "write test string");
                 ioWriteFlush(write);
                 ioWriteFlush(write);
 
@@ -564,16 +583,15 @@ testRun(void)
                 TEST_RESULT_VOID(ioWrite(write, buffer), "write buffer");
                 ioWriteFlush(write);
             }
-            HARNESS_FORK_CHILD_END();
+            HRN_FORK_CHILD_END();
 
-            HARNESS_FORK_PARENT_BEGIN()
+            HRN_FORK_PARENT_BEGIN()
             {
-                IoRead *read = ioFdReadNew(strNew("read test"), HARNESS_FORK_PARENT_READ_PROCESS(0), 1000);
+                IoRead *read = ioFdReadNewOpen(STRDEF("read test"), HRN_FORK_PARENT_READ_FD(0), 1000);
 
-                ioReadOpen(read);
                 TEST_RESULT_INT(ioReadFd(read), ((IoFdRead *)ioReadDriver(read))->fd, "check fd");
-                TEST_RESULT_PTR(ioReadInterface(read), &read->interface, "check interface");
-                TEST_RESULT_PTR(ioReadDriver(read), read->driver, "check driver");
+                TEST_RESULT_PTR(ioReadInterface(read), &read->pub.interface, "check interface");
+                TEST_RESULT_PTR(ioReadDriver(read), read->pub.driver, "check driver");
 
                 // Read a string
                 TEST_RESULT_STR_Z(ioReadLine(read), "test string 1", "read test string");
@@ -581,9 +599,9 @@ testRun(void)
                 // Only part of the buffer is written before timeout
                 Buffer *buffer = bufNew(16);
 
-                ((IoFdRead *)read->driver)->timeout = 1;
+                ((IoFdRead *)read->pub.driver)->timeout = 1;
                 TEST_RESULT_BOOL(ioReadReadyP(read), false, "read is not ready (without throwing error)");
-                ((IoFdRead *)read->driver)->timeout = 1000;
+                ((IoFdRead *)read->pub.driver)->timeout = 1000;
 
                 TEST_ERROR(ioRead(read, buffer), FileReadError, "timeout after 1000ms waiting for read from 'read test'");
                 TEST_RESULT_UINT(bufSize(buffer), 16, "buffer is only partially read");
@@ -603,18 +621,17 @@ testRun(void)
                 TEST_RESULT_UINT(ioFdRead(ioReadDriver(read), buffer, true), 0, "read buffer at eof");
                 TEST_RESULT_UINT(ioFdRead(ioReadDriver(read), buffer, true), 0, "read buffer at eof again");
             }
-            HARNESS_FORK_PARENT_END();
+            HRN_FORK_PARENT_END();
         }
-        HARNESS_FORK_END();
+        HRN_FORK_END();
 
         // -------------------------------------------------------------------------------------------------------------------------
-        TEST_ERROR(ioFdWriteOneStr(999999, strNew("test")), FileWriteError, "unable to write to fd: [9] Bad file descriptor");
+        TEST_ERROR(ioFdWriteOneStr(999999, STRDEF("test")), FileWriteError, "unable to write to fd: [9] Bad file descriptor");
 
         // -------------------------------------------------------------------------------------------------------------------------
-        String *fileName = strNewFmt("%s/test.txt", testPath());
-        int fd = open(strZ(fileName), O_CREAT | O_TRUNC | O_WRONLY, 0700);
+        int fd = open(TEST_PATH "/test.txt", O_CREAT | O_TRUNC | O_WRONLY, 0700);
 
-        TEST_RESULT_VOID(ioFdWriteOneStr(fd, strNew("test1\ntest2")), "write string to file");
+        TEST_RESULT_VOID(ioFdWriteOneStr(fd, STRDEF("test1\ntest2")), "write string to file");
 
         // -------------------------------------------------------------------------------------------------------------------------
         TEST_TITLE("fdReadyRetry() edge conditions");
@@ -660,8 +677,8 @@ testRun(void)
             THROW_ON_SYS_ERROR((flags = fcntl(fd, F_GETFL)) == -1, ProtocolError, "unable to get flags");
             THROW_ON_SYS_ERROR(fcntl(fd, F_SETFL, flags | O_NONBLOCK) == -1, ProtocolError, "unable to set O_NONBLOCK");
 
-            // Attempt connection
-            CHECK(connect(fd, hostBadAddress->ai_addr, hostBadAddress->ai_addrlen) == -1);
+            // Make sure the bad address does not work before using it for testing
+            ASSERT(connect(fd, hostBadAddress->ai_addr, hostBadAddress->ai_addrlen) == -1);
 
             // Create file descriptor write and wait for timeout
             IoWrite *write = NULL;
