@@ -9,21 +9,21 @@ Test Lock Handler
 /***********************************************************************************************************************************
 Test Run
 ***********************************************************************************************************************************/
-void
+static void
 testRun(void)
 {
     FUNCTION_HARNESS_VOID();
 
     // Create default storage object for testing
-    Storage *storageTest = storagePosixNewP(strNew(testPath()), .write = true);
+    Storage *storageTest = storagePosixNewP(TEST_PATH_STR, .write = true);
 
     // *****************************************************************************************************************************
     if (testBegin("lockAcquireFile() and lockReleaseFile()"))
     {
-        String *archiveLock = strNewFmt("%s/main-archive" LOCK_FILE_EXT, testPath());
+        const String *archiveLock = STRDEF(TEST_PATH "/main-archive" LOCK_FILE_EXT);
         int lockFdTest = -1;
 
-        TEST_RESULT_INT(system(strZ(strNewFmt("touch %s", strZ(archiveLock)))), 0, "touch lock file");
+        HRN_SYSTEM_FMT("touch %s", strZ(archiveLock));
         TEST_ASSIGN(lockFdTest, lockAcquireFile(archiveLock, STRDEF("1-test"), 0, true), "get lock");
         TEST_RESULT_BOOL(lockFdTest != -1, true, "lock succeeds");
         TEST_RESULT_BOOL(storageExistsP(storageTest, archiveLock), true, "lock file was created");
@@ -42,7 +42,7 @@ testRun(void)
         // -------------------------------------------------------------------------------------------------------------------------
         TEST_TITLE("fail file lock on the same exec-id when lock file is empty");
 
-        TEST_RESULT_INT(system(strZ(strNewFmt("echo '' > %s", strZ(archiveLock)))), 0, "overwrite lock file");
+        HRN_SYSTEM_FMT("echo '' > %s", strZ(archiveLock));
 
         TEST_ERROR(lockAcquireFile(archiveLock, STRDEF("2-test"), 0, true), LockAcquireError,
             strZ(
@@ -58,7 +58,7 @@ testRun(void)
         TEST_RESULT_VOID(lockReleaseFile(lockFdTest, archiveLock), "release lock again without error");
 
         // -------------------------------------------------------------------------------------------------------------------------
-        String *subPathLock = strNewFmt("%s/sub1/sub2/db-backup" LOCK_FILE_EXT, testPath());
+        const String *subPathLock = STRDEF(TEST_PATH "/sub1/sub2/db-backup" LOCK_FILE_EXT);
 
         TEST_ASSIGN(lockFdTest, lockAcquireFile(subPathLock, STRDEF("1-test"), 0, true), "get lock in subpath");
         TEST_RESULT_BOOL(storageExistsP(storageTest, subPathLock), true, "lock file was created");
@@ -67,18 +67,18 @@ testRun(void)
         TEST_RESULT_BOOL(storageExistsP(storageTest, subPathLock), false, "lock file was removed");
 
         // -------------------------------------------------------------------------------------------------------------------------
-        String *dirLock = strNewFmt("%s/dir" LOCK_FILE_EXT, testPath());
+        const String *dirLock = STRDEF(TEST_PATH "/dir" LOCK_FILE_EXT);
 
-        TEST_RESULT_INT(system(strZ(strNewFmt("mkdir -p 750 %s", strZ(dirLock)))), 0, "create dirtest.lock dir");
+        HRN_SYSTEM_FMT("mkdir -p 750 %s", strZ(dirLock));
 
         TEST_ERROR(
             lockAcquireFile(dirLock, STRDEF("1-test"), 0, true), LockAcquireError,
             strZ(strNewFmt("unable to acquire lock on file '%s': Is a directory", strZ(dirLock))));
 
         // -------------------------------------------------------------------------------------------------------------------------
-        String *noPermLock = strNewFmt("%s/noperm/noperm", testPath());
-        TEST_RESULT_INT(system(strZ(strNewFmt("mkdir -p 750 %s", strZ(strPath(noPermLock))))), 0, "create noperm dir");
-        TEST_RESULT_INT(system(strZ(strNewFmt("chmod 000 %s", strZ(strPath(noPermLock))))), 0, "chmod noperm dir");
+        const String *noPermLock = STRDEF(TEST_PATH "/noperm/noperm");
+        HRN_SYSTEM_FMT("mkdir -p 750 %s", strZ(strPath(noPermLock)));
+        HRN_SYSTEM_FMT("chmod 000 %s", strZ(strPath(noPermLock)));
 
         TEST_ERROR(
             lockAcquireFile(noPermLock, STRDEF("1-test"), 100, true), LockAcquireError,
@@ -89,20 +89,27 @@ testRun(void)
                     strZ(noPermLock), strZ(noPermLock))));
 
         // -------------------------------------------------------------------------------------------------------------------------
-        String *backupLock = strNewFmt("%s/main-backup" LOCK_FILE_EXT, testPath());
+        const String *backupLock = STRDEF(TEST_PATH "/main-backup" LOCK_FILE_EXT);
 
-        HARNESS_FORK_BEGIN()
+        HRN_FORK_BEGIN()
         {
-            HARNESS_FORK_CHILD_BEGIN(0, false)
+            HRN_FORK_CHILD_BEGIN()
             {
                 TEST_RESULT_INT_NE(lockAcquireFile(backupLock, STRDEF("1-test"), 0, true), -1, "lock on fork");
-                sleepMSec(500);
-            }
-            HARNESS_FORK_CHILD_END();
 
-            HARNESS_FORK_PARENT_BEGIN()
+                // Notify parent that lock has been acquired
+                HRN_FORK_CHILD_NOTIFY_PUT();
+
+                // Wait for parent to allow release lock
+                HRN_FORK_CHILD_NOTIFY_GET();
+            }
+            HRN_FORK_CHILD_END();
+
+            HRN_FORK_PARENT_BEGIN()
             {
-                sleepMSec(250);
+                // Wait for child to acquire lock
+                HRN_FORK_PARENT_NOTIFY_GET(0);
+
                 TEST_ERROR(
                     lockAcquireFile(backupLock, STRDEF("2-test"), 0, true),
                     LockAcquireError,
@@ -110,61 +117,60 @@ testRun(void)
                         strNewFmt(
                             "unable to acquire lock on file '%s': Resource temporarily unavailable\n"
                             "HINT: is another pgBackRest process running?", strZ(backupLock))));
+
+                // Notify child to release lock
+                HRN_FORK_PARENT_NOTIFY_PUT(0);
             }
-            HARNESS_FORK_PARENT_END();
+            HRN_FORK_PARENT_END();
         }
-        HARNESS_FORK_END();
+        HRN_FORK_END();
     }
 
     // *****************************************************************************************************************************
-    if (testBegin("lockAcquire(), lockRelease(), and lockClear()"))
+    if (testBegin("lockAcquire(), lockRelease()"))
     {
-        String *stanza = strNew("test");
-        String *lockPath = strNew(testPath());
-        String *archiveLockFile = strNewFmt("%s/%s-archive" LOCK_FILE_EXT, testPath(), strZ(stanza));
-        String *backupLockFile = strNewFmt("%s/%s-backup" LOCK_FILE_EXT, testPath(), strZ(stanza));
+        const String *stanza = STRDEF("test");
+        String *archiveLockFile = strNewFmt(TEST_PATH "/%s-archive" LOCK_FILE_EXT, strZ(stanza));
+        String *backupLockFile = strNewFmt(TEST_PATH "/%s-backup" LOCK_FILE_EXT, strZ(stanza));
         int lockFdTest = -1;
 
         // -------------------------------------------------------------------------------------------------------------------------
         TEST_ERROR(lockRelease(true), AssertError, "no lock is held by this process");
         TEST_RESULT_BOOL(lockRelease(false), false, "release when there is no lock");
 
-        TEST_ERROR(lockClear(true), AssertError, "no lock is held by this process");
-        TEST_RESULT_BOOL(lockClear(false), false, "release when there is no lock");
-
         // -------------------------------------------------------------------------------------------------------------------------
         TEST_ASSIGN(lockFdTest, lockAcquireFile(archiveLockFile, STRDEF("1-test"), 0, true), "archive lock by file");
         TEST_RESULT_BOOL(
-            lockAcquire(lockPath, stanza, STRDEF("2-test"), lockTypeArchive, 0, false), false, "archive already locked");
+            lockAcquire(TEST_PATH_STR, stanza, STRDEF("2-test"), lockTypeArchive, 0, false), false, "archive already locked");
         TEST_ERROR(
-            lockAcquire(lockPath, stanza, STRDEF("2-test"), lockTypeArchive, 0, true), LockAcquireError,
+            lockAcquire(TEST_PATH_STR, stanza, STRDEF("2-test"), lockTypeArchive, 0, true), LockAcquireError,
             strZ(strNewFmt(
                 "unable to acquire lock on file '%s': Resource temporarily unavailable\n"
                 "HINT: is another pgBackRest process running?", strZ(archiveLockFile))));
         TEST_ERROR(
-            lockAcquire(lockPath, stanza, STRDEF("2-test"), lockTypeAll, 0, true), LockAcquireError,
+            lockAcquire(TEST_PATH_STR, stanza, STRDEF("2-test"), lockTypeAll, 0, true), LockAcquireError,
             strZ(strNewFmt(
                 "unable to acquire lock on file '%s': Resource temporarily unavailable\n"
                 "HINT: is another pgBackRest process running?", strZ(archiveLockFile))));
         TEST_RESULT_VOID(lockReleaseFile(lockFdTest, archiveLockFile), "release lock");
 
         // -------------------------------------------------------------------------------------------------------------------------
-        TEST_RESULT_BOOL(lockAcquire(lockPath, stanza, STRDEF("1-test"), lockTypeArchive, 0, true), true, "archive lock");
+        TEST_RESULT_BOOL(lockAcquire(TEST_PATH_STR, stanza, STRDEF("1-test"), lockTypeArchive, 0, true), true, "archive lock");
         TEST_RESULT_BOOL(storageExistsP(storageTest, archiveLockFile), true, "archive lock file was created");
         TEST_ERROR(
-            lockAcquire(lockPath, stanza, STRDEF("1-test"), lockTypeArchive, 0, false), AssertError,
+            lockAcquire(TEST_PATH_STR, stanza, STRDEF("1-test"), lockTypeArchive, 0, false), AssertError,
             "lock is already held by this process");
         TEST_RESULT_VOID(lockRelease(true), "release archive lock");
 
         // // -------------------------------------------------------------------------------------------------------------------------
         TEST_ASSIGN(lockFdTest, lockAcquireFile(backupLockFile, STRDEF("1-test"), 0, true), "backup lock by file");
         TEST_ERROR(
-            lockAcquire(lockPath, stanza, STRDEF("2-test"), lockTypeBackup, 0, true), LockAcquireError,
+            lockAcquire(TEST_PATH_STR, stanza, STRDEF("2-test"), lockTypeBackup, 0, true), LockAcquireError,
             strZ(strNewFmt(
                 "unable to acquire lock on file '%s': Resource temporarily unavailable\n"
                 "HINT: is another pgBackRest process running?", strZ(backupLockFile))));
         TEST_ERROR(
-            lockAcquire(lockPath, stanza, STRDEF("2-test"), lockTypeAll, 0, true), LockAcquireError,
+            lockAcquire(TEST_PATH_STR, stanza, STRDEF("2-test"), lockTypeAll, 0, true), LockAcquireError,
             strZ(strNewFmt(
                 "unable to acquire lock on file '%s': Resource temporarily unavailable\n"
                 "HINT: is another pgBackRest process running?", strZ(backupLockFile))));
@@ -172,44 +178,32 @@ testRun(void)
         TEST_RESULT_VOID(lockReleaseFile(lockFdTest, backupLockFile), "release lock");
 
         // -------------------------------------------------------------------------------------------------------------------------
-        TEST_RESULT_BOOL(lockAcquire(lockPath, stanza, STRDEF("1-test"), lockTypeAll, 0, true), true, "all lock");
+        TEST_RESULT_BOOL(lockAcquire(TEST_PATH_STR, stanza, STRDEF("1-test"), lockTypeAll, 0, true), true, "all lock");
         TEST_RESULT_BOOL(storageExistsP(storageTest, archiveLockFile), true, "archive lock file was created");
         TEST_RESULT_BOOL(storageExistsP(storageTest, backupLockFile), true, "backup lock file was created");
         TEST_ERROR(
-            lockAcquire(lockPath, stanza, STRDEF("1-test"), lockTypeAll, 0, false), AssertError,
+            lockAcquire(TEST_PATH_STR, stanza, STRDEF("1-test"), lockTypeAll, 0, false), AssertError,
             "assertion 'failOnNoLock || lockType != lockTypeAll' failed");
-        TEST_RESULT_VOID(lockRelease(true), "release all lock");
+        TEST_RESULT_VOID(lockRelease(true), "release all locks");
 
-        // -------------------------------------------------------------------------------------------------------------------------
-        TEST_RESULT_BOOL(lockAcquire(lockPath, stanza, STRDEF("1-test"), lockTypeBackup, 0, true), true, "backup lock");
-
-        lockFdTest = lockFd[lockTypeBackup];
-        String *lockFileTest = strDup(lockFile[lockTypeBackup]);
-
-        TEST_RESULT_VOID(lockClear(true), "clear backup lock");
-        TEST_RESULT_BOOL(storageExistsP(storageTest, backupLockFile), true, "backup lock file still exists");
-        lockReleaseFile(lockFdTest, lockFileTest);
+        TEST_RESULT_BOOL(storageExistsP(storageTest, archiveLockFile), false, "archive lock file was removed");
+        TEST_RESULT_BOOL(storageExistsP(storageTest, backupLockFile), false, "backup lock file was removed");
 
         // -------------------------------------------------------------------------------------------------------------------------
         TEST_TITLE("acquire lock on the same exec-id and release");
 
-        TEST_RESULT_BOOL(lockAcquire(lockPath, stanza, STRDEF("1-test"), lockTypeBackup, 0, true), true, "backup lock");
+        TEST_RESULT_BOOL(lockAcquire(TEST_PATH_STR, stanza, STRDEF("1-test"), lockTypeBackup, 0, true), true, "backup lock");
 
+        // Make it look there is no lock
         lockFdTest = lockFd[lockTypeBackup];
-        lockFileTest = strDup(lockFile[lockTypeBackup]);
+        String *lockFileTest = strDup(lockFile[lockTypeBackup]);
+        lockTypeHeld = lockTypeNone;
 
-        TEST_RESULT_VOID(lockClear(true), "clear backup lock");
-
-        TEST_RESULT_BOOL(lockAcquire(lockPath, stanza, STRDEF("1-test"), lockTypeBackup, 0, true), true, "backup lock again");
+        TEST_RESULT_BOOL(lockAcquire(TEST_PATH_STR, stanza, STRDEF("1-test"), lockTypeBackup, 0, true), true, "backup lock again");
         TEST_RESULT_VOID(lockRelease(true), "release backup lock");
 
+        // Release lock manually
         lockReleaseFile(lockFdTest, lockFileTest);
-
-        // -------------------------------------------------------------------------------------------------------------------------
-        TEST_RESULT_BOOL(lockAcquire(lockPath, stanza, STRDEF("1-test"), lockTypeAll, 0, true), true, "all lock");
-        TEST_RESULT_VOID(lockClear(true), "clear all lock");
-        TEST_RESULT_BOOL(storageExistsP(storageTest, archiveLockFile), true, "archive lock file still exists");
-        TEST_RESULT_BOOL(storageExistsP(storageTest, backupLockFile), true, "backup lock file still exists");
     }
 
     FUNCTION_HARNESS_RETURN_VOID();
