@@ -70,7 +70,7 @@ testLogLoad(const char *logFile, char *buffer, size_t bufferSize)
 /***********************************************************************************************************************************
 Compare log to a static string
 ***********************************************************************************************************************************/
-void
+static void
 testLogResult(const char *logFile, const char *expected)
 {
     FUNCTION_HARNESS_BEGIN();
@@ -94,7 +94,7 @@ testLogResult(const char *logFile, const char *expected)
 /***********************************************************************************************************************************
 Test Run
 ***********************************************************************************************************************************/
-void
+static void
 testRun(void)
 {
     FUNCTION_HARNESS_VOID();
@@ -102,10 +102,10 @@ testRun(void)
     // *****************************************************************************************************************************
     if (testBegin("logLevelEnum() and logLevelStr()"))
     {
-        TEST_ERROR(logLevelEnum(BOGUS_STR), AssertError, "log level 'BOGUS' not found");
-        TEST_RESULT_INT(logLevelEnum("OFF"), logLevelOff, "log level 'OFF' found");
-        TEST_RESULT_INT(logLevelEnum("info"), logLevelInfo, "log level 'info' found");
-        TEST_RESULT_INT(logLevelEnum("TRACE"), logLevelTrace, "log level 'TRACE' found");
+        TEST_ERROR(logLevelEnum(strIdFromZ(BOGUS_STR)), AssertError, "invalid log level");
+        TEST_RESULT_INT(logLevelEnum(strIdFromZ("off")), logLevelOff, "log level 'OFF' found");
+        TEST_RESULT_INT(logLevelEnum(strIdFromZ("info")), logLevelInfo, "log level 'info' found");
+        TEST_RESULT_INT(logLevelEnum(strIdFromZ("trace")), logLevelTrace, "log level 'TRACE' found");
 
         TEST_ERROR(logLevelStr(999), AssertError, "assertion 'logLevel <= LOG_LEVEL_MAX' failed");
         TEST_RESULT_Z(logLevelStr(logLevelOff), "OFF", "log level 'OFF' found");
@@ -178,19 +178,17 @@ testRun(void)
         TEST_RESULT_VOID(
             logInternal(logLevelWarn, LOG_LEVEL_MIN, LOG_LEVEL_MAX, 0, "file", "function", 0, "TEST"), "log timestamp");
 
-        String *logTime = strNewN(logBuffer, 23);
+        String *logTime = strNewZN(logBuffer, 23);
         TEST_RESULT_BOOL(
             regExpMatchOne(
-                strNew("^20[0-9]{2}\\-[0-1][0-9]\\-[0-3][0-9] [0-2][0-9]\\:[0-5][0-9]\\:[0-5][0-9]\\.[0-9]{3}$"), logTime),
-            true, "check timestamp format: %s", strZ(logTime));
+                STRDEF("^20[0-9]{2}\\-[0-1][0-9]\\-[0-3][0-9] [0-2][0-9]\\:[0-5][0-9]\\:[0-5][0-9]\\.[0-9]{3}$"), logTime),
+            true, "check timestamp format");
 
         // Redirect output to files
-        char stdoutFile[1024];
-        snprintf(stdoutFile, sizeof(stdoutFile), "%s/stdout.log", testPath());
+        const char *const stdoutFile = TEST_PATH "/stdout.log";
         logFdStdOut = testLogOpen(stdoutFile, O_WRONLY | O_CREAT | O_TRUNC, 0640);
 
-        char stderrFile[1024];
-        snprintf(stderrFile, sizeof(stderrFile), "%s/stderr.log", testPath());
+        const char *const stderrFile = TEST_PATH "/stderr.log";
         logFdStdErr = testLogOpen(stderrFile, O_WRONLY | O_CREAT | O_TRUNC, 0640);
 
         TEST_RESULT_VOID(
@@ -220,8 +218,7 @@ testRun(void)
         TEST_RESULT_VOID(logInit(logLevelDebug, logLevelDebug, logLevelDebug, false, 0, 999, false), "init logging to debug");
 
         // Log to file
-        char fileFile[1024];
-        snprintf(fileFile, sizeof(stdoutFile), "%s/file.log", testPath());
+        const char *const fileFile = TEST_PATH "/file.log";
         logFileSet(fileFile);
 
         logBuffer[0] = 0;
