@@ -5,10 +5,10 @@ Test Memory Contexts
 /***********************************************************************************************************************************
 testFree - test callback function
 ***********************************************************************************************************************************/
-MemContext *memContextCallbackArgument = NULL;
-bool testFreeThrow = false;
+static MemContext *memContextCallbackArgument = NULL;
+static bool testFreeThrow = false;
 
-void
+static void
 testFree(void *thisVoid)
 {
     MemContext *this = thisVoid;
@@ -31,7 +31,7 @@ testFree(void *thisVoid)
 /***********************************************************************************************************************************
 Test Run
 ***********************************************************************************************************************************/
-void
+static void
 testRun(void)
 {
     FUNCTION_HARNESS_VOID();
@@ -74,6 +74,11 @@ testRun(void)
     // *****************************************************************************************************************************
     if (testBegin("memContextNew() and memContextFree()"))
     {
+        TEST_TITLE("struct size");
+
+        TEST_RESULT_UINT(sizeof(MemContext), TEST_64BIT() ? 72 : 48, "MemContext size");
+
+        // -------------------------------------------------------------------------------------------------------------------------
         // Make sure top context was created
         TEST_RESULT_Z(memContextName(memContextTop()), "TOP", "top context should exist");
         TEST_RESULT_INT(memContextTop()->contextChildListSize, 0, "top context should init with zero children");
@@ -83,9 +88,9 @@ testRun(void)
         TEST_RESULT_PTR(memContextCurrent(), memContextTop(), "top context == current context");
 
         // Context name length errors
-        TEST_ERROR(memContextNew(""), AssertError, "assertion 'name[0] != '\\0'' failed");
+        TEST_ERROR(memContextNewP(""), AssertError, "assertion 'name[0] != '\\0'' failed");
 
-        MemContext *memContext = memContextNew("test1");
+        MemContext *memContext = memContextNewP("test1");
         memContextKeep();
         TEST_RESULT_Z(memContextName(memContext), "test1", "test1 context name");
         TEST_RESULT_PTR(memContext->contextParent, memContextTop(), "test1 context parent is top");
@@ -101,7 +106,7 @@ testRun(void)
         for (int contextIdx = 1; contextIdx < MEM_CONTEXT_INITIAL_SIZE; contextIdx++)
         {
             memContextSwitch(memContextTop());
-            memContextNew("test-filler");
+            memContextNewP("test-filler");
             memContextKeep();
             TEST_RESULT_BOOL(
                 memContextTop()->contextChildList[contextIdx]->state == memContextStateActive, true, "new context is active");
@@ -109,20 +114,22 @@ testRun(void)
         }
 
         // This forces the child context array to grow
-        memContextNew("test5");
+        memContext = memContextNewP("test5", .allocExtra = 16);
+        TEST_RESULT_PTR(memContextAllocExtra(memContext), memContext + 1, "mem context alloc extra");
+        TEST_RESULT_PTR(memContextFromAllocExtra(memContext + 1), memContext, "mem context from alloc extra");
+        TEST_RESULT_PTR(memContextConstFromAllocExtra(memContext + 1), memContext, "const mem context from alloc extra");
         memContextKeep();
         TEST_RESULT_INT(memContextTop()->contextChildListSize, MEM_CONTEXT_INITIAL_SIZE * 2, "increased child context list size");
         TEST_RESULT_UINT(memContextTop()->contextChildFreeIdx, MEM_CONTEXT_INITIAL_SIZE + 1, "check context free idx");
 
         // Free a context
         memContextFree(memContextTop()->contextChildList[1]);
-        TEST_RESULT_BOOL(
-            memContextTop()->contextChildList[1]->state == memContextStateActive, false, "child context inactive after free");
+        TEST_RESULT_PTR(memContextTop()->contextChildList[1], NULL, "child context NULL after free");
         TEST_RESULT_PTR(memContextCurrent(), memContextTop(), "current context is top");
         TEST_RESULT_UINT(memContextTop()->contextChildFreeIdx, 1, "check context free idx");
 
         // Create a new context and it should end up in the same spot
-        memContextNew("test-reuse");
+        memContextNewP("test-reuse");
         memContextKeep();
         TEST_RESULT_BOOL(
             memContextTop()->contextChildList[1]->state == memContextStateActive,
@@ -131,13 +138,13 @@ testRun(void)
         TEST_RESULT_UINT(memContextTop()->contextChildFreeIdx, 2, "check context free idx");
 
         // Next context will be at the end
-        memContextNew("test-at-end");
+        memContextNewP("test-at-end");
         memContextKeep();
         TEST_RESULT_UINT(memContextTop()->contextChildFreeIdx, MEM_CONTEXT_INITIAL_SIZE + 2, "check context free idx");
 
         // Create a child context to test recursive free
         memContextSwitch(memContextTop()->contextChildList[MEM_CONTEXT_INITIAL_SIZE]);
-        memContextNew("test-reuse");
+        memContextNewP("test-reuse");
         memContextKeep();
         TEST_RESULT_PTR_NE(
             memContextTop()->contextChildList[MEM_CONTEXT_INITIAL_SIZE]->contextChildList, NULL, "context child list is allocated");
@@ -146,20 +153,17 @@ testRun(void)
             "context child list initial size");
 
         // This test will change if the contexts above change
-        TEST_RESULT_UINT(memContextSize(memContextTop()), TEST_64BIT() ? 960 : 544, "check size");
+        TEST_RESULT_UINT(memContextSize(memContextTop()), TEST_64BIT() ? 688 : 448, "check size");
 
         TEST_ERROR(
             memContextFree(memContextTop()->contextChildList[MEM_CONTEXT_INITIAL_SIZE]),
             AssertError, "cannot free current context 'test5'");
 
         memContextSwitch(memContextTop());
-        memContextFree(memContextTop()->contextChildList[MEM_CONTEXT_INITIAL_SIZE]);
+        // memContextFree(memContextTop()->contextChildList[MEM_CONTEXT_INITIAL_SIZE]);
+        memContextFree(memContextTop());
 
-        TEST_ERROR(
-            memContextFree(memContextTop()->contextChildList[MEM_CONTEXT_INITIAL_SIZE]),
-            AssertError, "cannot free inactive context");
-
-        MemContext *noAllocation = memContextNew("empty");
+        MemContext *noAllocation = memContextNewP("empty");
         memContextKeep();
         noAllocation->allocListSize = 0;
         free(noAllocation->allocList);
@@ -167,8 +171,13 @@ testRun(void)
     }
 
     // *****************************************************************************************************************************
-    if (testBegin("memContextAlloc(), memNew*(), memGrow(), and memFree()"))
+    if (testBegin("memContextAlloc*(), memNew*(), memGrow(), and memFree()"))
     {
+        TEST_TITLE("struct size");
+
+        TEST_RESULT_UINT(sizeof(MemContextAlloc), 8, "MemContextAlloc size");
+
+        // -------------------------------------------------------------------------------------------------------------------------
         TEST_RESULT_UINT(sizeof(MemContextAlloc), 8, "check MemContextAlloc size (same for 32/64 bit)");
         TEST_RESULT_PTR(MEM_CONTEXT_ALLOC_BUFFER((void *)1), (void *)(sizeof(MemContextAlloc) + 1), "check buffer macro");
         TEST_RESULT_PTR(MEM_CONTEXT_ALLOC_HEADER((void *)sizeof(MemContextAlloc)), (void *)0, "check header macro");
@@ -176,7 +185,7 @@ testRun(void)
         memContextSwitch(memContextTop());
         memNewPtrArray(1);
 
-        MemContext *memContext = memContextNew("test-alloc");
+        MemContext *memContext = memContextNewP("test-alloc");
         TEST_ERROR(memContextSwitchBack(), AssertError, "current context expected but new context 'test-alloc' found");
         memContextKeep();
         memContextSwitch(memContext);
@@ -223,7 +232,7 @@ testRun(void)
         TEST_RESULT_UINT(memContextCurrent()->allocFreeIdx, MEM_CONTEXT_ALLOC_INITIAL_SIZE + 3, "check alloc free idx");
 
         // This test will change if the allocations above change
-        TEST_RESULT_UINT(memContextSize(memContextCurrent()), TEST_64BIT() ? 249 : 165, "check size");
+        TEST_RESULT_UINT(memContextSize(memContextCurrent()), TEST_64BIT() ? 241 : 165, "check size");
 
         TEST_ERROR(
             memFree(NULL), AssertError,
@@ -245,7 +254,7 @@ testRun(void)
         TEST_ERROR(
             memContextCallbackSet(memContextTop(), testFree, NULL), AssertError, "top context may not have a callback");
 
-        MemContext *memContext = memContextNew("test-callback");
+        MemContext *memContext = memContextNewP("test-callback");
         memContextKeep();
         memContextCallbackSet(memContext, testFree, memContext);
         TEST_ERROR(
@@ -261,19 +270,18 @@ testRun(void)
 
         // Now test with an error
         // -------------------------------------------------------------------------------------------------------------------------
-        memContext = memContextNew("test-callback-error");
+        memContext = memContextNewP("test-callback-error");
         TEST_RESULT_VOID(memContextKeep(), "keep mem context");
         testFreeThrow = true;
         TEST_RESULT_VOID(memContextCallbackSet(memContext, testFree, memContext), "    set callback");
         TEST_ERROR(memContextFree(memContext), AssertError, "error in callback");
-        TEST_RESULT_UINT(memContext->state, memContextStateFree, "    check that mem context was completely freed");
     }
 
     // *****************************************************************************************************************************
     if (testBegin("MEM_CONTEXT_BEGIN() and MEM_CONTEXT_END()"))
     {
         memContextSwitch(memContextTop());
-        MemContext *memContext = memContextNew("test-block");
+        MemContext *memContext = memContextNewP("test-block");
         memContextKeep();
 
         // Check normal block
@@ -301,12 +309,12 @@ testRun(void)
         // -------------------------------------------------------------------------------------------------------------------------
         MEM_CONTEXT_TEMP_RESET_BEGIN()
         {
-            TEST_RESULT_PTR(MEM_CONTEXT_TEMP()->allocList[0], NULL, "nothing allocated");
+            TEST_RESULT_PTR(MEM_CONTEXT_TEMP()->allocList, NULL, "nothing allocated");
             memNew(99);
             TEST_RESULT_PTR_NE(MEM_CONTEXT_TEMP()->allocList[0], NULL, "1 allocation");
 
             MEM_CONTEXT_TEMP_RESET(1);
-            TEST_RESULT_PTR(MEM_CONTEXT_TEMP()->allocList[0], NULL, "nothing allocated");
+            TEST_RESULT_PTR(MEM_CONTEXT_TEMP()->allocList, NULL, "nothing allocated");
         }
         MEM_CONTEXT_TEMP_END();
     }
@@ -325,7 +333,7 @@ testRun(void)
         {
             memContext = MEM_CONTEXT_NEW();
             TEST_RESULT_PTR(memContext, memContextCurrent(), "new mem context is current");
-            TEST_RESULT_Z(memContextName(memContext), memContextTestName, "context is now '%s'", memContextTestName);
+            TEST_RESULT_Z(memContextName(memContext), memContextTestName, "check context name");
         }
         MEM_CONTEXT_NEW_END();
 
@@ -344,7 +352,7 @@ testRun(void)
             MEM_CONTEXT_NEW_BEGIN(memContextTestName)
             {
                 memContext = MEM_CONTEXT_NEW();
-                TEST_RESULT_Z(memContextName(memContext), memContextTestName, "context is now '%s'", memContextTestName);
+                TEST_RESULT_Z(memContextName(memContext), memContextTestName, "check mem context name");
                 THROW(AssertError, "create failed");
             }
             MEM_CONTEXT_NEW_END();
@@ -357,7 +365,6 @@ testRun(void)
 
         TEST_RESULT_BOOL(bCatch, true, "new context error was caught");
         TEST_RESULT_PTR(memContextCurrent(), memContextTop(), "context is now 'TOP'");
-        TEST_RESULT_UINT(memContext->state == memContextStateFree, true, "new mem context is not active");
     }
 
     // *****************************************************************************************************************************
@@ -375,7 +382,7 @@ testRun(void)
         {
             MEM_CONTEXT_TEMP_BEGIN()
             {
-                memContextNew("not-to-be-moved");
+                memContextNewP("not-to-be-moved");
                 memContextKeep();
 
                 MEM_CONTEXT_NEW_BEGIN("inner")
@@ -390,7 +397,9 @@ testRun(void)
 
                 // Null out the mem context in the parent so the move will fail
                 memContextCurrent()->contextChildList[1] = NULL;
-                TEST_ERROR(memContextMove(memContext, memContextPrior()), AssertError, "unable to find mem context in old parent");
+                TEST_ERROR(
+                    memContextMove(memContext, memContextPrior()), AssertError,
+                    "assertion 'this->contextParent->contextChildList[this->contextParentIdx] == this' failed");
 
                 // Set it back so the move will succeed
                 memContextCurrent()->contextChildList[1] = memContext;
