@@ -6,7 +6,7 @@ Test Stack Trace Handler
 /***********************************************************************************************************************************
 Test Run
 ***********************************************************************************************************************************/
-void
+static void
 testRun(void)
 {
     FUNCTION_HARNESS_VOID();
@@ -44,7 +44,7 @@ testRun(void)
     // *****************************************************************************************************************************
     if (testBegin("stackTraceTestStart(), stackTraceTestStop(), and stackTraceTest()"))
     {
-#ifndef NDEBUG
+#ifdef DEBUG
         assert(stackTraceTest());
 
         stackTraceTestStop();
