@@ -6,7 +6,7 @@ Test Time Management
 /***********************************************************************************************************************************
 Test Run
 ***********************************************************************************************************************************/
-void
+static void
 testRun(void)
 {
     FUNCTION_HARNESS_VOID();
@@ -22,11 +22,24 @@ testRun(void)
     // *****************************************************************************************************************************
     if (testBegin("sleepMSec()"))
     {
+        TEST_TITLE("sleep 0ms");
+
         // Sleep and measure time slept
         TimeMSec begin = timeMSec();
-        sleepMSec(1400);
+        sleepMSec(0);
         TimeMSec end = timeMSec();
 
+        // Check bounds for time slept (within a range of .02 seconds)
+        TEST_RESULT_BOOL(end - begin < (TimeMSec)20, true, "upper range check");
+
+        // -------------------------------------------------------------------------------------------------------------------------
+        TEST_TITLE("sleep 1400ms");
+
+        // Sleep and measure time slept
+        begin = timeMSec();
+        sleepMSec(1400);
+        end = timeMSec();
+
         // Check bounds for time slept (within a range of .1 seconds)
         TEST_RESULT_BOOL(end - begin >= (TimeMSec)1400, true, "lower range check");
         TEST_RESULT_BOOL(end - begin < (TimeMSec)1500, true, "upper range check");
