@@ -24,7 +24,7 @@ testComparator(const void *item1, const void *item2)
 /***********************************************************************************************************************************
 Test Run
 ***********************************************************************************************************************************/
-void
+static void
 testRun(void)
 {
     FUNCTION_HARNESS_VOID();
@@ -35,9 +35,9 @@ testRun(void)
         List *list = lstNewP(sizeof(void *));
 
         TEST_RESULT_UINT(list->itemSize, sizeof(void *), "item size");
-        TEST_RESULT_UINT(list->listSize, 0, "list size");
+        TEST_RESULT_UINT(list->pub.listSize, 0, "list size");
         TEST_RESULT_UINT(list->listSizeMax, 0, "list size max");
-        TEST_RESULT_PTR(lstMemContext(list), list->memContext, "list mem context");
+        TEST_RESULT_PTR(lstMemContext(list), objMemContext(list), "list mem context");
         TEST_RESULT_VOID(lstClear(list), "clear list");
 
         void *ptr = NULL;
@@ -53,12 +53,12 @@ testRun(void)
 
         TEST_ASSIGN(list, lstNewP(sizeof(String *), .comparator = lstComparatorStr), "new list with params");
 
-        String *string1 = strNew("string1");
+        const String *string1 = STRDEF("string1");
         TEST_RESULT_STR_Z(*(String **)lstAdd(list, &string1), "string1", "    add string1");
-        String *string2 = strNew("string2");
+        const String *string2 = STRDEF("string2");
         TEST_RESULT_VOID(lstAdd(list, &string2), "    add string2");
 
-        String *string3 = strNew("string3");
+        const String *string3 = STRDEF("string3");
         TEST_RESULT_PTR(lstFindDefault(list, &string3, (void *)1), (void *)1, "    find string3 returns default");
         TEST_RESULT_BOOL(lstExists(list, &string3), false, "    string3 does not exist");
         TEST_RESULT_STR_Z(*(String **)lstFind(list, &string2), "string2", "    find string2");
@@ -86,7 +86,9 @@ testRun(void)
 
             // Add ints to the list
             for (int listIdx = 1; listIdx <= LIST_INITIAL_SIZE; listIdx++)
-                TEST_RESULT_VOID(lstAdd(list, &listIdx), "add item %d", listIdx);
+            {
+                TEST_RESULT_VOID(lstAdd(list, &listIdx), strZ(strNewFmt("add item %d", listIdx)));
+            }
 
             lstMove(list, memContextPrior());
         }
@@ -94,7 +96,7 @@ testRun(void)
 
         // Insert an int at the beginning
         int insertIdx = 0;
-        TEST_RESULT_INT(*(int *)lstInsert(list, 0, &insertIdx), 0, "insert item %d", insertIdx);
+        TEST_RESULT_INT(*(int *)lstInsert(list, 0, &insertIdx), 0, strZ(strNewFmt("insert item %d", insertIdx)));
 
         // Check the size
         TEST_RESULT_INT(lstSize(list), 9, "list size");
@@ -104,7 +106,7 @@ testRun(void)
         for (unsigned int listIdx = 0; listIdx < lstSize(list); listIdx++)
         {
             int *item = lstGet(list, listIdx);
-            TEST_RESULT_INT(*item, listIdx, "check item %u", listIdx);
+            TEST_RESULT_INT(*item, listIdx, strZ(strNewFmt("check item %u", listIdx)));
         }
 
         // Remove first item
@@ -115,7 +117,7 @@ testRun(void)
         {
             int *item = listIdx == lstSize(list) - 1 ? lstGetLast(list) : lstGet(list, listIdx);
 
-            TEST_RESULT_INT(*item, listIdx + 1, "check item %u", listIdx);
+            TEST_RESULT_INT(*item, listIdx + 1, strZ(strNewFmt("check item %u", listIdx)));
         }
 
         // -------------------------------------------------------------------------------------------------------------------------
@@ -127,10 +129,10 @@ testRun(void)
         for (int listIdx = 0; listIdx < 8; listIdx++)
         {
             int item = listIdx + 9;
-            TEST_RESULT_VOID(lstAdd(list, &item), "add item %d", item);
+            TEST_RESULT_VOID(lstAdd(list, &item), strZ(strNewFmt("add item %d", item)));
         }
 
-        TEST_RESULT_INT(list->listSize, list->listSizeMax, "size equals max size");
+        TEST_RESULT_UINT(lstSize(list), list->listSizeMax, "size equals max size");
 
         // Remove last item
         TEST_RESULT_VOID(lstRemoveLast(list), "remove last item");
@@ -139,7 +141,7 @@ testRun(void)
         for (unsigned int listIdx = 0; listIdx < lstSize(list); listIdx++)
         {
             int *item = lstGet(list, listIdx);
-            TEST_RESULT_INT(*item, listIdx + 1, "check item %u", listIdx);
+            TEST_RESULT_INT(*item, listIdx + 1, strZ(strNewFmt("check item %u", listIdx)));
         }
 
         TEST_ERROR(lstGet(list, lstSize(list)), AssertError, "cannot get index 15 from list with 15 value(s)");
@@ -178,6 +180,16 @@ testRun(void)
         TEST_RESULT_INT(*(int *)lstGet(list, 1), 3, "sort value 1");
         TEST_RESULT_INT(*(int *)lstGet(list, 2), 3, "sort value 2");
         TEST_RESULT_INT(*(int *)lstGet(list, 3), 2, "sort value 3");
+
+        // -------------------------------------------------------------------------------------------------------------------------
+        TEST_TITLE("lstComparatorZ()");
+
+        const char *string1 = "abc";
+        const char *string2 = "def";
+
+        TEST_RESULT_INT(lstComparatorZ(&string1, &string1), 0, "strings are equal");
+        TEST_RESULT_BOOL(lstComparatorZ(&string1, &string2) < 0, true, "first string is less");
+        TEST_RESULT_BOOL(lstComparatorZ(&string2, &string1) > 0, true, "first string is greater");
     }
 
     // *****************************************************************************************************************************
@@ -191,7 +203,7 @@ testRun(void)
         for (int listIdx = 0; listIdx < testMax; listIdx++)
             lstAdd(list, &listIdx);
 
-        CHECK(lstSize(list) == (unsigned int)testMax);
+        ASSERT(lstSize(list) == (unsigned int)testMax);
 
         // -------------------------------------------------------------------------------------------------------------------------
         TEST_TITLE("search ascending sort");
@@ -199,7 +211,7 @@ testRun(void)
         lstSort(list, sortOrderAsc);
 
         for (int listIdx = 0; listIdx < testMax; listIdx++)
-            CHECK(*(int *)lstFind(list, &listIdx) == listIdx);
+            ASSERT(*(int *)lstFind(list, &listIdx) == listIdx);
 
         // -------------------------------------------------------------------------------------------------------------------------
         TEST_TITLE("search descending sort");
@@ -207,7 +219,7 @@ testRun(void)
         lstSort(list, sortOrderDesc);
 
         for (int listIdx = 0; listIdx < testMax; listIdx++)
-            CHECK(*(int *)lstFind(list, &listIdx) == listIdx);
+            ASSERT(*(int *)lstFind(list, &listIdx) == listIdx);
     }
 
     FUNCTION_HARNESS_RETURN_VOID();
