@@ -9,7 +9,7 @@ Test Pack Type
 /***********************************************************************************************************************************
 Test Run
 ***********************************************************************************************************************************/
-void
+static void
 testRun(void)
 {
     FUNCTION_HARNESS_VOID();
@@ -17,6 +17,12 @@ testRun(void)
     // *****************************************************************************************************************************
     if (testBegin("PackWrite and PackRead"))
     {
+        TEST_TITLE("type size");
+
+        TEST_RESULT_UINT(sizeof(PackType), 4, "PackType");
+        TEST_RESULT_UINT(sizeof(PackTypeMapData), 8, "PackTypeMapData");
+
+        // -------------------------------------------------------------------------------------------------------------------------
         TEST_TITLE("write pack");
 
         Buffer *pack = bufNew(0);
@@ -27,11 +33,16 @@ testRun(void)
         ioBufferSizeSet(3);
 
         PackWrite *packWrite = NULL;
-        TEST_ASSIGN(packWrite, pckWriteNew(write), "new write");
 
-        TEST_RESULT_STR_Z(pckWriteToLog(packWrite), "{depth: 1, idLast: 0}", "log");
+        MEM_CONTEXT_TEMP_BEGIN()
+        {
+            TEST_ASSIGN(packWrite, pckWriteMove(pckWriteNewIo(write), memContextPrior()), "move new write");
+        }
+        MEM_CONTEXT_TEMP_END();
+
+        TEST_RESULT_STR_Z(pckWriteToLog(packWrite), "{depth: 0, idLast: 0}", "log");
         TEST_RESULT_VOID(pckWriteU64P(packWrite, 0750), "write mode");
-        TEST_RESULT_STR_Z(pckWriteToLog(packWrite), "{depth: 1, idLast: 1}", "log");
+        TEST_RESULT_STR_Z(pckWriteToLog(packWrite), "{depth: 0, idLast: 1}", "log");
         TEST_RESULT_VOID(pckWriteU64P(packWrite, 1911246845), "write timestamp");
         TEST_RESULT_VOID(pckWriteU64P(packWrite, 0xFFFFFFFFFFFFFFFF, .id = 7), "write max u64");
         TEST_RESULT_VOID(pckWriteU64P(packWrite, 1, .id = 10), "write 1");
@@ -44,6 +55,10 @@ testRun(void)
         TEST_RESULT_VOID(pckWriteObjBeginP(packWrite, .id = 28), "write obj begin");
         TEST_RESULT_VOID(pckWriteBoolP(packWrite, true), "write true");
         TEST_RESULT_VOID(pckWriteBoolP(packWrite, false, .defaultWrite = true), "write false");
+        TEST_RESULT_VOID(pckWriteStrIdP(packWrite, pckTypeTime, .id = 5), "write strid");
+        TEST_RESULT_VOID(pckWriteStrIdP(packWrite, pckTypeTime, .defaultValue = pckTypeTime), "write default strid");
+        TEST_RESULT_VOID(pckWriteModeP(packWrite, 0707, .id = 7), "write mode");
+        TEST_RESULT_VOID(pckWriteModeP(packWrite, 0644, .defaultValue = 0644), "write default mode");
         TEST_RESULT_VOID(pckWriteObjEndP(packWrite), "write obj end");
         TEST_RESULT_VOID(pckWriteArrayBeginP(packWrite, .id = 37), "write array begin");
         TEST_RESULT_VOID(pckWriteU64P(packWrite, 0, .defaultWrite = true), "write 0");
@@ -85,13 +100,31 @@ testRun(void)
         TEST_RESULT_VOID(pckWriteBinP(packWrite, NULL), "write bin NULL default");
         TEST_RESULT_VOID(pckWriteBinP(packWrite, bufNew(0)), "write bin zero length");
 
+        // Write pack
+        PackWrite *packSub = pckWriteNewP();
+        pckWriteU64P(packSub, 345);
+        pckWriteStrP(packSub, STRDEF("sub"), .id = 3);
+        pckWriteEndP(packSub);
+
+        TEST_RESULT_VOID(pckWritePackP(packWrite, pckWriteResult(packSub)), "write pack");
+        TEST_RESULT_VOID(pckWritePackP(packWrite, NULL), "write null pack");
+
+        // Write string list
+        StringList *const strList = strLstNew();
+        strLstAddZ(strList, "a");
+        strLstAddZ(strList, "bcd");
+
+        TEST_RESULT_VOID(pckWriteStrLstP(packWrite, strList), "write string list");
+        TEST_RESULT_VOID(pckWriteStrLstP(packWrite, NULL), "write null string list");
+
+        // End pack
         TEST_RESULT_VOID(pckWriteEndP(packWrite), "end");
         TEST_RESULT_VOID(pckWriteFree(packWrite), "free");
 
         ioWriteClose(write);
 
         TEST_RESULT_STR_Z(
-            hrnPackBufToStr(pack),
+            hrnPackToStr(pckFromBuf(pack)),
                "1:u64:488"
              ", 2:u64:1911246845"
              ", 7:u64:18446744073709551615"
@@ -106,6 +139,8 @@ testRun(void)
             "{"
                   "1:bool:true"
                 ", 2:bool:false"
+                ", 5:strid:time"
+                ", 7:mode:0707"
             "}"
             ", 37:array:"
             "["
@@ -135,51 +170,57 @@ testRun(void)
                 ", 6:time:66"
             "]"
             ", 49:bin:050403020100"
-            ", 51:bin:",
+            ", 51:bin:"
+            ", 52:pack:<1:u64:345, 3:str:sub>"
+            ", 54:array:[1:str:a, 2:str:bcd]",
             "check pack string");
 
         TEST_RESULT_STR_Z(
             bufHex(pack),
-            "b8e803"                                                //  1,  u64, 750
-            "b8fd9fad8f07"                                          //  2,  u64, 1911246845
-            "bc01ffffffffffffffffff01"                              //  7,  u64, 0xFFFFFFFFFFFFFFFF
-            "b601"                                                  // 10,  u64, 1
-            "b84d"                                                  // 11,  u64, 77
-            "a87f"                                                  // 12,  u32, 127
-            "54"                                                    // 13,  i64, -1
-            "44"                                                    // 14,  i32, -1
-            "38"                                                    // 15, bool, true
-            "3401"                                                  // 20, bool, false
-            "67"                                                    // 28, obj begin
-                "38"                                                //      1, bool
-                "30"                                                //      2, bool
+            "98e803"                                                //  1,  u64, 750
+            "98fd9fad8f07"                                          //  2,  u64, 1911246845
+            "9c01ffffffffffffffffff01"                              //  7,  u64, 0xFFFFFFFFFFFFFFFF
+            "9601"                                                  // 10,  u64, 1
+            "984d"                                                  // 11,  u64, 77
+            "887f"                                                  // 12,  u32, 127
+            "44"                                                    // 13,  i64, -1
+            "34"                                                    // 14,  i32, -1
+            "28"                                                    // 15, bool, true
+            "2401"                                                  // 20, bool, false
+            "57"                                                    // 28, obj begin
+                "28"                                                //      1, bool
+                "20"                                                //      2, bool
+                "aac0a6ad01"                                        //      5, strid time
+                "f903c703"                                          //      7, mode 0707
                 "00"                                                //     obj end
             "1801"                                                  // 37, array begin
-                "b0"                                                //      1,  u64, 0
-                "b4"                                                //      2,  u64, 1
-                "b802"                                              //      3,  u64, 2
-                "b803"                                              //      4,  u64, 3
+                "90"                                                //      1,  u64, 0
+                "94"                                                //      2,  u64, 1
+                "9802"                                              //      3,  u64, 2
+                "9803"                                              //      4,  u64, 3
                 "00"                                                //     array end
-            "880673616d706c65"                                      // 38,  str, sample
-            "8816656e6f756768746f696e637265617365627566666572"      // 39,  str, enoughtoincreasebuffer
-            "80"                                                    // 40,  str, zero length
-            "8805736d616c6c"                                        // 41,  str, small
-            "80"                                                    // 42,  str, zero length
-            "82"                                                    // 45,  str, zero length
-            "a1"                                                    // 47,  u32, 0
+            "780673616d706c65"                                      // 38,  str, sample
+            "7816656e6f756768746f696e637265617365627566666572"      // 39,  str, enoughtoincreasebuffer
+            "70"                                                    // 40,  str, zero length
+            "7805736d616c6c"                                        // 41,  str, small
+            "70"                                                    // 42,  str, zero length
+            "72"                                                    // 45,  str, zero length
+            "81"                                                    // 47,  u32, 0
             "10"                                                    // 48, array begin
-                "60"                                                //      1, obj begin
-                    "48d608"                                        //           1, i32, 555
-                    "49920c"                                        //           3, i32, 777
-                    "5902"                                          //           5, i64, 1
-                    "b5"                                            //           7, u64, 1
+                "50"                                                //      1, obj begin
+                    "38d608"                                        //           1, i32, 555
+                    "39920c"                                        //           3, i32, 777
+                    "4902"                                          //           5, i64, 1
+                    "95"                                            //           7, u64, 1
                     "00"                                            //         obj end
-                "890141"                                            //      3,  str, A
-                "9942"                                              //      5, time, 33
-                "988401"                                            //      6, time, 66
+                "790141"                                            //      3,  str, A
+                "f90042"                                            //      5, time, 33
+                "f8008401"                                          //      6, time, 66
                 "00"                                                //     array end
-            "2806050403020100"                                      // 49,  bin, 0x050403020100
-            "21"                                                    // 51,  bin, zero length
+            "f80106050403020100"                                    // 49,  bin, 0x050403020100
+            "f101"                                                  // 51,  bin, zero length
+            "f0020998d902790373756200"                              // 52,  pack, 1:u64:345, 3:str:sub
+            "11780161780362636400"                                  // 54,  strlst, 1:str:a, 2:str:bcd
             "00",                                                   // end
             "check pack hex");
 
@@ -190,7 +231,12 @@ testRun(void)
         ioReadOpen(read);
 
         PackRead *packRead = NULL;
-        TEST_ASSIGN(packRead, pckReadNew(read), "new read");
+
+        MEM_CONTEXT_TEMP_BEGIN()
+        {
+            TEST_ASSIGN(packRead, pckReadMove(pckReadNewIo(read), memContextPrior()), "move new read");
+        }
+        MEM_CONTEXT_TEMP_END();
 
         TEST_RESULT_UINT(pckReadU64P(packRead), 0750, "read mode");
         TEST_RESULT_UINT(pckReadU64P(packRead), 1911246845, "read timestamp");
@@ -206,13 +252,17 @@ testRun(void)
         TEST_RESULT_BOOL(pckReadBoolP(packRead, .id = 15), true, "read true");
         TEST_RESULT_BOOL(pckReadBoolP(packRead, .id = 20), false, "read false");
 
-        TEST_ERROR(pckReadObjEndP(packRead), FormatError, "not in object");
+        TEST_ERROR(pckReadObjEndP(packRead), FormatError, "not in obj");
         TEST_RESULT_VOID(pckReadObjBeginP(packRead, .id = 28), "read object begin");
         TEST_ERROR(pckReadArrayEndP(packRead), FormatError, "not in array");
         TEST_RESULT_BOOL(pckReadBoolP(packRead), true, "read true");
         TEST_RESULT_BOOL(pckReadBoolP(packRead), false, "read false");
-        TEST_RESULT_BOOL(pckReadBoolP(packRead), false, "field 3 default is false");
+        TEST_RESULT_BOOL(pckReadBoolP(packRead), false, "field 4 default is false");
         TEST_RESULT_BOOL(pckReadNullP(packRead, .id = 4), true, "field 4 is null");
+        TEST_RESULT_UINT(pckReadStrIdP(packRead), pckTypeTime, "read strid");
+        TEST_RESULT_UINT(pckReadStrIdP(packRead, .defaultValue = pckTypeTime), pckTypeTime, "read default strid");
+        TEST_RESULT_UINT(pckReadModeP(packRead), 0707, "read mode");
+        TEST_RESULT_UINT(pckReadModeP(packRead, .defaultValue = 0644), 0644, "read default mode");
         TEST_RESULT_BOOL(pckReadBoolP(packRead), false, "read default false");
         TEST_RESULT_VOID(pckReadObjEndP(packRead), "read object end");
 
@@ -221,13 +271,13 @@ testRun(void)
         TEST_RESULT_UINT(pckReadId(packRead), 37, "check array id");
         TEST_RESULT_VOID(pckReadArrayBeginP(packRead, .id = pckReadId(packRead)), "read array begin");
 
-        TEST_ERROR(pckReadObjEndP(packRead), FormatError, "not in object");
+        TEST_ERROR(pckReadObjEndP(packRead), FormatError, "not in obj");
 
         unsigned int value = 0;
 
         while (pckReadNext(packRead))
         {
-            TEST_RESULT_UINT(pckReadU64P(packRead, .id = pckReadId(packRead)), value, "read %u", value);
+            TEST_RESULT_UINT(pckReadU64P(packRead, .id = pckReadId(packRead)), value, strZ(strNewFmt("read %u", value)));
             value++;
         }
 
@@ -262,6 +312,12 @@ testRun(void)
         TEST_RESULT_PTR(pckReadBinP(packRead), NULL, "read bin null");
         TEST_RESULT_UINT(bufSize(pckReadBinP(packRead)), 0, "read bin zero length");
 
+        TEST_RESULT_STR_Z(hrnPackReadToStr(pckReadPackReadP(packRead)), "1:u64:345, 3:str:sub", "read pack");
+        TEST_RESULT_PTR(pckReadPackReadP(packRead), NULL, "read null pack");
+
+        TEST_RESULT_STRLST_Z(pckReadStrLstP(packRead), "a\nbcd\n", "read string list");
+        TEST_RESULT_PTR(pckReadStrLstP(packRead), NULL, "read null string list");
+
         TEST_RESULT_BOOL(pckReadNullP(packRead, .id = 999), true, "field 999 is null");
         TEST_RESULT_UINT(pckReadU64P(packRead, .id = 1000), 0, "field 1000 default is 0");
 
@@ -271,29 +327,62 @@ testRun(void)
         // -------------------------------------------------------------------------------------------------------------------------
         TEST_TITLE("EOF on short buffer");
 
-        TEST_ASSIGN(packRead, pckReadNewBuf(BUFSTRDEF("\255")), "new read");
-        TEST_ERROR(pckReadUInt64Internal(packRead), FormatError, "unexpected EOF");
+        TEST_ASSIGN(packRead, pckReadNew(pckFromBuf(BUFSTRDEF("\255"))), "new read");
+        TEST_ERROR(pckReadU64Internal(packRead), FormatError, "unexpected EOF");
 
         // -------------------------------------------------------------------------------------------------------------------------
         TEST_TITLE("error on invalid uint64");
 
-        TEST_ASSIGN(packRead, pckReadNewBuf(BUFSTRDEF("\255\255\255\255\255\255\255\255\255\255")), "new read");
-        TEST_ERROR(pckReadUInt64Internal(packRead), FormatError, "unterminated base-128 integer");
+        TEST_ASSIGN(packRead, pckReadNew(pckFromBuf(BUFSTRDEF("\255\255\255\255\255\255\255\255\255\255"))), "new read");
+        TEST_ERROR(pckReadU64Internal(packRead), FormatError, "unterminated base-128 integer");
 
         // -------------------------------------------------------------------------------------------------------------------------
         TEST_TITLE("pack/unpack pointer");
 
-        pack = bufNew(0);
-
-        TEST_ASSIGN(packWrite, pckWriteNewBuf(pack), "new write");
+        TEST_ASSIGN(packWrite, pckWriteNewP(.size = 1), "new write");
         TEST_RESULT_VOID(pckWritePtrP(packWrite, NULL), "write default pointer");
         TEST_RESULT_VOID(pckWritePtrP(packWrite, "sample"), "write pointer");
         TEST_RESULT_VOID(pckWriteEndP(packWrite), "write end");
 
-        TEST_ASSIGN(packRead, pckReadNewBuf(pack), "new read");
+        TEST_ASSIGN(packRead, pckReadNew(pckDup(pckWriteResult(packWrite))), "new read");
         TEST_RESULT_Z(pckReadPtrP(packRead), NULL, "read default pointer");
         TEST_RESULT_Z(pckReadPtrP(packRead, .id = 2), "sample", "read pointer");
 
+        TEST_RESULT_PTR(pckWriteResult(NULL), NULL, "null pack result");
+
+        // -------------------------------------------------------------------------------------------------------------------------
+        TEST_TITLE("read const packs");
+
+        TEST_ASSIGN(packWrite, pckWriteNewP(), "new write");
+
+        // Write pack to read as ptr/size
+        packSub = pckWriteNewP();
+        pckWriteU64P(packSub, 777);
+        pckWriteEndP(packSub);
+
+        TEST_RESULT_VOID(pckWritePackP(packWrite, pckWriteResult(packSub)), "write pack");
+
+        // Write pack to read as const
+        TEST_RESULT_VOID(pckWritePackP(packWrite, NULL), "write pack");
+
+        packSub = pckWriteNewP();
+        pckWriteU64P(packSub, 99);
+        pckWriteEndP(packSub);
+
+        TEST_RESULT_VOID(pckWritePackP(packWrite, pckWriteResult(packSub)), "write pack");
+        TEST_RESULT_VOID(pckWriteEndP(packWrite), "write pack end");
+
+        TEST_ASSIGN(packRead, pckReadNew(pckWriteResult(packWrite)), "new read");
+
+        TEST_RESULT_BOOL(pckReadNext(packRead), true, "next pack");
+        TEST_RESULT_UINT(pckReadSize(packRead), 4, "pack size");
+        TEST_RESULT_STR_Z(bufHex(BUF(pckReadBufPtr(packRead), pckReadSize(packRead))), "98890600", "pack hex");
+        TEST_RESULT_UINT(pckReadU64P(pckReadNewC(pckReadBufPtr(packRead), pckReadSize(packRead))), 777, "u64 value");
+        TEST_RESULT_VOID(pckReadConsume(packRead), "consume pack");
+
+        TEST_RESULT_PTR(pckReadPackReadConstP(packRead), NULL, "const null pack");
+        TEST_RESULT_UINT(pckReadU64P(pckReadPackReadConstP(packRead)), 99, "const pack");
+
         // -------------------------------------------------------------------------------------------------------------------------
         TEST_TITLE("pack/unpack write internal buffer empty");
 
@@ -304,11 +393,11 @@ testRun(void)
         // Make internal buffer small enough that it will never be used
         ioBufferSizeSet(0);
 
-        TEST_ASSIGN(packWrite, pckWriteNew(write), "new write");
+        TEST_ASSIGN(packWrite, pckWriteNewIo(write), "new write");
         TEST_RESULT_VOID(pckWriteStrP(packWrite, STRDEF("test")), "write string longer than internal buffer");
         TEST_RESULT_VOID(pckWriteEndP(packWrite), "end with internal buffer empty");
 
-        TEST_ASSIGN(packRead, pckReadNewBuf(pack), "new read");
+        TEST_ASSIGN(packRead, pckReadNew(pckFromBuf(pack)), "new read");
         TEST_RESULT_STR_Z(pckReadStrP(packRead), "test", "read string");
     }
 
