@@ -12,7 +12,7 @@ Test Configuration Protocol
 /***********************************************************************************************************************************
 Test run
 ***********************************************************************************************************************************/
-void
+static void
 testRun(void)
 {
     FUNCTION_HARNESS_VOID();
@@ -20,50 +20,42 @@ testRun(void)
     // *****************************************************************************************************************************
     if (testBegin("configOptionProtocol() and configOptionRemote()"))
     {
-        HARNESS_FORK_BEGIN()
+        HRN_FORK_BEGIN()
         {
-            HARNESS_FORK_CHILD_BEGIN(0, true)
+            HRN_FORK_CHILD_BEGIN()
             {
-                IoRead *read = ioFdReadNew(strNew("client read"), HARNESS_FORK_CHILD_READ(), 2000);
-                ioReadOpen(read);
-                IoWrite *write = ioFdWriteNew(strNew("client write"), HARNESS_FORK_CHILD_WRITE(), 2000);
-                ioWriteOpen(write);
-
                 StringList *argList = strLstNew();
-                strLstAddZ(argList, "--stanza=test1");
+                hrnCfgArgRawZ(argList, cfgOptStanza, "test1");
                 hrnCfgArgRawZ(argList, cfgOptPgPath, "/path/to/pg");
-                strLstAddZ(argList, "--repo1-host=repo-host");
-                strLstAddZ(argList, "--repo1-host-user=repo-host-user");
-                harnessCfgLoad(cfgCmdArchiveGet, argList);
+                hrnCfgArgRawZ(argList, cfgOptRepoHost, "repo-host");
+                hrnCfgArgRawZ(argList, cfgOptRepoHostUser, "repo-host-user");
+                HRN_CFG_LOAD(cfgCmdArchiveGet, argList);
 
-                ProtocolServer *server = protocolServerNew(strNew("test"), strNew("config"), read, write);
+                ProtocolServer *server = protocolServerNew(
+                    STRDEF("test"), STRDEF("config"), HRN_FORK_CHILD_READ(), HRN_FORK_CHILD_WRITE());
 
                 static const ProtocolServerHandler commandHandler[] = {PROTOCOL_SERVER_HANDLER_OPTION_LIST};
                 protocolServerProcess(server, NULL, commandHandler, PROTOCOL_SERVER_HANDLER_LIST_SIZE(commandHandler));
             }
-            HARNESS_FORK_CHILD_END();
+            HRN_FORK_CHILD_END();
 
-            HARNESS_FORK_PARENT_BEGIN()
+            HRN_FORK_PARENT_BEGIN()
             {
-                IoRead *read = ioFdReadNew(strNew("server read"), HARNESS_FORK_PARENT_READ_PROCESS(0), 2000);
-                ioReadOpen(read);
-                IoWrite *write = ioFdWriteNew(strNew("server write"), HARNESS_FORK_PARENT_WRITE_PROCESS(0), 2000);
-                ioWriteOpen(write);
-
-                ProtocolClient *client = protocolClientNew(strNew("test"), strNew("config"), read, write);
+                ProtocolClient *client = protocolClientNew(
+                    STRDEF("test"), STRDEF("config"), HRN_FORK_PARENT_READ(0), HRN_FORK_PARENT_WRITE(0));
 
                 VariantList *list = varLstNew();
-                varLstAdd(list, varNewStr(strNew("repo1-host")));
-                varLstAdd(list, varNewStr(strNew("repo1-host-user")));
+                varLstAdd(list, varNewStr(STRDEF("repo1-host")));
+                varLstAdd(list, varNewStr(STRDEF("repo1-host-user")));
 
                 TEST_RESULT_STRLST_Z(
                     strLstNewVarLst(configOptionRemote(client, list)), "repo-host\nrepo-host-user\n", "get options");
 
                 protocolClientFree(client);
             }
-            HARNESS_FORK_PARENT_END();
+            HRN_FORK_PARENT_END();
         }
-        HARNESS_FORK_END();
+        HRN_FORK_END();
     }
 
     FUNCTION_HARNESS_RETURN_VOID();
