@@ -5,6 +5,7 @@ Test PostgreSQL Info Handler
 #include "common/io/bufferWrite.h"
 
 #include "common/harnessInfo.h"
+#include "common/harnessPostgres.h"
 
 /***********************************************************************************************************************************
 Test save callback
@@ -27,7 +28,7 @@ testInfoBackupSaveCallback(void *data, const String *sectionNext, InfoSave *info
 /***********************************************************************************************************************************
 Test Run
 ***********************************************************************************************************************************/
-void
+static void
 testRun(void)
 {
     // *****************************************************************************************************************************
@@ -40,7 +41,7 @@ testRun(void)
         TEST_RESULT_STR(infoCipherPass(infoPgInfo(infoPg)), NULL, "  cipherPass NULL");
         TEST_RESULT_INT(infoPgDataCurrentId(infoPg), 0, "  0 historyCurrent");
 
-        TEST_ASSIGN(infoPg, infoPgNew(infoPgArchive, strNew("123xyz")), "infoPgNew(cipherTypeAes256Cbc, 123xyz)");
+        TEST_ASSIGN(infoPg, infoPgNew(infoPgArchive, STRDEF("123xyz")), "infoPgNew(cipherTypeAes256Cbc, 123xyz)");
         TEST_RESULT_INT(infoPgDataTotal(infoPg), 0, "  0 history");
         TEST_RESULT_STR_Z(infoCipherPass(infoPgInfo(infoPg)), "123xyz", "  cipherPass set");
         TEST_RESULT_INT(infoPgDataCurrentId(infoPg), 0, "  0 historyCurrent");
@@ -50,7 +51,7 @@ testRun(void)
             infoPg,
             infoPgSet(
                 infoPgNew(infoPgArchive, NULL), infoPgArchive, PG_VERSION_94, 6569239123849665679,
-                pgCatalogTestVersion(PG_VERSION_94)),
+                hrnPgCatalogVersion(PG_VERSION_94)),
             "infoPgSet - infoPgArchive");
         TEST_RESULT_INT(infoPgDataTotal(infoPg), 1, "  1 history");
         TEST_RESULT_INT(infoPgDataCurrentId(infoPg), 0, "  0 historyCurrent");
@@ -61,7 +62,7 @@ testRun(void)
         TEST_RESULT_UINT(pgData.catalogVersion, 0, "  catalog version not set for archive");
 
         TEST_ASSIGN(
-            infoPg, infoPgSet(infoPg, infoPgArchive, PG_VERSION_95, 6569239123849665999, pgCatalogTestVersion(PG_VERSION_95)),
+            infoPg, infoPgSet(infoPg, infoPgArchive, PG_VERSION_95, 6569239123849665999, hrnPgCatalogVersion(PG_VERSION_95)),
             "infoPgSet - infoPgArchive second db");
         TEST_RESULT_INT(infoPgDataTotal(infoPg), 2, "  2 history");
         TEST_RESULT_INT(infoPgDataCurrentId(infoPg), 0, "  0 historyCurrent");
@@ -76,8 +77,8 @@ testRun(void)
         TEST_ASSIGN(
             infoPg,
             infoPgSet(
-                infoPgNew(infoPgBackup, strNew("123xyz")), infoPgBackup, PG_VERSION_94, 6569239123849665679,
-                pgCatalogTestVersion(PG_VERSION_94)),
+                infoPgNew(infoPgBackup, STRDEF("123xyz")), infoPgBackup, PG_VERSION_94, 6569239123849665679,
+                hrnPgCatalogVersion(PG_VERSION_94)),
             "infoPgSet - infoPgBackup");
         TEST_RESULT_INT(infoPgDataTotal(infoPg), 1, "  1 history");
         TEST_RESULT_INT(infoPgDataCurrentId(infoPg), 0, "  0 historyCurrent");
@@ -112,7 +113,7 @@ testRun(void)
             "[later]\n"
             "key=\"value\"\n");
 
-        String *callbackContent = strNew("");
+        String *callbackContent = strNew();
         InfoPg *infoPg = NULL;
 
         TEST_ASSIGN(
@@ -124,7 +125,7 @@ testRun(void)
                 "[db:backup] key=\"value\"\n"
                 "[later] key=\"value\"\n",
             "    check callback content");
-        TEST_RESULT_INT(lstSize(infoPg->history), 1, "    history record added");
+        TEST_RESULT_INT(lstSize(infoPg->pub.history), 1, "    history record added");
 
         InfoPgData pgData = infoPgDataCurrent(infoPg);
         TEST_RESULT_INT(pgData.id, 1, "    id set");
@@ -164,7 +165,7 @@ testRun(void)
             "20161219-212741F={}\n"
             CONTENT_DB_HISTORY);
 
-        callbackContent = strNew("");
+        callbackContent = strNew();
 
         TEST_ASSIGN(infoPg, infoPgNewLoad(ioBufferReadNew(contentLoad), infoPgBackup, NULL, NULL), "load file");
         TEST_RESULT_STR_Z(callbackContent, "", "    check callback content");
@@ -190,13 +191,13 @@ testRun(void)
         //--------------------------------------------------------------------------------------------------------------------------
         pgData.id = 3;
         pgData.version = PG_VERSION_96;
-        pgData.systemId = 6399999999999999999;
+        pgData.systemId = HRN_PG_SYSTEMID_96;
         TEST_RESULT_VOID(infoPgAdd(infoPg, &pgData), "infoPgAdd");
 
         InfoPgData pgDataTest = infoPgDataCurrent(infoPg);
         TEST_RESULT_INT(pgDataTest.id, 3, "    id set");
         TEST_RESULT_INT(pgDataTest.version, PG_VERSION_96, "    version set");
-        TEST_RESULT_UINT(pgDataTest.systemId, 6399999999999999999, "    system-id set");
+        TEST_RESULT_UINT(pgDataTest.systemId, HRN_PG_SYSTEMID_96, "    system-id set");
 
         // infoPgDataToLog
         //--------------------------------------------------------------------------------------------------------------------------
