@@ -8,15 +8,19 @@ These starting values can then be scaled up for profiling and stress testing as
 running out of memory on the test systems or taking an undue amount of time.  It should be noted that in this context scaling to
 1000 is nowhere near turning it up to 11.
 ***********************************************************************************************************************************/
+#include <unistd.h>
+
 #include "common/ini.h"
 #include "common/io/bufferRead.h"
 #include "common/io/bufferWrite.h"
+#include "common/io/socket/client.h"
 #include "common/stat.h"
 #include "common/time.h"
 #include "common/type/list.h"
 #include "common/type/object.h"
 #include "info/manifest.h"
 #include "postgres/version.h"
+#include "storage/posix/storage.h"
 
 #include "common/harnessInfo.h"
 #include "common/harnessStorage.h"
@@ -61,6 +65,8 @@ typedef struct
     uint64_t fileTotal;
 } StorageTestManifestNewBuild;
 
+STRING_STATIC(TEST_MANIFEST_PATH_USER_STR,                          "test");
+
 static StorageInfo
 storageTestManifestNewBuildInfo(THIS_VOID, const String *file, StorageInfoLevel level, StorageInterfaceInfoParam param)
 {
@@ -74,8 +80,8 @@ storageTestManifestNewBuildInfo(THIS_VOID, const String *file, StorageInfoLevel
         .mode = 0600,
         .userId = 100,
         .groupId = 100,
-        .user = STRDEF("test"),
-        .group = STRDEF("test"),
+        .user = TEST_MANIFEST_PATH_USER_STR,
+        .group = TEST_MANIFEST_PATH_USER_STR,
     };
 
     if (strEq(file, STRDEF("/pg")))
@@ -145,7 +151,7 @@ storageTestManifestNewBuildInfoList(
 /***********************************************************************************************************************************
 Test Run
 ***********************************************************************************************************************************/
-void
+static void
 testRun(void)
 {
     FUNCTION_HARNESS_VOID();
@@ -153,8 +159,8 @@ testRun(void)
     // *****************************************************************************************************************************
     if (testBegin("lstFind()"))
     {
-        CHECK(testScale() <= 10000);
-        int testMax = 100000 * (int)testScale();
+        ASSERT(TEST_SCALE <= 10000);
+        int testMax = 100000 * (int)TEST_SCALE;
 
         // Generate a large list of values (use int instead of string so there fewer allocations)
         List *list = lstNewP(sizeof(int), .comparator = testComparator);
@@ -162,7 +168,7 @@ testRun(void)
         for (int listIdx = 0; listIdx < testMax; listIdx++)
             lstAdd(list, &listIdx);
 
-        CHECK(lstSize(list) == (unsigned int)testMax);
+        ASSERT(lstSize(list) == (unsigned int)testMax);
 
         TEST_LOG_FMT("generated %d item list", testMax);
 
@@ -172,7 +178,7 @@ testRun(void)
         TimeMSec timeBegin = timeMSec();
 
         for (int listIdx = 0; listIdx < testMax; listIdx++)
-            CHECK(*(int *)lstFind(list, &listIdx) == listIdx);
+            ASSERT(*(int *)lstFind(list, &listIdx) == listIdx);
 
         TEST_LOG_FMT("asc search completed in %ums", (unsigned int)(timeMSec() - timeBegin));
 
@@ -182,7 +188,7 @@ testRun(void)
         timeBegin = timeMSec();
 
         for (int listIdx = 0; listIdx < testMax; listIdx++)
-            CHECK(*(int *)lstFind(list, &listIdx) == listIdx);
+            ASSERT(*(int *)lstFind(list, &listIdx) == listIdx);
 
         TEST_LOG_FMT("desc search completed in %ums", (unsigned int)(timeMSec() - timeBegin));
     }
@@ -190,8 +196,8 @@ testRun(void)
     // *****************************************************************************************************************************
     if (testBegin("lstRemoveIdx()"))
     {
-        CHECK(testScale() <= 10000);
-        int testMax = 1000000 * (int)testScale();
+        ASSERT(TEST_SCALE <= 10000);
+        int testMax = 1000000 * (int)TEST_SCALE;
 
         // Generate a large list of values (use int instead of string so there fewer allocations)
         List *list = lstNewP(sizeof(int));
@@ -199,7 +205,7 @@ testRun(void)
         for (int listIdx = 0; listIdx < testMax; listIdx++)
             lstAdd(list, &listIdx);
 
-        CHECK(lstSize(list) == (unsigned int)testMax);
+        ASSERT(lstSize(list) == (unsigned int)testMax);
 
         TEST_LOG_FMT("generated %d item list", testMax);
 
@@ -211,16 +217,16 @@ testRun(void)
 
         TEST_LOG_FMT("remove completed in %ums", (unsigned int)(timeMSec() - timeBegin));
 
-        CHECK(lstEmpty(list));
+        ASSERT(lstEmpty(list));
     }
 
     // *****************************************************************************************************************************
     if (testBegin("iniLoad()"))
     {
-        CHECK(testScale() <= 10000);
+        ASSERT(TEST_SCALE <= 10000);
 
-        String *iniStr = strNew("[section1]\n");
-        unsigned int iniMax = 100000 * (unsigned int)testScale();
+        String *iniStr = strCatZ(strNew(), "[section1]\n");
+        unsigned int iniMax = 100000 * (unsigned int)TEST_SCALE;
 
         for (unsigned int keyIdx = 0; keyIdx < iniMax; keyIdx++)
             strCatFmt(iniStr, "key%u=\"value%u\"\n", keyIdx, keyIdx);
@@ -240,33 +246,32 @@ testRun(void)
     // *****************************************************************************************************************************
     if (testBegin("manifestNewBuild()/manifestNewLoad()/manifestSave()"))
     {
-        CHECK(testScale() <= 1000000);
+        ASSERT(TEST_SCALE <= 1000000);
 
         // Create a storage driver to test manifest build with an arbitrary number of files
         StorageTestManifestNewBuild driver =
         {
             .interface = storageInterfaceTestDummy,
-            .fileTotal = 100000 * (unsigned int)testScale(),
+            .fileTotal = 100000 * (unsigned int)TEST_SCALE,
         };
 
         driver.interface.info = storageTestManifestNewBuildInfo;
         driver.interface.infoList = storageTestManifestNewBuildInfoList;
 
-        Storage *storagePg = storageNew(STRDEF("TEST"), STRDEF("/pg"), 0, 0, false, NULL, &driver, driver.interface);
+        const Storage *const storagePg = storageNew(
+            strIdFromZ("test"), STRDEF("/pg"), 0, 0, false, NULL, &driver, driver.interface);
 
         // -------------------------------------------------------------------------------------------------------------------------
         TEST_TITLE("build manifest");
 
-        MemContext *testContext = memContextNew("test");
+        MemContext *testContext = memContextNewP("test");
         memContextKeep();
         Manifest *manifest = NULL;
         TimeMSec timeBegin = timeMSec();
 
         MEM_CONTEXT_BEGIN(testContext)
         {
-            TEST_ASSIGN(
-                manifest, manifestNewBuild(storagePg, PG_VERSION_91, 999999999, false, false, NULL, NULL),
-                "build with %" PRIu64 " files", driver.fileTotal);
+            TEST_ASSIGN(manifest, manifestNewBuild(storagePg, PG_VERSION_91, 999999999, false, false, NULL, NULL), "build files");
         }
         MEM_CONTEXT_END();
 
@@ -290,7 +295,7 @@ testRun(void)
         // -------------------------------------------------------------------------------------------------------------------------
         TEST_TITLE("load manifest");
 
-        testContext = memContextNew("test");
+        testContext = memContextNewP("test");
         memContextKeep();
         timeBegin = timeMSec();
 
@@ -313,7 +318,7 @@ testRun(void)
         for (unsigned int fileIdx = 0; fileIdx < manifestFileTotal(manifest); fileIdx++)
         {
             const ManifestFile *file = manifestFile(manifest, fileIdx);
-            CHECK(file == manifestFileFind(manifest, file->name));
+            ASSERT(file == manifestFileFind(manifest, file->name));
         }
 
         TEST_LOG_FMT("completed in %ums", (unsigned int)(timeMSec() - timeBegin));
@@ -323,7 +328,7 @@ testRun(void)
     // *****************************************************************************************************************************
     if (testBegin("statistics collector"))
     {
-        CHECK(testScale() <= 1000000);
+        ASSERT(TEST_SCALE <= 1000000);
 
         // Setup a list of stats to use for testing
         #define TEST_STAT_TOTAL 100
@@ -332,7 +337,7 @@ testRun(void)
         for (unsigned int statIdx = 0; statIdx < TEST_STAT_TOTAL; statIdx++)
             statList[statIdx] = strNewFmt("STAT%u", statIdx);
 
-        uint64_t runTotal = (uint64_t)testScale() * (uint64_t)100000;
+        uint64_t runTotal = (uint64_t)TEST_SCALE * (uint64_t)100000;
 
         // -------------------------------------------------------------------------------------------------------------------------
         TEST_TITLE_FMT("update %d stats %" PRIu64 " times", TEST_STAT_TOTAL, runTotal);
@@ -355,10 +360,29 @@ testRun(void)
         for (unsigned int statIdx = 0; statIdx < TEST_STAT_TOTAL; statIdx++)
         {
             TEST_RESULT_UINT(
-                varUInt64(kvGet(varKv(kvGet(statKv, VARSTR(statList[statIdx]))), STAT_VALUE_TOTAL_VAR)), runTotal, "check stat %u",
-                statIdx);
+                varUInt64(kvGet(varKv(kvGet(statKv, VARSTR(statList[statIdx]))), STAT_VALUE_TOTAL_VAR)), runTotal,
+                strZ(strNewFmt("check stat %u", statIdx)));
         }
     }
 
+    // *****************************************************************************************************************************
+    if (testBegin("SocketClient"))
+    {
+        // This test must be done here because the problem with variables being clobbered after a long jump is only present in
+        // optimized builds, so the unit test will not notice if the volatile keyword goes missing in sckClientOpen(). Since the
+        // performance tests are built with optimization is it more likely to be caught here.
+        // -------------------------------------------------------------------------------------------------------------------------
+        TEST_TITLE("create socket with error to check for leaks");
+
+        const Storage *const storageFd = storagePosixNewP(strNewFmt("/proc/%d/fd", getpid()));
+        unsigned int fdBefore = strLstSize(storageListP(storageFd, NULL));
+
+        TEST_ERROR(
+            ioClientOpen(sckClientNew(STRDEF("172.31.255.255"), 7777, 0, 0)), HostConnectError,
+            "timeout connecting to '172.31.255.255:7777'");
+
+        TEST_RESULT_UINT(strLstSize(storageListP(storageFd, NULL)), fdBefore, "socket was freed");
+    }
+
     FUNCTION_HARNESS_RETURN_VOID();
 }
