@@ -3,6 +3,7 @@ Test GCS Storage
 ***********************************************************************************************************************************/
 #include "common/io/fdRead.h"
 #include "common/io/fdWrite.h"
+#include "storage/helper.h"
 
 #include "common/harnessConfig.h"
 #include "common/harnessFork.h"
@@ -81,7 +82,8 @@ typedef struct TestRequestParam
 static void
 testRequest(IoWrite *write, const char *verb, TestRequestParam param)
 {
-    String *request = strNewFmt("%s %s/storage/v1/b%s", verb, param.upload ? "/upload" : "", param.noBucket ? "" : "/bucket/o");
+    String *request = strCatFmt(
+        strNew(), "%s %s/storage/v1/b%s", verb, param.upload ? "/upload" : "", param.noBucket ? "" : "/bucket/o");
 
     // Add object
     if (param.object != NULL)
@@ -139,7 +141,7 @@ testResponse(IoWrite *write, TestResponseParam param)
     param.code = param.code == 0 ? 200 : param.code;
 
     // Output header and code
-    String *response = strNewFmt("HTTP/1.1 %u ", param.code);
+    String *response = strCatFmt(strNew(), "HTTP/1.1 %u ", param.code);
 
     // Add reason for some codes
     switch (param.code)
@@ -179,17 +181,22 @@ testResponse(IoWrite *write, TestResponseParam param)
 /***********************************************************************************************************************************
 Test Run
 ***********************************************************************************************************************************/
-void
+static void
 testRun(void)
 {
     FUNCTION_HARNESS_VOID();
 
-    Storage *storageTest = storagePosixNewP(strNew(testPath()), .write = true);
+    // Set storage helper
+    static const StorageHelper storageHelperList[] = {STORAGE_GCS_HELPER, STORAGE_END_HELPER};
+    storageHelperInit(storageHelperList);
+
+    Storage *storageTest = storagePosixNewP(TEST_PATH_STR, .write = true);
 
     // Get test host and ports
     const String *const testHost = hrnServerHost();
     const unsigned int testPort = hrnServerPort(0);
     const unsigned int testPortAuth = hrnServerPort(1);
+    const unsigned int testPortMeta = hrnServerPort(2);
 
     // *****************************************************************************************************************************
     if (testBegin("storageRepoGet()"))
@@ -198,23 +205,23 @@ testRun(void)
         TEST_TITLE("storage with default options");
 
         StringList *argList = strLstNew();
-        strLstAddZ(argList, "--" CFGOPT_STANZA "=test");
-        hrnCfgArgRawZ(argList, cfgOptRepoType, STORAGE_GCS_TYPE);
+        hrnCfgArgRawZ(argList, cfgOptStanza, "test");
+        hrnCfgArgRawStrId(argList, cfgOptRepoType, STORAGE_GCS_TYPE);
         hrnCfgArgRawZ(argList, cfgOptRepoPath, "/repo");
         hrnCfgArgRawZ(argList, cfgOptRepoGcsBucket, TEST_BUCKET);
-        hrnCfgArgRawZ(argList, cfgOptRepoGcsKeyType, STORAGE_GCS_KEY_TYPE_TOKEN);
+        hrnCfgArgRawStrId(argList, cfgOptRepoGcsKeyType, storageGcsKeyTypeToken);
         hrnCfgEnvRawZ(cfgOptRepoGcsKey, TEST_TOKEN);
-        harnessCfgLoad(cfgCmdArchivePush, argList);
+        HRN_CFG_LOAD(cfgCmdArchivePush, argList);
 
         Storage *storage = NULL;
         TEST_ASSIGN(storage, storageRepoGet(0, false), "get repo storage");
-        TEST_RESULT_STR_Z(storage->path, "/repo", "    check path");
-        TEST_RESULT_STR(((StorageGcs *)storage->driver)->bucket, TEST_BUCKET_STR, "    check bucket");
-        TEST_RESULT_STR_Z(((StorageGcs *)storage->driver)->endpoint, "storage.googleapis.com", "    check endpoint");
-        TEST_RESULT_UINT(((StorageGcs *)storage->driver)->chunkSize, STORAGE_GCS_CHUNKSIZE_DEFAULT, "    check chunk size");
-        TEST_RESULT_STR(((StorageGcs *)storage->driver)->token, TEST_TOKEN_STR, "    check token");
-        TEST_RESULT_BOOL(storageFeature(storage, storageFeaturePath), false, "    check path feature");
-        TEST_RESULT_BOOL(storageFeature(storage, storageFeatureCompress), false, "    check compress feature");
+        TEST_RESULT_STR_Z(storage->path, "/repo", "check path");
+        TEST_RESULT_STR(((StorageGcs *)storageDriver(storage))->bucket, TEST_BUCKET_STR, "check bucket");
+        TEST_RESULT_STR_Z(((StorageGcs *)storageDriver(storage))->endpoint, "storage.googleapis.com", "check endpoint");
+        TEST_RESULT_UINT(((StorageGcs *)storageDriver(storage))->chunkSize, STORAGE_GCS_CHUNKSIZE_DEFAULT, "check chunk size");
+        TEST_RESULT_STR(((StorageGcs *)storageDriver(storage))->token, TEST_TOKEN_STR, "check token");
+        TEST_RESULT_BOOL(storageFeature(storage, storageFeaturePath), false, "check path feature");
+        TEST_RESULT_BOOL(storageFeature(storage, storageFeatureCompress), false, "check compress feature");
     }
 
     // *****************************************************************************************************************************
@@ -276,59 +283,61 @@ testRun(void)
     {
         HRN_STORAGE_PUT(storageTest, TEST_KEY_FILE, BUFSTR(strNewFmt(TEST_KEY, strZ(testHost), testPortAuth)));
 
-        HARNESS_FORK_BEGIN()
+        HRN_FORK_BEGIN()
         {
-            HARNESS_FORK_CHILD_BEGIN(0, true)
+            HRN_FORK_CHILD_BEGIN(.prefix = "gcs server", .timeout = 5000)
+            {
+                TEST_RESULT_VOID(hrnServerRunP(HRN_FORK_CHILD_READ(), hrnServerProtocolTls, .port = testPort), "gcs server run");
+            }
+            HRN_FORK_CHILD_END();
+
+            HRN_FORK_CHILD_BEGIN(.prefix = "auth server", .timeout = 5000)
             {
                 TEST_RESULT_VOID(
-                    hrnServerRunP(
-                        ioFdReadNew(strNew("gcs server read"), HARNESS_FORK_CHILD_READ(), 5000), hrnServerProtocolTls,
-                        .port = testPort),
-                    "gcs server run");
+                    hrnServerRunP(HRN_FORK_CHILD_READ(), hrnServerProtocolTls, .port = testPortAuth), "auth server run");
             }
-            HARNESS_FORK_CHILD_END();
+            HRN_FORK_CHILD_END();
 
-            HARNESS_FORK_CHILD_BEGIN(0, true)
+            HRN_FORK_CHILD_BEGIN(.prefix = "meta server", .timeout = 15000)
             {
                 TEST_RESULT_VOID(
-                    hrnServerRunP(
-                        ioFdReadNew(strNew("auth server read"), HARNESS_FORK_CHILD_READ(), 5000), hrnServerProtocolTls,
-                        .port = testPortAuth),
-                    "auth server run");
+                    hrnServerRunP(HRN_FORK_CHILD_READ(), hrnServerProtocolSocket, .port = testPortMeta), "meta server run");
             }
-            HARNESS_FORK_CHILD_END();
+            HRN_FORK_CHILD_END();
 
-            HARNESS_FORK_PARENT_BEGIN()
+            HRN_FORK_PARENT_BEGIN()
             {
+                // Do not use HRN_FORK_PARENT_WRITE() here so individual names can be assigned to help with debugging
                 IoWrite *service = hrnServerScriptBegin(
-                    ioFdWriteNew(strNew("gcs client write"), HARNESS_FORK_PARENT_WRITE_PROCESS(0), 2000));
+                    ioFdWriteNewOpen(STRDEF("gcs client write"), HRN_FORK_PARENT_WRITE_FD(0), 2000));
                 IoWrite *auth = hrnServerScriptBegin(
-                    ioFdWriteNew(strNew("auth client write"), HARNESS_FORK_PARENT_WRITE_PROCESS(1), 2000));
+                    ioFdWriteNewOpen(STRDEF("auth client write"), HRN_FORK_PARENT_WRITE_FD(1), 2000));
+                IoWrite *meta = hrnServerScriptBegin(
+                    ioFdWriteNewOpen(STRDEF("meta client write"), HRN_FORK_PARENT_WRITE_FD(2), 2000));
 
                 // -----------------------------------------------------------------------------------------------------------------
                 TEST_TITLE("test service auth");
 
                 StringList *argList = strLstNew();
-                strLstAddZ(argList, "--" CFGOPT_STANZA "=test");
-                hrnCfgArgRawZ(argList, cfgOptRepoType, STORAGE_GCS_TYPE);
+                hrnCfgArgRawZ(argList, cfgOptStanza, "test");
+                hrnCfgArgRawStrId(argList, cfgOptRepoType, STORAGE_GCS_TYPE);
                 hrnCfgArgRawZ(argList, cfgOptRepoPath, "/");
                 hrnCfgArgRawZ(argList, cfgOptRepoGcsBucket, TEST_BUCKET);
-                hrnCfgArgRawFmt(argList, cfgOptRepoGcsEndpoint, "%s:%u", strZ(hrnServerHost()), hrnServerPort(0));
-                hrnCfgArgRawBool(argList, cfgOptRepoStorageVerifyTls, testContainer());
+                hrnCfgArgRawFmt(argList, cfgOptRepoGcsEndpoint, "%s:%u", strZ(hrnServerHost()), testPort);
+                hrnCfgArgRawBool(argList, cfgOptRepoStorageVerifyTls, TEST_IN_CONTAINER);
                 hrnCfgEnvRawZ(cfgOptRepoGcsKey, TEST_KEY_FILE);
-                harnessCfgLoad(cfgCmdArchivePush, argList);
+                HRN_CFG_LOAD(cfgCmdArchivePush, argList);
+                hrnCfgEnvRemoveRaw(cfgOptRepoGcsKey);
 
                 Storage *storage = NULL;
                 TEST_ASSIGN(storage, storageRepoGet(0, true), "get repo storage");
 
-                // Tests need the chunk size to be 16
-                ((StorageGcs *)storage->driver)->chunkSize = 16;
-
                 // Generate the auth request. The JWT part will need to be ? since it can vary in content and size.
                 const char *const preamble = "grant_type=urn%3Aietf%3Aparams%3Aoauth%3Agrant-type%3Ajwt-bearer&assertion=";
-                const String *const jwt = storageGcsAuthJwt(((StorageGcs *)storage->driver), time(NULL));
+                const String *const jwt = storageGcsAuthJwt(((StorageGcs *)storageDriver(storage)), time(NULL));
 
-                String *const authRequest = strNewFmt(
+                String *const authRequest = strCatFmt(
+                    strNew(),
                     "POST /token HTTP/1.1\r\n"
                     "user-agent:" PROJECT_NAME "/" PROJECT_VERSION "\r\n"
                     "content-length:%zu\r\n"
@@ -354,7 +363,7 @@ testRun(void)
                 testResponseP(service);
 
                 storageGcsRequestP(
-                    (StorageGcs *)storage->driver, HTTP_VERB_POST_STR, .noBucket = true,
+                    (StorageGcs *)storageDriver(storage), HTTP_VERB_POST_STR, .noBucket = true,
                     .content = BUFSTR(jsonFromKv(kvPut(kvNew(), GCS_JSON_NAME_VAR, VARSTRDEF("bucket")))));
 
                 // -----------------------------------------------------------------------------------------------------------------
@@ -405,16 +414,54 @@ testRun(void)
                 testResponseP(service, .content = "this is a sample file");
 
                 TEST_RESULT_STR_Z(
-                    strNewBuf(storageGetP(storageNewReadP(storage, strNew("file.txt")))), "this is a sample file", "get file");
+                    strNewBuf(storageGetP(storageNewReadP(storage, STRDEF("file.txt")))), "this is a sample file", "get file");
+
+                // -----------------------------------------------------------------------------------------------------------------
+                TEST_TITLE("switch to auto auth");
+
+                hrnServerScriptClose(service);
+
+                StringList *argListAuto = strLstDup(argList);
+                hrnCfgArgRawStrId(argListAuto, cfgOptRepoGcsKeyType, storageGcsKeyTypeAuto);
+                HRN_CFG_LOAD(cfgCmdArchivePush, argListAuto);
+
+                TEST_ASSIGN(storage, storageRepoGet(0, true), "get repo storage");
+
+                // Replace the default authClient with one that points locally. The default host and url will still be used so they
+                // can be verified when testing auth.
+                ((StorageGcs *)storageDriver(storage))->authClient = httpClientNew(
+                    sckClientNew(hrnServerHost(), testPortMeta, 2000, 2000), 2000);
+
+                // Tests need the chunk size to be 16
+                ((StorageGcs *)storageDriver(storage))->chunkSize = 16;
+
+                hrnServerScriptAccept(service);
 
                 // -----------------------------------------------------------------------------------------------------------------
                 TEST_TITLE("get zero-length file");
 
+                // Get token automatically from metadata
+                hrnServerScriptAccept(meta);
+                hrnServerScriptExpectZ(
+                    meta,
+                    "GET /computeMetadata/v1/instance/service-accounts/default/token HTTP/1.1\r\n"
+                    "user-agent:" PROJECT_NAME "/" PROJECT_VERSION "\r\n"
+                    "content-length:0\r\n"
+                    "host:metadata.google.internal\r\n"
+                    "metadata-flavor:Google\r\n"
+                    "\r\n");
+
+                testResponseP(meta, .content = "{\"access_token\":\"X\",\"token_type\":\"X\",\"expires_in\":3600}");
+                hrnServerScriptClose(meta);
+
+                // Meta service no longer needed
+                hrnServerScriptEnd(meta);
+
                 testRequestP(service, HTTP_VERB_GET, .object = "file0.txt", .query = "alt=media");
                 testResponseP(service);
 
                 TEST_RESULT_STR_Z(
-                    strNewBuf(storageGetP(storageNewReadP(storage, strNew("file0.txt")))), "", "get zero-length file");
+                    strNewBuf(storageGetP(storageNewReadP(storage, STRDEF("file0.txt")))), "", "get zero-length file");
 
                 // -----------------------------------------------------------------------------------------------------------------
                 TEST_TITLE("non-404 error");
@@ -423,15 +470,15 @@ testRun(void)
                 testResponseP(service, .code = 303, .content = "CONTENT");
 
                 StorageRead *read = NULL;
-                TEST_ASSIGN(read, storageNewReadP(storage, strNew("file.txt"), .ignoreMissing = true), "new read file");
-                TEST_RESULT_BOOL(storageReadIgnoreMissing(read), true, "    check ignore missing");
-                TEST_RESULT_STR_Z(storageReadName(read), "/file.txt", "    check name");
+                TEST_ASSIGN(read, storageNewReadP(storage, STRDEF("file.txt"), .ignoreMissing = true), "new read file");
+                TEST_RESULT_BOOL(storageReadIgnoreMissing(read), true, "check ignore missing");
+                TEST_RESULT_STR_Z(storageReadName(read), "/file.txt", "check name");
 
                 TEST_ERROR_FMT(
                     ioReadOpen(storageReadIo(read)), ProtocolError,
                     "HTTP request failed with 303:\n"
                     "*** Path/Query ***:\n"
-                    "/storage/v1/b/bucket/o/file.txt?alt=media\n"
+                    "GET /storage/v1/b/bucket/o/file.txt?alt=media\n"
                     "*** Request Headers ***:\n"
                     "authorization: <redacted>\n"
                     "content-length: 0\n"
@@ -451,10 +498,10 @@ testRun(void)
                 testResponseP(service, .code = 403);
 
                 TEST_ERROR_FMT(
-                    storagePutP(storageNewWriteP(storage, strNew("file.txt")), BUFSTRDEF("ABCD")), ProtocolError,
+                    storagePutP(storageNewWriteP(storage, STRDEF("file.txt")), BUFSTRDEF("ABCD")), ProtocolError,
                     "HTTP request failed with 403 (Forbidden):\n"
                     "*** Path/Query ***:\n"
-                    "/upload/storage/v1/b/bucket/o?fields=md5Hash%%2Csize&name=file.txt&uploadType=media\n"
+                    "POST /upload/storage/v1/b/bucket/o?fields=md5Hash%%2Csize&name=file.txt&uploadType=media\n"
                     "*** Request Headers ***:\n"
                     "authorization: <redacted>\n"
                     "content-length: 4\n"
@@ -474,7 +521,7 @@ testRun(void)
                 testResponseP(service, .content = "{\"md5Hash\":\"ywjKSnu1+Wg8GRM6hIcspw==\"}");
 
                 StorageWrite *write = NULL;
-                TEST_ASSIGN(write, storageNewWriteP(storage, strNew("file.txt")), "new write");
+                TEST_ASSIGN(write, storageNewWriteP(storage, STRDEF("file.txt")), "new write");
                 TEST_RESULT_VOID(storagePutP(write, BUFSTRDEF("ABCD")), "write");
 
                 TEST_RESULT_BOOL(storageWriteAtomic(write), true, "write is atomic");
@@ -495,7 +542,7 @@ testRun(void)
                     .content = "");
                 testResponseP(service, .content = "{\"md5Hash\":\"1B2M2Y8AsgTpgAmY7PhCfg==\",\"size\":\"0\"}");
 
-                TEST_ASSIGN(write, storageNewWriteP(storage, strNew("file.txt")), "new write");
+                TEST_ASSIGN(write, storageNewWriteP(storage, STRDEF("file.txt")), "new write");
                 TEST_RESULT_VOID(storagePutP(write, NULL), "write");
 
                 // -----------------------------------------------------------------------------------------------------------------
@@ -506,7 +553,7 @@ testRun(void)
                     .content = "");
                 testResponseP(service, .content = "{\"md5Hash\":\"ywjK\",\"size\":\"0\"}");
 
-                TEST_ASSIGN(write, storageNewWriteP(storage, strNew("file.txt")), "new write");
+                TEST_ASSIGN(write, storageNewWriteP(storage, STRDEF("file.txt")), "new write");
                 TEST_ERROR(
                     storagePutP(write, NULL), FormatError,
                     "expected md5 'd41d8cd98f00b204e9800998ecf8427e' for '/file.txt' but actual is 'cb08ca'");
@@ -519,7 +566,7 @@ testRun(void)
                     .content = "");
                 testResponseP(service, .content = "{\"md5Hash\":\"1B2M2Y8AsgTpgAmY7PhCfg==\",\"size\":\"55\"}");
 
-                TEST_ASSIGN(write, storageNewWriteP(storage, strNew("file.txt")), "new write");
+                TEST_ASSIGN(write, storageNewWriteP(storage, STRDEF("file.txt")), "new write");
                 TEST_ERROR(storagePutP(write, NULL), FormatError, "expected size 55 for '/file.txt' but actual is 0");
 
                 // -----------------------------------------------------------------------------------------------------------------
@@ -540,7 +587,7 @@ testRun(void)
                     .content = "7890123456789012");
                 testResponseP(service, .content = "{\"md5Hash\":\"dnF5x6K/8ZZRzpfSlMMM+w==\",\"size\":\"32\"}");
 
-                TEST_ASSIGN(write, storageNewWriteP(storage, strNew("file.txt")), "new write");
+                TEST_ASSIGN(write, storageNewWriteP(storage, STRDEF("file.txt")), "new write");
                 TEST_RESULT_VOID(storagePutP(write, BUFSTRDEF("12345678901234567890123456789012")), "write");
 
                 // -----------------------------------------------------------------------------------------------------------------
@@ -566,7 +613,7 @@ testRun(void)
                     .content = "7890");
                 testResponseP(service, .content = "{\"md5Hash\":\"/YXmLZvrRUKHcexohBiycQ==\",\"size\":\"20\"}");
 
-                TEST_ASSIGN(write, storageNewWriteP(storage, strNew("file.txt")), "new write");
+                TEST_ASSIGN(write, storageNewWriteP(storage, STRDEF("file.txt")), "new write");
                 TEST_RESULT_VOID(storagePutP(write, BUFSTRDEF("12345678901234567890")), "write");
 
                 // -----------------------------------------------------------------------------------------------------------------
@@ -581,13 +628,13 @@ testRun(void)
                     .content = "1234567890123456");
                 testResponseP(service, .code = 403);
 
-                TEST_ASSIGN(write, storageNewWriteP(storage, strNew("file.txt")), "new write");
+                TEST_ASSIGN(write, storageNewWriteP(storage, STRDEF("file.txt")), "new write");
 
                 TEST_ERROR_FMT(
-                    storagePutP(storageNewWriteP(storage, strNew("file.txt")), BUFSTRDEF("12345678901234567")), ProtocolError,
+                    storagePutP(storageNewWriteP(storage, STRDEF("file.txt")), BUFSTRDEF("12345678901234567")), ProtocolError,
                     "HTTP request failed with 403 (Forbidden):\n"
                     "*** Path/Query ***:\n"
-                    "/upload/storage/v1/b/bucket/o?name=file.txt&uploadType=resumable&upload_id=<redacted>\n"
+                    "PUT /upload/storage/v1/b/bucket/o?name=file.txt&uploadType=resumable&upload_id=<redacted>\n"
                     "*** Request Headers ***:\n"
                     "content-length: 16\n"
                     "content-range: bytes 0-15/*\n"
@@ -606,7 +653,7 @@ testRun(void)
                 testResponseP(service, .code = 404);
 
                 TEST_RESULT_BOOL(
-                    storageInfoP(storage, strNew("BOGUS"), .ignoreMissing = true).exists, false, "file does not exist");
+                    storageInfoP(storage, STRDEF("BOGUS"), .ignoreMissing = true).exists, false, "file does not exist");
 
                 // -----------------------------------------------------------------------------------------------------------------
                 TEST_TITLE("info for file");
@@ -615,11 +662,11 @@ testRun(void)
                 testResponseP(service, .content = "{\"size\":\"9999\",\"updated\":\"2015-10-21T07:28:00.000Z\"}");
 
                 StorageInfo info;
-                TEST_ASSIGN(info, storageInfoP(storage, strNew("subdir/file1.txt")), "file exists");
-                TEST_RESULT_BOOL(info.exists, true, "    check exists");
-                TEST_RESULT_UINT(info.type, storageTypeFile, "    check type");
-                TEST_RESULT_UINT(info.size, 9999, "    check exists");
-                TEST_RESULT_INT(info.timeModified, 1445412480, "    check time");
+                TEST_ASSIGN(info, storageInfoP(storage, STRDEF("subdir/file1.txt")), "file exists");
+                TEST_RESULT_BOOL(info.exists, true, "check exists");
+                TEST_RESULT_UINT(info.type, storageTypeFile, "check type");
+                TEST_RESULT_UINT(info.size, 9999, "check exists");
+                TEST_RESULT_INT(info.timeModified, 1445412480, "check time");
 
                 // -----------------------------------------------------------------------------------------------------------------
                 TEST_TITLE("info check existence only");
@@ -628,11 +675,11 @@ testRun(void)
                 testResponseP(service, .content = "{}");
 
                 TEST_ASSIGN(
-                    info, storageInfoP(storage, strNew("subdir/file2.txt"), .level = storageInfoLevelExists), "file exists");
-                TEST_RESULT_BOOL(info.exists, true, "    check exists");
-                TEST_RESULT_UINT(info.type, storageTypeFile, "    check type");
-                TEST_RESULT_UINT(info.size, 0, "    check exists");
-                TEST_RESULT_INT(info.timeModified, 0, "    check time");
+                    info, storageInfoP(storage, STRDEF("subdir/file2.txt"), .level = storageInfoLevelExists), "file exists");
+                TEST_RESULT_BOOL(info.exists, true, "check exists");
+                TEST_RESULT_UINT(info.type, storageTypeFile, "check type");
+                TEST_RESULT_UINT(info.size, 0, "check exists");
+                TEST_RESULT_INT(info.timeModified, 0, "check time");
 
                 // -----------------------------------------------------------------------------------------------------------------
                 TEST_TITLE("list basic level");
@@ -659,15 +706,15 @@ testRun(void)
 
                 HarnessStorageInfoListCallbackData callbackData =
                 {
-                    .content = strNew(""),
+                    .content = strNew(),
                 };
 
                 TEST_ERROR(
-                    storageInfoListP(storage, strNew("/"), hrnStorageInfoListCallback, NULL, .errorOnMissing = true),
+                    storageInfoListP(storage, STRDEF("/"), hrnStorageInfoListCallback, NULL, .errorOnMissing = true),
                     AssertError, "assertion '!param.errorOnMissing || storageFeature(this, storageFeaturePath)' failed");
 
                 TEST_RESULT_VOID(
-                    storageInfoListP(storage, strNew("/path/to"), hrnStorageInfoListCallback, &callbackData), "list");
+                    storageInfoListP(storage, STRDEF("/path/to"), hrnStorageInfoListCallback, &callbackData), "list");
                 TEST_RESULT_STR_Z(
                     callbackData.content,
                     "test_path {path}\n"
@@ -692,11 +739,11 @@ testRun(void)
                         "  ]"
                         "}");
 
-                callbackData.content = strNew("");
+                callbackData.content = strNew();
 
                 TEST_RESULT_VOID(
                     storageInfoListP(
-                        storage, strNew("/"), hrnStorageInfoListCallback, &callbackData, .level = storageInfoLevelExists),
+                        storage, STRDEF("/"), hrnStorageInfoListCallback, &callbackData, .level = storageInfoLevelExists),
                     "list");
                 TEST_RESULT_STR_Z(
                     callbackData.content,
@@ -720,11 +767,11 @@ testRun(void)
                         "  ]"
                         "}");
 
-                callbackData.content = strNew("");
+                callbackData.content = strNew();
 
                 TEST_RESULT_VOID(
                     storageInfoListP(
-                        storage, strNew("/"), hrnStorageInfoListCallback, &callbackData, .expression = strNew("^test.*$"),
+                        storage, STRDEF("/"), hrnStorageInfoListCallback, &callbackData, .expression = STRDEF("^test.*$"),
                         .level = storageInfoLevelExists),
                     "list");
                 TEST_RESULT_STR_Z(
@@ -773,11 +820,11 @@ testRun(void)
                         "  ]"
                         "}");
 
-                callbackData.content = strNew("");
+                callbackData.content = strNew();
 
                 TEST_RESULT_VOID(
                     storageInfoListP(
-                        storage, strNew("/path/to"), hrnStorageInfoListCallback, &callbackData, .level = storageInfoLevelExists),
+                        storage, STRDEF("/path/to"), hrnStorageInfoListCallback, &callbackData, .level = storageInfoLevelExists),
                     "list");
                 TEST_RESULT_STR_Z(
                     callbackData.content,
@@ -815,11 +862,11 @@ testRun(void)
                         "  ]"
                         "}");
 
-                callbackData.content = strNew("");
+                callbackData.content = strNew();
 
                 TEST_RESULT_VOID(
                     storageInfoListP(
-                        storage, strNew("/path/to"), hrnStorageInfoListCallback, &callbackData, .expression = strNew("^test(1|3)"),
+                        storage, STRDEF("/path/to"), hrnStorageInfoListCallback, &callbackData, .expression = STRDEF("^test(1|3)"),
                         .level = storageInfoLevelExists),
                     "list");
                 TEST_RESULT_STR_Z(
@@ -829,14 +876,14 @@ testRun(void)
                     "test3.txt {}\n",
                     "check");
 
-                // // -----------------------------------------------------------------------------------------------------------------
+                // -----------------------------------------------------------------------------------------------------------------
                 TEST_TITLE("switch to token auth");
 
                 hrnServerScriptClose(service);
 
                 hrnCfgArgRawZ(argList, cfgOptRepoGcsKeyType, "token");
                 hrnCfgEnvRawZ(cfgOptRepoGcsKey, TEST_TOKEN);
-                harnessCfgLoad(cfgCmdArchivePush, argList);
+                HRN_CFG_LOAD(cfgCmdArchivePush, argList);
 
                 TEST_ASSIGN(storage, storageRepoGet(0, true), "get repo storage");
 
@@ -848,7 +895,7 @@ testRun(void)
                 testRequestP(service, HTTP_VERB_DELETE, .object = "path/to/test.txt");
                 testResponseP(service);
 
-                TEST_RESULT_VOID(storageRemoveP(storage, strNew("/path/to/test.txt")), "remove");
+                TEST_RESULT_VOID(storageRemoveP(storage, STRDEF("/path/to/test.txt")), "remove");
 
                 // -----------------------------------------------------------------------------------------------------------------
                 TEST_TITLE("remove missing file");
@@ -856,7 +903,7 @@ testRun(void)
                 testRequestP(service, HTTP_VERB_DELETE, .object = "path/to/missing.txt");
                 testResponseP(service, .code = 404);
 
-                TEST_RESULT_VOID(storageRemoveP(storage, strNew("/path/to/missing.txt")), "remove");
+                TEST_RESULT_VOID(storageRemoveP(storage, STRDEF("/path/to/missing.txt")), "remove");
 
                 // -----------------------------------------------------------------------------------------------------------------
                 TEST_TITLE("remove files from root");
@@ -885,7 +932,7 @@ testRun(void)
                 testRequestP(service, HTTP_VERB_DELETE, .object = "path1/xxx.zzz");
                 testResponseP(service);
 
-                TEST_RESULT_VOID(storagePathRemoveP(storage, strNew("/"), .recurse = true), "remove");
+                TEST_RESULT_VOID(storagePathRemoveP(storage, STRDEF("/"), .recurse = true), "remove");
 
                 // -----------------------------------------------------------------------------------------------------------------
                 TEST_TITLE("remove files from path");
@@ -914,7 +961,7 @@ testRun(void)
                 testRequestP(service, HTTP_VERB_DELETE, .object = "path/path1/xxx.zzz");
                 testResponseP(service);
 
-                TEST_RESULT_VOID(storagePathRemoveP(storage, strNew("/path"), .recurse = true), "remove");
+                TEST_RESULT_VOID(storagePathRemoveP(storage, STRDEF("/path"), .recurse = true), "remove");
 
                 // -----------------------------------------------------------------------------------------------------------------
                 TEST_TITLE("remove files in empty subpath (nothing to do)");
@@ -922,14 +969,14 @@ testRun(void)
                 testRequestP(service, HTTP_VERB_GET, .query = "fields=nextPageToken%2Cprefixes%2Citems%28name%29&prefix=path%2F");
                 testResponseP(service, .content = "{}");
 
-                TEST_RESULT_VOID(storagePathRemoveP(storage, strNew("/path"), .recurse = true), "remove");
+                TEST_RESULT_VOID(storagePathRemoveP(storage, STRDEF("/path"), .recurse = true), "remove");
 
                 // -----------------------------------------------------------------------------------------------------------------
                 hrnServerScriptEnd(service);
             }
-            HARNESS_FORK_PARENT_END();
+            HRN_FORK_PARENT_END();
         }
-        HARNESS_FORK_END();
+        HRN_FORK_END();
     }
 
     FUNCTION_HARNESS_RETURN_VOID();
