@@ -16,6 +16,7 @@ $SIG{__DIE__} = sub { Carp::confess @_ };
 
 use Digest::SHA qw(sha1_hex);
 use File::Basename qw(dirname);
+use File::stat;
 use Getopt::Long qw(GetOptions);
 use Cwd qw(abs_path cwd);
 use JSON::PP;
@@ -33,14 +34,6 @@ use pgBackRestDoc::Common::Log;
 use pgBackRestDoc::Common::String;
 use pgBackRestDoc::ProjectInfo;
 
-use pgBackRestBuild::Build;
-use pgBackRestBuild::Build::Common;
-use pgBackRestBuild::Config::Build;
-use pgBackRestBuild::Config::BuildHelp;
-use pgBackRestBuild::Config::BuildParse;
-use pgBackRestBuild::Error::Build;
-use pgBackRestBuild::Error::Data;
-
 use pgBackRestTest::Common::BuildTest;
 use pgBackRestTest::Common::CodeCountTest;
 use pgBackRestTest::Common::ContainerTest;
@@ -81,7 +74,6 @@ test.pl [options]
    --build-only         build the binary (and honor --build-package) but don't run tests
    --build-package      build the package
    --build-max          max processes to use for builds (default 4)
-   --coverage-only      only run coverage tests (as a subset of selected tests)
    --c-only             only run C tests
    --container-only     only run tests that must be run in a container
    --no-performance     do not run performance tests
@@ -89,10 +81,7 @@ test.pl [options]
    --no-gen             do not run code generation
    --gen-check          check that auto-generated files are correct (used in CI to detect changes)
    --code-count         generate code counts
-   --smart              perform bin/package builds only when source timestamps have changed
-   --dev                --smart --no-optimize
-   --dev-test           does nothing -- kept for backward compatibility
-   --expect             --vm=co7 --pg-version=9.6 --log-force
+   --expect             --vm=rh7 --pg-version=9.6 --log-force
    --no-valgrind        don't run valgrind on C unit tests (saves time)
    --no-coverage        don't run coverage on C unit tests (saves time)
    --no-coverage-report run coverage but don't generate coverage report (saves time)
@@ -106,6 +95,7 @@ test.pl [options]
 
  Report Options:
    --coverage-summary   generate a coverage summary report for the documentation
+   --coverage-only      only run coverage tests (as a subset of selected tests) for the documentation
 
  Configuration Options:
    --psql-bin           path to the psql executables (e.g. /usr/lib/postgresql/9.3/bin/)
@@ -118,7 +108,7 @@ test.pl [options]
    --quiet, -q          equivalent to --log-level=off
 
  VM Options:
-   --vm                 docker container to build/test (e.g. co7)
+   --vm                 docker container to build/test (e.g. rh7)
    --vm-build           build Docker containers
    --vm-force           force a rebuild of Docker containers
    --vm-out             Show VM output (default false)
@@ -155,7 +145,6 @@ my $bQuiet = false;
 my $strPgVersion = 'minimal';
 my $bLogForce = false;
 my $strVm;
-my $strVmHost = VM_HOST_DEFAULT;
 my $bVmBuild = false;
 my $bVmForce = false;
 my $bBuildOnly = false;
@@ -172,9 +161,6 @@ my $bGenOnly = false;
 my $bGenCheck = false;
 my $bNoGen = false;
 my $bCodeCount = false;
-my $bSmart = false;
-my $bDev = false;
-my $bDevTest = false;
 my $bBackTrace = false;
 my $bProfile = false;
 my $bExpect = false;
@@ -201,7 +187,6 @@ GetOptions ('q|quiet' => \$bQuiet,
             'log-level-test-file=s' => \$strLogLevelTestFile,
             'no-log-timestamp' => \$bNoLogTimestamp,
             'vm=s' => \$strVm,
-            'vm-host=s' => \$strVmHost,
             'vm-out' => \$bVmOut,
             'vm-build' => \$bVmBuild,
             'vm-force' => \$bVmForce,
@@ -228,9 +213,6 @@ GetOptions ('q|quiet' => \$bQuiet,
             'gen-check' => \$bGenCheck,
             'no-gen' => \$bNoGen,
             'code-count' => \$bCodeCount,
-            'smart' => \$bSmart,
-            'dev' => \$bDev,
-            'dev-test' => \$bDevTest,
             'backtrace' => \$bBackTrace,
             'profile' => \$bProfile,
             'expect' => \$bExpect,
@@ -288,20 +270,6 @@ eval
         $bCOnly = true;
     }
 
-    ################################################################################################################################
-    # Update options for --dev and --dev-fast and --dev-test
-    ################################################################################################################################
-    if ($bDev && $bDevTest)
-    {
-        confess "cannot combine --dev and --dev-test";
-    }
-
-    if ($bDev)
-    {
-        $bSmart = true;
-        $bNoOptimize = true;
-    }
-
     ################################################################################################################################
     # Update options for --profile
     ################################################################################################################################
@@ -334,7 +302,7 @@ eval
     }
 
     logLevelSet(uc($strLogLevel), uc($strLogLevel), OFF, !$bNoLogTimestamp);
-    &log(INFO, "test begin - log level ${strLogLevel}");
+    &log(INFO, 'test begin on ' . hostArch() . " - log level ${strLogLevel}");
 
     if (@stryModuleTest != 0 && @stryModule != 1)
     {
@@ -359,12 +327,11 @@ eval
     {
         if (!defined($strVm))
         {
-            &log(INFO, "Set --vm=${strVmHost} for coverage testing");
-            $strVm = $strVmHost;
+            confess &log(ERROR, "select a VM for coverage testing");
         }
         elsif ($strVm eq VM_ALL)
         {
-            confess &log(ERROR, "select a single Debian-based VM for coverage testing");
+            confess &log(ERROR, "select a single VM for coverage testing");
         }
     }
 
@@ -386,6 +353,17 @@ eval
     my $oStorageBackRest = new pgBackRestTest::Common::Storage(
         $strBackRestBase, new pgBackRestTest::Common::StoragePosix({bFileSync => false, bPathSync => false}));
 
+    # Check that the test path is not in the git repo path
+    if (index("${strTestPath}/", "${strBackRestBase}/") != -1)
+    {
+        confess &log(
+            ERROR,
+            "test path '${strTestPath}' may not be in the repo path '${strBackRestBase}'\n" .
+            "HINT: was test.pl run in '${strBackRestBase}'?\n" .
+            "HINT: use --test-path to set a test path\n" .
+            "HINT: run test.pl from outside the repo, e.g. 'pgbackrest/test/test.pl'");
+    }
+
     ################################################################################################################################
     # Clean working and result paths
     ################################################################################################################################
@@ -426,53 +404,156 @@ eval
     ################################################################################################################################
     if (!defined($iVmId))
     {
-        # Make a copy of the repo to track which files have been changed.  Eventually all builds will be done from this directory.
+        # Clean any existing files in the src path that might interfere with the vpath build. This is kosher because the user should
+        # be expecting us to do builds in the src path during testing. Instead we clean the src path and do the builds elsewhere.
         #---------------------------------------------------------------------------------------------------------------------------
-        my $strRepoCachePath = "${strTestPath}/repo";
-        my $strRepoCacheManifest = 'repo.manifest';
+        executeTest("make -C ${strBackRestBase}/src -f Makefile.in clean-all");
 
-        # Create the repo path -- this should hopefully prevent obvious rsync errors below
-        $oStorageTest->pathCreate("${strTestPath}/repo", {strMode => '0770', bIgnoreExists => true, bCreateParent => true});
-
-        # Check if there are any files existing already.  If none, that means a full copy is happening and we shouldn't report
-        # modified files
-        my @stryExistingList = $oStorageTest->list($strRepoCachePath, {bIgnoreMissing => true});
-
-        # First check if there is an old manifest that has not been cleared.  This indicates that an error happened before all new
-        # files could be processed, which means they should be processed again.
-        my @stryModifiedList;
-        my $rstrModifiedList = $oStorageTest->get(
-            $oStorageTest->openRead("${strRepoCachePath}/${strRepoCacheManifest}", {bIgnoreMissing => true}));
-
-        if (defined($rstrModifiedList))
+        # Auto-generate configure files unless --no-gen specified
+        #---------------------------------------------------------------------------------------------------------------------------
+        if (!$bNoGen)
         {
-            @stryModifiedList = split("\n", trim($$rstrModifiedList));
+            &log(INFO, "autogenerate configure");
+
+            # Auto-generate version for configure.ac script
+            #-----------------------------------------------------------------------------------------------------------------------
+            my $strConfigureAcOld = ${$oStorageTest->get("${strBackRestBase}/src/build/configure.ac")};
+            my $strConfigureAcNew;
+
+            foreach my $strLine (split("\n", $strConfigureAcOld))
+            {
+                if ($strLine =~ /^AC_INIT\(/)
+                {
+                    $strLine = 'AC_INIT([' . PROJECT_NAME . '], [' . PROJECT_VERSION . '])';
+                }
+
+                $strConfigureAcNew .= "${strLine}\n";
+            }
+
+            # Save into the src dir
+            my @stryBuilt;
+            my $strBuilt = 'src/build/configure.ac';
+
+            if (buildPutDiffers($oStorageBackRest, "${strBackRestBase}/${strBuilt}", $strConfigureAcNew))
+            {
+                push(@stryBuilt, $strBuilt);
+            }
+
+            # Error when checking that files have already been generated but they change
+            if ($bGenCheck && @stryBuilt)
+            {
+                confess &log(
+                    ERROR,
+                    "unexpected autogeneration of version in configure.ac script: " . join(', ', @stryBuilt) . ":\n" .
+                        trim(executeTest("git -C ${strBackRestBase} diff")));
+            }
+
+            &log(INFO,
+                "    autogenerated version in configure.ac script: " . (@stryBuilt ? join(', ', @stryBuilt) : 'no changes'));
+
+            # Auto-generate configure script
+            #-----------------------------------------------------------------------------------------------------------------------
+            # Set build file
+            @stryBuilt = ();
+            $strBuilt = 'src/configure';
+
+            # Get configure.ac and configure to see if anything has changed
+            my $strConfigureAc = ${$oStorageBackRest->get('src/build/configure.ac')};
+            my $strConfigureAcHash = sha1_hex($strConfigureAc);
+            my $rstrConfigure = $oStorageBackRest->get($oStorageBackRest->openRead($strBuilt, {bIgnoreMissing => true}));
+
+            # Check if configure needs to be regenerated
+            if (!defined($rstrConfigure) || !defined($$rstrConfigure) ||
+                $strConfigureAcHash ne substr($$rstrConfigure, length($$rstrConfigure) - 41, 40))
+            {
+                # Generate aclocal.m4
+                my $strAcLocal = executeTest("cd ${strBackRestBase}/src/build && aclocal --OUT=-");
+                $strAcLocal = trim($strAcLocal) . "\n";
+
+                buildPutDiffers($oStorageBackRest, "${strBackRestBase}/src/build/aclocal.m4", $strAcLocal);
+
+                # Generate configure
+                my $strConfigure = executeTest("cd ${strBackRestBase}/src/build && autoconf --output=-");
+                $strConfigure =
+                    trim($strConfigure) . "\n\n# Generated from src/build/configure.ac sha1 ${strConfigureAcHash}\n";
+
+                # Remove cache created by autconf
+                executeTest("rm -rf ${strBackRestBase}/src/build/autom4te.cache");
+
+                # Remove unused options from help
+                my $strDirList =
+                    "sbin|libexec|sysconf|sharedstate|localstate|runstate|lib|include|oldinclude|dataroot|data|info" .
+                    "|locale|man|doc|html|dvi|pdf|ps";
+
+                $strConfigure =~ s/^  --(${strDirList})*dir=DIR.*\n//mg;
+
+                # Save into the src dir
+                $oStorageBackRest->put(
+                    $oStorageBackRest->openWrite("${strBackRestBase}/${strBuilt}", {strMode => '0755'}), $strConfigure);
+
+                # Add to built list
+                push(@stryBuilt, $strBuilt);
+            }
+
+            # Error when checking that files have already been generated but they change
+            if ($bGenCheck && @stryBuilt)
+            {
+                confess &log(
+                    ERROR,
+                    "unexpected autogeneration of configure script: " . join(', ', @stryBuilt) . ":\n" .
+                        trim(executeTest("git -C ${strBackRestBase} diff")));
+            }
+
+            &log(INFO, "    autogenerated configure script: " . (@stryBuilt ? join(', ', @stryBuilt) : 'no changes'));
         }
 
-        push(
-            @stryModifiedList,
-            split(
-                "\n",
-                trim(
-                    executeTest(
-                        "git -C ${strBackRestBase} ls-files -c --others --exclude-standard |" .
-                            " rsync -rtW --out-format=\"\%n\" --delete" .
-                            # This option is not supported on MacOS. The eventual plan is to remove the need for it.
-                            (trim(`uname`) ne 'Darwin' ? ' --ignore-missing-args' : '') .
-                            " --exclude=test/result --exclude=repo.manifest" .
-                            " ${strBackRestBase}/ --files-from=- ${strRepoCachePath}" .
-                            " | grep -E -v '/\$' | cat"))));
+        # Create the build path
+        #---------------------------------------------------------------------------------------------------------------------------
+        my $strBuildPath = "${strTestPath}/build";
 
-        if (@stryModifiedList > 0)
+        # Determine if we need to start from scratch due to changes that make may not detect
+        if (!-e "${strBuildPath}/Makefile" ||
+            stat("${strBackRestBase}/src/Makefile.in")->mtime > stat("${strBuildPath}/Makefile")->mtime ||
+            stat("${strBackRestBase}/src/configure")->mtime > stat("${strBuildPath}/Makefile")->mtime ||
+            stat("${strBackRestBase}/src/build.auto.h.in")->mtime > stat("${strBuildPath}/Makefile")->mtime)
         {
-            $oStorageTest->put("${strRepoCachePath}/${strRepoCacheManifest}", join("\n", @stryModifiedList));
+            &log(INFO, "configure build");
 
-            if (@stryExistingList > 0)
+            $oStorageTest->pathCreate("${strBuildPath}/repo", {strMode => '0770', bIgnoreExists => true, bCreateParent => true});
+            executeTest("find ${strBuildPath} -mindepth 1 -print0 | xargs -0 rm -rf");
+            executeTest("cd ${strBuildPath} && ${strBackRestBase}/src/configure -q --enable-test");
+        }
+
+        # Auto-generate code files unless --no-gen specified
+        #---------------------------------------------------------------------------------------------------------------------------
+        if (!$bNoGen)
+        {
+            &log(INFO, "autogenerate code");
+
+            # Build code
+            executeTest("make -C ${strBuildPath} build-config build-error build-help");
+
+            if ($bGenOnly)
             {
-                &log(INFO, "modified since last run: " . join(', ', @stryModifiedList));
+                exit 0;
             }
         }
 
+        # Make a copy of the repo to track which files have been changed
+        #---------------------------------------------------------------------------------------------------------------------------
+        my $strRepoCachePath = "${strTestPath}/repo";
+
+        # Create the repo path -- this should hopefully prevent obvious rsync errors below
+        $oStorageTest->pathCreate($strRepoCachePath, {strMode => '0770', bIgnoreExists => true, bCreateParent => true});
+
+        # Copy the repo
+        executeTest(
+            "git -C ${strBackRestBase} ls-files -c --others --exclude-standard |" .
+                " rsync -rtW --delete --files-from=- --exclude=test/result" .
+                # This option is not supported on MacOS. The eventual plan is to remove the need for it.
+                (trim(`uname`) ne 'Darwin' ? ' --ignore-missing-args' : '') .
+                " ${strBackRestBase}/ ${strRepoCachePath}");
+
         # Generate code counts
         #---------------------------------------------------------------------------------------------------------------------------
         if ($bCodeCount)
@@ -483,172 +564,6 @@ eval
             exit 0;
         }
 
-        # Auto-generate files unless --no-gen specified
-        #---------------------------------------------------------------------------------------------------------------------------
-        if (!$bNoGen)
-        {
-            my @stryBuiltAll;
-            &log(INFO, "check code autogenerate");
-
-            # Auto-generate version for configure.ac script
-            #-----------------------------------------------------------------------------------------------------------------------
-            if (!$bSmart || grep(/^src\/version\.h/, @stryModifiedList))
-            {
-                my $strConfigureAcOld = ${$oStorageTest->get("${strBackRestBase}/src/build/configure.ac")};
-                my $strConfigureAcNew;
-
-                foreach my $strLine (split("\n", $strConfigureAcOld))
-                {
-                    if ($strLine =~ /^AC_INIT\(/)
-                    {
-                        $strLine = 'AC_INIT([' . PROJECT_NAME . '], [' . PROJECT_VERSION . '])';
-                    }
-
-                    $strConfigureAcNew .= "${strLine}\n";
-                }
-
-                # Save into the src dir
-                my @stryBuilt;
-                my $strBuilt = 'src/build/configure.ac';
-
-                if (buildPutDiffers($oStorageBackRest, "${strBackRestBase}/${strBuilt}", $strConfigureAcNew))
-                {
-                    push(@stryBuilt, $strBuilt);
-                    push(@stryBuiltAll, @stryBuilt);
-                    push(@stryModifiedList, @stryBuilt);
-                }
-
-                # Error when checking that files have already been generated but they change
-                if ($bGenCheck && @stryBuilt)
-                {
-                    confess &log(ERROR, "unexpected autogeneration of version in configure.ac script: " . join(', ', @stryBuilt));
-                }
-
-                &log(INFO,
-                    "    autogenerated version in configure.ac script: " . (@stryBuilt ? join(', ', @stryBuilt) : 'no changes'));
-            }
-
-            # Auto-generate configure script
-            #-----------------------------------------------------------------------------------------------------------------------
-            if (!$bSmart || grep(/^src\/build\/configure\.ac/, @stryModifiedList))
-            {
-                # Set build file
-                my @stryBuilt;
-                my $strBuilt = 'src/configure';
-
-                # Get configure.ac and configure to see if anything has changed
-                my $strConfigureAc = ${$oStorageBackRest->get('src/build/configure.ac')};
-                my $strConfigureAcHash = sha1_hex($strConfigureAc);
-                my $rstrConfigure = $oStorageBackRest->get($oStorageBackRest->openRead($strBuilt, {bIgnoreMissing => true}));
-
-                # Check if configure needs to be regenerated
-                if (!defined($rstrConfigure) || !defined($$rstrConfigure) ||
-                    $strConfigureAcHash ne substr($$rstrConfigure, length($$rstrConfigure) - 41, 40))
-                {
-                    # Generate aclocal.m4
-                    my $strAcLocal = executeTest("cd ${strBackRestBase}/src/build && aclocal --OUT=-");
-                    $strAcLocal = trim($strAcLocal) . "\n";
-
-                    buildPutDiffers($oStorageBackRest, "${strBackRestBase}/src/build/aclocal.m4", $strAcLocal);
-
-                    # Generate configure
-                    my $strConfigure = executeTest("cd ${strBackRestBase}/src/build && autoconf --output=-");
-                    $strConfigure =
-                        trim($strConfigure) . "\n\n# Generated from src/build/configure.ac sha1 ${strConfigureAcHash}\n";
-
-                    # Remove cache created by autconf
-                    executeTest("rm -rf ${strBackRestBase}/src/build/autom4te.cache");
-
-                    # Remove unused options from help
-                    my $strDirList =
-                        "sbin|libexec|sysconf|sharedstate|localstate|runstate|lib|include|oldinclude|dataroot|data|info" .
-                        "|locale|man|doc|html|dvi|pdf|ps";
-
-                    $strConfigure =~ s/^  --(${strDirList})*dir=DIR.*\n//mg;
-
-                    # Save into the src dir
-                    $oStorageBackRest->put(
-                        $oStorageBackRest->openWrite("${strBackRestBase}/${strBuilt}", {strMode => '0755'}), $strConfigure);
-
-                    # Add to built list
-                    push(@stryBuilt, $strBuilt);
-                    push(@stryBuiltAll, @stryBuilt);
-                    push(@stryModifiedList, @stryBuilt);
-                }
-
-                # Error when checking that files have already been generated but they change
-                if ($bGenCheck && @stryBuilt)
-                {
-                    confess &log(ERROR, "unexpected autogeneration of configure script: " . join(', ', @stryBuilt));
-                }
-
-                &log(INFO, "    autogenerated configure script: " . (@stryBuilt ? join(', ', @stryBuilt) : 'no changes'));
-            }
-
-            # Auto-generate C files
-            #-----------------------------------------------------------------------------------------------------------------------
-            if (!$bSmart || grep(/^build\//, @stryModifiedList) || grep(/^doc\/xml\/reference\.xml/, @stryModifiedList) ||
-                grep(/^src\/build\/config\/config\.yaml/, @stryModifiedList))
-            {
-                errorDefineLoad(${$oStorageBackRest->get("build/error.yaml")});
-
-                my $rhBuild =
-                {
-                    'config' =>
-                    {
-                        &BLD_DATA => buildConfig(),
-                        &BLD_PATH => 'config',
-                    },
-
-                    'configHelp' =>
-                    {
-                        &BLD_DATA => buildConfigHelp(),
-                        &BLD_PATH => 'command/help',
-                    },
-
-                    'configParse' =>
-                    {
-                        &BLD_DATA => buildConfigParse(),
-                        &BLD_PATH => 'config',
-                    },
-
-                    'error' =>
-                    {
-                        &BLD_DATA => buildError(),
-                        &BLD_PATH => 'common',
-                    },
-                };
-
-                my @stryBuilt = buildAll("${strBackRestBase}/src", $rhBuild);
-
-                # Error when checking that files have already been generated but they change
-                if ($bGenCheck && @stryBuilt)
-                {
-                    confess &log(ERROR, "unexpected autogeneration of C code: " . join(', ', @stryBuilt));
-                }
-
-                &log(INFO, "    autogenerated C code: " . (@stryBuilt ? join(', ', @stryBuilt) : 'no changes'));
-
-                if (@stryBuilt)
-                {
-                    push(@stryBuiltAll, @stryBuilt);
-                    push(@stryModifiedList, @stryBuilt);
-                }
-            }
-
-            # Copy the files that were auto-generated to the repo cache so they will be included in the current build
-            #-----------------------------------------------------------------------------------------------------------------------
-            foreach my $strBuilt (@stryBuiltAll)
-            {
-                executeTest("cp -p ${strBackRestBase}/${strBuilt} ${strRepoCachePath}/${strBuilt}");
-            }
-
-            if ($bGenOnly)
-            {
-                exit 0;
-            }
-        }
-
         # Clean up
         #---------------------------------------------------------------------------------------------------------------------------
         my $iTestFail = 0;
@@ -672,7 +587,7 @@ eval
 
             executeTest(
                 "chmod 700 -R ${strTestPath}/test-* 2>&1 || true && rm -rf ${strTestPath}/temp ${strTestPath}/test-*" .
-                    " ${strTestPath}/data-*" . ($bDev ? '' : " ${strTestPath}/gcov-*"));
+                    " ${strTestPath}/data-*");
             $oStorageTest->pathCreate("${strTestPath}/temp", {strMode => '0770', bIgnoreExists => true, bCreateParent => true});
 
             # Remove old lcov dirs -- do it this way so the dirs stay open in finder/explorer, etc.
@@ -773,12 +688,11 @@ eval
                 foreach my $strBuildVM (@stryBuildVm)
                 {
                     my $strBuildPath = "${strBinPath}/${strBuildVM}";
-                    my $bRebuild = !$bSmart;
-                    $rhBinBuild->{$strBuildVM} = true;
+                    my $bRebuild = false;
+                    $rhBinBuild->{$strBuildVM} = false;
 
                     # Build configure/compile options and see if they have changed from the previous build
                     my $strCFlags =
-                        "-Wfatal-errors -g" .
                         (vmWithBackTrace($strBuildVM) && $bBackTrace ? ' -DWITH_BACKTRACE' : '') .
                         ($bDebugTestTrace ? ' -DDEBUG_TEST_TRACE' : '');
                     my $strLdFlags = vmWithBackTrace($strBuildVM) && $bBackTrace  ? '-lbacktrace' : '';
@@ -787,59 +701,46 @@ eval
                     my $strBuildFlagFile = "${strBinPath}/${strBuildVM}/build.flags";
 
                     my $bBuildOptionsDiffer = buildPutDiffers($oStorageBackRest, $strBuildFlagFile, $strBuildFlags);
-                    $bBuildOptionsDiffer |= grep(/^src\/configure|src\/Makefile.in|src\/build\.auto\.h\.in$/, @stryModifiedList);
 
-                    # Rebuild if the modification time of the bin file is less than the last changes in source paths
-                    my $strBinSmart = "${strBuildPath}/pgbackrest";
+                    &log(INFO, "    build bin for ${strBuildVM} (${strBuildPath})");
 
-                    if ($bBuildOptionsDiffer ||
-                        ($bSmart &&
-                         (!$oStorageBackRest->exists($strBinSmart) ||
-                          $oStorageBackRest->info($strBinSmart)->mtime < $lTimestampLast)))
+                    if ($strBuildVM ne VM_NONE)
                     {
-                        &log(
-                            INFO, "    bin dependencies have changed for ${strBuildVM}, " . ($bBuildOptionsDiffer ? 're' : '') .
-                            'building...');
-
-                        $bRebuild = true;
+                        executeTest(
+                            "docker run -itd -h test-build --name=test-build" .
+                                " -v ${strBackRestBase}:${strBackRestBase} -v ${strTestPath}:${strTestPath} " .
+                                containerRepo() . ":${strBuildVM}-test",
+                            {bSuppressStdErr => true});
                     }
 
-                    if ($bRebuild)
+                    if ($bBuildOptionsDiffer ||
+                        !-e "${strBuildPath}/Makefile" ||
+                        stat("${strBackRestBase}/src/Makefile.in")->mtime > stat("${strBuildPath}/Makefile")->mtime ||
+                        stat("${strBackRestBase}/src/configure")->mtime > stat("${strBuildPath}/Makefile")->mtime ||
+                        stat("${strBackRestBase}/src/build.auto.h.in")->mtime > stat("${strBuildPath}/Makefile")->mtime)
                     {
-                        &log(INFO, "    build bin for ${strBuildVM} (${strBuildPath})");
+                        &log(INFO, '        bin dependencies have changed, rebuilding');
 
-                        if ($strBuildVM ne VM_NONE)
-                        {
-                            executeTest(
-                                "docker run -itd -h test-build --name=test-build" .
-                                    " -v ${strBackRestBase}:${strBackRestBase} -v ${strTestPath}:${strTestPath} " .
-                                    containerRepo() . ":${strBuildVM}-test",
-                                {bSuppressStdErr => true});
-                        }
-
-                        if (!$bSmart || $bBuildOptionsDiffer || !$oStorageBackRest->exists("${strBuildPath}/Makefile"))
-                        {
-                            # Remove old path if it exists and save the build flags
-                            executeTest("rm -rf ${strBuildPath}");
-                            buildPutDiffers($oStorageBackRest, $strBuildFlagFile, $strBuildFlags);
-
-                            executeTest(
-                                ($strBuildVM ne VM_NONE ? 'docker exec -i -u ' . TEST_USER . ' test-build ' : '') .
-                                "bash -c 'cd ${strBuildPath} && ${strBackRestBase}/src/configure -q${strConfigOptions}'",
-                                {bShowOutputAsync => $bLogDetail});
-                        }
+                        # Remove old path if it exists and save the build flags
+                        executeTest("rm -rf ${strBuildPath}");
+                        buildPutDiffers($oStorageBackRest, $strBuildFlagFile, $strBuildFlags);
 
                         executeTest(
                             ($strBuildVM ne VM_NONE ? 'docker exec -i -u ' . TEST_USER . ' test-build ' : '') .
-                            "${strMakeCmd} -s -j ${iBuildMax}" . ($bLogDetail ? '' : ' --silent') .
-                                " --directory ${strBuildPath} CFLAGS_EXTRA='${strCFlags}'" .
-                                ($strLdFlags ne '' ? " LDFLAGS_EXTRA='${strLdFlags}'" : ''),
+                            "bash -c 'cd ${strBuildPath} && ${strBackRestBase}/src/configure -q${strConfigOptions}'",
                             {bShowOutputAsync => $bLogDetail});
+                    }
 
-                        if ($strBuildVM ne VM_NONE)
-                        {
-                            executeTest("docker rm -f test-build");
-                        }
+                    executeTest(
+                        ($strBuildVM ne VM_NONE ? 'docker exec -i -u ' . TEST_USER . ' test-build ' : '') .
+                        "${strMakeCmd} -s -j ${iBuildMax}" . ($bLogDetail ? '' : ' --silent') .
+                            " --directory ${strBuildPath} CFLAGS_EXTRA='${strCFlags}'" .
+                            ($strLdFlags ne '' ? " LDFLAGS_EXTRA='${strLdFlags}'" : ''),
+                        {bShowOutputAsync => $bLogDetail});
+
+                    if ($strBuildVM ne VM_NONE)
+                    {
+                        executeTest("docker rm -f test-build");
                     }
                 }
             }
@@ -888,7 +789,7 @@ eval
                         # Patch files in debian package builds
                         #
                         # Use these commands to create a new patch (may need to modify first line):
-                        # BRDIR=/backrest;BRVM=u18;BRPATCHFILE=${BRDIR?}/test/patch/debian-package.patch
+                        # BRDIR=/backrest;BRVM=u20;BRPATCHFILE=${BRDIR?}/test/patch/debian-package.patch
                         # DBDIR=${BRDIR?}/test/result/package/${BRVM}/debian
                         # diff -Naur ${DBDIR?}.old ${DBDIR}.new > ${BRPATCHFILE?}
                         my $strDebianPackagePatch = "${strBackRestBase}/test/patch/debian-package.patch";
@@ -928,7 +829,7 @@ eval
 
                         executeTest(
                             ($strVm ne VM_NONE ? "docker exec -i test-build " : '') .
-                            "bash -c 'cd ${strBuildPath} && debuild -i -us -uc -b'");
+                            "bash -c 'cd ${strBuildPath} && debuild -d -i -us -uc -b'");
 
                         executeTest(
                             ($strVm ne VM_NONE ? "docker exec -i test-build " : '') .
@@ -961,14 +862,14 @@ eval
                             "bash -c \"" .
                             "mkdir /root/package-src && " .
                             "wget -q -O /root/package-src/pgbackrest-conf.patch " .
-                                "'https://git.postgresql.org/gitweb/?p=pgrpms.git;a=blob_plain;hb=refs/heads/master;" .
-                                "f=rpm/redhat/master/common/pgbackrest/master/pgbackrest-conf.patch' && " .
+                                "'https://git.postgresql.org/gitweb/?p=pgrpms.git;a=blob_plain;hb=refs/heads/mas"."ter;" .
+                                "f=rpm/redhat/mas"."ter/common/pgbackrest/mas"."ter/pgbackrest-conf.patch' && " .
                             "wget -q -O /root/package-src/pgbackrest.logrotate " .
-                                "'https://git.postgresql.org/gitweb/?p=pgrpms.git;a=blob_plain;hb=refs/heads/master;" .
-                                "f=rpm/redhat/master/common/pgbackrest/master/pgbackrest.logrotate' && " .
+                                "'https://git.postgresql.org/gitweb/?p=pgrpms.git;a=blob_plain;hb=refs/heads/mas"."ter;" .
+                                "f=rpm/redhat/mas"."ter/common/pgbackrest/mas"."ter/pgbackrest.logrotate' && " .
                             "wget -q -O /root/package-src/pgbackrest.spec " .
-                                "'https://git.postgresql.org/gitweb/?p=pgrpms.git;a=blob_plain;hb=refs/heads/master;" .
-                                "f=rpm/redhat/master/common/pgbackrest/master/pgbackrest.spec'\"");
+                                "'https://git.postgresql.org/gitweb/?p=pgrpms.git;a=blob_plain;hb=refs/heads/mas"."ter;" .
+                                "f=rpm/redhat/mas"."ter/common/pgbackrest/mas"."ter/pgbackrest.spec'\"");
 
                         # Create build directories
                         $oStorageBackRest->pathCreate($strBuildPath, {bIgnoreExists => true, bCreateParent => true});
@@ -1000,7 +901,7 @@ eval
                         # Patch files in RHEL package builds
                         #
                         # Use these commands to create a new patch (may need to modify first line):
-                        # BRDIR=/backrest;BRVM=co7;BRPATCHFILE=${BRDIR?}/test/patch/rhel-package.patch
+                        # BRDIR=/backrest;BRVM=rh7;BRPATCHFILE=${BRDIR?}/test/patch/rhel-package.patch
                         # PKDIR=${BRDIR?}/test/result/package/${BRVM}/SPECS
                         # diff -Naur ${PKDIR?}.old ${PKDIR}.new > ${BRPATCHFILE?}
                         my $strPackagePatch = "${strBackRestBase}/test/patch/rhel-package.patch";
@@ -1036,10 +937,6 @@ eval
             exit 0 if $bBuildOnly;
         }
 
-        # Remove repo.manifest now that all processing that depends on modified files has been completed
-        #---------------------------------------------------------------------------------------------------------------------------
-        $oStorageTest->remove("${strRepoCachePath}/${strRepoCacheManifest}");
-
         # Perform static source code analysis
         #---------------------------------------------------------------------------------------------------------------------------
         if (!$bDryRun)
@@ -1133,11 +1030,11 @@ eval
                 if (!defined($$oyProcess[$iVmIdx]) && $iTestIdx < @{$oyTestRun})
                 {
                     my $oJob = new pgBackRestTest::Common::JobTest(
-                        $oStorageTest, $strBackRestBase, $strTestPath, $$oyTestRun[$iTestIdx], $bDryRun, $strVmHost, $bVmOut,
-                        $iVmIdx, $iVmMax, $strMakeCmd, $iTestIdx, $iTestMax, $strLogLevel, $strLogLevelTest, $strLogLevelTestFile,
-                        !$bNoLogTimestamp, $bLogForce, $bShowOutputAsync, $bNoCleanup, $iRetry, !$bNoValgrind, !$bNoCoverage,
-                        $bCoverageSummary, !$bNoOptimize, $bBackTrace, $bProfile, $iScale, $strTimeZone, !$bNoDebug,
-                        $bDebugTestTrace, $iBuildMax / $iVmMax < 1 ? 1 : int($iBuildMax / $iVmMax));
+                        $oStorageTest, $strBackRestBase, $strTestPath, $$oyTestRun[$iTestIdx], $bDryRun, $bVmOut, $iVmIdx, $iVmMax,
+                        $strMakeCmd, $iTestIdx, $iTestMax, $strLogLevel, $strLogLevelTest, $strLogLevelTestFile, !$bNoLogTimestamp,
+                        $bLogForce, $bShowOutputAsync, $bNoCleanup, $iRetry, !$bNoValgrind, !$bNoCoverage, $bCoverageSummary,
+                        !$bNoOptimize, $bBackTrace, $bProfile, $iScale, $strTimeZone, !$bNoDebug, $bDebugTestTrace,
+                        $iBuildMax / $iVmMax < 1 ? 1 : int($iBuildMax / $iVmMax));
                     $iTestIdx++;
 
                     if ($oJob->run())
